import { __extends, __awaiter, __generator, __assign, __spreadArray } from 'tslib';
import webApplication$1, { Session, RestService, webApplication, ConfigHelper, PermissionService, Utils, mapGetters, mapActions, mapMutations, router, config, HttpRequest, DefaultInterceptorType, WebApplicationEventType } from '@fly-vue/core';
import { MenuService, RouteHelper, requestAnimation } from '@fly-vue/iview-admin';
import _$1, { isEmpty as isEmpty$1, trim as trim$1, split, trimEnd, isArray, forEach, isString, debounce, throttle, isUndefined, isFunction, camelCase as camelCase$1, includes } from 'lodash';
import pathToRegexp from 'path-to-regexp';
import { mapState, mapMutations as mapMutations$1, mapGetters as mapGetters$1 } from 'vuex';
import { ufsUploadPolicy, leapQueryConvertor, buildQueryMethodsMixin, userSelectSetting, orgSelectSetting, treeUtils } from '@fly-vue/components';
import Vue from 'vue';
import { createPopper } from '@popperjs/core/lib/popper-lite';
import preventOverflow from '@popperjs/core/lib/modifiers/preventOverflow';
import flip from '@popperjs/core/lib/modifiers/flip';
import dayjs from 'dayjs';

var I18nService = /** @class */ (function (_super) {
    __extends(I18nService, _super);
    function I18nService() {
        var _this = _super.call(this, '​ui​/messages') || this;
        _this.cachedMessages = new Map();
        return _this;
    }
    I18nService.prototype.ensure = function (route) {
        return __awaiter(this, void 0, void 0, function () {
            var _i, _a, matched, pathKey, resp, routeLocaleMsg, ex_1, localeMsg;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        if (!Session.isLogin()) {
                            return [2 /*return*/];
                        }
                        _i = 0, _a = route.matched;
                        _b.label = 1;
                    case 1:
                        if (!(_i < _a.length)) return [3 /*break*/, 8];
                        matched = _a[_i];
                        pathKey = this.buildKey(matched);
                        if (isEmpty$1(pathKey) || this.cachedMessages.get(pathKey) != null) {
                            return [3 /*break*/, 7];
                        }
                        resp = void 0, routeLocaleMsg = void 0;
                        _b.label = 2;
                    case 2:
                        _b.trys.push([2, 4, 5, 6]);
                        return [4 /*yield*/, this.loadMessages(pathKey)];
                    case 3:
                        resp = _b.sent();
                        return [3 /*break*/, 6];
                    case 4:
                        ex_1 = _b.sent();
                        console.error(ex_1);
                        return [3 /*break*/, 6];
                    case 5:
                        routeLocaleMsg = resp.data;
                        this.cachedMessages.set(pathKey, routeLocaleMsg || {});
                        return [7 /*endfinally*/];
                    case 6:
                        if (!routeLocaleMsg) {
                            return [3 /*break*/, 7];
                        }
                        localeMsg = this.buildLocaleMessage(pathKey, routeLocaleMsg);
                        webApplication.i18n.mergeLocaleMessage(ConfigHelper.getConfigVal('locale'), localeMsg);
                        _b.label = 7;
                    case 7:
                        _i++;
                        return [3 /*break*/, 1];
                    case 8: return [2 /*return*/];
                }
            });
        });
    };
    I18nService.prototype.loadMessages = function (key) {
        return __awaiter(this, void 0, void 0, function () {
            var url;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url = 'ui/messages/data/' + key;
                        return [4 /*yield*/, this.http.get(url)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    I18nService.prototype.buildKey = function (route) {
        var path = route.path;
        path = trim$1(path, '/');
        return path.replace(/:[^/]+/gi, '$var').replace(/\//gi, '.');
    };
    /**
     * 将路径转换为对象格式,构造locale message
     * @param pathKey 以.分隔的路径key
     */
    I18nService.prototype.buildLocaleMessage = function (pathKey, msg) {
        var keys = split(pathKey, '.');
        var obj = {};
        var current = obj;
        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            if (i == keys.length - 1) {
                current[key] = msg;
            }
            else {
                current[key] = {};
            }
            current = current[key];
        }
        return obj;
    };
    return I18nService;
}(RestService));

var SecurityManager = /** @class */ (function (_super) {
    __extends(SecurityManager, _super);
    function SecurityManager() {
        return _super.call(this, 'ui/security') || this;
    }
    SecurityManager.prototype.loadPerms = function () {
        return __awaiter(this, void 0, void 0, function () {
            var resource, data;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        resource = this.nest('perms');
                        return [4 /*yield*/, resource.onError('log').query({})];
                    case 1:
                        data = (_a.sent()).data;
                        PermissionService.addAuthorization(data);
                        return [2 /*return*/];
                }
            });
        });
    };
    SecurityManager.prototype.getRowPermissions = function (entityName, id) {
        return __awaiter(this, void 0, void 0, function () {
            var resource, data;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        resource = this.nest('entities/:entity/:id/perms', { entity: entityName, id: id });
                        return [4 /*yield*/, resource.query()];
                    case 1:
                        data = (_a.sent()).data;
                        return [2 /*return*/, data];
                }
            });
        });
    };
    return SecurityManager;
}(RestService));

var AICConsole = {
    consoleUrl: function () {
        var url = ConfigHelper.getConfigVal('service.aic.website');
        if (!Utils.isAbsoluteUrl(url)) {
            var root = window.location.href.substr(0, window.location.href.indexOf('/', 8));
            url = root + url;
        }
        return url;
    },
    getUrlForApp: function (appId) {
        return this.consoleUrl() + ("/app/" + appId + "?appId=" + appId);
    },
    getUrlForCreateApp: function (returnUrl) {
        var url = this.consoleUrl() + "/apps/create";
        if (returnUrl) {
            url += "?returnUrl=" + encodeURIComponent(returnUrl);
        }
        return url;
    },
    getUrlForFindApp: function (returnUrl) {
        var url = this.consoleUrl() + "/apps/find";
        if (returnUrl) {
            url += "?returnUrl=" + encodeURIComponent(returnUrl);
        }
        return url;
    },
    getUrlForFindPrj: function (returnUrl) {
        var url = this.consoleUrl() + "/projects/find";
        if (returnUrl) {
            url += "?returnUrl=" + encodeURIComponent(returnUrl);
        }
        return url;
    },
    getUrlForCreatePrj: function (returnUrl) {
        var url = this.consoleUrl() + "/projects/create";
        if (returnUrl) {
            url += "?returnUrl=" + encodeURIComponent(returnUrl);
        }
        return url;
    },
    getUrlForApi: function () {
        var url = this.consoleUrl();
        url = trimEnd(url, '#');
        return Utils.mergePath(url, 'api');
    }
};

var appStore = __assign(__assign(__assign({}, mapGetters('fuse/app', ['current', 'appPerms', 'hasAppPerms'])), mapActions('fuse/app', ['init', 'initPerms'])), { hasPerm: function (op) {
        return this.hasAppPerms()(op);
    } });
var AppService = /** @class */ (function (_super) {
    __extends(AppService, _super);
    function AppService(config) {
        return _super.call(this, 'app{/id}', function () {
            return AICConsole.getUrlForApi();
        }, config) || this;
    }
    // 概览
    AppService.prototype.summary = function (appId, params) {
        var url = "/app/" + appId + "/summary";
        return this.http.get(url, { params: params });
    };
    AppService.prototype.authServices = function (appId, queryOptions) {
        return __awaiter(this, void 0, void 0, function () {
            var filters, innerQueryOptions;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        filters = "auth_obj_id eq '" + appId + "' and auth_obj_type eq 'app'";
                        innerQueryOptions = _$1.cloneDeep(queryOptions);
                        if (innerQueryOptions && innerQueryOptions.filters) {
                            filters += " and " + queryOptions.filters;
                            delete innerQueryOptions.filters;
                        }
                        queryOptions = Object.assign({
                            filters: filters,
                            orderby: 'updatedAt desc'
                        }, innerQueryOptions);
                        return [4 /*yield*/, this.getAuthService(queryOptions)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppService.prototype.getAuthService = function (queryOptions) {
        var url = "/service_authorization";
        queryOptions = queryOptions || {};
        return this.http.get(url, { params: queryOptions });
    };
    AppService.prototype.appliedServices = function (appId, queryOption) {
        return __awaiter(this, void 0, void 0, function () {
            var resp, serviceMap, statusPriorityMap, _i, _a, authService, exist, existPriority, agreementPriority, services;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, this.authServices(appId, queryOption)];
                    case 1:
                        resp = _b.sent();
                        serviceMap = {};
                        statusPriorityMap = [1, 4, 3, 0, 2];
                        for (_i = 0, _a = resp.data; _i < _a.length; _i++) {
                            authService = _a[_i];
                            exist = serviceMap[authService.serviceId];
                            if (!exist) {
                                exist = authService;
                                serviceMap[authService.serviceId] = authService;
                                continue;
                            }
                            existPriority = statusPriorityMap.indexOf(exist.status);
                            agreementPriority = statusPriorityMap.indexOf(authService.status);
                            if (agreementPriority >= existPriority) {
                                continue;
                            }
                            serviceMap[authService.serviceId] = authService;
                        }
                        services = _$1.map(serviceMap, function (val) { return val; });
                        return [2 /*return*/, { data: services, headers: resp.headers } || []];
                }
            });
        });
    };
    AppService.prototype.mine = function (params) {
        var url = "/app/mine";
        params = params || {};
        Object.assign(params, {
            mine: true
        });
        return this.http.get(url, { params: params });
    };
    AppService.prototype.authorized = function (params) {
        var url = "/app/authorized";
        params = params || {};
        Object.assign(params, {
            mine: true
        });
        return this.http.get(url, { params: params });
    };
    AppService.prototype.authorizedApp = function (id) {
        var url = "/app/authorized/" + id;
        return this.http.get(url);
    };
    AppService.prototype.mineApp = function (id, params) {
        var url = "/app/mine/" + id;
        params = params || {};
        Object.assign(params, {
            mine: true
        });
        return this.http.get(url, { params: params });
    };
    AppService.prototype.authFilter = function (needPerms) {
        var _this = this;
        return function (to, _from, _next) { return __awaiter(_this, void 0, void 0, function () {
            var appId;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        appId = to.params.appId;
                        if (!(!appStore.current() || appStore.current().id !== appId)) return [3 /*break*/, 2];
                        return [4 /*yield*/, appStore.init(appId)];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (!(appStore.appPerms() === null)) return [3 /*break*/, 4];
                        return [4 /*yield*/, appStore.initPerms(appId)];
                    case 3:
                        _a.sent();
                        _a.label = 4;
                    case 4: return [2 /*return*/, appStore.hasPerm(needPerms)];
                }
            });
        }); };
    };
    AppService.prototype.getMemberIds = function (appId) {
        var url = "/app/" + appId + "/member/ids";
        return this.http.get(url);
    };
    AppService.prototype.adminCount = function (appId) {
        var url = "/app/" + appId + "/member/admin/count";
        return this.http.get(url);
    };
    AppService.prototype.getAppMember = function (appId, params) {
        var url = "/app/" + appId + "/members";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    AppService.prototype.servicePublished = function (options) {
        var url = "/service/published";
        return this.http.get(url, { params: options });
    };
    // 获取账号
    AppService.prototype.getClients = function (appId, params) {
        var url = "/app/" + appId + "/clients";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    return AppService;
}(RestService));

var ProjectService = /** @class */ (function (_super) {
    __extends(ProjectService, _super);
    function ProjectService(baseURL, config) {
        return _super.call(this, 'project{/id}', baseURL, config) || this;
    }
    ProjectService.prototype.apps = function (projectId, params) {
        var url = "/project/" + projectId + "/apps";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    ProjectService.prototype.mine = function (params) {
        var url = "/project/mine";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    ProjectService.prototype.mineApp = function (id, params) {
        var url = "/project/mine/" + id;
        params = params || {};
        return this.http.get(url, { params: params });
    };
    return ProjectService;
}(RestService));

var AicService = /** @class */ (function (_super) {
    __extends(AicService, _super);
    function AicService(config) {
        return _super.call(this, '', function () {
            return AICConsole.getUrlForApi();
        }, config) || this;
    }
    /**
     * 申请开通服务
     * @param data 申请单数据
     * @param config 请求配置
     */
    AicService.prototype.applyService = function (data, config) {
        var url = 'service_agreement?force=true';
        return this.http.post(url, data, config);
    };
    /**
     * 获取当前服务信息
     */
    AicService.prototype.localServiceInfo = function () {
        var url = 'service_info';
        return new RestService('').http.get(url);
    };
    /**
     * 根据Code获取平台上已注册的服务详情
     */
    AicService.prototype.findServiceByCode = function (code) {
        var url = "service/check/code/" + code;
        return this.nest(url).get();
    };
    /**
     * 根据Id获取服务详情
     * @param id 服务Id
     */
    AicService.prototype.findServiceById = function (id) {
        var url = "service/{id}";
        return this.nest(url).get(id);
    };
    /**
     * 平台中，我的应用列表
     */
    AicService.prototype.myApps = function (params) {
        var url = 'app/mine';
        params = params || {};
        return this.nest(url).query(params);
    };
    /**
     * 平台中，我的应用列表
     */
    AicService.prototype.myProjects = function (params) {
        var url = 'project/mine';
        params = params || {};
        return this.nest(url).query(params);
    };
    /**
     * 根据Id获取应用详情
     * @param id 应用Id
     */
    AicService.prototype.findAppById = function (id) {
        var url = "app/{id}";
        return this.nest(url).get(id);
    };
    /**
     * 根据Id获取业务系统详情
     * @param id 业务系统Id
     */
    AicService.prototype.findProjectById = function (id) {
        var url = "project/{id}";
        return this.nest(url).get(id);
    };
    /**
     * 查询指定业务系统下的应用
     * @param projectId 业务系统Id
     * @param params
     */
    AicService.prototype.projectApps = function (projectId, params) {
        var url = "/project/" + projectId + "/apps";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    /**
     * 服务服务的已授权列表
     * @param serviceId 服务ID
     */
    AicService.prototype.serviceAuthorizations = function (serviceId) {
        var url = "service_authorization/status?serviceId=" + serviceId;
        return this.http.get(url);
    };
    AicService.prototype.abortAuth = function (id) {
        var url = "/service_authorization/" + id + "/abort";
        return this.http.post(url, {});
    };
    AicService.prototype.syncUser = function (userId) {
        var url = "/user/" + userId + "/sync";
        return this.http.get(url);
    };
    AicService.prototype.servicePublished = function (id, config) {
        var url = "/service/published/" + id;
        return this.http.get(url, __assign({}, config));
    };
    AicService.prototype.getAllPublish = function (options) {
        //这个接口会把产品和服务都查询过来（无论市场id是什么，都会查询到全部的产品信息）
        var url = "/service/all-published";
        return this.http.get(url, { params: options });
    };
    AicService.prototype.queryMarket = function (options) {
        var url = "/market/auth";
        options = options || {};
        return this.http.get(url, { params: options });
    };
    AicService.prototype.catalogTree = function (params, config) {
        var url = "/catalog/tree";
        return this.http.get(url, __assign({ params: params }, config));
    };
    AicService.prototype.getServiceById = function (id, config) {
        var url = "/service/" + id;
        return this.http.get(url, __assign({}, config));
    };
    AicService.prototype.queryServiceAgreement = function (options, config) {
        var url = "/service_agreement";
        options = options || {};
        return this.http.get(url, __assign({ params: options }, config));
    };
    AicService.prototype.getScopeKindComponents = function (params) {
        var url = "/scope_kind/component";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    AicService.prototype.getScopeComponents = function (params) {
        var url = "/scope/component";
        params = params || {};
        return this.http.get(url, { params: params });
    };
    return AicService;
}(RestService));

var MemberService = /** @class */ (function (_super) {
    __extends(MemberService, _super);
    function MemberService(config) {
        return _super.call(this, 'member{/id}', function () {
            return AICConsole.getUrlForApi();
        }, config) || this;
    }
    MemberService.prototype.getMemberIds = function (appId) {
        var url = "/app/" + appId + "/member/ids";
        return this.http.get(url);
    };
    MemberService.prototype.adminCount = function (appId) {
        var url = "/app/" + appId + "/member/admin/count";
        return this.http.get(url);
    };
    return MemberService;
}(RestService));

var IamUserService = /** @class */ (function (_super) {
    __extends(IamUserService, _super);
    function IamUserService(baseURL, config) {
        return _super.call(this, '/user{/id}', 'service.iam.console-api', config) || this;
    }
    return IamUserService;
}(RestService));

var AicClientService = /** @class */ (function (_super) {
    __extends(AicClientService, _super);
    function AicClientService(config) {
        return _super.call(this, 'client{/id}', function () {
            return AICConsole.getUrlForApi();
        }, config) || this;
    }
    AicClientService.prototype.claim = function (data, config) {
        var url = "/client/claim";
        return this.http.post(url, data, config);
    };
    return AicClientService;
}(RestService));

var i18nService = new I18nService();
var securityManager = new SecurityManager();
var appService$2 = new AppService();
var projectService = new ProjectService();
var aicService = new AicService();
var memberService = new MemberService();
var iamUserService = new IamUserService();
var aicClientService = new AicClientService();

var MicroAppHelper = __assign(__assign(__assign({ KEY_FOR_APP_ID_IN_QUERY: 'appId' }, mapMutations('fuse/app', ['setApp'])), mapGetters('fuse/app', ['current'])), { routeToApp: function (item) {
        if (webApplication$1.isSubApp()) {
            webApplication$1.microApp.setGlobalState({
                appId: item.id,
                action: 'AppIdChanged'
            });
            return;
        }
        this.setApp(item);
        var appMenus = this.rebuildAppMenus(item);
        var firstMenu;
        if (appMenus) {
            firstMenu = appMenus[0];
            if (firstMenu.children && firstMenu.children.length > 0) {
                firstMenu = firstMenu.children[0];
            }
        }
        if (firstMenu) {
            router().push({
                path: firstMenu.path
            });
        }
    },
    routeToServiceForApp: function (service) {
        var currentApp = this.current();
        var appInteMode = service.appInteMode, url = service.appInteUrl, consoleUrl = service.consoleUrl;
        url = url || consoleUrl;
        var parseCtx = {
            app: currentApp,
            appId: currentApp && currentApp.id,
            serviceId: service.id
        };
        if (url) {
            url = Utils.parseUrl(url, parseCtx);
        }
        if (appInteMode === 'iframe' || !webApplication$1.isSubApp()) {
            window.open(url);
            return;
        }
        webApplication$1.microApp.setGlobalState({
            action: 'ServiceIdChanged',
            serviceId: service.id
        });
    },
    rebuildAppMenus: function (app) {
        var appMenus = MenuService.filterSiderMenus('app'); // 获取当前header对应的侧边栏，跳转到当前侧边栏第一个
        appMenus.forEach(function (itemMenus) {
            // 左侧菜单保持sid生效，不清理
            itemMenus.keepSid = true;
            if (itemMenus.children && itemMenus.children.length) {
                itemMenus.children.forEach(function (itemChild) {
                    itemChild.keepSid = true;
                    compileAppId(itemChild, app);
                });
            }
            else {
                compileAppId(itemMenus, app);
            }
        });
        return appMenus;
    } });
function compileAppId(menuItem, app) {
    if (menuItem.target === 'iframe') {
        menuItem.path = '/iframe/index';
        for (var paramName in menuItem.$query) {
            var paramValue = menuItem.$query[paramName];
            if (paramName === 'url') {
                paramValue = pathToRegexp.compile(paramValue)(Object.assign({
                    appId: app.id
                }, app));
            }
            menuItem.path = Utils.appendParam(menuItem.path, paramName, paramValue);
        }
    }
    else {
        // 由于pathToRegexp会把?后面的query参数当成特殊字符也给转化掉，所以需要先转换没有query的路径，然后再拼接回query
        menuItem.path = pathToRegexp.compile(menuItem.$path)(Object.assign({ appId: app.id }, app));
        // 替换query里面的appId
        var appKey = ['appId', 'scope_app', 'clientId']; //兼容各个控制台key不一致的问题
        appKey.forEach(function (keyItem) {
            if (Object.prototype.hasOwnProperty.call(menuItem.$query, keyItem)) {
                menuItem.$query[keyItem] = app.id;
            }
        });
        //遍历query，如果值是:appId 直接替换
        Object.keys(menuItem.$query).forEach(function (queryKeyItem) {
            if (menuItem.$query[queryKeyItem] == ':appId') {
                menuItem.$query[queryKeyItem] = app.id;
            }
        });
        // 替换x_top_entity_row里面的appId
        if (menuItem.$query['x_top_entity_row']) {
            menuItem.$query['x_top_entity_row'] = pathToRegexp.compile(menuItem.$query['x_top_entity_row'])({
                appId: app.id
            });
        }
        // 补全query
        menuItem.path += objectConvertToQuery(menuItem.$query);
    }
}
function objectConvertToQuery(payload) {
    var queryStr = '?';
    var i = Object.keys(payload).length;
    if (!payload) {
        queryStr = '';
    }
    Object.keys(payload).forEach(function (key, index) {
        if (i === index + 1) {
            queryStr += key + '=' + payload[key];
        }
        else {
            queryStr += key + '=' + payload[key] + '&';
        }
    });
    return queryStr;
}

var APP_IN_SESSION_KEY = '_fuse_app_id_';
function getAppId() {
    //从session取
    var appId = window.sessionStorage.getItem(APP_IN_SESSION_KEY);
    if (appId)
        return appId;
    //从地址栏取
    //保证多种键名对应上
    var keys = ['appId', 'clientId', 'scope_app', 'app_id'];
    var query = RouteHelper.resolveQueryString(window.location.href);
    var queryObj;
    //判断是否有returnUrl
    if (query.returnUrl) {
        queryObj = RouteHelper.resolveQueryString(query.returnUrl);
    }
    else {
        queryObj = query;
    }
    for (var i = 0; i < keys.length; i++) {
        if (queryObj[keys[i]])
            return queryObj[keys[i]];
    }
}
var innerAppId = null;
function setAppId(value) {
    return window.sessionStorage.setItem(APP_IN_SESSION_KEY, value);
}
var app = {
    namespaced: true,
    state: {
        appId: null,
        app: null,
        perms: null
    },
    getters: {
        current: function (state) { return state.app; },
        appId: function (state) { return state.appId; },
        appTitle: function (state) {
            if (state.app) {
                return state.app.title;
            }
            return '';
        },
        appPerms: function (state) { return state.perms; },
        hasAppPerms: function (state) {
            return function (op) {
                if (!op) {
                    return true;
                }
                if (!isArray(op)) {
                    return state.perms.indexOf(op) > -1;
                }
                var result = true;
                forEach(op, function (p1) {
                    if (!state.perms)
                        return false;
                    var r = state.perms.indexOf(p1) > -1;
                    if (!r) {
                        result = false;
                        return false;
                    }
                });
                return result;
            };
        }
    },
    mutations: {
        setApp: function (state, app) {
            if (app) {
                if (app.id !== state.appId) {
                    state.perms = null;
                }
                state.app = app;
                state.appId = app.id;
                setAppId(app.id);
                // mvueCore.topEntityService.set('app', app.id);
            }
            else {
                state.app = null;
                state.appId = null;
                state.perms = null;
                setAppId(''); //设置null 获取出来是字符串'null'
                // mvueCore.topEntityService.removeAll();
            }
        }
    },
    actions: {
        init: function (_a, app) {
            var commit = _a.commit, state = _a.state, dispatch = _a.dispatch;
            return __awaiter(this, void 0, void 0, function () {
                var resp;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            if (app) {
                                if (isString(app)) {
                                    //state.appId = app;
                                    innerAppId = app;
                                }
                                else {
                                    innerAppId = app.id;
                                }
                            }
                            else {
                                innerAppId = getAppId();
                            }
                            if (state.app && state.app.id === innerAppId) {
                                return [2 /*return*/, state.app];
                            }
                            if (!innerAppId) return [3 /*break*/, 4];
                            return [4 /*yield*/, appService$2.onError('log').get(innerAppId)];
                        case 1:
                            resp = _b.sent();
                            if (!resp.data) return [3 /*break*/, 3];
                            commit('setApp', resp.data);
                            return [4 /*yield*/, dispatch('initPerms', innerAppId)];
                        case 2:
                            _b.sent();
                            return [2 /*return*/, resp.data];
                        case 3:
                            commit('setApp', null);
                            return [2 /*return*/, null];
                        case 4: return [2 /*return*/, null];
                    }
                });
            });
        },
        initPerms: function (_a, appId) {
            var state = _a.state;
            return __awaiter(this, void 0, void 0, function () {
                var data, entityPerms;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            if (state.perms && state.appId === appId) {
                                return [2 /*return*/];
                            }
                            return [4 /*yield*/, securityManager.getRowPermissions('App', appId)];
                        case 1:
                            data = _b.sent();
                            if (data) {
                                state.perms = data;
                            }
                            else {
                                state.perms = [];
                            }
                            entityPerms = {
                                __row_ops__: null
                            };
                            state.perms.forEach(function (item) {
                                entityPerms[item] = '';
                            });
                            PermissionService.addAuthorization({
                                entities: {
                                    app: entityPerms
                                }
                            });
                            return [2 /*return*/, data];
                    }
                });
            });
        }
    }
};

var stores = {
    namespaced: true,
    modules: {
        app: app
    }
};

//

var script$1l = {
  name: 'iHeaderUser',
  computed: {
    ...mapState('admin/user', ['info']),
    ...mapState('admin/layout', ['isMobile', 'logoutConfirm']),
    hasAdminRouter() {
      let sideMenus = MenuService.filterSiderMenus('admin'); // 判断当前用户有没有进入管理控制台的路由权限
      return sideMenus.length !== 0;
    }
  },
  methods: {
    handleClick(name) {
      if (name === 'logout') {
        this.$Modal.confirm({
          title: '退出确认',
          content: '是否退出当前系统？',
          onOk: () => {
            Session.doLogout();
          }
        });
      } else if (name === 'personalWorkbench') {
        this.$router.push({ name: 'appsList', query: { _clearSid: '1' } });
      } else if (name === 'administrativeConsole') {
        this.$router.push({ name: 'consoleEntry', query: { _clearSid: '1' } });
      }
    }
  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$1l = script$1l;

/* template */
var __vue_render__$1m = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('span',{staticClass:"i-layout-header-trigger i-layout-header-trigger-min"},[_c('Dropdown',{staticClass:"i-layout-header-user",class:{ 'i-layout-header-user-mobile': _vm.isMobile },staticStyle:{"margin-right":"10px"},attrs:{"trigger":_vm.isMobile ? 'click' : 'hover'},on:{"on-click":_vm.handleClick}},[(_vm.info.avatar)?_c('Avatar',{attrs:{"size":"small","src":_vm.info.avatar}}):_c('Avatar',{attrs:{"size":"small","icon":"ios-person"}}),_vm._v(" "),(!_vm.isMobile)?_c('span',{staticClass:"i-layout-header-user-name"},[_vm._v(_vm._s(_vm.info.name))]):_vm._e(),_vm._v(" "),_c('DropdownMenu',{attrs:{"slot":"list"},slot:"list"},[_c('DropdownItem',{attrs:{"name":"administrativeConsole"}},[_c('Icon',{attrs:{"type":"ios-construct-outline"}}),_vm._v(" "),_c('span',[_vm._v("系统管理")])],1),_vm._v(" "),_c('DropdownItem',{attrs:{"divided":"","name":"logout"}},[_c('Icon',{attrs:{"type":"ios-log-out"}}),_vm._v(" "),_c('span',[_vm._v(_vm._s(_vm.$t('basicLayout.user.logOut')))])],1)],1)],1)],1)};
var __vue_staticRenderFns__$1m = [];

  /* style */
  const __vue_inject_styles__$1m = undefined;
  /* scoped */
  const __vue_scope_id__$1m = undefined;
  /* module identifier */
  const __vue_module_identifier__$1m = undefined;
  /* functional template */
  const __vue_is_functional_template__$1m = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1m = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1m, staticRenderFns: __vue_staticRenderFns__$1m },
    __vue_inject_styles__$1m,
    __vue_script__$1l,
    __vue_scope_id__$1m,
    __vue_is_functional_template__$1m,
    __vue_module_identifier__$1m,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$1k = {
  name: 'FuseSubAppLayout',
  components: { iHeaderUser: __vue_component__$1m },
  data() {
    return {
      loadRouter: true,
      logo: {
        small: './images/logo-small.png',
        normal: './images/logo.png',
        dark: './images/logo-dark.png'
      }
    };
  },
  computed: {
    ...mapState('admin/page', ['keepAlive']),
    ...mapState('admin/layout', ['isDesktop', 'showFullscreen', 'appTitle'])
  },
  watch: {
    $route(to, from) {
      if (to.name === from.name) {
        // 相同路由，不同参数，跳转时，重载页面
        if (config().sameRouteForceUpdate) {
          this.handleReload();
        }
      }
    }
  },
  methods: {
    ...mapMutations$1('admin/layout', ['updateMenuCollapse']),
    ...mapMutations$1('admin/page', ['keepAlivePush', 'keepAliveRemove']),
    handleScroll() {
      if (!this.headerHide) return;

      const scrollTop = document.body.scrollTop + document.documentElement.scrollTop;

      if (!this.ticking) {
        this.ticking = true;
        requestAnimation(() => {
          if (this.oldScrollTop > scrollTop) {
            this.headerVisible = true;
          } else if (scrollTop > 300 && this.headerVisible) {
            this.headerVisible = false;
          } else if (scrollTop < 300 && !this.headerVisible) {
            this.headerVisible = true;
          }
          this.oldScrollTop = scrollTop;
          this.ticking = false;
        });
      }
    },
    handleReload() {
      // 针对缓存的页面也生效
      const isCurrentPageCache = this.keepAlive.indexOf(this.$route.name) > -1;
      const pageName = this.$route.name;
      if (isCurrentPageCache) {
        this.keepAliveRemove(pageName);
      }
      this.loadRouter = false;
      this.$nextTick(() => {
        this.loadRouter = true;
        if (isCurrentPageCache) {
          this.keepAlivePush(pageName);
        }
      });
    }
  },
  mounted() {
    document.addEventListener('scroll', this.handleScroll, { passive: true });
  },
  beforeDestroy() {
    document.removeEventListener('scroll', this.handleScroll);
  },
  created() {
    if (this.isTablet && this.showSiderCollapse) this.updateMenuCollapse(true);
  }
};

const isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return (id, style) => addStyle(id, style);
}
let HEAD;
const styles = {};
function addStyle(id, css) {
    const group = isOldIE ? css.media || 'default' : id;
    const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        let code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                style.element.setAttribute('media', css.media);
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            const index = style.ids.size - 1;
            const textNode = document.createTextNode(code);
            const nodes = style.element.childNodes;
            if (nodes[index])
                style.element.removeChild(nodes[index]);
            if (nodes.length)
                style.element.insertBefore(textNode, nodes[index]);
            else
                style.element.appendChild(textNode);
        }
    }
}

/* script */
const __vue_script__$1k = script$1k;

/* template */
var __vue_render__$1l = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Layout',{staticClass:"app-layout"},[_c('Affix',[_c('Header',{staticClass:"i-layout-header"},[_c('router-link',{staticClass:"i-layout-sider-logo-dark",attrs:{"to":"/"}},[_c('img',{attrs:{"src":_vm.logo.dark,"alt":_vm.appTitle}}),_vm._v(" "),_c('span',{staticClass:"i-layout-header-title"},[_vm._v(_vm._s(_vm.appTitle))])]),_vm._v(" "),_c('div',{staticClass:"i-layout-header-right"},[_c('i-header-user')],1)],1)],1),_vm._v(" "),_c('Content',{staticClass:"app-content"},[_c('bg-keep-alive',{attrs:{"include":_vm.keepAlive}},[(_vm.loadRouter)?_c('router-view',{staticClass:"ivu-p"}):_vm._e()],1)],1)],1)};
var __vue_staticRenderFns__$1l = [];

  /* style */
  const __vue_inject_styles__$1l = function (inject) {
    if (!inject) return
    inject("data-v-f822019c_0", { source: ".app-layout[data-v-f822019c]{height:100%}.app-layout[data-v-f822019c] .form-item-desc{font-size:12px}.app-layout[data-v-f822019c] .app-index .ivu-menu-item{font-size:18px}.app-layout[data-v-f822019c] .ivu-tabs-content{min-height:400px}.app-content[data-v-f822019c]{margin:0 auto;width:100%;height:100%;background-color:#fff;max-width:1280px;padding:0 16px 20px 16px}.i-layout-header[data-v-f822019c]{background-color:#191a23;color:#fff;position:relative;padding:0 24px}.i-layout-header-title[data-v-f822019c]{font-size:20px;vertical-align:middle;line-height:64px;color:#fff}.i-layout-header .i-layout-sider-logo-dark[data-v-f822019c]{width:400px;height:64px;float:left}.i-layout-header .i-layout-sider-logo-dark img[data-v-f822019c]{height:80%;vertical-align:middle;display:inline-block;margin-right:10px}.i-layout-header[data-v-f822019c] .i-layout-header-trigger:hover{background:#555561}.i-layout-header .navigation[data-v-f822019c]{color:#fff;font-size:14px;line-height:64px;padding:0 15px;display:inline-block}.i-layout-header .navigation[data-v-f822019c]:hover{background:#555561}.i-layout-header .navigation .ivu-icon[data-v-f822019c]{margin-right:5px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1l = "data-v-f822019c";
  /* module identifier */
  const __vue_module_identifier__$1l = undefined;
  /* functional template */
  const __vue_is_functional_template__$1l = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1l = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1l, staticRenderFns: __vue_staticRenderFns__$1l },
    __vue_inject_styles__$1l,
    __vue_script__$1k,
    __vue_scope_id__$1l,
    __vue_is_functional_template__$1l,
    __vue_module_identifier__$1l,
    false,
    createInjector,
    undefined,
    undefined
  );

var cardListItemMixin = {
  props: {
    item: {
      type: Object,
      required: true
    }
  },
  data() {
    let randomBgClass = this.getRandomBgClass();
    return {
      randomBgClass: randomBgClass
    };
  },
  computed: {
    itemTitle: function () {
      return this.item.title || this.item.name || '无';
    },
    firstChar: function () {
      return this.itemTitle.substr(0, 1);
    }
  },
  methods: {
    handleOnItemClick(item) {
      this.$emit('on-item-click', item);
    },
    getRandomBgClass() {
      let bgColorClass = ['bg-primary', 'bg-info', 'bg-success', 'bg-warning', 'bg-error'];
      return bgColorClass[Math.floor(Math.random() * bgColorClass.length)];
    }
  }
};

const uploadPolicy$1 = {
  getUploadBasePath() {
    let uploadBasePath = ConfigHelper.getConfigVal('service.stream.endpoint');
    return uploadBasePath;
  },
  /**
   * 上传文件
   * @param {*} file 待上传的文件
   * @param {*} requestOptions 上传进度等处理器
   * @param {*} _ufsOptions ufs的上传配置选项
   */
  async upload(file, requestOptions, _ufsOptions) {
    let uploadEndpoint = this.getUploadBasePath();
    let http = new HttpRequest(uploadEndpoint);
    let formData = new FormData();
    formData.append('file', file);
    let res = await http.post('/', formData, {
      onUploadProgress: (e) => {
        if (e.total > 0) {
          e.percent = (e.loaded / e.total) * 100;
        }
        requestOptions.onProgress(e);
      }
    });
    let data = res.data;
    let id = data.id;
    return {
      id: id,
      name: file.name,
      url: `${id}`,
      size: file.size
    };
  },
  /**
   * 待转换的上传组件对应的数据结构，如：
   * 原始结构：{fileId:'',fileName:'',size:'',url:''} --> 控件需要的结构：{id:'',name:'',size:'',url:''}
   *
   * 框架默认返回原始值
   * @param {*} item
   */
  resolve(item) {
    return item;
  },
  /**
   * 将上传控件内部的数据结构innerItem，转换成数据库保存的结构
   * @param {*} innerItem
   */
  serialize(innerItem) {
    return innerItem;
  },
  /**
   * 单文件等价性判断
   * @param {*} newItem
   * @param {*} oldItem
   */
  isEqual(newItem, oldItem) {
    let _newValidPart = null;
    let _oldValidPart = null;
    if (newItem) {
      _newValidPart = {
        name: newItem.name,
        url: newItem.url
      };
    }
    if (oldItem) {
      _oldValidPart = {
        name: oldItem.name,
        url: oldItem.url
      };
    }
    return _$1.isEqual(_newValidPart, _oldValidPart);
  },
  /**
   * 多文件等价性判断
   * @param {*} newItems
   * @param {*} oldItems
   */
  isArrayEqual(newItems, oldItems) {
    var _newValidPart = [];
    var _oldValidPart = [];
    if (!_$1.isEmpty(newItems)) {
      _$1.each(newItems, function (file) {
        _newValidPart.push({
          name: file.name,
          url: file.url
        });
      });
    }
    if (!_$1.isEmpty(oldItems)) {
      _$1.each(oldItems, function (file) {
        _oldValidPart.push({
          name: file.name,
          url: file.url
        });
      });
    }
    return _$1.isEqual(_newValidPart, _oldValidPart);
  }
};

//
/**
 * fuse平台上传的图片显示组件
 */
var script$1j = {
  props: {
    /**
     * fuse-ui上传组件上传后的数据
     */
    item: {
      type: Object,
      required: true
    },
    /**
     * 图片宽度，单位px
     */
    width: {
      type: [Number, String]
    },
    /**
     * 图片高度，单位px
     */
    height: {
      type: [Number, String]
    }
  },
  data() {
    let uploadBasePath = uploadPolicy$1.getUploadBasePath();
    return {
      uploadBasePath: uploadBasePath
    };
  },
  computed: {
    innerWidth() {
      if (_$1.isNumber(this.width)) {
        return `${this.width}px;`;
      }
      return this.width;
    },
    innerHeight() {
      if (_$1.isNumber(this.height)) {
        return `${this.height}px;`;
      }
      return this.height;
    }
  }
};

/* script */
const __vue_script__$1j = script$1j;

/* template */
var __vue_render__$1k = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('m-image',{attrs:{"item":_vm.item,"width":_vm.innerWidth,"height":_vm.innerHeight,"uploadBasePath":_vm.uploadBasePath}})};
var __vue_staticRenderFns__$1k = [];

  /* style */
  const __vue_inject_styles__$1k = undefined;
  /* scoped */
  const __vue_scope_id__$1k = undefined;
  /* module identifier */
  const __vue_module_identifier__$1k = undefined;
  /* functional template */
  const __vue_is_functional_template__$1k = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1k = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1k, staticRenderFns: __vue_staticRenderFns__$1k },
    __vue_inject_styles__$1k,
    __vue_script__$1j,
    __vue_scope_id__$1k,
    __vue_is_functional_template__$1k,
    __vue_module_identifier__$1k,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$1i = {
  components: {
    FImage: __vue_component__$1k
  },
  mixins: [cardListItemMixin]
};

/* script */
const __vue_script__$1i = script$1i;

/* template */
var __vue_render__$1j = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{directives:[{name:"height",rawName:"v-height",value:(180),expression:"180"}],staticClass:"fuse-card-list-item",attrs:{"bordered":""},nativeOn:{"click":function($event){return _vm.handleOnItemClick(_vm.item)}}},[_c('div',{staticClass:"fuse-card-list-item-header",attrs:{"slot":"title"},slot:"title"},[(_vm.item.icon)?_c('f-image',{attrs:{"width":"50px","height":"50px","item":_vm.item.icon}}):_c('div',{class:['fuse-card-list-item-circle', 'bg-opacity', _vm.randomBgClass]},[_vm._v("\n      "+_vm._s(_vm.firstChar)+"\n    ")]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-content"},[_c('h3',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-content-title"},[_vm._v(_vm._s(_vm.itemTitle))])])],1),_vm._v(" "),_c('p',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(2),expression:"2"}]},[_vm._v(_vm._s(_vm.item.description || '暂无描述'))]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-foot"},[(_vm.item.updatedAt)?_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-foot-left"},[_vm._v("\n      更新于："),_c('Time',{attrs:{"time":_vm.item.updatedAt}})],1):_vm._e(),_vm._v(" "),(_vm.item.project && _vm.item.project.title)?_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-foot-right"},[_vm._v("\n      "+_vm._s(_vm.item.project.title)+"\n    ")]):_vm._e()])])};
var __vue_staticRenderFns__$1j = [];

  /* style */
  const __vue_inject_styles__$1j = undefined;
  /* scoped */
  const __vue_scope_id__$1j = undefined;
  /* module identifier */
  const __vue_module_identifier__$1j = undefined;
  /* functional template */
  const __vue_is_functional_template__$1j = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1j = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1j, staticRenderFns: __vue_staticRenderFns__$1j },
    __vue_inject_styles__$1j,
    __vue_script__$1i,
    __vue_scope_id__$1j,
    __vue_is_functional_template__$1j,
    __vue_module_identifier__$1j,
    false,
    undefined,
    undefined,
    undefined
  );

var cardListMixin = {
  props: {
    queryOptions: {
      type: Object,
      default() {
        return {
          page: 1,
          page_size: 12
        };
      }
    },
    total: {
      type: Number,
      default: 0
    }
  },
  data() {
    return {
      debounceQuery: _$1.debounce(this.query, 300)
    };
  },
  watch: {
    queryOptions: {
      handler() {
        this.query();
      },
      deep: true
    }
  },
  methods: {
    async query() {
      this.$refs.infiniteScroll.reload();
    }
  }
};

//
//
//
//
//
//
//
//
//
//
//
//
//
//

/**
 * 无限加载提示，可根据当前数据是否有更多、是否正在加载、是否加载完毕显示不同的按钮或者提示
 */
var script$1h = {
  inject: ['parentInfiniteScrollList'],
  props: {
    /**
     * 标记是否还有更多数据
     */
    hasMoreData: {
      type: Boolean,
      default: true
    },
    /**
     * 更多数据提示语
     */
    moreDataTips: {
      type: String,
      default: '查看更多'
    },
    /**
     * 完成提示
     */
    completeText: {
      type: String,
      default: '暂无更多数据'
    },
    /**
     * 是否加载中
     */
    loading: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {};
  },
  methods: {
    loadMore() {
      this.parentInfiniteScrollList && this.parentInfiniteScrollList.innerLoadMore();
    }
  }
};

/* script */
const __vue_script__$1h = script$1h;

/* template */
var __vue_render__$1i = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"ivu-m"},[(_vm.hasMoreData && !_vm.loading)?_c('div',{staticClass:"text-center",attrs:{"title":"点击加载"},on:{"click":_vm.loadMore}},[_c('a',[_vm._v(_vm._s(_vm.moreDataTips))])]):_vm._e(),_vm._v(" "),(_vm.loading)?_c('Spin',[_c('Icon',{staticClass:"ivu-load-loop",attrs:{"type":"ios-loading","size":"18"}})],1):_vm._e(),_vm._v(" "),(!_vm.hasMoreData)?_c('div',{staticClass:"text-center"},[_vm._v(_vm._s(_vm.completeText))]):_vm._e()],1)};
var __vue_staticRenderFns__$1i = [];

  /* style */
  const __vue_inject_styles__$1i = undefined;
  /* scoped */
  const __vue_scope_id__$1i = undefined;
  /* module identifier */
  const __vue_module_identifier__$1i = undefined;
  /* functional template */
  const __vue_is_functional_template__$1i = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1i = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1i, staticRenderFns: __vue_staticRenderFns__$1i },
    __vue_inject_styles__$1i,
    __vue_script__$1h,
    __vue_scope_id__$1i,
    __vue_is_functional_template__$1i,
    __vue_module_identifier__$1i,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 无限滚动列表容器，支持滚动页面时自动加载数据，直到没有更多数据
 */
var script$1g = {
  components: {
    FLoadingTip: __vue_component__$1i
  },
  provide() {
    return {
      parentInfiniteScrollList: this
    };
  },
  props: {
    /**
     * 是否组件加载时立即获取数据到屏幕占满
     */
    immediate: {
      type: Boolean,
      default: true
    },
    /**
     * 距离最底部激发加载的距离，默认60px
     */
    distance: {
      type: Number,
      default: 60
    },
    /**
     * 加载函数，必须返回Promise，由外部指定
     */
    loadMore: {
      type: Function,
      required: true
    },
    /**
     * 指定首页从几开始，默认第1页
     */
    page: {
      type: Number,
      default: 1
    }
  },
  data() {
    return {
      innerPage: this.page,
      listData: [],
      hasMoreData: true,
      loading: false,
      disabled: false
    };
  },
  mounted() {
    this.innerLoadMore();
  },
  methods: {
    async innerLoadMore() {
      // 标记加载中
      this.loading = true;
      // 先禁用无限滚动
      this.disabled = true;
      let queryOptions = { page: this.innerPage };
      let { data, total } = await this.loadMore(queryOptions);
      this.innerPage++;
      this.listData = this.listData.concat(data);
      // 标记加载完成
      this.loading = false;
      if (total <= this.listData.length) {
        // 标记没有更多数据了
        this.hasMoreData = false;
        // 禁用无限滚动
        this.disabled = true;
        return;
      }
      // 如果还有更多数据，无限滚动继续可用
      if (this.hasMoreData) {
        this.disabled = false;
      }
    },
    // 重新加载数据：从起始页开始
    reload() {
      this.innerPage = this.page;
      this.listData = [];
      this.hasMoreData = true;
      this.innerLoadMore();
    }
  }
};

/* script */
const __vue_script__$1g = script$1g;

/* template */
var __vue_render__$1h = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{directives:[{name:"infinite-scroll",rawName:"v-infinite-scroll",value:(_vm.innerLoadMore),expression:"innerLoadMore"}],staticClass:"fuse-card-list",attrs:{"infinite-scroll-disabled":_vm.disabled,"infinite-scroll-immediate":_vm.immediate,"infinite-scroll-distance":_vm.distance}},[_vm._t("default",null,{"listData":_vm.listData}),_vm._v(" "),_c('f-loading-tip',{attrs:{"has-more-data":_vm.hasMoreData,"loading":_vm.loading}})],2)};
var __vue_staticRenderFns__$1h = [];

  /* style */
  const __vue_inject_styles__$1h = undefined;
  /* scoped */
  const __vue_scope_id__$1h = undefined;
  /* module identifier */
  const __vue_module_identifier__$1h = undefined;
  /* functional template */
  const __vue_is_functional_template__$1h = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1h = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1h, staticRenderFns: __vue_staticRenderFns__$1h },
    __vue_inject_styles__$1h,
    __vue_script__$1g,
    __vue_scope_id__$1h,
    __vue_is_functional_template__$1h,
    __vue_module_identifier__$1h,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$1f = {
  mixins: [cardListMixin],
  components: {
    CardListItem: __vue_component__$1j,
    FInfiniteScrollList: __vue_component__$1h
  },
  props: {
    type: {
      type: String,
      required: true,
      validator: function (value) {
        return ['app', 'my_app', 'project_app', 'authorized_app'].indexOf(value) !== -1;
      }
    },
    projectId: {
      type: String
    }
  },
  methods: {
    async loadMore(queryOptions) {
      let resp;
      let innerQueryOptions = Object.assign({}, this.queryOptions, queryOptions);
      if (this.type === 'app') {
        resp = await appService$2.query(innerQueryOptions);
      } else if (this.type === 'my_app') {
        // 主页应用首页
        resp = await aicService.myApps(innerQueryOptions, { expand: 'project' });
      } else if (this.type === 'project_app') {
        // 主页业务系统 点击业务系统
        resp = await aicService.projectApps(this.projectId, innerQueryOptions);
      } else if (this.type === 'authorized_app') {
        // 已开通当前服务的应用列表
        resp = await appService$2.authorized(innerQueryOptions, { expand: 'project' });
      }

      // 修改返回的总记录数值
      let total = Number(resp.headers['x-total-count']);
      this.$emit('update:total', total);
      this.$emit('on-changed', {
        list: this.listData,
        total: total
      });
      return {
        data: resp.data,
        total: total
      };
    },

    handleOnItemClick(item) {
      item.type = this.type;
      this.$emit('on-item-click', item);
    },
    // 重新加载数据：默认调用query
    reload() {
      this.query();
    }
  }
};

/* script */
const __vue_script__$1f = script$1f;

/* template */
var __vue_render__$1g = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('f-infinite-scroll-list',{ref:"infiniteScroll",attrs:{"immediate":false,"load-more":_vm.loadMore},scopedSlots:_vm._u([{key:"default",fn:function(ref){
var listData = ref.listData;
return [_c('Row',{attrs:{"type":"flex","gutter":24}},_vm._l((listData),function(item,index){return _c('i-col',{key:index,staticClass:"ivu-mb",attrs:{"xl":6,"lg":6,"md":6,"sm":8,"xs":12}},[_c('CardListItem',{attrs:{"item":item},on:{"on-item-click":_vm.handleOnItemClick}})],1)}),1)]}}])})};
var __vue_staticRenderFns__$1g = [];

  /* style */
  const __vue_inject_styles__$1g = undefined;
  /* scoped */
  const __vue_scope_id__$1g = undefined;
  /* module identifier */
  const __vue_module_identifier__$1g = undefined;
  /* functional template */
  const __vue_is_functional_template__$1g = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1g = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1g, staticRenderFns: __vue_staticRenderFns__$1g },
    __vue_inject_styles__$1g,
    __vue_script__$1f,
    __vue_scope_id__$1g,
    __vue_is_functional_template__$1g,
    __vue_module_identifier__$1g,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$1e = {
  name: 'appIndex',
  components: { appList: __vue_component__$1g },
  data() {
    let initTab = this.$route.query.tab || 'authorizedApp';
    return {
      tabName: initTab,
      search: '',
      hasLoadTab: [initTab], // 组件懒加载
      myAppOptions: {
        // 我参与的应用
        page_size: 12,
        total: 1,
        page: 1,
        orderby: 'updatedAt desc',
        filters: '',
        expand: 'project(title)'
      },
      myAppTabTotal: 0, // 我参与的应用总数,
      authorizedAppOptions: {
        // 我参与的应用
        page_size: 12,
        total: 1,
        page: 1,
        orderby: 'updatedAt desc',
        filters: '',
        expand: 'project(title)'
      },
      authorizedAppTabTotal: 0, // 我参与的应用总数
      selectedProject: null,
      projectList: [],
      orderBy: 'updatedAt desc'
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    }),
    myAppTabLabel() {
      return (h) => {
        return h('div', [
          h('span', '所有应用'),
          h('Badge', {
            props: {
              showZero: !!this.loadComponent('myApp'),
              count: this.myAppTabTotal,
              type: 'normal'
            }
          })
        ]);
      };
    },
    authorizedAppTabLabel() {
      return (h) => {
        return h('div', [
          h('span', '已开通应用'),
          h('Badge', {
            props: {
              showZero: true,
              count: this.authorizedAppTabTotal,
              type: 'normal'
            }
          })
        ]);
      };
    }
  },
  async mounted() {
    let { data } = await projectService.mine();
    this.projectList = data;
  },
  watch: {
    search() {
      this.changeQueryOptions();
    },
    selectedProject() {
      this.changeQueryOptions();
    },
    orderBy() {
      this.changeQueryOptions();
    },
    tabName() {
      this.changeQueryOptions();
    }
  },
  methods: {
    loadComponent(tabName) {
      return this.hasLoadTab.some((item) => item === tabName);
    },
    changeQueryOptions() {
      let filters = [];
      if (this.search) {
        filters.push(`title like '%${this.search}%'`);
      }
      if (this.selectedProject) {
        filters.push(`projectId eq '${this.selectedProject}'`);
      }
      let { queryOption } = this.currentTabInfo();

      queryOption.filters = filters.join(' and ');
      queryOption.page = 1;
      queryOption.orderby = this.orderBy;
      queryOption.expand = 'project(title)';
    },
    tabClick(tabName) {
      if (!this.hasLoadTab.some((item) => item === tabName)) {
        this.hasLoadTab.push(tabName);
      }
    },
    currentTabInfo() {
      if (this.tabName === 'myApp') {
        return {
          queryOption: this.myAppOptions,
          totalField: 'myAppTabTotal',
          list: this.$refs.appList
        };
      } else {
        return {
          queryOption: this.authorizedAppOptions,
          totalField: 'authorizedAppTabTotal',
          list: this.$refs.authorizedAppList
        };
      }
    },
    handleClick(item) {
      MicroAppHelper.routeToApp(item);
    },
    handleMyAppClick(item) {
      this.$routerThen
        .push({ name: 'appApply', query: { appId: item.id }, params: { returnUrl: this.buildReturnUrl() } })
        .onChange((result, _vm) => {
          if (result) {
            this.reload(result);
          }
        });
    },
    handleCreate() {
      this.$routerThen
        .push({ name: 'appCreate', params: { returnUrl: this.buildReturnUrl() } })
        .onChange((result, _vm) => {
          if (result) {
            this.reload();
          }
        });
    },
    handleFind() {
      this.$routerThen
        .push({ name: 'appFind', params: { returnUrl: this.buildReturnUrl() } })
        .onChange((result, _vm) => {
          if (result) {
            this.reload();
          }
        });
    },
    handleApply() {
      this.$routerThen
        .push({ name: 'appApply', query: { routerName: 'appsList', tab: this.tabName } })
        .onChange((result, _vm) => {
          if (result) {
            this.reload();
          }
        });
    },
    buildReturnUrl() {
      let url = window.location.href;
      if (!this.$route.query.tab) {
        if (url.includes('?')) {
          url += `&tab=${this.tabName}`;
        } else {
          url += `?tab=${this.tabName}`;
        }
      }
      return url;
    },
    reload(result) {
      if (result && result.tab) {
        this.tabName = result.tab;
      }
      this.changeQueryOptions();
      this.currentTabInfo().list.reload();
    },
    onListChanged(event) {
      if (!event.list) {
        return;
      }
      for (const app of event.list) {
        if (!app.projectId || app.project) {
          continue;
        }
        let exist = false;
        for (const project of this.projectList) {
          if (project.id === app.projectId) {
            exist = true;
            break;
          }
        }
        if (!exist) {
          this.projectList.push({ id: app.projectId, title: app.project.title });
        }
      }
    }
  }
};

/* script */
const __vue_script__$1e = script$1e;

/* template */
var __vue_render__$1f = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"app-index"},[_c('Menu',{staticClass:"ivu-mb",attrs:{"mode":"horizontal","active-name":"1"}},[_c('MenuItem',{attrs:{"name":"1","to":{ path: '/apps' }}},[_vm._v(" 应 用 ")]),_vm._v(" "),_c('MenuItem',{attrs:{"name":"2","to":{ path: '/projects' }}},[_vm._v(" 业务系统 ")])],1),_vm._v(" "),_c('Tabs',{on:{"on-click":_vm.tabClick},model:{value:(_vm.tabName),callback:function ($$v) {_vm.tabName=$$v;},expression:"tabName"}},[_c('TabPane',{attrs:{"label":_vm.authorizedAppTabLabel,"name":"authorizedApp"}},[_c('app-list',{ref:"authorizedAppList",attrs:{"query-options":_vm.authorizedAppOptions,"total":_vm.authorizedAppTabTotal,"type":"authorized_app"},on:{"on-changed":_vm.onListChanged,"update:total":function($event){_vm.authorizedAppTabTotal=$event;},"on-item-click":_vm.handleClick}})],1),_vm._v(" "),_c('TabPane',{attrs:{"label":_vm.myAppTabLabel,"name":"myApp"}},[(_vm.loadComponent('myApp'))?_c('app-list',{ref:"appList",attrs:{"query-options":_vm.myAppOptions,"total":_vm.myAppTabTotal,"type":"my_app"},on:{"on-changed":_vm.onListChanged,"update:total":function($event){_vm.myAppTabTotal=$event;},"on-item-click":_vm.handleMyAppClick}}):_vm._e()],1),_vm._v(" "),_c('div',{staticClass:"extra",attrs:{"slot":"extra"},slot:"extra"},[_c('Input',{staticClass:"input",attrs:{"search":"","clearable":"","placeholder":"按应用名称搜索"},model:{value:(_vm.search),callback:function ($$v) {_vm.search=$$v;},expression:"search"}}),_vm._v(" "),_c('Select',{staticStyle:{"width":"200px"},attrs:{"clearable":"","filterable":"","placeholder":"选择业务系统"},model:{value:(_vm.selectedProject),callback:function ($$v) {_vm.selectedProject=$$v;},expression:"selectedProject"}},_vm._l((_vm.projectList),function(item){return _c('Option',{key:item.id,attrs:{"value":item.id}},[_vm._v(_vm._s(item.title))])}),1),_vm._v(" "),_c('Select',{staticStyle:{"width":"150px","margin-right":"2px"},attrs:{"placeholder":"选择排序时间"},model:{value:(_vm.orderBy),callback:function ($$v) {_vm.orderBy=$$v;},expression:"orderBy"}},[_c('Option',{attrs:{"value":'updatedAt desc'}},[_vm._v("最近更新")]),_vm._v(" "),_c('Option',{attrs:{"value":'updatedAt'}},[_vm._v("最近更新(倒序)")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt desc'}},[_vm._v("最新创建")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt'}},[_vm._v("最新创建(倒序)")])],1),_vm._v(" "),(_vm.tabName == 'authorizedApp')?_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"success"},on:{"click":_vm.handleApply}},[_vm._v("开通应用")]):_vm._e(),_vm._v(" "),(_vm.tabName == 'myApp')?_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"success"},on:{"click":_vm.handleFind}},[_vm._v("找回应用")]):_vm._e(),_vm._v(" "),(_vm.tabName == 'myApp')?_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"primary"},on:{"click":_vm.handleCreate}},[_vm._v("新建应用")]):_vm._e()],1)],1)],1)};
var __vue_staticRenderFns__$1f = [];

  /* style */
  const __vue_inject_styles__$1f = function (inject) {
    if (!inject) return
    inject("data-v-f8937bec_0", { source: ".app-index{margin-top:-8px;background-color:#fff}.app-index .ivu-tabs-bar{display:flow-root;z-index:1!important}.app-index .input{width:300px;margin-right:10px}.app-index .ivu-select{margin-right:10px}.app-index .ivu-page-header{padding:0}.app-index .ivu-tabs-tab{padding:8px 8px}.app-index .ivu-tabs-bar{background-color:#fff;position:sticky;top:0;zoom:1;z-index:100}.app-index .ivu-badge{margin-left:8px}.app-index .ivu-menu-light.ivu-menu-horizontal .ivu-menu-item{border-bottom:none}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1f = undefined;
  /* module identifier */
  const __vue_module_identifier__$1f = undefined;
  /* functional template */
  const __vue_is_functional_template__$1f = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1f = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1f, staticRenderFns: __vue_staticRenderFns__$1f },
    __vue_inject_styles__$1f,
    __vue_script__$1e,
    __vue_scope_id__$1f,
    __vue_is_functional_template__$1f,
    __vue_module_identifier__$1f,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$1d = {
  mounted() {
    let returnUrl = this.$route.params.returnUrl;
    let url = AICConsole.getUrlForCreateApp(returnUrl);
    let success = window.location.href.substring(0, window.location.href.indexOf('#'));
    success += '#/apps/apply?appId=:appId';
    url += `&from=service&success=${encodeURIComponent(success)}`;
    window.location.href = url;
  }
};

/* script */
const __vue_script__$1d = script$1d;

/* template */
var __vue_render__$1e = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
var __vue_staticRenderFns__$1e = [];

  /* style */
  const __vue_inject_styles__$1e = undefined;
  /* scoped */
  const __vue_scope_id__$1e = undefined;
  /* module identifier */
  const __vue_module_identifier__$1e = undefined;
  /* functional template */
  const __vue_is_functional_template__$1e = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1e = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1e, staticRenderFns: __vue_staticRenderFns__$1e },
    __vue_inject_styles__$1e,
    __vue_script__$1d,
    __vue_scope_id__$1e,
    __vue_is_functional_template__$1e,
    __vue_module_identifier__$1e,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$1c = {
  mounted() {
    let returnUrl = this.$route.params.returnUrl;
    let url = AICConsole.getUrlForFindApp(returnUrl);
    window.location.href = url;
  }
};

/* script */
const __vue_script__$1c = script$1c;

/* template */
var __vue_render__$1d = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
var __vue_staticRenderFns__$1d = [];

  /* style */
  const __vue_inject_styles__$1d = undefined;
  /* scoped */
  const __vue_scope_id__$1d = undefined;
  /* module identifier */
  const __vue_module_identifier__$1d = undefined;
  /* functional template */
  const __vue_is_functional_template__$1d = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1d = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1d, staticRenderFns: __vue_staticRenderFns__$1d },
    __vue_inject_styles__$1d,
    __vue_script__$1c,
    __vue_scope_id__$1d,
    __vue_is_functional_template__$1d,
    __vue_module_identifier__$1d,
    false,
    undefined,
    undefined,
    undefined
  );

var baseMixin$1 = {
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: [Object, Array],
      default: function () {
        return null;
      }
    },
    /**
     * 文件大小限制
     */
    maxSize: {
      type: Number,
      default: 200 // 默认200M
    },
    /**
     * 最大文件个数，多选时生效
     */
    maxLength: {
      type: Number
    },
    /**
     * 支持的文件格式
     */
    format: {
      type: Array,
      default() {
        return [];
      }
    },
    errorCallback: {
      type: Function
    },
    /**
     * 自定义上传策略
     */
    uploadPolicy: {
      type: Object
    },
    /**
     * fuse这边上传组件默认使用简单上传接口，如果需要使用ufs，需要开启ufs
     */
    ufs: {
      type: Boolean,
      default: false
    },
    /**
     * 是否禁用
     */
    disabled: {
      type: Boolean,
      default: false
    }
  },
  methods: {
    getUploadPolicy() {
      if (this.ufs) {
        return ufsUploadPolicy;
      }
      return this.uploadPolicy || uploadPolicy$1;
    }
  }
};

function broadcast(componentName, eventName, params) {
  this.$children.forEach((child) => {
    const name = child.$options.name;

    if (name === componentName) {
      child.$emit.apply(child, [eventName].concat(params));
    } else {
      // todo 如果 params 是空数组，接收到的会是 undefined
      broadcast.apply(child, [componentName, eventName].concat([params]));
    }
  });
}
var Emitter = {
  methods: {
    dispatch(componentName, eventName, params) {
      let parent = this.$parent || this.$root;
      let name = parent.$options.name;

      while (parent && (!name || name !== componentName)) {
        parent = parent.$parent;

        if (parent) {
          name = parent.$options.name;
        }
      }
      if (parent) {
        parent.$emit.apply(parent, [eventName].concat(params));
      }
    },
    broadcast(componentName, eventName, params) {
      broadcast.call(this, componentName, eventName, params);
    }
  }
};

var vModelMixin = {
  mixins: [baseMixin$1, Emitter],
  data() {
    return {
      innerValue: _$1.cloneDeep(this.value)
    };
  },
  watch: {
    value: {
      handler() {
        if (!this.isEqual(this.value, this.innerValue)) {
          this.innerValue = _$1.cloneDeep(this.value);
        }
      },
      deep: true
    },
    innerValue: {
      handler(newV, oldV) {
        this.$emit('input', this.innerValue);
        /**
         * 选择文件后执行
         *
         * @event on-change
         */
        this.$emit('on-change', this.innerValue, oldV);
        this.dispatch('FormItem', 'on-form-change', this.innerValue);
      },
      deep: true
    }
  },
  methods: {
    isEqual(newV, oldV) {
      let uploadPolicy = this.getUploadPolicy();
      if (this.multiple) {
        return uploadPolicy.isArrayEqual(newV, oldV);
      } else {
        return uploadPolicy.isEqual(newV, oldV);
      }
    },
    handleOnError(params) {
      /**
       * 文件不合法时抛出错误
       *
       * @event on-error
       */
      this.$emit('on-error', params);
    }
  }
};

//
/**
 * 单图片上传组件
 */
var script$1b = {
  mixins: [vModelMixin],
  props: {
    /**
     * 图片显示宽度
     */
    width: {
      type: Number,
      default: 130
    },
    /**
     * 图片显示高度
     */
    height: {
      type: Number,
      default: 150
    },
    /**
     * 上传图标
     */
    icon: {
      type: String,
      default: 'ios-image-outline'
    },
    maxSize: {
      type: Number,
      default: 1 // 默认1M
    }
  }
};

/* script */
const __vue_script__$1b = script$1b;

/* template */
var __vue_render__$1c = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('MSingleImageUpload',{attrs:{"upload-policy":_vm.getUploadPolicy(),"width":_vm.width,"height":_vm.height,"format":_vm.format,"disabled":_vm.disabled,"icon":_vm.icon,"max-size":_vm.maxSize,"error-callback":_vm.errorCallback},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}})};
var __vue_staticRenderFns__$1c = [];

  /* style */
  const __vue_inject_styles__$1c = undefined;
  /* scoped */
  const __vue_scope_id__$1c = undefined;
  /* module identifier */
  const __vue_module_identifier__$1c = undefined;
  /* functional template */
  const __vue_is_functional_template__$1c = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1c = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1c, staticRenderFns: __vue_staticRenderFns__$1c },
    __vue_inject_styles__$1c,
    __vue_script__$1b,
    __vue_scope_id__$1c,
    __vue_is_functional_template__$1c,
    __vue_module_identifier__$1c,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 用来渲染使用bingo builder的构建的远程表单
 */
var script$1a = {
  props: {
    /**
     * 远程表单的访问地址，只支持由bingo-builder开启buildRemotes构建的表单
     */
    url: {
      type: String,
      required: true
    },
    /**
     * 自定义的外部参数，远程组件内部使用同名属性接收
     */
    settings: {
      type: Object,
      default: () => {
        return {
          data: {},
          mode: 'create'
        };
      }
    }
  },
  data() {
    return {
      preprocessed: false,
      remoteVueCom: null,
      errorObj: {
        hasError: false,
        message: ''
      }
    };
  },
  async mounted() {
    let url = this.url;
    var self = this;
    let name = url.substring(url.lastIndexOf('/') + 1, url.lastIndexOf('.js'));
    let res = await this.$http
      .disableInterceptor(DefaultInterceptorType.DefaultResponseError)
      .baseURL('')
      .get(url)
      .catch(() => {
        this.errorObj.hasError = true;
        this.errorObj.message = `${this.url}`;
        /**
         * 远程表单渲染出错时执行
         *
         * @event on-error
         */
        this.$emit('on-error', this.errorObj);
      });
    if (this.errorObj.hasError) {
      return;
    }
    let comFunc = new Function('self', res.data);
    comFunc(self);
    self.remoteVueCom = self[name].default;
    this.preprocessed = true;
  },
  methods: {
    handleOnChange(model) {
      /**
       * 远程表单抛出on-change事件时执行
       *
       * @event on-change
       */
      this.$emit('on-change', model);
    },
    back() {
      this.$router.back();
    }
  }
};

/* script */
const __vue_script__$1a = script$1a;

/* template */
var __vue_render__$1b = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return (_vm.preprocessed)?_c(_vm.remoteVueCom,{tag:"component",attrs:{"settings":_vm.settings},on:{"on-change":_vm.handleOnChange}}):(_vm.errorObj.hasError)?_c('div',[_vm._t("error",[_c('Alert',{staticStyle:{"margin":"20px 200px"},attrs:{"type":"warning","show-icon":""}},[_vm._v("\n      加载错误\n      "),_c('template',{slot:"desc"},[_vm._v("\n        远程表单加载异常："+_vm._s(_vm.errorObj.message)),_c('br'),_vm._v(" "),_c('Button',{on:{"click":_vm.back}},[_vm._v("返 回")])],1)],2)])],2):_vm._e()};
var __vue_staticRenderFns__$1b = [];

  /* style */
  const __vue_inject_styles__$1b = undefined;
  /* scoped */
  const __vue_scope_id__$1b = undefined;
  /* module identifier */
  const __vue_module_identifier__$1b = undefined;
  /* functional template */
  const __vue_is_functional_template__$1b = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1b = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1b, staticRenderFns: __vue_staticRenderFns__$1b },
    __vue_inject_styles__$1b,
    __vue_script__$1a,
    __vue_scope_id__$1b,
    __vue_is_functional_template__$1b,
    __vue_module_identifier__$1b,
    false,
    undefined,
    undefined,
    undefined
  );

//
// 0:审批中,1:已开通，2:审批拒绝，3:开通中,4：开通失败
let statusMap$1 = {
  0: {
    type: 'success',
    desc: '申请成功，管理员正在审批中，请稍后！',
    title: '申请成功'
  },
  1: {
    type: 'success',
    desc: '您的申请的服务已经开通成功，现在您可以通过下面链接访问已申请的服务',
    title: '开通成功',
    extra: true // 是否展示额外的内容
  },
  2: {
    type: 'error',
    desc: '审批拒绝！',
    title: '开通失败'
  },
  3: {
    type: 'error',
    desc: '审批拒绝！',
    title: '开通失败'
  },
  4: {
    type: 'info',
    desc: '开通失败！',
    title: '开通失败'
  }
};
var script$19 = {
  components: {
    FSingleImageUpload: __vue_component__$1c,
    FRemote: __vue_component__$1b
  },
  provide: function () {
    return {
      context: {
        getService: () => this.service,
        getApp: () => this.selectedItem,
        submit: (applyForm) => this.apply(applyForm),
        back: () => {
          this.back();
        }
      }
    };
  },
  data() {
    return {
      disableSelect: false,
      service: null,
      localServiceInfo: null,
      serviceAgreement: null,
      apps: [],
      selectedItem: null,
      searchOptions: {
        page: 1,
        size: 12,
        expand: 'project(title)'
      },
      total: 0,
      resultMsg: null,
      servicestatusMap: {}
    };
  },
  async mounted() {
    let appId = this.$route.query.appId;
    if (appId) {
      this.disableSelect = true;
      await this.initAppInfo(appId);
    }
    this.getApps();
    await this.getService();
    await this.getServiceAuthorizations();
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    }),
    isEnd() {
      // 当取回来的条目数，当currentSize！= searchOptions.limit 证明没有数据了
      return this.total <= this.searchOptions.page * this.searchOptions.size;
    }
  },
  methods: {
    async getService() {
      const { data } = await aicService.localServiceInfo();
      this.localServiceInfo = data;
      const resp = await aicService.findServiceByCode(this.localServiceInfo.code);
      this.service = resp.data;
    },
    async getServiceAuthorizations() {
      const { data } = await aicService.serviceAuthorizations(this.service.id);
      this.servicestatusMap = data;
    },
    async initAppInfo(appId) {
      const { data } = await aicService.findAppById(appId);
      this.selectedItem = data;
      if (this.selectedItem) {
        const resp = await appService$2.authorizedApp(this.selectedItem.id);
        if (resp && resp.data) {
          MicroAppHelper.routeToApp(this.selectedItem);
        }
      }
    },
    jump() {
      if (!this.service.docUrl) {
        this.$Message.error('暂未配置文档地址！');
        return;
      }
      this.$Modal.confirm({
        title: '提示',
        content: `<p>即将访问：<strong style="word-break: break-all">${this.service.docUrl}</strong>，点击确定按钮即可访问</p>`,
        onOk: () => {
          window.open(this.service.docUrl);
        }
      });
    },
    back() {
      if (this.$route.query.routerName) {
        this.$router.replace({ name: this.$route.query.routerName, query: { tab: this.$route.query.tab } });
      } else {
        this.$router.back();
      }
    },
    apply(formData) {
      if (!this.selectedItem) {
        this.$Modal.warning({
          title: '校验错误',
          content: '请至少选择一个应用'
        });
      } else {
        let isApplied = this.servicestatusMap[this.selectedItem.id];
        let confirmMsg = `是否为该应用开通${this.service.title}？`;
        if (isApplied) {
          confirmMsg = `当前应用已开通过${this.service.title}，是否需要重新开通？`;
        }
        this.$Modal.confirm({
          title: '提示',
          content: confirmMsg,
          onOk: async () => {
            await this.doApply(this.selectedItem, formData);
          }
        });
      }
    },
    async doApply(item, formData) {
      let form = {};
      form.serviceId = this.service.id;
      form.serviceName = this.service.title;
      form.type = 'service_agreement';
      form.appId = item.id;
      form.appName = item.title;
      form.data = formData;
      let isApplied = this.servicestatusMap[form.appId];
      try {
        let resp = await aicService.applyService(form, { params: { force: !!isApplied }, onError: true });
        this.serviceAgreement = resp.data;
        this.resultMsg = statusMap$1[resp.data.status];
      } catch (error) {
        this.serviceAgreement = {};
        this.resultMsg = {
          title: '开通成功',
          type: 'success',
          desc: '应用已开通该服务，请勿重复开通！',
          extra: false
        };
      }
    },
    getUrlForApp(item) {
      if (!this.service) {
        return '';
      }
      let currentApp = item || this.selectedItem;
      let { forAppUrl: url, consoleUrl } = this.localServiceInfo;
      url = url || consoleUrl;
      let parseCtx = {
        app: currentApp,
        appId: currentApp && currentApp.id,
        serviceId: this.service.id
      };
      if (url) {
        try {
          url = Utils.parseUrl(url, parseCtx);
        } catch (error) {
          return url;
        }
      }
      return url;
    },
    toService() {
      let url = this.getUrlForApp(this.selectedItem);
      window.location.href = url;
    },
    toApps() {
      this.$routerReturn({ tab: 'authorizedApp' });
      this.$router.push({ name: 'appsList' });
    },
    async getApps() {
      this.loading = true;
      const resp = await aicService.myApps(this.searchOptions);
      this.apps = resp.data;
      this.total = Number(resp.headers['x-total-count']);
      this.loading = false;
    },
    handleSelect(item) {
      this.selectedItem = item;
    },
    next() {
      this.searchOptions.page++;
      this.getApps();
    },
    prev() {
      this.searchOptions.page--;
      this.getApps();
    },
    handleCreate() {
      this.$Modal.confirm({
        title: '提示',
        content: `<p>即将跳转到应用新建页面，是否继续？</p>`,
        onOk: () => {
          this.$routerThen.push({ name: 'appCreate', params: { returnUrl: window.location.href } });
        }
      });
    },
    inputChange: debounce(function () {
      if (this.search) {
        this.searchOptions.filters = `title like %${this.search}%`;
      } else {
        this.searchOptions.filters = '';
      }
      this.searchOptions.page = 1;
      this.getApps();
    }, 300),
    getTagType(status) {
      if (!status) return;
      // 0:审批中,1:已开通，2:审批拒绝，3:开通中,4：开通失败
      let map = {
        0: {
          color: '#515a6e',
          title: '审批中'
        },
        1: {
          color: '#19be6b',
          title: '已开通'
        },
        2: {
          color: '#ed4014',
          title: '审批拒绝'
        },
        3: {
          color: '#2d8cf0',
          title: '开通中'
        },
        4: {
          color: '#ff9900',
          title: '开通失败'
        }
      };
      return map[status];
    }
  }
};

/* script */
const __vue_script__$19 = script$19;

/* template */
var __vue_render__$1a = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return (_vm.service)?_c('div',[_c('PageHeader',{attrs:{"back":true},on:{"on-back":_vm.back}},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("\n      "+_vm._s(_vm.service.title)+"\n    ")]),_vm._v(" "),(_vm.service.icon)?_c('f-single-image-upload',{attrs:{"disabled":true},model:{value:(_vm.service.icon),callback:function ($$v) {_vm.$set(_vm.service, "icon", $$v);},expression:"service.icon"}}):_c('f-default-icon',{attrs:{"slot":"logo","title":_vm.service.title.substr(0, 1)},slot:"logo"}),_vm._v(" "),_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(4),expression:"4"}],attrs:{"slot":"content","title":_vm.service.summary},slot:"content"},[_vm._v(_vm._s(_vm.service.summary || '暂无'))])],1),_vm._v(" "),(_vm.resultMsg === null)?_c('div',{staticClass:"footer"},[_c('Form',{ref:"form",attrs:{"label-width":120}},[(_vm.disableSelect)?_c('FormItem',{attrs:{"label":"应  用"}},[_c('Row',[_c('Input',{attrs:{"disabled":""},model:{value:(_vm.selectedItem.title),callback:function ($$v) {_vm.$set(_vm.selectedItem, "title", $$v);},expression:"selectedItem.title"}})],1)],1):_c('FormItem',{attrs:{"label":"应  用"}},[_c('Row',[_c('div',{staticStyle:{"margin-right":"100px"}},[_c('Input',{attrs:{"search":"","enter-button":"搜索","placeholder":"按应用名称搜索"},on:{"on-change":_vm.inputChange,"on-enter":_vm.inputChange,"on-search":_vm.inputChange},model:{value:(_vm.search),callback:function ($$v) {_vm.search=$$v;},expression:"search"}})],1),_vm._v(" "),_c('Button',{staticStyle:{"position":"absolute","top":"0px","right":"0px"},attrs:{"type":"success"},on:{"click":_vm.handleCreate}},[_vm._v("新建应用")])],1),_vm._v(" "),_c('Row',{staticClass:"ivu-mt",attrs:{"type":"flex","gutter":24}},[(_vm.loading)?_c('Spin',{attrs:{"fix":""}}):_vm._e(),_vm._v(" "),_vm._l((_vm.apps),function(item){return _c('Col',{key:item.appId,staticClass:"ivu-mb",attrs:{"xl":6,"lg":6,"md":6,"sm":8,"xs":12}},[_c('Card',{staticClass:"app-list-item",attrs:{"bordered":true,"padding":0}},[(_vm.selectedItem && _vm.selectedItem.id === item.id)?_c('Tag',{attrs:{"color":"primary"}},[_vm._v("已选")]):_vm._e(),_vm._v(" "),_c('Button',{directives:[{name:"height",rawName:"v-height",value:(80),expression:"80"}],staticClass:"btn",attrs:{"title":item.title,"type":"text","long":""},on:{"click":function($event){return _vm.handleSelect(item)}}},[_vm._v("\n                "+_vm._s(item.title)+"\n              ")]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-foot"},[(_vm.servicestatusMap[item.id] !== undefined)?_c('span',{staticClass:"fuse-card-list-item-foot-left",style:({ color: _vm.getTagType(_vm.servicestatusMap[item.id]).color })},[_vm._v("\n                  "+_vm._s(_vm.getTagType(_vm.servicestatusMap[item.id]).title)+"\n                ")]):_vm._e(),_vm._v(" "),(item.project && item.project.title)?_c('span',{staticClass:"fuse-card-list-item-foot-right"},[_vm._v("\n                  "+_vm._s(item.project.title)+"\n                ")]):_vm._e()])],1)],1)})],2),_vm._v(" "),_c('Row',[_c('Col',{staticClass:"text-right"},[_c('Button',{attrs:{"type":"text","disabled":_vm.searchOptions.page == 1},on:{"click":_vm.prev}},[_c('Icon',{attrs:{"type":"ios-arrow-back"}}),_vm._v("上一页\n            ")],1),_vm._v(" "),_c('Button',{attrs:{"type":"text","disabled":_vm.loading || _vm.isEnd},on:{"click":_vm.next}},[_vm._v("下一页 "),_c('Icon',{attrs:{"type":"ios-arrow-forward"}})],1)],1)],1),_vm._v(" "),(_vm.apps && _vm.apps.length == 0)?_c('div',{staticStyle:{"margin":"50px 0","text-align":"center"}},[_vm._v("暂无应用")]):_vm._e()],1)],1),_vm._v(" "),(_vm.localServiceInfo.applyFormUrl)?_c('f-remote',{attrs:{"url":_vm.localServiceInfo.applyFormUrl}}):_c('div',{staticStyle:{"margin-left":"120px"}},[_c('Button',{on:{"click":_vm.back}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{staticClass:"ivu-ml",attrs:{"type":"primary"},on:{"click":_vm.apply}},[_vm._v("立即开通")])],1)],1):_c('Result',{staticClass:"mt-lg",attrs:{"type":_vm.resultMsg.type,"title":_vm.resultMsg.title}},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("\n      "+_vm._s(_vm.resultMsg.desc)+"\n    ")]),_vm._v(" "),(_vm.resultMsg.extra)?_c('div',{attrs:{"slot":"extra"},slot:"extra"},[_c('a',{on:{"click":_vm.toService}},[_vm._v(_vm._s(_vm.getUrlForApp()))])]):_vm._e(),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.toApps}},[_vm._v("返回应用列表")]),_vm._v(" "),_c('Button',{on:{"click":_vm.toService}},[_vm._v("访问服务")])],1)])],1):_vm._e()};
var __vue_staticRenderFns__$1a = [];

  /* style */
  const __vue_inject_styles__$1a = function (inject) {
    if (!inject) return
    inject("data-v-3d399823_0", { source: ".document-icon[data-v-3d399823]{margin-left:8px;cursor:pointer}.footer[data-v-3d399823]{margin:30px 70px}.footer h3[data-v-3d399823]{line-height:5}.step[data-v-3d399823]{width:50%;min-width:400px;max-width:700px;margin:20px auto}[data-v-3d399823] .ivu-btn .ivu-icon{vertical-align:-.2em}[data-v-3d399823] .ivu-select-multiple .ivu-select-head-flex{height:30px}[data-v-3d399823] .ivu-select-multiple .ivu-select-head-flex .ivu-select-prefix i{vertical-align:bottom}.app-list-item[data-v-3d399823] .ivu-tag{position:absolute;top:5px;right:5px}.btn[data-v-3d399823] span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block}.fuse-card-list-item-foot-left[data-v-3d399823]{font-size:12px;line-height:1;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block;padding:2px 5px}.fuse-card-list-item-foot-right[data-v-3d399823]{font-size:12px;line-height:1;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:block}.result[data-v-3d399823]{width:65%;margin:24px auto}.result-item[data-v-3d399823]{display:flex;justify-content:space-between;margin-bottom:8px}.result-item>div[data-v-3d399823]{display:flex;align-items:center}.demo-spin-icon-load[data-v-3d399823]{animation:ani-demo-spin-data-v-3d399823 1s linear infinite}@keyframes ani-demo-spin-data-v-3d399823{from{transform:rotate(0)}50%{transform:rotate(180deg)}to{transform:rotate(360deg)}}.ivu-icon-ios-checkmark-circle[data-v-3d399823]{color:#19be6b}.table[data-v-3d399823]{margin:24px}h3[data-v-3d399823]{text-align:center;margin:16px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1a = "data-v-3d399823";
  /* module identifier */
  const __vue_module_identifier__$1a = undefined;
  /* functional template */
  const __vue_is_functional_template__$1a = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1a = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1a, staticRenderFns: __vue_staticRenderFns__$1a },
    __vue_inject_styles__$1a,
    __vue_script__$19,
    __vue_scope_id__$1a,
    __vue_is_functional_template__$1a,
    __vue_module_identifier__$1a,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$18 = {
  data() {
    return {
      hasError: false,
      appId: this.$route.params.appId
    };
  },
  async mounted() {
    if (!this.appId) {
      this.hasError = true;
      return;
    }
    const resp = await appService$2.authorizedApp(this.appId);
    if (resp && resp.data) {
      MicroAppHelper.routeToApp(resp.data);
    }
  },
  methods: {
    toApps() {
      this.$router.push({ name: 'appsList' });
    }
  }
};

/* script */
const __vue_script__$18 = script$18;

/* template */
var __vue_render__$19 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[(_vm.hasError)?_c('Result',{attrs:{"type":"error","title":_vm.应用不存在}},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("找不到应用ID为"+_vm._s(_vm.appId)+"的应用，如果应用存在，请确认您是否有该应用的访问权限！")]),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.toApps}},[_vm._v("返回应用列表")])],1)]):_vm._e()],1)};
var __vue_staticRenderFns__$19 = [];

  /* style */
  const __vue_inject_styles__$19 = undefined;
  /* scoped */
  const __vue_scope_id__$19 = undefined;
  /* module identifier */
  const __vue_module_identifier__$19 = undefined;
  /* functional template */
  const __vue_is_functional_template__$19 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$19 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$19, staticRenderFns: __vue_staticRenderFns__$19 },
    __vue_inject_styles__$19,
    __vue_script__$18,
    __vue_scope_id__$19,
    __vue_is_functional_template__$19,
    __vue_module_identifier__$19,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$17 = {
  mixins: [cardListItemMixin]
};

/* script */
const __vue_script__$17 = script$17;

/* template */
var __vue_render__$18 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{directives:[{name:"height",rawName:"v-height",value:(180),expression:"180"}],staticClass:"fuse-card-list-item",attrs:{"bordered":""},nativeOn:{"click":function($event){return _vm.handleOnItemClick(_vm.item)}}},[_c('div',{staticClass:"fuse-card-list-item-header",attrs:{"slot":"title"},slot:"title"},[_c('div',{class:['fuse-card-list-item-circle', 'bg-opacity', _vm.randomBgClass]},[_vm._v("\n      "+_vm._s(_vm.firstChar)+"\n    ")]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-content"},[_c('h3',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-content-title"},[_vm._v(_vm._s(_vm.itemTitle))])])]),_vm._v(" "),_c('p',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(2),expression:"2"}]},[_vm._v(_vm._s(_vm.item.summary || '暂无描述'))]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-foot"},[(_vm.item.updatedAt)?_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-foot-left"},[_vm._v("\n      更新于："),_c('Time',{attrs:{"time":_vm.item.updatedAt}})],1):_vm._e()])])};
var __vue_staticRenderFns__$18 = [];

  /* style */
  const __vue_inject_styles__$18 = undefined;
  /* scoped */
  const __vue_scope_id__$18 = undefined;
  /* module identifier */
  const __vue_module_identifier__$18 = undefined;
  /* functional template */
  const __vue_is_functional_template__$18 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$18 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$18, staticRenderFns: __vue_staticRenderFns__$18 },
    __vue_inject_styles__$18,
    __vue_script__$17,
    __vue_scope_id__$18,
    __vue_is_functional_template__$18,
    __vue_module_identifier__$18,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$16 = {
  mixins: [cardListMixin],
  components: {
    CardListItem: __vue_component__$18,
    FInfiniteScrollList: __vue_component__$1h
  },
  props: {
    type: {
      type: String,
      required: true,
      validator: function (value) {
        return ['project', 'my_project'].indexOf(value) !== -1;
      }
    }
  },
  methods: {
    async loadMore(queryOptions) {
      this.showSpin = true;
      let resp;
      let innerQueryOptions = Object.assign({}, this.queryOptions, queryOptions);
      if (this.type === 'project') {
        resp = await aicService.myProjects(innerQueryOptions);
      } else if (this.type === 'my_project') {
        // this.queryOptions.expand='app'
        resp = await aicService.myProjects(innerQueryOptions);
      }

      // 修改返回的总记录数值
      let total = Number(resp.headers['x-total-count']);
      this.$emit('update:total', total);
      this.$emit('on-changed', {
        list: this.listData,
        total: total
      });
      return {
        data: resp.data,
        total: total
      };
    },
    handleOnItemClick(item) {
      item.type = this.type;
      this.$emit('on-item-click', item);
    },
    // 重新加载数据：默认调用query
    reload() {
      this.query();
    }
  }
};

/* script */
const __vue_script__$16 = script$16;

/* template */
var __vue_render__$17 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('f-infinite-scroll-list',{ref:"infiniteScroll",attrs:{"immediate":false,"load-more":_vm.loadMore},scopedSlots:_vm._u([{key:"default",fn:function(ref){
var listData = ref.listData;
return [_c('Row',{attrs:{"type":"flex","gutter":24}},_vm._l((listData),function(item){return _c('i-col',{key:item.id,staticClass:"ivu-mb",attrs:{"xl":6,"lg":6,"md":6,"sm":8,"xs":12}},[_c('CardListItem',{attrs:{"item":item},on:{"on-item-click":_vm.handleOnItemClick}})],1)}),1)]}}])})};
var __vue_staticRenderFns__$17 = [];

  /* style */
  const __vue_inject_styles__$17 = undefined;
  /* scoped */
  const __vue_scope_id__$17 = undefined;
  /* module identifier */
  const __vue_module_identifier__$17 = undefined;
  /* functional template */
  const __vue_is_functional_template__$17 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$17 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$17, staticRenderFns: __vue_staticRenderFns__$17 },
    __vue_inject_styles__$17,
    __vue_script__$16,
    __vue_scope_id__$17,
    __vue_is_functional_template__$17,
    __vue_module_identifier__$17,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$15 = {
  components: { ProjectList: __vue_component__$17 },
  data() {
    return {
      tabName: 'myProject',
      search: '',
      hasLoadTab: ['myProject'], // 组件懒加载
      myProjectOptions: {
        // 我参与的系统
        page_size: 12,
        total: 1,
        page: 1,
        orderby: 'updatedAt desc',
        filters: ''
      },
      myProjectTabTotal: 0, // 我参与的应用总数
      orderBy: 'updatedAt desc'
    };
  },
  computed: {
    myProjectTabLabel() {
      return (h) => {
        return h('div', [
          h('span', '我的系统'),
          h('Badge', {
            props: {
              showZero: true,
              count: this.myProjectTabTotal,
              type: 'normal'
            }
          })
        ]);
      };
    }
  },
  watch: {
    search() {
      this.changeQueryOptions();
    },
    orderBy() {
      this.changeQueryOptions();
    },
    tabName() {
      this.changeQueryOptions();
    }
  },
  methods: {
    changeQueryOptions() {
      let filters = [];
      if (this.search) {
        filters.push(`title like '%${this.search}%'`);
      }
      this.myProjectOptions.filters = filters.join(' and ');
      this.myProjectOptions.page = 1;
      this.myProjectOptions.orderby = this.orderBy;
      this.myProjectOptions._t = new Date().getTime();
      // this.myProjectOptions.expand = "project(id,name)";
    },
    tabClick(tabName) {
      if (!this.hasLoadTab.some((item) => item === tabName)) {
        this.hasLoadTab.push(tabName);
      }
    },
    loadComponent(tabName) {
      return this.hasLoadTab.some((item) => item === tabName);
    },
    handleClick(item) {
      if (item.type === 'project' || item.type === 'my_project') {
        this.$routerThen.push({ name: 'projectApps', params: { projectId: item.id } });
      }
    },
    handleFind() {
      this.$routerThen
        .push({ name: 'projectFind', params: { returnUrl: window.location.href } })
        .onChange((result, _vm) => {
          if (result) {
            this.changeQueryOptions();
            this.$refs.projectList.reload();
          }
        });
    },
    handleCreate() {
      this.$routerThen
        .push({ name: 'projectCreate', params: { returnUrl: window.location.href } })
        .onChange((result, _vm) => {
          if (result) {
            this.changeQueryOptions();
            this.$refs.projectList.reload();
          }
        });
    },
    onListChanged() {
      return;
    }
  }
};

/* script */
const __vue_script__$15 = script$15;

/* template */
var __vue_render__$16 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"app-index"},[_c('Menu',{staticClass:"ivu-mb",attrs:{"mode":"horizontal","active-name":"2"}},[_c('MenuItem',{attrs:{"name":"1","to":{ path: '/apps' }}},[_vm._v(" 应 用 ")]),_vm._v(" "),_c('MenuItem',{attrs:{"name":"2","to":{ path: '/projects' }}},[_vm._v(" 业务系统 ")])],1),_vm._v(" "),_c('Tabs',{on:{"on-click":_vm.tabClick},model:{value:(_vm.tabName),callback:function ($$v) {_vm.tabName=$$v;},expression:"tabName"}},[_c('TabPane',{attrs:{"label":_vm.myProjectTabLabel,"name":"myProject"}},[_c('project-list',{ref:"projectList",attrs:{"query-options":_vm.myProjectOptions,"total":_vm.myProjectTabTotal,"type":"my_project"},on:{"on-changed":_vm.onListChanged,"update:total":function($event){_vm.myProjectTabTotal=$event;},"on-item-click":_vm.handleClick}})],1),_vm._v(" "),_c('div',{staticClass:"extra",attrs:{"slot":"extra"},slot:"extra"},[_c('Input',{staticClass:"input",attrs:{"search":"","clearable":"","placeholder":"按名称系统名称搜索"},model:{value:(_vm.search),callback:function ($$v) {_vm.search=$$v;},expression:"search"}}),_vm._v(" "),_c('Select',{staticStyle:{"width":"150px","margin-right":"2px"},attrs:{"placeholder":"选择排序时间"},model:{value:(_vm.orderBy),callback:function ($$v) {_vm.orderBy=$$v;},expression:"orderBy"}},[_c('Option',{attrs:{"value":'updatedAt desc'}},[_vm._v("最近更新")]),_vm._v(" "),_c('Option',{attrs:{"value":'updatedAt'}},[_vm._v("最近更新(倒序)")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt desc'}},[_vm._v("最新创建")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt'}},[_vm._v("最新创建(倒序)")])],1),_vm._v(" "),_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"success"},on:{"click":_vm.handleFind}},[_vm._v("找回业务系统")]),_vm._v(" "),_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"primary"},on:{"click":_vm.handleCreate}},[_vm._v("新建业务系统")])],1)],1)],1)};
var __vue_staticRenderFns__$16 = [];

  /* style */
  const __vue_inject_styles__$16 = undefined;
  /* scoped */
  const __vue_scope_id__$16 = undefined;
  /* module identifier */
  const __vue_module_identifier__$16 = undefined;
  /* functional template */
  const __vue_is_functional_template__$16 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$16 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$16, staticRenderFns: __vue_staticRenderFns__$16 },
    __vue_inject_styles__$16,
    __vue_script__$15,
    __vue_scope_id__$16,
    __vue_is_functional_template__$16,
    __vue_module_identifier__$16,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$14 = {
  name: 'projectApps',
  components: { appList: __vue_component__$1g },
  data() {
    let projectId = this.$route.params.projectId;
    return {
      projectId,
      tabName: 'myApp',
      search: '',
      hasLoadTab: ['myApp'], // 组件懒加载
      myAppOptions: {
        // 我参与的应用
        page_size: 12,
        total: 1,
        page: 1,
        orderby: 'updatedAt desc',
        filters: ``,
        expand: 'project(title)'
      },
      myAppTabTotal: 0, // 我参与的应用总数
      project: null,
      orderBy: 'updatedAt desc'
    };
  },
  computed: {
    myAppTabLabel() {
      return (h) => {
        return h('div', [
          h('span', this.project.title),
          h('Badge', {
            props: {
              showZero: true,
              count: this.myAppTabTotal,
              type: 'normal'
            }
          })
        ]);
      };
    }
  },
  async mounted() {
    let { data } = await aicService.findProjectById(this.projectId);
    this.project = data;
  },
  watch: {
    search() {
      this.changeQueryOptions();
    },
    orderBy() {
      this.changeQueryOptions();
    },
    tabName() {
      this.changeQueryOptions();
    }
  },
  methods: {
    changeQueryOptions() {
      let filters = [];
      if (this.search) {
        filters.push(`title like '%${this.search}%'`);
      }
      this.myAppOptions.filters = filters.join(' and ');
      this.myAppOptions.page = 1;
      this.myAppOptions.orderby = this.orderBy;
      this.myAppOptions.expand = 'project(title)';
    },
    tabClick(tabName) {
      if (!this.hasLoadTab.some((item) => item === tabName)) {
        this.hasLoadTab.push(tabName);
      }
    },
    loadComponent(tabName) {
      return this.hasLoadTab.some((item) => item === tabName);
    },
    handleClick(item) {
      this.$routerThen
        .push({ name: 'appApply', query: { appId: item.id }, params: { returnUrl: window.location.href } })
        .onChange((result, _vm) => {
          if (result) {
            this.changeQueryOptions();
            this.$refs.appList.reload();
          }
        });
    },
    handleCreate() {
      this.$routerThen
        .push({
          name: 'appCreate',
          params: { returnUrl: window.location.href },
          query: { projectId: this.projectId }
        })
        .onChange((result, _vm) => {
          if (result) {
            this.changeQueryOptions();
            this.$refs.appList.reload();
          }
        });
    },
    handleFind() {
      this.$routerThen
        .push({ name: 'appFind', params: { returnUrl: window.location.href } })
        .onChange((result, _vm) => {
          if (result) {
            this.changeQueryOptions();
            this.$refs.appList.reload();
          }
        });
    }
  }
};

/* script */
const __vue_script__$14 = script$14;

/* template */
var __vue_render__$15 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"app-index"},[_c('Menu',{staticClass:"ivu-mb",attrs:{"mode":"horizontal","active-name":"2"}},[_c('MenuItem',{attrs:{"name":"1","to":{ path: '/apps' }}},[_vm._v(" 应 用 ")]),_vm._v(" "),_c('MenuItem',{attrs:{"name":"2","to":{ path: '/projects' }}},[_vm._v(" 业务系统 ")])],1),_vm._v(" "),_c('Tabs',{on:{"on-click":_vm.tabClick},model:{value:(_vm.tabName),callback:function ($$v) {_vm.tabName=$$v;},expression:"tabName"}},[(_vm.project != null)?_c('TabPane',{attrs:{"label":_vm.myAppTabLabel,"name":"myApp"}},[_c('app-list',{ref:"appList",attrs:{"type":"project_app","query-options":_vm.myAppOptions,"project-id":_vm.projectId,"total":_vm.myAppTabTotal},on:{"update:total":function($event){_vm.myAppTabTotal=$event;},"on-item-click":_vm.handleClick}})],1):_vm._e(),_vm._v(" "),_c('div',{staticClass:"extra",attrs:{"slot":"extra"},slot:"extra"},[_c('Input',{staticClass:"input",attrs:{"search":"","clearable":"","placeholder":"按应用名称搜索"},model:{value:(_vm.search),callback:function ($$v) {_vm.search=$$v;},expression:"search"}}),_vm._v(" "),_c('Select',{staticStyle:{"width":"150px","margin-right":"2px"},attrs:{"placeholder":"选择排序时间"},model:{value:(_vm.orderBy),callback:function ($$v) {_vm.orderBy=$$v;},expression:"orderBy"}},[_c('Option',{attrs:{"value":'updatedAt desc'}},[_vm._v("最近更新")]),_vm._v(" "),_c('Option',{attrs:{"value":'updatedAt'}},[_vm._v("最近更新(倒序)")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt desc'}},[_vm._v("最新创建")]),_vm._v(" "),_c('Option',{attrs:{"value":'createdAt'}},[_vm._v("最新创建(倒序)")])],1),_vm._v(" "),_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"success"},on:{"click":_vm.handleFind}},[_vm._v("找回应用")]),_vm._v(" "),_c('Button',{staticStyle:{"margin-left":"5px"},attrs:{"type":"primary"},on:{"click":_vm.handleCreate}},[_vm._v("新建应用")])],1)],1)],1)};
var __vue_staticRenderFns__$15 = [];

  /* style */
  const __vue_inject_styles__$15 = undefined;
  /* scoped */
  const __vue_scope_id__$15 = undefined;
  /* module identifier */
  const __vue_module_identifier__$15 = undefined;
  /* functional template */
  const __vue_is_functional_template__$15 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$15 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$15, staticRenderFns: __vue_staticRenderFns__$15 },
    __vue_inject_styles__$15,
    __vue_script__$14,
    __vue_scope_id__$15,
    __vue_is_functional_template__$15,
    __vue_module_identifier__$15,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$13 = {
  mounted() {
    let returnUrl = this.$route.params.returnUrl;
    let url = AICConsole.getUrlForCreatePrj(returnUrl);
    window.location.href = url;
  }
};

/* script */
const __vue_script__$13 = script$13;

/* template */
var __vue_render__$14 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
var __vue_staticRenderFns__$14 = [];

  /* style */
  const __vue_inject_styles__$14 = undefined;
  /* scoped */
  const __vue_scope_id__$14 = undefined;
  /* module identifier */
  const __vue_module_identifier__$14 = undefined;
  /* functional template */
  const __vue_is_functional_template__$14 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$14 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$14, staticRenderFns: __vue_staticRenderFns__$14 },
    __vue_inject_styles__$14,
    __vue_script__$13,
    __vue_scope_id__$14,
    __vue_is_functional_template__$14,
    __vue_module_identifier__$14,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$12 = {
  mounted() {
    let returnUrl = this.$route.params.returnUrl;
    let url = AICConsole.getUrlForFindPrj(returnUrl);
    window.location.href = url;
  }
};

/* script */
const __vue_script__$12 = script$12;

/* template */
var __vue_render__$13 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
var __vue_staticRenderFns__$13 = [];

  /* style */
  const __vue_inject_styles__$13 = undefined;
  /* scoped */
  const __vue_scope_id__$13 = undefined;
  /* module identifier */
  const __vue_module_identifier__$13 = undefined;
  /* functional template */
  const __vue_is_functional_template__$13 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$13 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$13, staticRenderFns: __vue_staticRenderFns__$13 },
    __vue_inject_styles__$13,
    __vue_script__$12,
    __vue_scope_id__$13,
    __vue_is_functional_template__$13,
    __vue_module_identifier__$13,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$11 = {
  name: 'adminConsole',
  created() {
    let sideMenus = MenuService.filterSiderMenus('admin'); // 获取当前header对应的侧边栏，跳转到当前侧边栏第一个
    let firstMenu;
    if (sideMenus) {
      firstMenu = sideMenus[0];
      if (firstMenu.children && firstMenu.children.length > 0) {
        firstMenu = firstMenu.children[0];
      }
    }
    if (firstMenu) {
      this.$router.replace({
        path: firstMenu.path
      });
    }
  }
};

/* script */
const __vue_script__$11 = script$11;

/* template */
var __vue_render__$12 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
var __vue_staticRenderFns__$12 = [];

  /* style */
  const __vue_inject_styles__$12 = undefined;
  /* scoped */
  const __vue_scope_id__$12 = undefined;
  /* module identifier */
  const __vue_module_identifier__$12 = undefined;
  /* functional template */
  const __vue_is_functional_template__$12 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$12 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$12, staticRenderFns: __vue_staticRenderFns__$12 },
    __vue_inject_styles__$12,
    __vue_script__$11,
    __vue_scope_id__$12,
    __vue_is_functional_template__$12,
    __vue_module_identifier__$12,
    false,
    undefined,
    undefined,
    undefined
  );

var appsRouter = [
    {
        path: '/apps',
        redirect: '/apps/index',
        meta: {
            auth: true,
            header: 'home'
        },
        component: __vue_component__$1l,
        children: [
            {
                path: 'index',
                name: 'appsList',
                meta: {
                    title: '首页',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$1f
            },
            {
                path: 'create',
                name: 'appCreate',
                meta: {
                    title: '创建应用',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$1e
            },
            {
                path: 'find',
                name: 'appFind',
                meta: {
                    title: '找回应用',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$1d
            },
            {
                path: 'apply',
                name: 'appApply',
                meta: {
                    title: '开通服务',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$1a
            },
            {
                path: ':appId',
                name: 'appEntry',
                meta: {
                    title: '应用入口',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$19
            }
        ]
    },
    {
        path: '/projects',
        redirect: '/projects/index',
        meta: {
            auth: true,
            header: 'home'
        },
        component: __vue_component__$1l,
        children: [
            {
                path: 'index',
                name: 'projectsList',
                meta: {
                    title: '首页',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$16
            },
            {
                path: ':projectId/apps',
                name: 'projectApps',
                meta: {
                    title: '业务系统的应用',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$15
            },
            {
                path: 'create',
                name: 'projectCreate',
                meta: {
                    title: '创建业务系统',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$14
            },
            {
                path: 'find',
                name: 'projectFind',
                meta: {
                    title: '找回业务系统',
                    auth: true,
                    header: 'home'
                },
                component: __vue_component__$13
            }
        ]
    },
    {
        path: '/console',
        name: 'consoleEntry',
        meta: {
            title: '控制台入口',
            auth: true,
            header: 'home'
        },
        component: __vue_component__$12
    }
];

function modalHeight(bias, width) {
    // 获取模式对话框的合适高度
    if (!document.documentElement) {
        return 400;
    }
    var mvueSettings = ConfigHelper.getConfigVal('mvue');
    var defaultPageSideHeight = (mvueSettings && mvueSettings.pageSideHeight) || 220;
    var clientHeight = document.documentElement.clientHeight - defaultPageSideHeight;
    if (bias) {
        clientHeight = clientHeight - bias;
    }
    var maxHeight = clientHeight > 0 ? clientHeight : 400;
    if (width) {
        if (width < 100) {
            width = (document.documentElement.clientWidth * width) / 100;
        }
        var height = (width * 9) / 16;
        if (height > maxHeight) {
            height = maxHeight;
        }
        return height;
    }
    return maxHeight;
}
function modalWidth() {
    if (!document.documentElement) {
        return 70;
    }
    var clientWidth = document.documentElement.clientWidth;
    if (clientWidth < 768) {
        return 90;
    }
    else if (clientWidth < 1200) {
        return 80;
    }
    else if (clientWidth < 1600) {
        return 70;
    }
    else {
        return 60;
    }
}

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

let roleSetting = {
  admin: {
    icon: 'ios-contact',
    sort: 1
  },
  maintainer: {
    icon: 'md-person',
    sort: 2
  }
};
var script$10 = {
  data() {
    return {
      userList: [],
      selfId: Session.getCurrentUser().userId,
      sideHeight: modalHeight(64),
      queryOptions: {
        total: true,
        page_size: 20,
        page: 1,
        filters: `oid eq ${this.$route.params.appId || this.$route.params.projectId}`
      },
      total: -1,
      roleList: [
        { value: 'maintainer', label: '维护者', auth: [] },
        { value: 'admin', label: '管理员', auth: ['manage'] }
      ],
      basePath: this.$route.path.split('member-management')[0] + 'member-management'
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', ['hasAppPerms'])
  },
  async mounted() {
    this.addEventBus();
    await this.loadMember();
    const routerName = this.$route.name;
    //为第一层路由（侧边栏点进来的情况）
    if (routerName == 'memberManagement') {
      if (this.userList.length) {
        //如果query有mid则跳转到mid上 否则跳转第一个
        if (this.$route.query.mid) {
          this.toTargetMember(this.$route.query.mid);
        } else {
          this.toTargetMember();
        }
      } else {
        //跳转引导页
        this.toGuide();
      }
    }
  },
  watch: {
    $route: {
      deep: true,
      handler: function (route) {
        if (route.name == 'memberManagement') {
          if (this.userList.length) {
            //跳转第一个
            this.toTargetMember();
          } else {
            //跳转引导页
            this.toGuide();
          }
        }
      }
    }
  },
  methods: {
    handleReachBottom() {
      // eslint-disable-next-line no-async-promise-executor
      return new Promise(async (resolve) => {
        if (this.total > this.userList.length) {
          this.queryOptions.page++;
          await this.loadMember();
        }
        resolve();
      });
    },
    chkPerm(member) {
      this.roleList.forEach((item) => {
        if (item.value === member.role) {
          if (!this.hasAppPerms(item.auth)) {
            member.disabled = true;
          }
        }
      });
    },
    async loadMember() {
      const { data, headers } = await memberService.query(this.queryOptions);
      this.total = headers['x-total-count'];
      this.initMember(data);
    },
    async initMember(list) {
      let userList = list.map((item) => {
        item = Object.assign(item, roleSetting[item.role]);
        if (item.member && this.selfId == item.member.id) {
          item.disabled = true;
        }
        this.chkPerm(item);
        return item;
      });
      //变化之后全部重新排序
      this.userList = this.userList.concat(userList);
      //this.sortMember(userList);
    },
    sortMember(userList = this.userList) {
      this.userList = _.sortBy(userList, function (item) {
        return item.sort;
      });
    },
    addEventBus() {
      //type data
      this.$eventBus.$on('memberChange', async (type, data) => {
        if (type == 'add') {
          this.initMember(data);
          this.total += data.length;
        } else if (type == 'edit') {
          this.userList.forEach((item) => {
            if (item.mid == data.mid[0]) {
              item.role = data.role;
              item = Object.assign(item, roleSetting[data.role]);
              this.sortMember();
            }
          });
        } else if (type == 'delete') {
          //找到当前所属的index
          let index = -1;
          for (let i = 0; i < this.userList.length; i++) {
            if (this.userList[i].id === data.id) {
              index = i;
              break;
            }
          }
          let content = `<p>即将退出，退出之后将无法再管理该应用！！！请确认是否继续？</p>`;
          //回主页
          this.doRemove(content, data, index, true);
        }
      });
    },
    toGuide() {
      this.$router.push({ path: `${this.basePath}/guide` });
    },
    toTargetMember(id = this.userList[0] && this.userList[0].id) {
      //根据id跳转到目标编辑页面
      if (id) {
        this.changeRouter({ path: `${this.basePath}/edit/${id}` });
      } else {
        this.toGuide();
      }
    },
    changeRouter(router) {
      this.$router.replace(router);
    },
    handleCellClick(id) {
      this.changeRouter({ path: `${this.basePath}/edit/${id}` });
    },
    remove(item, index) {
      //不允许删除自己
      if (item.member && this.selfId == item.member.id) return;
      //没删除权限
      if (item.disabled) return;
      let content = `<p>即将删除${item.role == 'admin' ? '管理员' : '成员'} <strong>${
        item.member ? item.member.name : item.mid
      }</strong>，被删除的成员无法再管理该应用！！！请确认是否继续删除？</p>`;
      this.doRemove(content, item, index);
    },
    doRemove(content, item, index, backToIndex = false) {
      this.$Modal.confirm({
        title: '确认操作',
        content: content,
        onOk: async () => {
          await memberService.remove(item.id);
          this.$Message.success('操作成功');
          this.userList.splice(index, 1);
          this.total--;
          if (backToIndex) {
            this.$router.replace({ name: 'appsList', query: { _clearSid: '1' } });
          } else {
            //如果删除的项为当前路由项
            if (item.id === this.$route.params.id) {
              this.toTargetMember();
            }
          }
        }
      });
    }
  },
  destroyed() {
    this.$eventBus.$off('memberChange');
  }
};

/* script */
const __vue_script__$10 = script$10;

/* template */
var __vue_render__$11 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"bvue-page member"},[_c('b-childheader',{attrs:{"title":"成员管理","subtitle":"成员为应用本身的角色，用于管理应用、对应用进行初始化（可设置多个）","showBack":false}}),_vm._v(" "),_c('div',{staticClass:"bvue-page-body"},[_c('f-double-columns-view',{attrs:{"fixedPartWidth":250}},[_c('template',{slot:"left"},[_c('Card',{attrs:{"padding":0}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("成员管理")]),_vm._v(" "),_c('Icon',{attrs:{"slot":"extra","title":"添加成员","type":"md-add-circle","size":"18","color":_vm.$route.path.includes('create') ? '#2d8cf0' : ''},on:{"click":function($event){return _vm.changeRouter({ path: (_vm.basePath + "/create") })}},slot:"extra"}),_vm._v(" "),_c('Scroll',{attrs:{"height":_vm.sideHeight,"on-reach-bottom":_vm.handleReachBottom,"distance-to-edge":[-24, -24]}},[_c('CellGroup',{on:{"on-click":_vm.handleCellClick}},_vm._l((_vm.userList),function(item,index){return _c('Cell',{key:item.id,attrs:{"title":item.member ? item.member.name : item.mid,"name":item.id,"selected":_vm.$route.params.id == item.id}},[_c('Icon',{attrs:{"slot":"icon","type":item.icon,"color":item.role == 'admin' ? '#ff9900' : '',"size":item.size},slot:"icon"}),_vm._v(" "),_c('Tooltip',{attrs:{"slot":"extra","content":item.disabled ? '不允许删除' : '删除',"transfer":"","placement":"top-start"},slot:"extra"},[_c('Icon',{class:{ disabled: item.disabled },attrs:{"type":"md-remove-circle","size":16},on:{"click":function($event){$event.stopPropagation();return _vm.remove(item, index)}}})],1)],1)}),1)],1)],1)],1),_vm._v(" "),_c('template',{slot:"right"},[_c('router-view',{key:_vm.$route.params.id,attrs:{"base-path":_vm.basePath}})],1)],2)],1)],1)};
var __vue_staticRenderFns__$11 = [];

  /* style */
  const __vue_inject_styles__$11 = function (inject) {
    if (!inject) return
    inject("data-v-6ac610f6_0", { source: ".member[data-v-6ac610f6] .ivu-cell-item{display:flex;align-items:center}.member[data-v-6ac610f6] .ivu-card-extra{top:14px}.member[data-v-6ac610f6] .ivu-cell-main{flex:1;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;word-break:break-all}.member[data-v-6ac610f6] .ivu-cell-title{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;word-break:break-all}.member[data-v-6ac610f6] .ivu-cell-footer{position:relative;transform:none;top:0;right:0}.member[data-v-6ac610f6] ::-webkit-scrollbar-track-piece{background-color:#fff}.member[data-v-6ac610f6] ::-webkit-scrollbar{width:3px;height:3px}.member[data-v-6ac610f6] ::-webkit-scrollbar-thumb{background-color:#808695;background-clip:padding-box;min-height:28px}.member[data-v-6ac610f6] ::-webkit-scrollbar-thumb:hover{background-color:#bbb}.disabled[data-v-6ac610f6]{color:#ccc;cursor:not-allowed}.ivu-icon-md-add-circle[data-v-6ac610f6]{cursor:pointer}.ivu-icon-md-add-circle[data-v-6ac610f6]:hover{color:#2d8cf0}.ivu-cell[data-v-6ac610f6]{padding:7px 14px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$11 = "data-v-6ac610f6";
  /* module identifier */
  const __vue_module_identifier__$11 = undefined;
  /* functional template */
  const __vue_is_functional_template__$11 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$11 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$11, staticRenderFns: __vue_staticRenderFns__$11 },
    __vue_inject_styles__$11,
    __vue_script__$10,
    __vue_scope_id__$11,
    __vue_is_functional_template__$11,
    __vue_module_identifier__$11,
    false,
    createInjector,
    undefined,
    undefined
  );

var formMixins$1 = {
  data() {
    return {
      form: {
        role: 'admin', //admin
        oid: '', //appId
        mid: '', //memberId
        objectType: 'app', //app 应用 proj 系统
        memberType: 'u',
        selectUserName: ''
      },
      roleList: [
        { value: 'maintainer', label: '维护者', auth: [] },
        { value: 'admin', label: '管理员', auth: ['manage'] }
      ],
      rules: {
        selectUserName: [{ required: true, message: '请选择成员', trigger: 'change' }],
        role: [{ required: true, message: '请选择成员角色', trigger: 'blur' }]
      }
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', ['hasAppPerms']),
    ...mapGetters$1('fuse/app', {
      app: 'current'
    })
  }
};

//
let initForm = () => {
  return {
    role: 'admin', //admin
    oid: '', //appId
    mid: [], //memberId
    objectType: 'app', //app 应用 proj 系统
    memberType: 'u',
    selectUserName: ''
  };
};
var script$$ = {
  mixins: [formMixins$1],
  data() {
    return {
      disableUsers: [],
      form: initForm(),
      memberList: [],
      initIngForm: false
    };
  },
  mounted() {
    this.initDisableUsers();
  },
  methods: {
    async initDisableUsers() {
      const { data } = await memberService.getMemberIds(this.$route.params.appId);
      this.disableUsers = data;
    },
    handleSubmit(name) {
      this.$refs[name].validate(async (valid) => {
        if (valid) {
          const { role, objectType, memberType } = this.form;
          this.memberList.forEach((item) => {
            item.role = role;
            item.objectType = objectType;
            item.memberType = memberType;
            item.oid = this.$route.params.appId;
          });
          try {
            let { data } = await memberService.save(this.memberList);
            data.forEach((item, index) => {
              item.member = { name: this.memberList[index].mName };
              this.disableUsers.push(item.mid);
            });
            this.$Message.success('保存成功');

            //保存成功之后清空数据
            //解决change之后爆红问题
            this.initIngForm = true;
            this.form = initForm();
            this.$nextTick(() => {
              this.initIngForm = false;
            });

            this.$eventBus.$emit('memberChange', 'add', data);
          } catch (error) {
            //失败要让按钮变成可以点击状态
            this.$refs.fButton.innerDisabled = false;
          }
        }
      });
    },
    handleOnUserChanged(val, details) {
      let nameList = [];
      this.memberList = [];
      for (const userId in details) {
        this.memberList.push({
          mid: userId,
          mName: details[userId].name
        });
        nameList.push(details[userId].name);
      }
      this.form.selectUserName = nameList.join(',');
    }
  }
};

/* script */
const __vue_script__$$ = script$$;

/* template */
var __vue_render__$10 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{attrs:{"padding":16}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("创建成员")]),_vm._v(" "),_c('Form',{ref:"formRef",attrs:{"label-width":120,"model":_vm.form,"rules":_vm.rules},nativeOn:{"submit":function($event){$event.preventDefault();}}},[_c('FormItem',{attrs:{"label":"应用名称","required":""}},[_c('Input',{attrs:{"value":_vm.app.title,"disabled":"","placeholder":"请输入应用名称"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员名称","prop":"selectUserName"}},[_c('f-member-select',{attrs:{"global-query-options":{ user: { filters: "userType ne 'virtual'" } },"disabled-value":_vm.disableUsers,"multiple":""},on:{"on-change":_vm.handleOnUserChanged},model:{value:(_vm.form.mid),callback:function ($$v) {_vm.$set(_vm.form, "mid", $$v);},expression:"form.mid"}},[(!_vm.initIngForm)?_c('Input',{attrs:{"readonly":"","placeholder":"请选择成员名称"},model:{value:(_vm.form.selectUserName),callback:function ($$v) {_vm.$set(_vm.form, "selectUserName", $$v);},expression:"form.selectUserName"}}):_vm._e()],1)],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员角色","prop":"role"}},[_c('template',{slot:"label"},[_vm._t("label",[_vm._v("成员角色\n          "),_c('f-info-tip',{attrs:{"content":"管理该应用的角色设置，如对应用进行初始化设置的管理员等"}})])],2),_vm._v(" "),_c('Select',{attrs:{"placeholder":"请选择成员角色"},model:{value:(_vm.form.role),callback:function ($$v) {_vm.$set(_vm.form, "role", $$v);},expression:"form.role"}},[_vm._l((_vm.roleList),function(item){return [(_vm.hasAppPerms(item.auth))?_c('Option',{key:item.value,attrs:{"value":item.value}},[_vm._v(_vm._s(item.label))]):_vm._e()]})],2)],2),_vm._v(" "),_c('FormItem',[_c('f-button',{ref:"fButton",attrs:{"type":"primary","model":_vm.form},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")])],1)],1)],1)};
var __vue_staticRenderFns__$10 = [];

  /* style */
  const __vue_inject_styles__$10 = undefined;
  /* scoped */
  const __vue_scope_id__$10 = undefined;
  /* module identifier */
  const __vue_module_identifier__$10 = undefined;
  /* functional template */
  const __vue_is_functional_template__$10 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$10 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$10, staticRenderFns: __vue_staticRenderFns__$10 },
    __vue_inject_styles__$10,
    __vue_script__$$,
    __vue_scope_id__$10,
    __vue_is_functional_template__$10,
    __vue_module_identifier__$10,
    false,
    undefined,
    undefined,
    undefined
  );

Vue.prototype.$isServer;
// 判断参数是否是其中之一
function oneOf(value, validList) {
  for (let i = 0; i < validList.length; i++) {
    if (value === validList[i]) {
      return true;
    }
  }
  return false;
}

const SPECIAL_CHARS_REGEXP = /([:\-_]+(.))/g;
const MOZ_HACK_REGEXP = /^moz([A-Z])/;

function camelCase(name) {
  return name
    .replace(SPECIAL_CHARS_REGEXP, function (_, separator, letter, offset) {
      return offset ? letter.toUpperCase() : letter;
    })
    .replace(MOZ_HACK_REGEXP, 'Moz$1');
}
// getStyle
function getStyle$1(element, styleName) {
  if (!element || !styleName) return null;
  styleName = camelCase(styleName);
  if (styleName === 'float') {
    styleName = 'cssFloat';
  }
  try {
    const computed = document.defaultView.getComputedStyle(element, '');
    return element.style[styleName] || computed ? computed[styleName] : null;
  } catch (e) {
    return element.style[styleName];
  }
}

// Find components upward
function findComponentUpward(context, componentName, componentNames) {
  if (typeof componentName === 'string') {
    componentNames = [componentName];
  } else {
    componentNames = componentName;
  }

  let parent = context.$parent;
  let name = parent.$options.name;
  while (parent && (!name || componentNames.indexOf(name) < 0)) {
    parent = parent.$parent;
    if (parent) name = parent.$options.name;
  }
  return parent;
}

// Find components downward
function findComponentsDownward(context, componentName) {
  return context.$children.reduce((components, child) => {
    if (child.$options.name === componentName) components.push(child);
    const foundChilds = findComponentsDownward(child, componentName);
    return components.concat(foundChilds);
  }, []);
}

/* istanbul ignore next */
const trim = function (string) {
  return (string || '').replace(/^[\s\uFEFF]+|[\s\uFEFF]+$/g, '');
};

/* istanbul ignore next */
function hasClass(el, cls) {
  if (!el || !cls) return false;
  if (cls.indexOf(' ') !== -1) throw new Error('className should not contain space.');
  if (el.classList) {
    return el.classList.contains(cls);
  } else {
    return (' ' + el.className + ' ').indexOf(' ' + cls + ' ') > -1;
  }
}

/* istanbul ignore next */
function addClass(el, cls) {
  if (!el) return;
  let curClass = el.className;
  const classes = (cls || '').split(' ');

  for (let i = 0, j = classes.length; i < j; i++) {
    const clsName = classes[i];
    if (!clsName) continue;

    if (el.classList) {
      el.classList.add(clsName);
    } else {
      if (!hasClass(el, clsName)) {
        curClass += ' ' + clsName;
      }
    }
  }
  if (!el.classList) {
    el.className = curClass;
  }
}

/* istanbul ignore next */
function removeClass(el, cls) {
  if (!el || !cls) return;
  const classes = cls.split(' ');
  let curClass = ' ' + el.className + ' ';

  for (let i = 0, j = classes.length; i < j; i++) {
    const clsName = classes[i];
    if (!clsName) continue;

    if (el.classList) {
      el.classList.remove(clsName);
    } else {
      if (hasClass(el, clsName)) {
        curClass = curClass.replace(' ' + clsName + ' ', ' ');
      }
    }
  }
  if (!el.classList) {
    el.className = trim(curClass);
  }
}

var formItemChanged = {
  data() {
    return {
      formItems: []
    };
  },
  methods: {
    /**
     * 清理表单项变更状态
     * @param {string} formId 指定要清理的表单id，如果组件同时包含多个Form组件，需要在每个Form组件设置id属性
     */
    resetFormItems(formId) {
      let _formItems = this.formItems;
      if (formId) {
        _formItems = _$1.filter(_formItems, (formItem) => {
          return formItem.FormInstance.$attrs.id === formId;
        });
      }
      _$1.forEach(_formItems, (formItem) => {
        let labels = formItem.$el.getElementsByTagName('label');
        let label = labels && labels.length && labels[0];
        label && removeClass(label, 'fuse-form-item-changed');
      });
    },
    handleOnFormItemAdded(formItem) {
      this.formItems.push(formItem);
      formItem.onFieldChange = () => {
        this.$nextTick(() => {
          let labels = formItem.$el.getElementsByTagName('label');
          let label = labels && labels.length && labels[0];
          label && addClass(label, 'fuse-form-item-changed');
        });
        if (formItem.validateDisabled) {
          formItem.validateDisabled = false;
          return;
        }
        formItem.validate('change');
      };
    }
  }
};

//
var script$_ = {
  mixins: [formMixins$1, formItemChanged],
  data() {
    return {
      spinShow: true,
      user: {},
      hasPerm: true,
      authRoleList: [],
      selfId: Session.getCurrentUser().userId,
      isOwn: false,
      isLastAdmin: false
    };
  },
  async mounted() {
    this.getMember(this.$route.params.id);
  },
  computed: {
    initComplete() {
      return !this.spinShow && this.form.selectUserName;
    }
  },
  methods: {
    async getMember(id) {
      const res = await memberService.get(id);
      const { role, mid } = res.data;
      this.user = res.data;
      this.form.role = role;
      this.form.mid = [mid];
      this.isOwn = this.selfId === this.user.mid ? true : false;
      if (this.isOwn) {
        //判断是不是最后一个管理员 是的话不给删除
        const { data } = await memberService.adminCount(this.$route.params.appId || this.$route.params.projectId);
        this.isLastAdmin = data === 1 ? true : false;
      }
      this.chkPerm();
      this.spinShow = false;
    },
    handleSubmit(name) {
      this.$refs[name].validate(async (valid) => {
        if (valid) {
          await memberService.update(this.$route.params.id, this.form);
          this.$eventBus.$emit('memberChange', 'edit', this.form);
          this.resetFormItems();
          this.$Message.success('保存成功');
        }
      });
    },
    handleOnUserChanged(val, details) {
      this.form.selectUserName = details[val] && details[val].name;
    },
    chkPerm() {
      this.roleList.forEach((item) => {
        if (item.value === this.form.role) {
          this.authRoleList.push(item);
          if (!this.hasAppPerms(item.auth)) {
            this.hasPerm = false;
          }
        } else {
          if (this.hasAppPerms(item.auth)) {
            this.authRoleList.push(item);
          }
        }
      });
    },
    async exit() {
      //如果是最后一名管理员 删除失败
      const { data } = await memberService.adminCount(this.$route.params.appId || this.$route.params.projectId);
      if (data === 1) {
        this.$Message.error('删除失败，应用不能没有管理员');
        return;
      }
      this.$eventBus.$emit('memberChange', 'delete', Object.assign(this.form, { id: this.$route.params.id }));
    }
  }
};

/* script */
const __vue_script__$_ = script$_;

/* template */
var __vue_render__$$ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{attrs:{"padding":16}},[(_vm.spinShow)?_c('Spin',{attrs:{"fix":""}}):_vm._e(),_vm._v(" "),_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("编辑成员")]),_vm._v(" "),(!_vm.spinShow)?_c('Form',{ref:"formRef",attrs:{"label-width":120,"model":_vm.form,"rules":_vm.rules},on:{"on-form-item-add":_vm.handleOnFormItemAdded}},[_c('FormItem',{attrs:{"label":"应用名称","required":""}},[_c('Input',{attrs:{"value":_vm.app.title,"disabled":"","placeholder":"请输入应用名称"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员名称"}},[(_vm.user.member)?_c('f-member-select',{attrs:{"disabled":true},on:{"on-change":_vm.handleOnUserChanged},model:{value:(_vm.form.mid),callback:function ($$v) {_vm.$set(_vm.form, "mid", $$v);},expression:"form.mid"}},[_c('Input',{attrs:{"value":_vm.form.selectUserName,"disabled":""}})],1):_c('Input',{attrs:{"value":_vm.form.mid,"disabled":""}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员角色","prop":"role"}},[_c('template',{slot:"label"},[_vm._t("label",[_vm._v("成员角色\n          "),_c('f-info-tip',{attrs:{"content":"管理该应用的角色设置，如对应用进行初始化设置的管理员等"}})])],2),_vm._v(" "),_c('Select',{attrs:{"disabled":!_vm.hasPerm || _vm.isOwn,"placeholder":"请选择成员角色"},model:{value:(_vm.form.role),callback:function ($$v) {_vm.$set(_vm.form, "role", $$v);},expression:"form.role"}},_vm._l((_vm.authRoleList),function(item){return _c('Option',{key:item.value,attrs:{"value":item.value}},[_vm._v(_vm._s(item.label))])}),1)],2),_vm._v(" "),(_vm.initComplete)?_c('FormItem',[(!_vm.isOwn)?_c('f-button',{attrs:{"type":"primary","model":_vm.form},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")]):_vm._e(),_vm._v(" "),(_vm.isOwn)?_c('Button',{attrs:{"type":"error","disabled":_vm.isLastAdmin},on:{"click":_vm.exit}},[_vm._v("退出")]):_vm._e()],1):_vm._e()],1):_vm._e()],1)};
var __vue_staticRenderFns__$$ = [];

  /* style */
  const __vue_inject_styles__$$ = undefined;
  /* scoped */
  const __vue_scope_id__$$ = undefined;
  /* module identifier */
  const __vue_module_identifier__$$ = undefined;
  /* functional template */
  const __vue_is_functional_template__$$ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$$ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$$, staticRenderFns: __vue_staticRenderFns__$$ },
    __vue_inject_styles__$$,
    __vue_script__$_,
    __vue_scope_id__$$,
    __vue_is_functional_template__$$,
    __vue_module_identifier__$$,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//

var script$Z = {
  props: {
    basePath: {
      type: String
    }
  },
  methods: {
    jump() {
      this.$router.push({ path: `${this.basePath}/create` });
    }
  }
};

/* script */
const __vue_script__$Z = script$Z;

/* template */
var __vue_render__$_ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{staticClass:"card",attrs:{"padding":16},nativeOn:{"click":function($event){return _vm.jump($event)}}},[_c('Alert',{attrs:{"type":"warning"}},[_c('Icon',{attrs:{"type":"md-bulb"}}),_vm._v(" 成员为应用本身的使用者/管理者，用于管理应用或对应用进行初始化的用户\n  ")],1),_vm._v(" "),_c('PageHeader',{staticClass:"header"},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("手工创建")]),_vm._v(" "),_c('Icon',{attrs:{"slot":"logo","type":"md-list-box","size":35,"color":"#2d8cf0"},slot:"logo"}),_vm._v(" "),_c('div',{attrs:{"slot":"content"},slot:"content"},[_vm._v("提供图形化界面，简单快速创建应用成员")])],1)],1)};
var __vue_staticRenderFns__$_ = [];

  /* style */
  const __vue_inject_styles__$_ = function (inject) {
    if (!inject) return
    inject("data-v-a2c6df16_0", { source: ".card[data-v-a2c6df16]{cursor:pointer}.ivu-page-header[data-v-a2c6df16]{margin:25px 10px;padding:10px 0 10px 30px;border:1px solid #5cadff}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$_ = "data-v-a2c6df16";
  /* module identifier */
  const __vue_module_identifier__$_ = undefined;
  /* functional template */
  const __vue_is_functional_template__$_ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$_ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$_, staticRenderFns: __vue_staticRenderFns__$_ },
    __vue_inject_styles__$_,
    __vue_script__$Z,
    __vue_scope_id__$_,
    __vue_is_functional_template__$_,
    __vue_module_identifier__$_,
    false,
    createInjector,
    undefined,
    undefined
  );

//旧版代码 有使用 不易删除
var memberRouter$1 = {
    path: 'member-management',
    name: 'memberManagement',
    meta: {
        title: '成员管理',
        auth: appService$2.authFilter(['read'])
    },
    component: __vue_component__$11,
    children: [
        {
            path: 'create',
            meta: {
                title: '新增成员'
            },
            component: __vue_component__$10
        },
        {
            path: 'edit/:id',
            meta: {
                title: '编辑成员'
            },
            component: __vue_component__$$
        },
        {
            path: 'guide',
            meta: {
                title: '引导页'
            },
            component: __vue_component__$_
        }
    ]
};

//
var script$Y = {
  data() {
    return {
      modalShow: false,
      form: {
        role: '', //admin
        oid: '', //appId
        mid: [], //memberId
        objectType: 'app', //app 应用 proj 系统
        memberType: 'u',
        selectUserName: ''
      },
      roleList: [
        { value: 'maintainer', label: '维护者', auth: [] },
        { value: 'admin', label: '管理员', auth: ['manage'] }
      ],
      rules: {
        selectUserName: [{ required: true, message: '请选择成员', trigger: 'change' }],
        role: [{ required: true, message: '请选择成员角色', trigger: 'blur' }]
      },
      disableUsers: [],
      memberList: []
    };
  },
  props: {
    appId: {
      type: String
    },
    appMemberCount: {
      type: Number,
      default: 0
    }
  },
  computed: {
    ...mapGetters$1('fuse/app', ['hasAppPerms']),
    ...mapGetters$1('fuse/app', {
      app: 'current'
    })
  },
  methods: {
    show() {
      this.modalShow = true;
      this.initDisableUsers();
    },
    cancel() {
      this.modalShow = false;
      this.$refs['formRef'].resetFields();
    },
    async initDisableUsers() {
      const { data } = await memberService.getMemberIds(this.$route.params.appId);
      this.disableUsers = data;
    },
    handleSubmit(name) {
      this.$refs[name].validate(async (valid) => {
        if (valid) {
          const { role, objectType, memberType } = this.form;
          this.memberList.forEach((item) => {
            item.role = role;
            item.objectType = objectType;
            item.memberType = memberType;
            item.oid = this.$route.params.appId;
          });
          try {
            await memberService.save(this.memberList);
            this.$Message.success('保存成功');
            this.cancel();
            this.form.mid = [];
            this.$emit('on-success');
          } catch (error) {
            //失败要让按钮变成可以点击状态
            this.$refs.fButton.innerDisabled = false;
          }
        }
      });
    },
    handleOnUserChanged(val, details) {
      let nameList = [];
      this.memberList = [];
      for (const userId in details) {
        this.memberList.push({
          mid: userId,
          mName: details[userId].name
        });
        nameList.push(details[userId].name);
      }
      this.form.selectUserName = nameList.join(',');
    }
  }
};

/* script */
const __vue_script__$Y = script$Y;

/* template */
var __vue_render__$Z = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Modal',{attrs:{"title":"添加成员"},model:{value:(_vm.modalShow),callback:function ($$v) {_vm.modalShow=$$v;},expression:"modalShow"}},[_c('Form',{ref:"formRef",attrs:{"label-width":110,"model":_vm.form,"rules":_vm.rules},nativeOn:{"submit":function($event){$event.preventDefault();}}},[_c('FormItem',{attrs:{"label":"应用名称","required":""}},[_c('Input',{attrs:{"value":_vm.app && _vm.app.title,"disabled":"","placeholder":"请输入应用名称"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员名称","prop":"selectUserName"}},[(_vm.modalShow)?_c('f-member-select',{attrs:{"global-query-options":{ user: { filters: "userType ne 'virtual'" } },"disabled-value":_vm.disableUsers,"multiple":""},on:{"on-change":_vm.handleOnUserChanged},model:{value:(_vm.form.mid),callback:function ($$v) {_vm.$set(_vm.form, "mid", $$v);},expression:"form.mid"}},[_c('Input',{attrs:{"readonly":"","placeholder":"请选择成员名称"},model:{value:(_vm.form.selectUserName),callback:function ($$v) {_vm.$set(_vm.form, "selectUserName", $$v);},expression:"form.selectUserName"}})],1):_vm._e()],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员角色","prop":"role"}},[_c('template',{slot:"label"},[_vm._t("label",[_vm._v("成员角色\n          "),_c('f-info-tip',{attrs:{"content":"管理该应用的角色设置，如对应用进行初始化设置的管理员等"}})])],2),_vm._v(" "),_c('RadioGroup',{model:{value:(_vm.form.role),callback:function ($$v) {_vm.$set(_vm.form, "role", $$v);},expression:"form.role"}},[_vm._l((_vm.roleList),function(item){return [(_vm.hasAppPerms(item.auth) || _vm.appMemberCount === 0)?_c('Radio',{key:item.value,attrs:{"value":item.value,"label":item.value}},[_vm._v(_vm._s(item.label))]):_vm._e()]})],2)],2)],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":_vm.cancel}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")])],1)],1)};
var __vue_staticRenderFns__$Z = [];

  /* style */
  const __vue_inject_styles__$Z = undefined;
  /* scoped */
  const __vue_scope_id__$Z = undefined;
  /* module identifier */
  const __vue_module_identifier__$Z = undefined;
  /* functional template */
  const __vue_is_functional_template__$Z = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$Z = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$Z, staticRenderFns: __vue_staticRenderFns__$Z },
    __vue_inject_styles__$Z,
    __vue_script__$Y,
    __vue_scope_id__$Z,
    __vue_is_functional_template__$Z,
    __vue_module_identifier__$Z,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$X = {
  data() {
    return {
      modalShow: false,
      spinShow: true,
      user: {},
      hasPerm: true,
      authRoleList: [],
      selfId: Session.getCurrentUser().userId,
      isOwn: false,
      isLastAdmin: false,
      roleList: [
        { value: 'maintainer', label: '维护者', auth: [] },
        { value: 'admin', label: '管理员', auth: ['manage'] }
      ],
      rules: {
        selectUserName: [{ required: true, message: '请选择成员', trigger: 'change' }],
        role: [{ required: true, message: '请选择成员角色', trigger: 'blur' }]
      },
      form: {
        role: 'admin', //admin
        oid: '', //appId
        mid: [], //memberId
        objectType: 'app', //app 应用 proj 系统
        memberType: 'u',
        selectUserName: ''
      }
    };
  },
  props: {
    appId: {
      type: String
    }
  },
  computed: {
    ...mapGetters$1('fuse/app', ['hasAppPerms']),
    ...mapGetters$1('fuse/app', {
      app: 'current'
    }),
    initComplete() {
      return !this.spinShow && this.form.selectUserName;
    }
  },
  methods: {
    show(item) {
      this.getMember(item);
      this.modalShow = true;
    },
    cancel() {
      this.modalShow = false;
      this.$refs['formRef'].resetFields();
    },
    async getMember(item) {
      const { role, mid } = item;
      this.user = item;
      this.form.role = role;
      this.form.mid = [mid];
      this.isOwn = this.selfId === this.user.mid ? true : false;
      if (this.isOwn) {
        //判断是不是最后一个管理员 是的话不给删除
        const { data } = await memberService.adminCount(this.$route.params.appId || this.$route.params.projectId);
        this.isLastAdmin = data === 1 ? true : false;
      }
      this.chkPerm();
      this.spinShow = false;
    },
    handleSubmit(name) {
      this.$refs[name].validate(async (valid) => {
        if (valid) {
          await memberService.update(this.user.id, this.form);
          this.$emit('on-success');
          this.cancel();
          this.$Message.success('保存成功');
        }
      });
    },
    handleOnUserChanged(val, details) {
      this.form.selectUserName = details[val] && details[val].name;
    },
    chkPerm() {
      this.authRoleList = [];
      this.roleList.forEach((item) => {
        if (item.value === this.form.role) {
          this.authRoleList.push(item);
          if (!this.hasAppPerms(item.auth)) {
            this.hasPerm = false;
          }
        } else {
          if (this.hasAppPerms(item.auth)) {
            this.authRoleList.push(item);
          }
        }
      });
    },
    async exit() {
      //如果是最后一名管理员 删除失败
      const { data } = await memberService.adminCount(this.$route.params.appId || this.$route.params.projectId);
      if (data === 1) {
        this.$Message.error('删除失败，应用不能没有管理员');
        return;
      }
      this.$emit('on-success');
    }
  }
};

/* script */
const __vue_script__$X = script$X;

/* template */
var __vue_render__$Y = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Modal',{attrs:{"title":"编辑成员"},model:{value:(_vm.modalShow),callback:function ($$v) {_vm.modalShow=$$v;},expression:"modalShow"}},[(!_vm.spinShow)?_c('Form',{ref:"formRef",attrs:{"label-width":120,"model":_vm.form,"rules":_vm.rules}},[_c('FormItem',{attrs:{"label":"应用名称","required":""}},[_c('Input',{attrs:{"value":_vm.app.title,"disabled":"","placeholder":"请输入应用名称"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员名称"}},[(_vm.user.member)?_c('f-member-select',{attrs:{"disabled":true},on:{"on-change":_vm.handleOnUserChanged},model:{value:(_vm.form.mid),callback:function ($$v) {_vm.$set(_vm.form, "mid", $$v);},expression:"form.mid"}},[_c('Input',{attrs:{"value":_vm.form.selectUserName,"disabled":""}})],1):_c('Input',{attrs:{"value":_vm.form.mid,"disabled":""}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"成员角色","prop":"role"}},[_c('template',{slot:"label"},[_vm._t("label",[_vm._v("成员角色\n          "),_c('f-info-tip',{attrs:{"content":"管理该应用的角色设置，如对应用进行初始化设置的管理员等"}})])],2),_vm._v(" "),_c('Select',{attrs:{"disabled":!_vm.hasPerm || _vm.isOwn,"placeholder":"请选择成员角色"},model:{value:(_vm.form.role),callback:function ($$v) {_vm.$set(_vm.form, "role", $$v);},expression:"form.role"}},_vm._l((_vm.authRoleList),function(item){return _c('Option',{key:item.value,attrs:{"value":item.value}},[_vm._v(_vm._s(item.label))])}),1)],2)],1):_vm._e(),_vm._v(" "),(_vm.initComplete)?_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":_vm.cancel}},[_vm._v("取消")]),_vm._v(" "),(_vm.isOwn)?_c('Button',{attrs:{"type":"error","disabled":_vm.isLastAdmin},on:{"click":_vm.exit}},[_vm._v("退出")]):_vm._e(),_vm._v(" "),(!_vm.isOwn)?_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")]):_vm._e()],1):_vm._e()],1)};
var __vue_staticRenderFns__$Y = [];

  /* style */
  const __vue_inject_styles__$Y = undefined;
  /* scoped */
  const __vue_scope_id__$Y = undefined;
  /* module identifier */
  const __vue_module_identifier__$Y = undefined;
  /* functional template */
  const __vue_is_functional_template__$Y = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$Y = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$Y, staticRenderFns: __vue_staticRenderFns__$Y },
    __vue_inject_styles__$Y,
    __vue_script__$X,
    __vue_scope_id__$Y,
    __vue_is_functional_template__$Y,
    __vue_module_identifier__$Y,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$W = {
  components: {
    CreateModal: __vue_component__$Z,
    EditModal: __vue_component__$Y
  },
  data() {
    return {
      appId: this.$route.params.appId,
      columns: [
        {
          type: 'index',
          width: 60,
          align: 'center'
        },
        {
          title: '用户',
          slot: 'user'
        },
        {
          title: '角色',
          key: 'role',
          slot: 'role'
        },
        {
          title: '添加时间',
          slot: 'createdAt',
          sortable: true
        },
        {
          title: '操作',
          slot: 'action',
          align: 'center',
          width: 120
        }
      ],
      roleMap: {
        admin: '应用管理员',
        maintainer: '应用维护者'
      },
      roleList: [
        { value: 'maintainer', label: '维护者', auth: [] },
        { value: 'admin', label: '管理员', auth: ['manage'] }
      ],
      roleType: '',
      inputVal: '',
      isAdmin: true,
      memberList: []
    };
  },
  computed: {
    ...mapState('admin/user', ['info']),
    ...mapGetters$1('fuse/app', ['hasAppPerms'])
  },
  created() {
    this.initSeltInfo();
  },
  methods: {
    async initSeltInfo() {
      const { data } = await appService$2.getAppMember(this.appId, {
        filters: `mid eq ${this.info.userId} and role eq 'admin'`,
        limit: 1
      });
      this.isAdmin = data.length > 0;
    },
    handleCreate() {
      this.$refs.createModal.show();
    },
    edit(row) {
      if (!this.isAdmin || (row.member && this.info.userId == row.member.id)) return;
      if (!this.isAdmin || row.disabled) return;
      this.$refs.editModal.show(_.cloneDeep(row));
    },
    del(item) {
      //不允许删除自己
      if (item.member && this.info.userId == item.member.id) return;
      if (!this.isAdmin || item.disabled) return;
      let content = `<p>即将删除${item.role == 'admin' ? '管理员' : '成员'} <strong>${
        item.member ? item.member.name : item.mid
      }</strong>，被删除的成员无法再管理该应用！！！请确认是否继续删除？</p>`;
      this.$Modal.confirm({
        title: '确认操作',
        content: content,
        onOk: async () => {
          await memberService.delete(item.id);
          this.$Message.success('操作成功');
          this.reload();
        }
      });
    },
    canDelete(row) {
      if (!row.member) {
        return false;
      }
      //不能删除自己 身份信息为管理员的
      if (this.info.userId === row.member.id) {
        return false;
      }
      if (!this.hasPerm(row)) {
        return false;
      }
      return true;
    },
    hasPerm(member) {
      for (let i = 0; i < this.roleList.length; i++) {
        let item = this.roleList[i];
        if (item.value === member.role) {
          if (this.hasAppPerms(item.auth)) {
            return true;
          }
        }
      }
      return false;
    },
    onRadioChange() {
      this.reload();
    },
    reload() {
      this.$refs.listInst.doReload(true);
    },
    query(ctx) {
      let filters;
      if (this.roleType) {
        filters = `oid eq ${this.appId} and role eq ${this.roleType}`;
      } else {
        filters = `oid eq ${this.appId}`;
      }
      filters += ' and object_type eq app';
      const query = {
        page: ctx.currentPage,
        page_size: ctx.currentPageSize,
        total: true,
        filters: filters,
        search: decodeURIComponent(this.inputVal) || null
      };
      return new Promise((resolve) => {
        appService$2.getAppMember(this.appId, query).then((res) => {
          this.memberList = res.data;
          res.data.forEach((item) => {
            item.disabled = !this.canDelete(item);
          });
          resolve({ data: res.data, total: Number(res.headers['x-total-count']) });
        });
      });
    }
  }
};

/* script */
const __vue_script__$W = script$W;

/* template */
var __vue_render__$X = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('m-table',{ref:"listInst",attrs:{"show-config-columns-btn":false,"columns":_vm.columns,"query":_vm.query},scopedSlots:_vm._u([{key:"user",fn:function(ref){
var row = ref.row;
return [(row.member)?[_c('f-user-tool-tip',{attrs:{"id":row.member.id,"user-info":row.member}},[_vm._v("\n          "+_vm._s(row.member.name)+"\n          "),(row.member.isDeleted)?_c('Tag',[_vm._v("删")]):_vm._e()],1)]:_c('span',[_vm._v(_vm._s(row.mid))])]}},{key:"createdAt",fn:function(ref){
var row = ref.row;
return [_c('Time',{attrs:{"time":row.createdAt,"type":"datetime"}})]}},{key:"role",fn:function(ref){
var row = ref.row;
return [_vm._v("\n      "+_vm._s(_vm.roleMap[row.role] || '其他')+"\n    ")]}},{key:"action",fn:function(ref){
var row = ref.row;
return [(row.member)?[_c('Icon',{class:[
            'mr-sm',
            !_vm.isAdmin || row.member.id === _vm.info.userId || row.member.isDeleted ? 'icon-not-allow' : 'icon-allow'
          ],attrs:{"size":"16","type":"md-create","color":"#2d8cf0","title":"编辑"},on:{"click":function($event){return _vm.edit(row)}}}),_vm._v(" "),_c('Icon',{class:[_vm.isAdmin && _vm.info.userId != row.member.id ? 'icon-allow' : 'icon-not-allow'],attrs:{"type":"md-trash","size":"16","title":"删除"},on:{"click":function($event){return _vm.del(row)}}})]:_vm._e()]}}])},[_c('div',{staticClass:"display-inline",attrs:{"slot":"header-right"},slot:"header-right"},[(_vm.isAdmin || _vm.memberList.length === 0)?_c('Button',{staticClass:"mr-sm",attrs:{"type":"primary","icon":"md-add"},on:{"click":_vm.handleCreate}},[_vm._v("添加成员")]):_vm._e(),_vm._v(" "),_c('Input',{directives:[{name:"debounce",rawName:"v-debounce",value:([_vm.reload, "input", 300]),expression:"[reload, `input`, 300]"}],staticStyle:{"width":"270px"},attrs:{"placeholder":"根据用户名称搜索"},model:{value:(_vm.inputVal),callback:function ($$v) {_vm.inputVal=$$v;},expression:"inputVal"}}),_vm._v(" "),_c('RadioGroup',{staticClass:"ml-sm",on:{"on-change":_vm.onRadioChange},model:{value:(_vm.roleType),callback:function ($$v) {_vm.roleType=$$v;},expression:"roleType"}},[_c('Radio',{attrs:{"label":""}},[_vm._v("全部")]),_vm._v(" "),_c('Radio',{attrs:{"label":"admin"}},[_vm._v("应用管理员")]),_vm._v(" "),_c('Radio',{attrs:{"label":"maintainer"}},[_vm._v("应用维护者")])],1)],1)]),_vm._v(" "),_c('CreateModal',{ref:"createModal",attrs:{"appMemberCount":_vm.memberList.length,"appId":_vm.appId},on:{"on-success":_vm.reload}}),_vm._v(" "),_c('EditModal',{ref:"editModal",attrs:{"appId":_vm.appId},on:{"on-success":_vm.reload}})],1)};
var __vue_staticRenderFns__$X = [];

  /* style */
  const __vue_inject_styles__$X = undefined;
  /* scoped */
  const __vue_scope_id__$X = undefined;
  /* module identifier */
  const __vue_module_identifier__$X = undefined;
  /* functional template */
  const __vue_is_functional_template__$X = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$X = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$X, staticRenderFns: __vue_staticRenderFns__$X },
    __vue_inject_styles__$X,
    __vue_script__$W,
    __vue_scope_id__$X,
    __vue_is_functional_template__$X,
    __vue_module_identifier__$X,
    false,
    undefined,
    undefined,
    undefined
  );

var appService$1 = new AppService();
var memberRouter = {
    path: 'member',
    name: 'fuseAppMember',
    meta: {
        title: '应用成员',
        auth: appService$1.authFilter(['read'])
    },
    component: __vue_component__$X
};

/* script */

/* template */
var __vue_render__$W = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('f-app-overview')};
var __vue_staticRenderFns__$W = [];

  /* style */
  const __vue_inject_styles__$W = undefined;
  /* scoped */
  const __vue_scope_id__$W = undefined;
  /* module identifier */
  const __vue_module_identifier__$W = undefined;
  /* functional template */
  const __vue_is_functional_template__$W = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$W = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$W, staticRenderFns: __vue_staticRenderFns__$W },
    __vue_inject_styles__$W,
    {},
    __vue_scope_id__$W,
    __vue_is_functional_template__$W,
    __vue_module_identifier__$W,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$V = {
  props: {
    item: {
      type: Object,
      required: true
    }
  },
  data() {
    let randomBgClass = this.getRandomBgClass();
    return {
      randomBgClass: randomBgClass
    };
  },
  computed: {
    itemTitle: function () {
      return this.item.title || this.item.name || '无';
    },
    firstChar: function () {
      return this.itemTitle.substr(0, 1);
    }
  },
  methods: {
    handleClickHome(item) {
      this.jump(item);
    },
    jump(actionItem) {
      if (actionItem.consoleUrl) {
        window.open(actionItem.consoleUrl);
      } else {
        this.$Message.error('该产品或服务暂未配置访问地址');
      }
    },
    handleOnItemClick(item) {
      this.$emit('on-item-click', item);
    },
    getRandomBgClass() {
      let bgColorClass = ['bg-primary', 'bg-info', 'bg-success', 'bg-warning', 'bg-error'];
      return bgColorClass[Math.floor(Math.random() * bgColorClass.length)];
    }
  }
};

/* script */
const __vue_script__$V = script$V;

/* template */
var __vue_render__$V = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{directives:[{name:"height",rawName:"v-height",value:(180),expression:"180"}],staticClass:"fuse-card-list-item",attrs:{"bordered":""},nativeOn:{"click":function($event){return _vm.handleOnItemClick(_vm.item)}}},[_c('div',{staticClass:"fuse-card-list-item-header",attrs:{"slot":"title"},slot:"title"},[(_vm.item.icon)?_c('f-image',{attrs:{"width":"50px","height":"50px","item":_vm.item.icon}}):_c('div',{class:['fuse-card-list-item-circle', 'bg-opacity', _vm.randomBgClass]},[_vm._v("\n      "+_vm._s(_vm.firstChar)+"\n    ")]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-content"},[_c('div',{staticClass:"aic-card-list-item-content-title-box"},[_c('h3',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-content-title"},[_vm._v(_vm._s(_vm.itemTitle))])])])],1),_vm._v(" "),_c('p',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(2),expression:"2"}]},[_vm._v(_vm._s(_vm.item.summary || '暂无'))]),_vm._v(" "),_c('div',{staticClass:"fuse-card-list-item-foot"},[(_vm.item.updatedAt)?_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"fuse-card-list-item-foot-left"},[_vm._v("\n      更新于："),_c('Time',{attrs:{"time":_vm.item.updatedAt}})],1):_vm._e()])])};
var __vue_staticRenderFns__$V = [];

  /* style */
  const __vue_inject_styles__$V = function (inject) {
    if (!inject) return
    inject("data-v-05d5f10d_0", { source: ".aic-card-list-item-content-title-box[data-v-05d5f10d]{display:flex;justify-content:space-between}.fuse-card-list-item .ivu-tag[data-v-05d5f10d]{position:unset;top:unset;right:unset}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$V = "data-v-05d5f10d";
  /* module identifier */
  const __vue_module_identifier__$V = undefined;
  /* functional template */
  const __vue_is_functional_template__$V = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$V = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$V, staticRenderFns: __vue_staticRenderFns__$V },
    __vue_inject_styles__$V,
    __vue_script__$V,
    __vue_scope_id__$V,
    __vue_is_functional_template__$V,
    __vue_module_identifier__$V,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//

var script$U = {
  props: {
    data: {
      type: Object
    }
  }
};

/* script */
const __vue_script__$U = script$U;

/* template */
var __vue_render__$U = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"main"},[_c('div',{staticClass:"title"},[_c('span',{class:[_vm.data.selected ? 'ivu-tree-title-selected' : ''],attrs:{"title":_vm.data.title}},[_vm._v(_vm._s(_vm.data.title))])])])};
var __vue_staticRenderFns__$U = [];

  /* style */
  const __vue_inject_styles__$U = function (inject) {
    if (!inject) return
    inject("data-v-6ba8b0f5_0", { source: ".main[data-v-6ba8b0f5]{display:flex;cursor:pointer;align-items:center}.title[data-v-6ba8b0f5]{display:inline-block;align-items:center;flex:1;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.title span[data-v-6ba8b0f5]{margin-left:5px}.icons[data-v-6ba8b0f5]{display:flex;align-items:center}.add-btn[data-v-6ba8b0f5]:hover{color:#2d8cf0}.remove-btn[data-v-6ba8b0f5]:hover{color:#2d8cf0}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$U = "data-v-6ba8b0f5";
  /* module identifier */
  const __vue_module_identifier__$U = undefined;
  /* functional template */
  const __vue_is_functional_template__$U = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$U = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$U, staticRenderFns: __vue_staticRenderFns__$U },
    __vue_inject_styles__$U,
    __vue_script__$U,
    __vue_scope_id__$U,
    __vue_is_functional_template__$U,
    __vue_module_identifier__$U,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$T = {
  data() {
    return {
      searchVal: '',
      catalogId: null,
      spinShow: false,
      queryOptions: {
        total: true,
        page_size: 12,
        page: 1,
        orderby: 't.created_at desc',
        marketId: '',
        filters: ``
      },
      list: [],
      markets: [],
      catalogList: [],
      selectTreeItem: null
    };
  },
  async created() {
    await this.getMarkets();
  },
  components: {
    CardListItem: __vue_component__$V,
    treeRender: __vue_component__$U
  },
  watch: {
    'queryOptions.marketId': {
      handler() {
        this.selectTreeItem = null;
        this.catalogId = null;
        this.getCatalog();
        this.reload();
      },
      deep: true
    }
  },
  methods: {
    async getMarkets() {
      const { data } = await aicService.queryMarket({
        limit: 100,
        orderby: 'orderNo'
      });
      this.markets = data.map((item) => {
        item.value = item.id;
        item.label = item.title;
        return item;
      });
      this.queryOptions.marketId = this.markets.length ? this.markets[0].id : '';
    },
    async getCatalog() {
      const { data } = await aicService.catalogTree(
        {
          filters: `marketId eq ${this.queryOptions.marketId}`
        },
        { 'x-tenant': false }
      );
      this.initTree(data);
      this.catalogList = data;
    },
    initTree(list) {
      list.forEach((item) => {
        if (item.children && item.children.length) {
          item.expand = true;
          this.initTree(item.children);
        }
      });
    },
    onTreeSelectChange(list, current) {
      if (current.selected) {
        this.selectTreeItem = current;
        this.catalogId = current.id;
        this.reload();
      }
    },
    inputChange: debounce(function () {
      this.reload();
    }, 300),
    async loadMore(queryOptions) {
      //目前组件会自动加载数据 防止重复加载
      if (!this.queryOptions.marketId)
        return {
          data: [],
          taotal: 0
        };
      this.queryOptions = Object.assign(this.queryOptions, queryOptions);
      this.queryOptions.filters = this.calFilters();
      const { data, headers } = await aicService.getAllPublish(this.queryOptions);
      let total = Number(headers['x-total-count']);
      return {
        data: data,
        total: total
      };
    },
    calFilters() {
      let filters = `h.appId ne ${this.$route.params.appId}`;
      if (this.searchVal) {
        filters += ` and title like %${this.searchVal}%`;
      }
      if (this.catalogId) {
        filters += ` and catalogIds like %${this.catalogId}%`;
      }
      return filters;
    },
    reload() {
      this.$refs.infiniteScroll.reload();
    },
    async selectChange() {
      this.reload();
    },
    apply(item) {
      // this.$routerThen.push({
      //   path: `app-product-service/${item.id}/apply`,
      //   query: { _cache_opener: true }
      // });
      this.$router.push({ path: `app-product-service/${item.id}/apply` });
    },
    clearCatalogId() {
      this.catalogId = null;
      if (this.selectTreeItem && this.selectTreeItem.selected) {
        this.selectTreeItem.selected = false;
      }
      this.reload();
    },
    treeRender(h, { data }) {
      return h(__vue_component__$U, {
        props: {
          data,
          showIcon: false
        }
      });
    }
  }
};

/* script */
const __vue_script__$T = script$T;

/* template */
var __vue_render__$T = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"bvue-page product"},[_c('b-childheader',{attrs:{"title":"申请开通服务","subtitle":"支持快速申请开通企业市场上的服务"}}),_vm._v(" "),_c('div',{staticClass:"bvue-page-body"},[_c('f-double-columns-view',{attrs:{"fixed-part-width":250}},[_c('Card',{attrs:{"slot":"left"},slot:"left"},[_c('Select',{attrs:{"slot":"title","filterable":"","placeholder":"按市场查询","transfer":""},slot:"title",model:{value:(_vm.queryOptions.marketId),callback:function ($$v) {_vm.$set(_vm.queryOptions, "marketId", $$v);},expression:"queryOptions.marketId"}},_vm._l((_vm.markets),function(item){return _c('Option',{key:item.value,attrs:{"value":item.value}},[_vm._v(_vm._s(item.label))])}),1),_vm._v(" "),_c('span',{staticClass:"ivu-tree-title",style:({ backgroundColor: _vm.catalogId ? '' : '#d5e8fc' }),on:{"click":_vm.clearCatalogId}},[_vm._v("全部服务")]),_vm._v(" "),_c('Tree',{staticClass:"mt-sm tree",attrs:{"render":_vm.treeRender,"empty-text":"暂无目录","data":_vm.catalogList},on:{"on-select-change":_vm.onTreeSelectChange}})],1),_vm._v(" "),_c('Card',{attrs:{"slot":"right"},slot:"right"},[_c('Row',{attrs:{"type":"flex","justify":"space-between"}},[_c('Col',[_c('Input',{staticStyle:{"width":"250px"},attrs:{"clearable":"","search":"","placeholder":"按服务名称进行搜索"},on:{"on-change":_vm.inputChange},model:{value:(_vm.searchVal),callback:function ($$v) {_vm.searchVal=$$v;},expression:"searchVal"}})],1),_vm._v(" "),_c('Col',[_c('Select',{staticStyle:{"width":"150px"},attrs:{"placeholder":"选择排序时间"},on:{"on-change":_vm.selectChange},model:{value:(_vm.queryOptions.orderby),callback:function ($$v) {_vm.$set(_vm.queryOptions, "orderby", $$v);},expression:"queryOptions.orderby"}},[_c('Option',{attrs:{"value":"s.use_count desc"}},[_vm._v("最多开通")]),_vm._v(" "),_c('Option',{attrs:{"value":"s.use_count"}},[_vm._v("最多开通(倒序)")]),_vm._v(" "),_c('Option',{attrs:{"value":"t.created_at desc"}},[_vm._v("最新上架")]),_vm._v(" "),_c('Option',{attrs:{"value":"t.created_at"}},[_vm._v("最新上架(倒序)")])],1)],1)],1),_vm._v(" "),_c('f-infinite-scroll-list',{ref:"infiniteScroll",staticClass:"mt-md",attrs:{"immediate":false,"load-more":_vm.loadMore},scopedSlots:_vm._u([{key:"default",fn:function(ref){
var listData = ref.listData;
return [_c('Row',{attrs:{"type":"flex","gutter":24}},_vm._l((listData),function(item,index){return _c('i-col',{key:index,staticClass:"ivu-mb",attrs:{"xl":6,"lg":6,"md":6,"sm":8,"xs":12}},[_c('CardListItem',{attrs:{"item":item},on:{"on-item-click":function($event){return _vm.apply(item)}}})],1)}),1)]}}])})],1)],1)],1)],1)};
var __vue_staticRenderFns__$T = [];

  /* style */
  const __vue_inject_styles__$T = function (inject) {
    if (!inject) return
    inject("data-v-4ce10654_0", { source: ".tree[data-v-4ce10654] .ivu-tree-title{width:95%}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$T = "data-v-4ce10654";
  /* module identifier */
  const __vue_module_identifier__$T = undefined;
  /* functional template */
  const __vue_is_functional_template__$T = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$T = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$T, staticRenderFns: __vue_staticRenderFns__$T },
    __vue_inject_styles__$T,
    __vue_script__$T,
    __vue_scope_id__$T,
    __vue_is_functional_template__$T,
    __vue_module_identifier__$T,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//0:审批中,1:已开通，2:审批拒绝，3:开通中,4：开通失败
let statusMap = {
  0: {
    type: 'success',
    desc: '申请成功，管理员正在审批中，请稍后！',
    title: '申请成功'
  },
  1: {
    type: 'success',
    desc: '您的申请的服务已经开通成功，现在您可以通过下面链接访问已申请的服务',
    title: '开通成功',
    extra: true //是否展示额外的内容
  },
  2: {
    type: 'error',
    desc: '审批拒绝！',
    title: '开通失败'
  },
  3: {
    type: 'error',
    desc: '审批拒绝！',
    title: '开通失败'
  },
  4: {
    type: 'info',
    desc: '开通失败！',
    title: '开通失败'
  }
};
var script$S = {
  provide: function () {
    return {
      context: {
        getService: () => this.service,
        setService: (value) => {
          this.service = value;
        },
        getApp: () => this.app,
        submit: (formData) => this.apply(formData),
        back: () => {
          this.back();
        }
      }
    };
  },
  data() {
    return {
      service: null,
      serviceAgreement: null,
      resultMsg: null,
      formError: false,
      loading: true,
      formValidate: {
        scopes: [],
        clientId: null
      },
      ruleValidate: {
        clientId: [{ required: true, message: '请选择 申请应用客户端', trigger: 'blur' }]
      },
      clients: []
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    })
  },
  async created() {
    const { data } = await aicService.servicePublished(this.$route.params.serviceId, { 'x-tenant': false });
    this.service = data;
    await this.initClients();
    this.loading = false;
  },
  methods: {
    back() {
      this.$router.back();
    },
    async initClients() {
      let { data } = await appService$2.getClients(this.$route.params.appId, { limit: 100 });
      // const { data: disableData } = await appService.getAuthService({
      //   filters: `authObjectType eq app and appId eq ${this.$route.params.appId}`,
      //   limit: 100
      // });
      // data.forEach((item) => {
      //   if (disableData.some((innerItem) => innerItem.client.id === item.id)) {
      //     item.disabled = true;
      //   }
      // });
      this.clients = data;
    },
    buildClientScopes() {
      //除开分类 都返回
      let scopes = this.formValidate.scopes.filter((item) => item.code);
      return scopes.map((item) => {
        return {
          scopeId: item.id,
          dataRules: item.dataRules,
          dataFilters: item.dataFilters
        };
      });
    },
    apply(formData) {
      this.$refs['formValidate'].validate((valid) => {
        if (valid) {
          this.$Modal.confirm({
            title: '提示',
            content: '是否开通？',
            onOk: async () => {
              let form = {};
              let clientScopes = this.buildClientScopes();
              form.publishedId = this.service.id;
              form.serviceId = this.service.serviceId;
              form.publishedId = this.$route.params.serviceId;
              form.serviceName = this.service.title;
              form.type = 'service_agreement';
              form.appId = this.app.id;
              form.appName = this.app.title;
              form.data = formData;
              form.clientId = this.formValidate.clientId;
              form.authorization = {
                appId: this.app.id,
                clientId: this.formValidate.clientId,
                resourceAppId: this.service.appId,
                resourceComponentId: this.service.id,
                clientScopes
              };
              try {
                let resp = await aicService.applyService(form, { onError: true });
                this.serviceAgreement = resp.data;

                this.resultMsg = statusMap[resp.data.status];
              } catch (error) {
                this.serviceAgreement = {};
                this.resultMsg = {
                  title: '开通失败',
                  type: 'error',
                  desc: error.response.data.message || '服务已存在，请勿重复开通！',
                  extra: false
                };
              }
            }
          });
        }
      });
    },
    toService() {
      let item = this.serviceAgreement;
      if (item.status == 1) {
        MicroAppHelper.routeToServiceForApp(item.service);
      } else {
        this.$router.push({
          path: '/app/proc/details',
          query: { appId: item.appId, processInstanceId: item.procId }
        });
      }
    },
    getUrlForApp() {
      if (!this.service) {
        return '';
      }
      let currentApp = this.app;
      let { appInteUrl: url, consoleUrl } = this.service;
      url = url || consoleUrl;
      let parseCtx = {
        app: currentApp,
        appId: currentApp && currentApp.id,
        serviceId: this.service.id
      };
      if (url) {
        try {
          url = Utils.parseUrl(url, parseCtx);
        } catch (error) {
          return url;
        }
      }
      return url;
    },
    toOverview() {
      this.$router.push({ path: `/app/${this.app.id}/overview` });
    },
    onRemoteError() {
      this.formError = true;
    }
  }
};

/* script */
const __vue_script__$S = script$S;

/* template */
var __vue_render__$S = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[(_vm.service)?_c('Card',[_c('PageHeader',{staticClass:"header"},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("\n        "+_vm._s(_vm.service.title)+"\n        "),_c('Tag',{attrs:{"color":"error"}},[_vm._v("版本："+_vm._s(_vm.service.version))])],1),_vm._v(" "),(_vm.service.icon)?_c('f-image',{staticClass:"mr-md",attrs:{"slot":"logo","width":"110px","height":"110px","item":_vm.service.icon},slot:"logo"}):_c('f-default-icon',{attrs:{"slot":"logo","title":_vm.service.title.substr(0, 1)},slot:"logo"}),_vm._v(" "),_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(4),expression:"4"}],attrs:{"slot":"content","title":_vm.service.summary},slot:"content"},[_vm._v("\n        "+_vm._s(_vm.service.summary || '暂无')+"\n      ")]),_vm._v(" "),_c('Button',{attrs:{"slot":"extra","icon":"md-arrow-back","shape":"circle","size":"large"},on:{"click":_vm.back},slot:"extra"})],1),_vm._v(" "),(_vm.resultMsg == null)?_c('div',{staticClass:"footer"},[_c('h3',[_vm._v("正在为 "+_vm._s(_vm.app.title)+" 开通 "+_vm._s(_vm.service.title))]),_vm._v(" "),_c('Form',{ref:"formValidate",attrs:{"model":_vm.formValidate,"rules":_vm.ruleValidate,"label-width":130}},[_c('FormItem',{attrs:{"label":"申请应用客户端","prop":"clientId"}},[_c('Select',{attrs:{"placeholder":"请选择授权客户端"},model:{value:(_vm.formValidate.clientId),callback:function ($$v) {_vm.$set(_vm.formValidate, "clientId", $$v);},expression:"formValidate.clientId"}},_vm._l((_vm.clients),function(item){return _c('Option',{key:item.id,attrs:{"disabled":item.disabled,"value":item.id}},[_vm._v(_vm._s(item.disabled ? item.name + '（已授权）' : item.name))])}),1)],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"授权权限"}},[_c('f-authorize-scope-tree',{attrs:{"component-id":_vm.service.serviceId,"app-id":_vm.service.appId},model:{value:(_vm.formValidate.scopes),callback:function ($$v) {_vm.$set(_vm.formValidate, "scopes", $$v);},expression:"formValidate.scopes"}})],1),_vm._v(" "),(_vm.service.applyFormUrl)?_c('f-remote',{attrs:{"url":_vm.service.applyFormUrl},on:{"on-error":_vm.onRemoteError}},[_c('aic-result',{staticClass:"ivu-mt",attrs:{"slot":"error","type":"info","title":"表单加载异常"},slot:"error"},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("申请表单加载错误，请联系管理员或服务提供者，确认服务申请表单配置是否正确。")]),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.back}},[_vm._v("返 回")])],1)])],1):[_c('FormItem',[_c('Button',{on:{"click":_vm.back}},[_vm._v("取 消")]),_vm._v(" "),_c('Button',{staticClass:"ivu-ml",attrs:{"type":"primary"},on:{"click":function($event){return _vm.apply(null)}}},[_vm._v("立即开通")])],1)]],2)],1):_c('f-result',{staticClass:"ivu-mt",attrs:{"type":_vm.resultMsg.type,"title":_vm.resultMsg.title}},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("\n        "+_vm._s(_vm.resultMsg.desc)+"\n      ")]),_vm._v(" "),(_vm.resultMsg.extra)?_c('div',{attrs:{"slot":"extra"},slot:"extra"},[_c('a',{on:{"click":_vm.toService}},[_vm._v(_vm._s(_vm.getUrlForApp()))])]):_vm._e(),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.toOverview}},[_vm._v("返回应用概览面")]),_vm._v(" "),_c('Button',{on:{"click":_vm.toService}},[_vm._v("访问服务")])],1)])],1):_vm._e(),_vm._v(" "),(!_vm.loading && !_vm.service)?_c('Card',[_c('Result',{staticClass:"mt-lg mb-lg",attrs:{"type":"error","title":"出错了"}},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("找不到当前服务信息")]),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.back}},[_vm._v("返回")])],1)])],1):_vm._e()],1)};
var __vue_staticRenderFns__$S = [];

  /* style */
  const __vue_inject_styles__$S = function (inject) {
    if (!inject) return
    inject("data-v-26cf4192_0", { source: ".document-icon[data-v-26cf4192]{margin-left:8px;cursor:pointer}.footer[data-v-26cf4192]{margin:30px 70px}.footer h3[data-v-26cf4192]{line-height:5}.header[data-v-26cf4192] .ivu-page-header-title{margin-bottom:8px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$S = "data-v-26cf4192";
  /* module identifier */
  const __vue_module_identifier__$S = undefined;
  /* functional template */
  const __vue_is_functional_template__$S = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$S = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$S, staticRenderFns: __vue_staticRenderFns__$S },
    __vue_inject_styles__$S,
    __vue_script__$S,
    __vue_scope_id__$S,
    __vue_is_functional_template__$S,
    __vue_module_identifier__$S,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$R = {
  provide: function () {
    return {
      context: {
        getService: () => this.service,
        setService: (value) => {
          this.service = value;
        },
        getApp: () => this.app,
        submit: (formData) => this.apply(formData),
        back: () => {
          this.back();
        }
      }
    };
  },
  data() {
    return {
      notFount: false,
      service: null,
      serviceAgreement: null,
      resultMsg: null,
      formError: false,
      applyInfo: null,
      remoteFormSettings: {
        mode: 'view',
        data: {}
      }
    };
  },
  async created() {
    const { data } = await aicService.getServiceById(this.$route.params.serviceId, { 'x-tenant': false });
    this.service = data;
    if (!this.service) {
      this.notFount = true;
      return;
    }
    this.getApplyInfo();
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    })
  },
  methods: {
    apply() {
      this.$router.push({ path: 'apply' });
    },
    del() {
      this.$Modal.confirm({
        title: '提示',
        content: '<p>是否删除？</p>',
        onOk: async () => {
          await aicService.abortAuth(this.service.id);
          this.$Message.success('删除成功');
          this.$router.back();
        }
      });
    },
    jump() {
      if (!this.service.docUrl) {
        this.$Message.error('该服务或产品暂未配置文档地址');
        return;
      }
      this.$Modal.confirm({
        title: '提示',
        content: `<p>即将访问：<strong style="word-break: break-all">${this.service.docUrl}</strong>，点击确定按钮即可访问</p>`,
        onOk: () => {
          window.open(this.service.docUrl);
        }
      });
    },
    toService() {
      MicroAppHelper.routeToServiceForApp(this.applyInfo.service);
    },
    async getApplyInfo() {
      let { data } = await aicService.queryServiceAgreement(
        {
          filters: `appId eq ${this.app.id} and serviceId eq ${this.service.id}`,
          orderby: 'createdAt desc',
          limit: 1
        },
        { 'x-tenant': false }
      );
      this.applyInfo = data && data[0];
      this.remoteFormSettings.data = this.applyInfo.formData;
      //debugger
    },
    getState(status) {
      //0:审批中,1:已开通，2:审批拒绝，3:开通中,4：开通失败
      let map = {
        0: '审批中',
        1: '已开通',
        2: '已拒绝',
        3: '开通中',
        4: '开通失败'
      };
      return map[status];
    },
    back() {
      this.$router.back();
    },
    onRemoteError() {
      this.formError = true;
    }
  }
};

/* script */
const __vue_script__$R = script$R;

/* template */
var __vue_render__$R = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',[(_vm.notFount)?_c('Result',{staticClass:"mt-lg mb-lg",attrs:{"type":"error","title":"出错了"}},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("找不到当前服务信息")]),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.back}},[_vm._v("返回")])],1)]):_vm._e(),_vm._v(" "),(_vm.service)?[_c('PageHeader',{staticClass:"header"},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("\n        "+_vm._s(_vm.service.title)+"\n        "),_c('Icon',{staticClass:"document-icon",attrs:{"type":"md-open","color":"#2d8cf0"},on:{"click":_vm.jump}})],1),_vm._v(" "),(_vm.service.icon)?_c('f-image',{staticClass:"mr-md",attrs:{"slot":"logo","width":"110px","height":"110px","item":_vm.service.icon},slot:"logo"}):_c('f-default-icon',{attrs:{"slot":"logo","title":_vm.service.title.substr(0, 1)},slot:"logo"}),_vm._v(" "),_c('div',{attrs:{"slot":"content"},slot:"content"},[_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(4),expression:"4"}],attrs:{"title":_vm.service.summary}},[_vm._v(_vm._s(_vm.service.summary || '暂无'))]),_vm._v(" "),(_vm.service.appInteUrl && _vm.applyInfo && _vm.applyInfo.status === 1)?_c('Button',{staticClass:"mt-lg",attrs:{"type":"primary","size":"large","disabled":_vm.applyInfo && _vm.applyInfo.status !== 1},on:{"click":_vm.toService}},[_vm._v("进入服务")]):_vm._e(),_vm._v(" "),(_vm.applyInfo && _vm.applyInfo.status === 4)?_c('div',{staticClass:"mt-sm"},[_c('Button',{staticClass:"mr-sm",attrs:{"size":"small"},on:{"click":_vm.apply}},[_vm._v("重新开通")])],1):_vm._e()],1),_vm._v(" "),_c('Button',{attrs:{"slot":"extra","icon":"md-arrow-back","shape":"circle","size":"large"},on:{"click":_vm.back},slot:"extra"})],1),_vm._v(" "),(_vm.resultMsg == null)?_c('div',{staticClass:"footer"},[_c('Card',{attrs:{"dis-hover":""}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{staticClass:"mr-sm",attrs:{"type":"md-list-box"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("申请信息")])],1),_vm._v(" "),(_vm.applyInfo)?_c('div',{staticClass:"body"},[_c('DescriptionList',{attrs:{"col":2}},[(_vm.applyInfo.applicant)?_c('Description',{attrs:{"term":"申请人："}},[_vm._v("\n              "+_vm._s(_vm.applyInfo.applicant.name)+"\n            ")]):_vm._e(),_vm._v(" "),_c('Description',{attrs:{"term":"申请时间："}},[_c('Time',{attrs:{"time":_vm.applyInfo.createdAt,"type":"datetime"}})],1)],1),_vm._v(" "),_c('DescriptionList',{attrs:{"col":2}},[_c('Description',{attrs:{"term":"应用名称："}},[_vm._v("\n              "+_vm._s(_vm.applyInfo.appName)+"\n            ")]),_vm._v(" "),_c('Description',{attrs:{"term":"申请信息："}},[_vm._v("\n              "+_vm._s(_vm.applyInfo.title)+"\n            ")])],1),_vm._v(" "),_c('DescriptionList',{attrs:{"col":1}},[_c('Description',{attrs:{"term":"状态："}},[_vm._v("\n              "+_vm._s(_vm.getState(_vm.applyInfo.status))+"\n            ")])],1),_vm._v(" "),(_vm.applyInfo.providerReturn && _vm.applyInfo.providerReturn.result)?_c('DescriptionList',{attrs:{"col":1}},[_c('Description',{attrs:{"term":"错误信息："}},[_vm._v("\n              "+_vm._s(_vm.applyInfo.providerReturn.result.message)+"\n              "),_c('Icon',{attrs:{"type":"md-alert","size":"16","color":"#2d8cf0","title":_vm.applyInfo.providerReturn.result.innerMsg}})],1)],1):_vm._e()],1):_vm._e()]),_vm._v(" "),(_vm.applyInfo && _vm.applyInfo.service.applyFormUrl)?_c('Card',{staticStyle:{"margin-top":"16px"},attrs:{"dis-hover":""}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{staticClass:"mr-sm",attrs:{"type":"md-list-box"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("申请表单")])],1),_vm._v(" "),_c('div',{staticClass:"body"},[_c('f-remote',{attrs:{"url":_vm.applyInfo.service.applyFormUrl,"settings":_vm.remoteFormSettings},on:{"on-error":_vm.onRemoteError}},[(_vm.formError)?_c('aic-result',{staticClass:"ivu-mt",attrs:{"slot":"error","type":"info","title":"表单加载异常"},slot:"error"},[_c('div',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v("申请表单加载错误，请联系管理员或服务提供者，确认服务申请表单配置是否正确。")]),_vm._v(" "),_c('div',{attrs:{"slot":"actions"},slot:"actions"},[_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.back}},[_vm._v("返 回")])],1)]):_vm._e()],1)],1)]):_vm._e()],1):_vm._e()]:_vm._e()],2)};
var __vue_staticRenderFns__$R = [];

  /* style */
  const __vue_inject_styles__$R = function (inject) {
    if (!inject) return
    inject("data-v-4e317fd3_0", { source: ".document-icon[data-v-4e317fd3]{margin-left:8px;cursor:pointer}.footer[data-v-4e317fd3]{margin:16px}.footer h3[data-v-4e317fd3]{line-height:5}.header[data-v-4e317fd3] .ivu-page-header-title{margin-bottom:8px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$R = "data-v-4e317fd3";
  /* module identifier */
  const __vue_module_identifier__$R = undefined;
  /* functional template */
  const __vue_is_functional_template__$R = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$R = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$R, staticRenderFns: __vue_staticRenderFns__$R },
    __vue_inject_styles__$R,
    __vue_script__$R,
    __vue_scope_id__$R,
    __vue_is_functional_template__$R,
    __vue_module_identifier__$R,
    false,
    createInjector,
    undefined,
    undefined
  );

var appService = new AppService();
var overviewRouter = [
    {
        path: 'overview',
        name: 'fuseAppOverview',
        meta: {
            title: '应用概览',
            auth: appService.authFilter(['read'])
        },
        component: __vue_component__$W
    },
    {
        path: 'app-product-service',
        name: 'fuseAppProductService',
        meta: {
            title: '服务',
            auth: appService.authFilter(['read'])
        },
        component: __vue_component__$T
    },
    {
        path: 'app-product-service/:serviceId/apply',
        name: 'fuseAppProductServiceApplyApp',
        meta: {
            title: '申请应用',
            auth: appService.authFilter(['read'])
        },
        component: __vue_component__$S
    },
    {
        path: 'app-product-service/:serviceId/show',
        name: 'fuseAppProductServiceShow',
        meta: {
            title: '查看申请应用',
            auth: appService.authFilter(['read'])
        },
        component: __vue_component__$R
    }
];

//
var script$Q = {
  data() {
    return {
      clients: [],
      basePath: this.$route.path.split('account-management')[0] + 'account-management'
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    })
  },
  watch: {
    '$route.name'(routerName) {
      if (routerName == 'fuseAppAccountManagement') {
        if (this.clients.length) {
          //跳转第一个
          this.toTargetClient();
        } else {
          //跳转引导页
          this.toGuide();
        }
      }
    }
  },
  async created() {
    this.addEventBus();
    await this.initClient();
    const routerName = this.$route.name;
    //为第一层路由（侧边栏点进来的情况）
    if (routerName == 'fuseAppAccountManagement') {
      if (this.clients.length) {
        //跳转第一个
        this.toTargetClient();
      } else {
        //跳转引导页
        this.toGuide();
      }
    }
  },
  destroyed() {
    this.$eventBus.$off('clientChange');
  },
  methods: {
    async initClient() {
      const res = await appService$2.getClients(this.$route.params.appId);
      this.clients = res.data.map((item) => {
        item.icon = 'md-person';
        return item;
      });
    },
    toTargetClient(id = this.clients[0] && this.clients[0].id) {
      //根据id跳转到目标编辑页面
      if (id) {
        this.handleCellClick(id);
      } else {
        this.toGuide();
      }
    },
    handleCellClick(id) {
      this.$router.replace({ path: `${this.basePath}/edit/${id}` });
    },
    dropdownMenuChange(path) {
      this.$router.push({ path: `${this.basePath}/${path}` });
    },
    addAccount() {
      this.$router.push({ path: `${this.basePath}/create` });
    },
    forget() {
      this.$router.push({ path: `${this.basePath}/forget` });
    },
    toGuide() {
      this.$router.push({ path: `${this.basePath}/guide` });
    },
    addEventBus() {
      this.$eventBus.$on('clientChange', async (data) => {
        //刷新列表并且跳转到id的编辑页面
        await this.initClient();
        if (data.action == 'create') {
          this.toTargetClient(data.id);
        } else if (data.action == 'del') {
          this.toTargetClient();
        } else if (data.action == 'update') ; else if (data.action == 'forget') {
          this.toTargetClient(data.id);
        }
      });
    }
  }
};

/* script */
const __vue_script__$Q = script$Q;

/* template */
var __vue_render__$Q = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"bvue-page account"},[_c('b-childheader',{attrs:{"title":"账号管理","subtitle":"账号用作应用的身份认证，您可在此为应用的不同端创建不同的应用账号（无需另外创建应用）","show-back":false}}),_vm._v(" "),_c('div',{staticClass:"bvue-page-body"},[_c('f-double-columns-view',{attrs:{"fixed-part-width":250}},[_c('template',{slot:"left"},[_c('Card',{staticClass:"card"},[_c('p',{staticClass:"title",attrs:{"slot":"title"},slot:"title"},[_c('Icon',{staticStyle:{"margin-right":"5px"},attrs:{"type":"md-contact","size":"20"}}),_vm._v("\n            账号设置\n          ")],1),_vm._v(" "),_c('div',{staticClass:"flex",attrs:{"slot":"extra"},slot:"extra"},[_c('Icon',{attrs:{"type":"md-add-circle","title":"添加账号","size":"20","color":_vm.$route.name == 'fuseCreateAccountManagement' ? '#2d8cf0' : ''},on:{"click":_vm.addAccount}}),_vm._v(" "),_c('Dropdown',{attrs:{"transfer":""},on:{"on-click":_vm.dropdownMenuChange}},[_c('Icon',{attrs:{"type":"md-more","size":"20","title":"展示更多","color":_vm.$route.name == 'fuseAppAccountForget' ? '#2d8cf0' : ''}}),_vm._v(" "),_c('DropdownMenu',{attrs:{"slot":"list"},slot:"list"},[_c('DropdownItem',{attrs:{"name":"Forget"}},[_vm._v("找回账号")])],1)],1)],1),_vm._v(" "),_c('CellGroup',{on:{"on-click":_vm.handleCellClick}},_vm._l((_vm.clients),function(item){return _c('Cell',{key:item.name,attrs:{"title":item.name || '默认',"name":item.id,"selected":_vm.$route.params.clientId == item.id}},[_c('Icon',{attrs:{"slot":"icon","type":item.icon},slot:"icon"}),_vm._v(" "),_c('span',{attrs:{"title":item.name || '默认'}},[_vm._v(_vm._s(item.name || '默认'))]),_vm._v(" "),(_vm.app && _vm.app.clientId == item.id)?_c('Icon',{attrs:{"slot":"extra","type":"md-radio-button-on","color":"#19be6b","title":"默认账号"},slot:"extra"}):_vm._e()],1)}),1)],1)],1),_vm._v(" "),_c('template',{slot:"right"},[_c('router-view',{key:_vm.$route.params.clientId})],1)],2)],1)],1)};
var __vue_staticRenderFns__$Q = [];

  /* style */
  const __vue_inject_styles__$Q = function (inject) {
    if (!inject) return
    inject("data-v-7b51475a_0", { source: ".account[data-v-7b51475a] .ivu-cell-title{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.account[data-v-7b51475a] .ivu-cell-main{width:100%}.card[data-v-7b51475a] .ivu-card-body{padding:8px}.account-setting[data-v-7b51475a]{line-height:30px}.account-setting span[data-v-7b51475a]{font-size:16px;margin:0 5px}.ivu-page-header[data-v-7b51475a]{padding:0 0 0 10px}.ivu-page-header[data-v-7b51475a] .ivu-page-header-breadcrumb{margin-bottom:0}.ivu-page-header[data-v-7b51475a] .ivu-page-header-title{margin-bottom:5px}.ivu-page-header[data-v-7b51475a] .ivu-page-header-action{margin-bottom:5px}.ivu-icon-md-more[data-v-7b51475a]{font-weight:700}.title[data-v-7b51475a]{display:flex;align-items:center}.ivu-card-extra>div[data-v-7b51475a]{top:0;transform:translateY(0)}.ivu-icon-md-add-circle[data-v-7b51475a],.ivu-icon-md-more[data-v-7b51475a]{cursor:pointer}.ivu-icon-md-add-circle[data-v-7b51475a]:hover,.ivu-icon-md-more[data-v-7b51475a]:hover{color:#2d8cf0}.account[data-v-7b51475a] .ivu-card-extra{top:14px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$Q = "data-v-7b51475a";
  /* module identifier */
  const __vue_module_identifier__$Q = undefined;
  /* functional template */
  const __vue_is_functional_template__$Q = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$Q = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$Q, staticRenderFns: __vue_staticRenderFns__$Q },
    __vue_inject_styles__$Q,
    __vue_script__$Q,
    __vue_scope_id__$Q,
    __vue_is_functional_template__$Q,
    __vue_module_identifier__$Q,
    false,
    createInjector,
    undefined,
    undefined
  );

var ipAddress = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/; //域名或IP地址
var domain = /^(?=^.{3,255}$)[a-zA-Z0-9][-a-zA-Z0-9]{0,62}(\.[a-zA-Z0-9][-a-zA-Z0-9]{0,62})+$/;
var formMixins = {
    data: function () {
        return {
            lengthLimit: {
                name: 150,
                title: 150,
                summary: 500,
                uri: 200,
                code: 50,
                version: 50,
                description: 1000,
                thumbnail: 250,
                readme: 30000,
                username: 50,
                password: 50,
                id: 36
            },
            model: {
                name: '',
                id: '',
                secret: '',
                redirectUriPattern: '',
                usePassword: true,
                allowWebLogin: false,
                allowUsePassword: false
            },
            rules: {
                name: [{ required: true, message: '客户端名称不能为空', trigger: 'change' }],
                id: [
                    { required: true, message: '应用账号不能为空', trigger: 'change' },
                    {
                        required: true,
                        pattern: /^[a-zA-Z0-9_-]*$/,
                        message: '请输入合法的应用账号，由字母数字中划线和下划线组成',
                        trigger: 'change'
                    }
                ],
                secret: [
                    { required: true, message: '应用密钥不能为空', trigger: 'change' },
                    {
                        required: true,
                        pattern: /^[a-zA-Z0-9_-]*$/,
                        message: '请输入合法的应用密钥，由字母数字中划线和下划线组成',
                        trigger: 'change'
                    }
                ],
                redirectUriPattern: [
                    { required: true, message: '请输入回调地址', trigger: 'change' },
                    {
                        required: true,
                        validator: function (rule, value, callback) {
                            if (value) {
                                if (value.startsWith('**')) {
                                    callback(new Error('回调地址不允许以**开头'));
                                }
                                else if (!ipAddress.test(value) && !domain.test(value)) {
                                    callback(new Error('回调地址需包含域名或IP信息，如：www.domain.com或192.168.1.100'));
                                }
                            }
                            callback();
                        },
                        trigger: 'change'
                    }
                ]
            },
            spinShow: true
        };
    }
};

//
var script$P = {
  mixins: [formMixins],
  methods: {
    handleSubmit(name) {
      this.$refs[name].validate((valid) => {
        if (valid) {
          this.create();
        }
      });
    },
    async create() {
      this.model.appId = this.$route.params.appId;
      if (!this.model.allowWebLogin) {
        //delete this.model.allowWebLogin;
        delete this.model.redirectUriPattern;
      }
      const res = await aicClientService.save(this.model);
      this.$Message.success('新增成功！');
      this.$router.back();
      const id = res.data.id;
      this.$eventBus.$emit('clientChange', { id, action: 'create' });
    },
    back() {
      this.$router.back();
    }
  }
};

/* script */
const __vue_script__$P = script$P;

/* template */
var __vue_render__$P = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{attrs:{"padding":16}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("创建账号")]),_vm._v(" "),_c('div',{staticClass:"form"},[_c('Form',{ref:"formRef",attrs:{"label-width":120,"model":_vm.model,"rules":_vm.rules},nativeOn:{"submit":function($event){$event.preventDefault();}}},[_c('FormItem',{attrs:{"label":"客户端名称","prop":"name"}},[_c('Input',{directives:[{name:"focus",rawName:"v-focus"}],attrs:{"maxlength":50,"placeholder":"请输入客户端名称"},model:{value:(_vm.model.name),callback:function ($$v) {_vm.$set(_vm.model, "name", $$v);},expression:"model.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用账号","prop":"id"}},[_c('f-password',{attrs:{"secret":false,"maxlength":_vm.lengthLimit.username,"placeholder":"请输入应用账号"},model:{value:(_vm.model.id),callback:function ($$v) {_vm.$set(_vm.model, "id", $$v);},expression:"model.id"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用密钥","prop":"secret"}},[_c('f-password',{attrs:{"maxlength":_vm.lengthLimit.password,"placeholder":"请输入应用密钥"},model:{value:(_vm.model.secret),callback:function ($$v) {_vm.$set(_vm.model, "secret", $$v);},expression:"model.secret"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"开启Web登录"}},[_c('i-switch',{attrs:{"size":"large"},model:{value:(_vm.model.allowWebLogin),callback:function ($$v) {_vm.$set(_vm.model, "allowWebLogin", $$v);},expression:"model.allowWebLogin"}},[_c('span',{attrs:{"slot":"open"},slot:"open"},[_vm._v("开启")]),_vm._v(" "),_c('span',{attrs:{"slot":"close"},slot:"close"},[_vm._v("关闭")])])],1),_vm._v(" "),(_vm.model.allowWebLogin)?_c('FormItem',{attrs:{"prop":"redirectUriPattern","label":"登录回调地址"}},[_c('Input',{attrs:{"maxlength":_vm.lengthLimit.uri,"placeholder":"请输入允许回调地址，如:https://fuse.bingosoft.net/**"},model:{value:(_vm.model.redirectUriPattern),callback:function ($$v) {_vm.$set(_vm.model, "redirectUriPattern", $$v);},expression:"model.redirectUriPattern"}},[_c('span',{attrs:{"slot":"append"},slot:"append"},[_vm._v("**")])]),_vm._v(" "),_c('div',{staticClass:"form-item-desc"},[_vm._v("\n          集成SSO登录后，指定当前帐号允许的重定向地址，地址支持\n          "),_c('confirm-link',{attrs:{"to":"https://docs.spring.io/spring-framework/docs/current/javadoc-api/org/springframework/util/AntPathMatcher.html","confirm":"是否打开Ant表达式介绍页面？"}},[_vm._v("Ant表达式 "),_c('Icon',{attrs:{"type":"md-open"}})],1),_vm._v("。允许任意重定向，可能引发系统\n          "),_c('confirm-link',{attrs:{"to":"https://cwe.mitre.org/data/definitions/601.html","confirm":"是否打开Open Redirect漏洞介绍页面？"}},[_vm._v("Open Redirect漏洞\n            "),_c('Icon',{attrs:{"type":"md-open"}})],1)],1)],1):_vm._e(),_vm._v(" "),_c('FormItem',[_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")]),_vm._v(" "),_c('Button',{staticStyle:{"margin-left":"10px"},on:{"click":_vm.back}},[_vm._v("取消")])],1)],1)],1)])};
var __vue_staticRenderFns__$P = [];

  /* style */
  const __vue_inject_styles__$P = function (inject) {
    if (!inject) return
    inject("data-v-33fec247_0", { source: ".form[data-v-33fec247]{padding:20px 10px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$P = "data-v-33fec247";
  /* module identifier */
  const __vue_module_identifier__$P = undefined;
  /* functional template */
  const __vue_is_functional_template__$P = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$P = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$P, staticRenderFns: __vue_staticRenderFns__$P },
    __vue_inject_styles__$P,
    __vue_script__$P,
    __vue_scope_id__$P,
    __vue_is_functional_template__$P,
    __vue_module_identifier__$P,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$O = {
  mixins: [formMixins],
  data() {
    return {
      error: false,
      errorMessage: ''
    };
  },
  methods: {
    handleSubmit(name) {
      this.$refs[name].validate((valid) => {
        if (valid) {
          this.claim();
        }
      });
    },
    claim() {
      aicClientService
        .claim(
          { clientId: this.model.id, clientSecret: this.model.secret, appId: this.$route.params.appId },
          { onError: true }
        )
        .then(() => {
          this.$Message.success('找回成功');
          this.$eventBus.$emit('clientChange', { action: 'forget', id: this.model.id });
        })
        .catch((exception) => {
          this.error = true;
          this.errorMessage = exception.response.data ? exception.response.data.message : exception.message;
        });
    },
    back() {
      this.$router.back();
    }
  }
};

/* script */
const __vue_script__$O = script$O;

/* template */
var __vue_render__$O = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{attrs:{"padding":16}},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("找回账号")]),_vm._v(" "),_c('div',{staticClass:"form"},[(_vm.error)?_c('Alert',{attrs:{"type":"error","show-icon":"","closable":""}},[_vm._v("\n      找回失败\n      "),_c('span',{attrs:{"slot":"desc"},slot:"desc"},[_vm._v(" "+_vm._s(_vm.errorMessage)),_c('Icon',{attrs:{"type":"help-circled","size":"14"}})],1)]):_vm._e(),_vm._v(" "),_c('Form',{ref:"formRef",attrs:{"label-width":100,"model":_vm.model,"rules":_vm.rules},nativeOn:{"submit":function($event){$event.preventDefault();}}},[_c('FormItem',{attrs:{"label":"应用账号","prop":"id"}},[_c('Input',{directives:[{name:"focus",rawName:"v-focus"}],attrs:{"maxlength":_vm.lengthLimit.username,"placeholder":"请输入应用账号"},model:{value:(_vm.model.id),callback:function ($$v) {_vm.$set(_vm.model, "id", $$v);},expression:"model.id"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用密钥","prop":"secret"}},[_c('Input',{attrs:{"type":"password","maxlength":_vm.lengthLimit.password,"password":"","placeholder":"请输入应用密钥"},model:{value:(_vm.model.secret),callback:function ($$v) {_vm.$set(_vm.model, "secret", $$v);},expression:"model.secret"}})],1),_vm._v(" "),_c('FormItem',[_c('Button',{on:{"click":_vm.back}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{staticClass:"ml-sm",attrs:{"type":"primary"},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")])],1)],1)],1)])};
var __vue_staticRenderFns__$O = [];

  /* style */
  const __vue_inject_styles__$O = function (inject) {
    if (!inject) return
    inject("data-v-9e7fbfb0_0", { source: ".form[data-v-9e7fbfb0]{padding:10px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$O = "data-v-9e7fbfb0";
  /* module identifier */
  const __vue_module_identifier__$O = undefined;
  /* functional template */
  const __vue_is_functional_template__$O = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$O = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$O, staticRenderFns: __vue_staticRenderFns__$O },
    __vue_inject_styles__$O,
    __vue_script__$O,
    __vue_scope_id__$O,
    __vue_is_functional_template__$O,
    __vue_module_identifier__$O,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$N = {
  mixins: [formMixins, formItemChanged],
  data() {
    return {
      modal: false,
      inputVal: '',
      clientId: this.$route.params.clientId
    };
  },
  computed: {
    ...mapGetters$1('fuse/app', {
      app: 'current'
    }),
    isDefaultClient() {
      return this.app.clientId == this.clientId;
    }
  },
  mounted() {
    this.getClient();
  },
  methods: {
    ...mapMutations$1('fuse/app', ['setApp']),
    handleBeforeChange() {
      return new Promise(() => {
        this.$Modal.confirm({
          title: '提示',
          content:
            '是否确认设置当前账号为默认账号，设为默认账号后，则取消原有设定的默认账号，一个应用中仅有一个默认账号！',
          onOk: async () => {
            await appService$2.update(this.app.id, { clientId: this.clientId, title: this.app.title });
            this.setApp(Object.assign(this.app, { clientId: this.clientId }));
            this.$Message.success('设置成功！');
          }
        });
      });
    },
    async getClient() {
      this.spinShow = true;
      const res = await aicClientService.get(this.$route.params.clientId);
      this.model = Object.assign(this.model, res.data) || {};
      this.spinShow = false;
    },
    async handleDelete() {
      this.modal = false;
      const msg = this.$Message.loading({
        content: '正在删除中...',
        duration: 0
      });
      try {
        await aicClientService.delete(this.model.id);
        //如果删除的当前客户端就是app的clientId 设置为null
        if (this.clientId === this.app.clientId) {
          await appService$2.update(this.app.id, { clientId: null, title: this.app.title });
        }
        this.setApp({
          item: Object.assign(this.app, { clientId: null }),
          returnRouter: { name: 'appsList' }
        });
        this.$Message.success('删除成功！');
        this.$eventBus.$emit('clientChange', { action: 'del' });
      } catch (error) {
        this.$Message.error('删除失败！');
      } finally {
        msg();
      }
    },
    handleSubmit(name) {
      this.$refs[name].validate(async (valid) => {
        if (valid) {
          await this.update();
          this.resetFormItems();
        }
      });
    },
    async update() {
      const { id, name, redirectUriPattern, secret, allowWebLogin, allowUsePassword } = this.model;
      await aicClientService.update(id, { name, redirectUriPattern, allowUsePassword, secret, allowWebLogin });
      this.$Message.success('保存成功!');
      this.$eventBus.$emit('clientChange', { action: 'update', id });
    }
  }
};

/* script */
const __vue_script__$N = script$N;

/* template */
var __vue_render__$N = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{attrs:{"padding":16}},[(_vm.spinShow)?_c('Spin',{attrs:{"fix":""}}):_vm._e(),_vm._v(" "),_c('p',{attrs:{"slot":"title"},slot:"title"},[_vm._v("账号管理")]),_vm._v(" "),_c('div',{staticClass:"form"},[_c('f-toggle-panel',{attrs:{"title":"基本信息","separator":"","subtitle":"更新账号基本信息，如密钥、地址等"}},[(!_vm.spinShow)?_c('Form',{ref:"formRef",attrs:{"label-width":130,"model":_vm.model,"rules":_vm.rules}},[_c('FormItem',{attrs:{"label":"客户端名称","prop":"name"}},[_c('Input',{directives:[{name:"focus",rawName:"v-focus"}],ref:"focusInput",attrs:{"maxlength":50,"placeholder":"请输入客户端名称"},model:{value:(_vm.model.name),callback:function ($$v) {_vm.$set(_vm.model, "name", $$v);},expression:"model.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用账号","prop":"id"}},[_c('Input',{attrs:{"maxlength":_vm.lengthLimit.username,"disabled":"","placeholder":"请输入应用账号"},model:{value:(_vm.model.id),callback:function ($$v) {_vm.$set(_vm.model, "id", $$v);},expression:"model.id"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用密钥","prop":"secret"}},[_c('f-password',{attrs:{"maxlength":_vm.lengthLimit.password,"placeholder":"请输入应用密钥"},model:{value:(_vm.model.secret),callback:function ($$v) {_vm.$set(_vm.model, "secret", $$v);},expression:"model.secret"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"默认账号","required":""}},[_c('i-switch',{attrs:{"value":_vm.isDefaultClient,"disabled":_vm.isDefaultClient,"before-change":_vm.handleBeforeChange}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"Web登录","prop":"allowWebLogin"}},[_c('i-switch',{attrs:{"size":"large"},model:{value:(_vm.model.allowWebLogin),callback:function ($$v) {_vm.$set(_vm.model, "allowWebLogin", $$v);},expression:"model.allowWebLogin"}},[_c('span',{attrs:{"slot":"open"},slot:"open"},[_vm._v("开启")]),_vm._v(" "),_c('span',{attrs:{"slot":"close"},slot:"close"},[_vm._v("关闭")])])],1),_vm._v(" "),(_vm.model.allowWebLogin)?_c('FormItem',{attrs:{"prop":"redirectUriPattern","label":"回调地址"}},[_c('Input',{attrs:{"maxlength":_vm.lengthLimit.uri,"placeholder":"请输入允许回调地址"},model:{value:(_vm.model.redirectUriPattern),callback:function ($$v) {_vm.$set(_vm.model, "redirectUriPattern", $$v);},expression:"model.redirectUriPattern"}},[_c('span',{attrs:{"slot":"append"},slot:"append"},[_vm._v("**")])]),_vm._v(" "),_c('div',{staticClass:"form-item-desc"},[_vm._v("\n            集成SSO登录后，指定当前帐号允许的重定向地址，地址支持\n            "),_c('confirm-link',{attrs:{"to":"https://docs.spring.io/spring-framework/docs/current/javadoc-api/org/springframework/util/AntPathMatcher.html","confirm":"是否打开Ant表达式介绍页面？"}},[_vm._v("Ant表达式 "),_c('Icon',{attrs:{"type":"md-open"}})],1),_vm._v("。允许任意重定向，可能引发系统\n            "),_c('confirm-link',{attrs:{"to":"https://cwe.mitre.org/data/definitions/601.html","confirm":"是否打开Open Redirect漏洞介绍页面？"}},[_vm._v("Open Redirect漏洞\n              "),_c('Icon',{attrs:{"type":"md-open"}})],1)],1)],1):_vm._e(),_vm._v(" "),_c('FormItem',[_c('f-button',{attrs:{"type":"primary","model":_vm.model},on:{"click":function($event){return _vm.handleSubmit('formRef')}}},[_vm._v("保存")])],1)],1):_vm._e()],1),_vm._v(" "),_c('f-toggle-panel',{attrs:{"title":"高级设置","subtitle":"删除账号等高级功能"}},[_c('f-advanced-settings-panel',{attrs:{"title":"删除账号","content":"删除账号操作将会导致当前客户端无法通过IAM的身份认证"}},[_c('Button',{attrs:{"slot":"action","disabled":_vm.isDefaultClient,"type":"error"},on:{"click":function($event){_vm.modal = true;}},slot:"action"},[_vm._v("删除账号")])],1)],1),_vm._v(" "),_c('Modal',{attrs:{"title":"确定操作"},model:{value:(_vm.modal),callback:function ($$v) {_vm.modal=$$v;},expression:"modal"}},[_c('div',{staticClass:"body"},[_c('div',{staticClass:"body-top"},[_vm._v("即将删除账号 "+_vm._s(_vm.model.name)+"，被删除的数据不能恢复！！！请确认是否继续删除？")]),_vm._v(" "),_c('div',[_vm._v("由于此操作将会导致数据丢失，需要再次确认才能继续")]),_vm._v(" "),_c('div',[_vm._v("\n          请在输入框输入"),_c('span',{staticClass:"title"},[_vm._v(_vm._s(_vm.model.name))]),_vm._v("进行确认\n        ")]),_vm._v(" "),_c('Input',{staticStyle:{"margin-top":"10px"},model:{value:(_vm.inputVal),callback:function ($$v) {_vm.inputVal=$$v;},expression:"inputVal"}})],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"error","disabled":_vm.inputVal != _vm.model.name},on:{"click":_vm.handleDelete}},[_vm._v("删除账号")])],1)])],1)],1)};
var __vue_staticRenderFns__$N = [];

  /* style */
  const __vue_inject_styles__$N = function (inject) {
    if (!inject) return
    inject("data-v-775ea3d0_0", { source: ".form[data-v-775ea3d0]{padding:0 10px}.body-top[data-v-775ea3d0]{color:#ed4014;margin:5px 0 15px 0}.body .title[data-v-775ea3d0]{color:#ed4014;background-color:#fbe5e1;padding:3px 10px;margin:0 8px;line-height:2}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$N = "data-v-775ea3d0";
  /* module identifier */
  const __vue_module_identifier__$N = undefined;
  /* functional template */
  const __vue_is_functional_template__$N = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$N = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$N, staticRenderFns: __vue_staticRenderFns__$N },
    __vue_inject_styles__$N,
    __vue_script__$N,
    __vue_scope_id__$N,
    __vue_is_functional_template__$N,
    __vue_module_identifier__$N,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//

var script$M = {
  methods: {
    jump() {
      this.$router.push({ name: 'fuseCreateAccountManagement' });
    }
  }
};

/* script */
const __vue_script__$M = script$M;

/* template */
var __vue_render__$M = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{staticClass:"card",attrs:{"padding":0},nativeOn:{"click":function($event){return _vm.jump($event)}}},[_c('PageHeader',{staticClass:"header"},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("手工创建")]),_vm._v(" "),_c('Icon',{attrs:{"slot":"logo","type":"md-list-box","size":35,"color":"#2d8cf0"},slot:"logo"}),_vm._v(" "),_c('div',{attrs:{"slot":"content"},slot:"content"},[_vm._v("提供图形化界面，简单快速创建账号")])],1)],1)};
var __vue_staticRenderFns__$M = [];

  /* style */
  const __vue_inject_styles__$M = function (inject) {
    if (!inject) return
    inject("data-v-5984fc36_0", { source: ".card[data-v-5984fc36]{cursor:pointer}.ivu-page-header[data-v-5984fc36]{margin:25px 10px;padding:10px 0 10px 30px;border:1px solid #5cadff}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$M = "data-v-5984fc36";
  /* module identifier */
  const __vue_module_identifier__$M = undefined;
  /* functional template */
  const __vue_is_functional_template__$M = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$M = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$M, staticRenderFns: __vue_staticRenderFns__$M },
    __vue_inject_styles__$M,
    __vue_script__$M,
    __vue_scope_id__$M,
    __vue_is_functional_template__$M,
    __vue_module_identifier__$M,
    false,
    createInjector,
    undefined,
    undefined
  );

var accountRouter = {
    path: 'account-management',
    name: 'fuseAppAccountManagement',
    meta: {
        title: '账号管理',
        auth: appService$2.authFilter(['read'])
    },
    component: __vue_component__$Q,
    children: [
        {
            path: 'create',
            name: 'fuseCreateAccountManagement',
            meta: {
                title: '新增账号'
            },
            component: __vue_component__$P
        },
        {
            path: 'forget',
            name: 'fuseAppAccountForget',
            meta: {
                title: '找回账号'
            },
            component: __vue_component__$O
        },
        {
            path: 'edit/:clientId',
            name: 'fuseAppAccountManagementShow',
            meta: {
                title: '账号编辑'
            },
            component: __vue_component__$N
        },
        {
            path: 'guide',
            name: 'fuseAppAccountManagementGuide',
            meta: {
                title: '引导页'
            },
            component: __vue_component__$M
        }
    ]
};

var appRouter = {
    member: memberRouter,
    overview: overviewRouter,
    account: accountRouter
};

//内部注册的路由 导出的是一个数组
var innerRouter = __spreadArray([], appsRouter);
//外部导出的路由 导出的是一个对象
var outer = {
    memberRouter: memberRouter$1,
    appRouter: appRouter
};
var outerRouter = outer;

var ModalMixin = {
  props: {
    /**
     * 弹出选择框标题
     */
    modalTitle: {
      type: String,
      default: '选择'
    },
    /**
     * 弹出选择框宽度
     */
    modalWidth: {
      // 这里不能设置默认值，否则窗口关闭后再打开会无法计算正确
      type: Number
    },
    /**
     * 弹出选择框高度
     */
    modalHeight: {
      // 这里不能设置默认值，否则窗口关闭后再打开会无法计算正确
      type: Number
    }
  },
  watch: {
    modalVisible() {
      if (this.modalVisible) {
        this.innerModalHeight = this.modalHeight || modalHeight(0, modalWidth());
        this.innerModalWidth = this.modalWidth || modalWidth();
      }
    }
  },
  data() {
    return {
      modalVisible: false,
      innerModalWidth: this.modalWidth || modalWidth(),
      innerModalHeight: this.modalHeight || modalHeight(0, modalWidth())
    };
  },
  methods: {
    toggleModal() {
      if (this.disabled) {
        return false;
      }
      this.modalVisible = !this.modalVisible;
    },
    close() {
      // 关闭对话框
      this.modalVisible = false;
    }
  }
};

/**
 * 在 vue 示例上扩展通用方法
 */
webApplication$1.Vue.prototype.$eventBus = new webApplication$1.Vue();

function isHtmlElement(node) {
  return node && node.nodeType === Node.ELEMENT_NODE;
}
function getStyle(element, styleName) {
  if (!element || !styleName) return null;
  styleName = camelCase$1(styleName);
  if (styleName === 'float') {
    styleName = 'cssFloat';
  }
  try {
    var computed = document.defaultView.getComputedStyle(element, '');
    return element.style[styleName] || computed ? computed[styleName] : null;
  } catch (e) {
    return element.style[styleName];
  }
}
const isScroll = (el, vertical) => {
  const determinedDirection = vertical !== null || vertical !== undefined;
  const overflow = determinedDirection
    ? vertical
      ? getStyle(el, 'overflow-y')
      : getStyle(el, 'overflow-x')
    : getStyle(el, 'overflow');

  return overflow.match(/(scroll|auto)/);
};
const getScrollContainer = (el, vertical) => {
  let parent = el;
  while (parent) {
    if ([window, document, document.documentElement].includes(parent)) {
      return window;
    }
    if (isScroll(parent, vertical)) {
      return parent;
    }
    parent = parent.parentNode;
  }

  return parent;
};

const getStyleComputedProperty = (element, property) => {
  if (element === window) {
    element = document.documentElement;
  }

  if (element.nodeType !== 1) {
    return [];
  }
  // NOTE: 1 DOM access here
  const css = window.getComputedStyle(element, null);
  return property ? css[property] : css;
};

const entries = (obj) => {
  return Object.keys(obj || {}).map((key) => [key, obj[key]]);
};

const getPositionSize = (el, prop) => {
  return el === window || el === document ? document.documentElement[prop] : el[prop];
};

const getOffsetHeight = (el) => {
  let offsetHeight = getPositionSize(el, 'offsetHeight');
  // 当容器为window时，offsetHeight没有包括已滚动的高度，所以补上
  if (el === window || el === document) {
    offsetHeight = offsetHeight + window.pageYOffset;
  }
  return offsetHeight;
};

const getClientHeight = (el) => {
  return getPositionSize(el, 'clientHeight');
};

const scope = 'ElInfiniteScroll';
const attributes = {
  delay: {
    type: Number,
    default: 200
  },
  distance: {
    type: Number,
    default: 0
  },
  disabled: {
    type: Boolean,
    default: false
  },
  immediate: {
    type: Boolean,
    default: true
  }
};

const getScrollOptions = (el, vm) => {
  if (!isHtmlElement(el)) return {};

  return entries(attributes).reduce((map, [key, option]) => {
    const { type, default: defaultValue } = option;
    let value = el.getAttribute(`infinite-scroll-${key}`);
    value = isUndefined(vm[value]) ? value : vm[value];
    switch (type) {
      case Number:
        value = Number(value);
        value = Number.isNaN(value) ? defaultValue : value;
        break;
      case Boolean:
        value = !isUndefined(value) ? (value === 'false' ? false : Boolean(value)) : defaultValue;
        break;
      default:
        value = type(value);
    }
    map[key] = value;
    return map;
  }, {});
};

const getElementTop = (el) => {
  return (el === window ? document.scrollingElement : el).getBoundingClientRect().top;
};

const handleScroll = function (cb) {
  const { el, vm, container, observer } = this[scope];
  const { distance, disabled } = getScrollOptions(el, vm);

  if (disabled) return;
  const containerInfo = (container === window ? document.scrollingElement : container).getBoundingClientRect();
  if (!containerInfo.width && !containerInfo.height) return;

  let shouldTrigger = false;
  if (container === el) {
    // be aware of difference between clientHeight & offsetHeight & window.getComputedStyle().height
    const scrollBottom = container.scrollTop + getClientHeight(container);
    shouldTrigger = container.scrollHeight - scrollBottom <= distance;
  } else {
    // 内容区底部相对于窗口顶部的距离
    const heightBelowTop = getOffsetHeight(el) + getElementTop(el) - getElementTop(container);
    // 滚动容器滚动条相对于窗口顶部的距离
    const offsetHeight = getOffsetHeight(container);
    const borderBottom = Number.parseFloat(getStyleComputedProperty(container, 'borderBottomWidth'));
    shouldTrigger = heightBelowTop - offsetHeight + borderBottom <= distance;
  }

  if (shouldTrigger && isFunction(cb)) {
    cb.call(vm);
  } else if (observer) {
    observer.disconnect();
    this[scope].observer = null;
  }
};
const InfiniteScrollDef = {
  name: 'InfiniteScroll',
  inserted(el, binding, vnode) {
    const cb = binding.value;

    const vm = vnode.context;
    // only include vertical scroll
    const container = getScrollContainer(el, true);
    const { delay, immediate } = getScrollOptions(el, vm);
    const onScroll = throttle(handleScroll.bind(el, cb), delay);

    el[scope] = { el, vm, container, onScroll };

    if (container) {
      container.addEventListener('scroll', onScroll);

      if (immediate) {
        const observer = (el[scope].observer = new MutationObserver(onScroll));
        observer.observe(container, { childList: true, subtree: true });
        onScroll();
      }
    }
  },
  unbind(el) {
    const { container, onScroll } = el[scope];
    if (container) {
      container.removeEventListener('scroll', onScroll);
    }
  }
};
const install = (Vue) => {
  Vue.directive(InfiniteScrollDef.name, InfiniteScrollDef);
};

webApplication.Vue.use(install);

//
/**
 * 密文填写组件：支持动态显示隐藏密文、支持自动生成密文
 */
var script$L = {
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: String
    },
    /**
     * 密文长度
     */
    length: {
      type: Number,
      default: 20
    },
    /**
     * 是否密文模式
     */
    secret: {
      type: Boolean,
      default: true
    },
    /**
     * 是否禁用
     */
    disabled: {
      type: Boolean,
      default: false
    },
    /**
     * 占位符
     */
    placeholder: {
      type: String
    },
    /**
     * 生成密文按钮文字
     */
    btnText: {
      type: String,
      default: '自动生成'
    },
    /**
     * 是否默认显示密文
     */
    showPassword: {
      type: Boolean,
      default: false
    },
    showGenerateBtn: {
      type: Boolean,
      default: true
    }
  },
  data() {
    return {
      innerValue: this.value,
      innerShowPassword: this.showPassword
    };
  },
  mounted() {
    if (this.showPassword) {
      this.$refs.inputRef.showPassword = true;
    }
  },
  watch: {
    value: function () {
      this.innerValue = this.value;
    }
  },
  methods: {
    updateValue: function () {
      this.$emit('input', this.innerValue);
    },
    updateSecret() {
      var randomStr = Utils.randomString(this.length);
      this.innerValue = randomStr;
      this.updateValue();
    },
    // 这里主要是处理disabled状态，切换明文、密文icon无法点击的问题，用自定义icon就可以点击
    handleToggleShowPassword() {
      this.innerShowPassword = !this.innerShowPassword;
      if (!this.disabled) {
        if (!this.$refs.inputRef.currentValue) {
          this.$refs.inputRef.currentValue = '';
        }
        this.$refs.inputRef.handleToggleShowPassword();
      } else {
        this.$refs.inputRef.showPassword = this.innerShowPassword;
      }
    }
  }
};

/* script */
const __vue_script__$L = script$L;

/* template */
var __vue_render__$L = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"fuse-input-group"},[_c('i-input',_vm._b({ref:"inputRef",class:{ 'fuse-input-group-content': _vm.showGenerateBtn },attrs:{"placeholder":_vm.placeholder,"type":_vm.secret ? 'password' : 'text',"disabled":_vm.disabled,"password":_vm.secret,"icon":_vm.secret ? (_vm.innerShowPassword ? 'ios-eye-off-outline' : 'ios-eye-outline') : ''},on:{"input":_vm.updateValue,"on-click":_vm.handleToggleShowPassword},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}},'i-input',_vm.$attrs,false)),_vm._v(" "),(_vm.showGenerateBtn)?_c('Button',{staticClass:"fuse-input-group-append",attrs:{"disabled":_vm.disabled,"type":"default"},on:{"click":function($event){return _vm.updateSecret()}}},[_vm._v(_vm._s(_vm.btnText))]):_vm._e()],1)};
var __vue_staticRenderFns__$L = [];

  /* style */
  const __vue_inject_styles__$L = undefined;
  /* scoped */
  const __vue_scope_id__$L = undefined;
  /* module identifier */
  const __vue_module_identifier__$L = undefined;
  /* functional template */
  const __vue_is_functional_template__$L = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$L = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$L, staticRenderFns: __vue_staticRenderFns__$L },
    __vue_inject_styles__$L,
    __vue_script__$L,
    __vue_scope_id__$L,
    __vue_is_functional_template__$L,
    __vue_module_identifier__$L,
    false,
    undefined,
    undefined,
    undefined
  );

let transferIndex = 0;

function transferIncrease() {
  transferIndex++;
}

//
const isServer = Vue.prototype.$isServer;

var script$K = {
  name: 'Drop',
  props: {
    placement: {
      type: String,
      default: 'bottom-start'
    },
    className: {
      type: String
    },
    transfer: {
      type: Boolean
    }
  },
  data() {
    return {
      popper: null,
      width: '',
      popperStatus: false,
      tIndex: this.handleGetIndex()
    };
  },
  computed: {
    styles() {
      let style = {};
      if (this.width) style.minWidth = `${this.width}px`;

      if (this.transfer) style['z-index'] = 1060 + this.tIndex;

      return style;
    }
  },
  methods: {
    update() {
      if (isServer) return;
      if (this.popper) {
        this.$nextTick(() => {
          this.popper.forceUpdate();
          this.popperStatus = true;
        });
      } else {
        this.$nextTick(() => {
          this.popper = createPopper(this.$parent.$refs.reference, this.$el, {
            placement: this.placement,
            modifiers: [
              flip,
              {
                name: 'computeStyles',
                options: {
                  gpuAcceleration: false
                }
              },
              preventOverflow, //仅仅为了引用preventOverflow，下方的应该会覆盖这个
              {
                name: 'preventOverflow',
                options: {
                  rootBoundary: 'document'
                }
              }
            ]
          });
        });
      }
      // set a height for parent is Modal and Select's width is 100%
      if (this.$parent.$options.name === 'fSelect') {
        this.width = parseInt(getStyle$1(this.$parent.$el, 'width'));
      }
      this.tIndex = this.handleGetIndex();
    },
    destroy() {
      if (this.popper) {
        setTimeout(() => {
          if (this.popper && !this.popperStatus) {
            this.popper.destroy();
            this.popper = null;
          }
          this.popperStatus = false;
        }, 300);
      }
    },
    handleGetIndex() {
      transferIncrease();
      return transferIndex;
    }
  },
  created() {
    this.$on('on-update-popper', this.update);
    this.$on('on-destroy-popper', this.destroy);
  },
  beforeDestroy() {
    if (this.popper) {
      this.popper.destroy();
    }
  }
};

/* script */
const __vue_script__$K = script$K;

/* template */
var __vue_render__$K = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"ivu-select-dropdown",class:_vm.className,style:(_vm.styles)},[_vm._t("default")],2)};
var __vue_staticRenderFns__$K = [];

  /* style */
  const __vue_inject_styles__$K = undefined;
  /* scoped */
  const __vue_scope_id__$K = undefined;
  /* module identifier */
  const __vue_module_identifier__$K = undefined;
  /* functional template */
  const __vue_is_functional_template__$K = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$K = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$K, staticRenderFns: __vue_staticRenderFns__$K },
    __vue_inject_styles__$K,
    __vue_script__$K,
    __vue_scope_id__$K,
    __vue_is_functional_template__$K,
    __vue_module_identifier__$K,
    false,
    undefined,
    undefined,
    undefined
  );

const CLICK = 'click';
const captureInstances = Object.create(null);
const nonCaptureInstances = Object.create(null);
const instancesList = [captureInstances, nonCaptureInstances];

/**
 * The common event handler for bot capture and non-capture events.
 *
 * @param {!Object} context - The event context.
 * @param {!Object} instances - The capture or non-capture registered instances.
 * @param {Event} event - The event object.
 * @returns {undefined} Default.
 */
const commonHandler = function _onCommonEvent(context, instances, event) {
  const { target } = event;

  const itemIteratee = function _itemIteratee(item) {
    const { el } = item;

    if (el !== target && !el.contains(target)) {
      const { binding } = item;

      if (binding.modifiers.stop) {
        event.stopPropagation();
      }

      if (binding.modifiers.prevent) {
        event.preventDefault();
      }

      binding.value.call(context, event);
    }
  };

  const keysIteratee = function _keysIteratee(eventName) {
    return instances[eventName].forEach(itemIteratee);
  };

  Object.keys(instances).forEach(keysIteratee);
};

/**
 * Event handler for capture events.
 *
 * @param {Event} event - The event object.
 */
const captureEventHandler = function onCaptureEvent(event) {
  commonHandler(this, captureInstances, event);
};

/**
 * Event handler for non-capture events.
 *
 * @param {Event} event - The event object.
 */
const nonCaptureEventHandler = function onNonCaptureEvent(event) {
  commonHandler(this, nonCaptureInstances, event);
};

/**
 * Get the correct event handler: Capture or non-capture.
 *
 * @param {boolean} useCapture - Indicate which handler to use; 'true' to use
 *  capture handler or 'false' for non-capture.
 * @returns {Function} - The event handler.
 */
const getEventHandler = function _getEventHandler(useCapture) {
  return useCapture ? captureEventHandler : nonCaptureEventHandler;
};

/**
 * The directive definition.
 * {@link https://vuejs.org/v2/guide/custom-directive.html|Custom directive}
 *
 * @namespace
 * @property {!Object} $_captureInstances - Registered capture instances.
 * @property {!Object} $_nonCaptureInstances - Registered non-capture instances.
 * @property {Function} $_onCaptureEvent - Event handler for capture events.
 * @property {Function} $_onNonCaptureEvent - Event handler for non-capture events.
 * @property {Function} bind - Called only once, when the directive is first
 *  bound to the element.
 * @property {Function} unbind - Called only once, when the directive is unbound
 *  from the element.
 * @property {string} version - The version number of this release.
 */
const directive$1 = Object.defineProperties(
  {},
  {
    $_captureInstances: {
      value: captureInstances
    },

    $_nonCaptureInstances: {
      value: nonCaptureInstances
    },

    $_onCaptureEvent: {
      value: captureEventHandler
    },

    $_onNonCaptureEvent: {
      value: nonCaptureEventHandler
    },

    /**
     * 注意，这里的 arg 修改为 capture，这样可以动态设置，原先的事件作为 modifiers
     * */
    bind: {
      value: function bind(el, binding) {
        if (typeof binding.value !== 'function') {
          throw new TypeError('Binding value must be a function.');
        }

        let eventType;
        const modifiers = binding.modifiers;
        if (modifiers.click) eventType = 'click';
        else if (modifiers.mousedown) eventType = 'mousedown';
        else if (modifiers.touchstart) eventType = 'touchstart';
        else eventType = CLICK;

        const useCapture = binding.arg;

        const normalisedBinding = {
          ...binding,
          ...{
            modifiers: {
              ...{
                capture: false,
                prevent: false,
                stop: false
              },
              ...binding.modifiers
            }
          }
        };

        const instances = useCapture ? captureInstances : nonCaptureInstances;

        if (!Array.isArray(instances[eventType])) {
          instances[eventType] = [];
        }

        if (instances[eventType].push({ el, binding: normalisedBinding }) === 1) {
          if (typeof document === 'object' && document) {
            document.addEventListener(eventType, getEventHandler(useCapture), useCapture);
          }
        }
      }
    },

    unbind: {
      value: function unbind(el) {
        const compareElements = function _compareElements(item) {
          return item.el !== el;
        };

        const instancesIteratee = function _instancesIteratee(instances) {
          const instanceKeys = Object.keys(instances);

          if (instanceKeys.length) {
            const useCapture = instances === captureInstances;

            const keysIteratee = function _keysIteratee(eventName) {
              const newInstance = instances[eventName].filter(compareElements);

              if (newInstance.length) {
                instances[eventName] = newInstance;
              } else {
                if (typeof document === 'object' && document) {
                  document.removeEventListener(eventName, getEventHandler(useCapture), useCapture);
                }

                delete instances[eventName];
              }
            };

            instanceKeys.forEach(keysIteratee);
          }
        };

        instancesList.forEach(instancesIteratee);
      }
    },

    /* Note: This needs to be manually updated to match package.json. */
    version: {
      enumerable: true,
      value: '3.7.1'
    }
  }
);

// Thanks to: https://github.com/airyland/vux/blob/v2/src/directives/transfer-dom/index.js
// Thanks to: https://github.com/calebroseland/vue-dom-portal

/**
 * Get target DOM Node
 * @param {(Node|string|Boolean)} [node=document.body] DOM Node, CSS selector, or Boolean
 * @return {Node} The target that the el will be appended to
 */
function getTarget(node) {
  if (node === void 0) {
    node = document.body;
  }
  if (node === true) {
    return document.body;
  }
  return node instanceof window.Node ? node : document.querySelector(node);
}

const directive = {
  inserted(el, { value }) {
    if (el.dataset && el.dataset.transfer !== 'true') return false;
    el.className = el.className ? el.className + ' v-transfer-dom' : 'v-transfer-dom';
    const parentNode = el.parentNode;
    if (!parentNode) return;
    const home = document.createComment('');
    let hasMovedOut = false;

    if (value !== false) {
      parentNode.replaceChild(home, el); // moving out, el is no longer in the document
      getTarget(value).appendChild(el); // moving into new place
      hasMovedOut = true;
    }
    if (!el.__transferDomData) {
      el.__transferDomData = {
        parentNode: parentNode,
        home: home,
        target: getTarget(value),
        hasMovedOut: hasMovedOut
      };
    }
  },
  componentUpdated(el, { value }) {
    if (el.dataset && el.dataset.transfer !== 'true') return false;
    // need to make sure children are done updating (vs. `update`)
    const ref$1 = el.__transferDomData;
    if (!ref$1) return;
    // homes.get(el)
    const parentNode = ref$1.parentNode;
    const home = ref$1.home;
    const hasMovedOut = ref$1.hasMovedOut; // recall where home is

    if (!hasMovedOut && value) {
      // remove from document and leave placeholder
      parentNode.replaceChild(home, el);
      // append to target
      getTarget(value).appendChild(el);
      el.__transferDomData = Object.assign({}, el.__transferDomData, { hasMovedOut: true, target: getTarget(value) });
    } else if (hasMovedOut && value === false) {
      // previously moved, coming back home
      parentNode.replaceChild(el, home);
      el.__transferDomData = Object.assign({}, el.__transferDomData, { hasMovedOut: false, target: getTarget(value) });
    } else if (value) {
      // already moved, going somewhere else
      getTarget(value).appendChild(el);
    }
  },
  unbind(el) {
    if (el.dataset && el.dataset.transfer !== 'true') return false;
    el.className = el.className.replace('v-transfer-dom', '');
    const ref$1 = el.__transferDomData;
    if (!ref$1) return;
    if (el.__transferDomData.hasMovedOut === true) {
      el.__transferDomData.parentNode && el.__transferDomData.parentNode.appendChild(el);
    }
    el.__transferDomData = null;
  }
};

var mixinsForm = {
  inject: {
    FormInstance: {
      default: ''
    }
  },
  computed: {
    itemDisabled() {
      let state = this.disabled;
      if (!state && this.FormInstance) state = this.FormInstance.disabled;
      return state;
    }
  }
};

// import { t } from '../locale';

var Locale = {
  methods: {
    t(...args) {
      return this.$t.apply(this, args);
      // return t.apply(this, args);
    }
  }
};

//

const prefixCls$4 = 'ivu-select';

var script$J = {
  name: 'fSelectHead',
  mixins: [Emitter, Locale],
  // components: { Icon },
  props: {
    disabled: {
      type: Boolean,
      default: false
    },
    filterable: {
      type: Boolean,
      default: false
    },
    multiple: {
      type: Boolean,
      default: false
    },
    remote: {
      type: Boolean,
      default: false
    },
    initialLabel: {
      type: [String, Number, Array]
    },
    values: {
      type: Array,
      default: () => []
    },
    clearable: {
      type: [Function, Boolean],
      default: false
    },
    inputElementId: {
      type: String
    },
    placeholder: {
      type: String
    },
    queryProp: {
      type: String,
      default: ''
    },
    prefix: {
      type: String
    },
    // 3.4.0
    maxTagCount: {
      type: Number
    },
    // 3.4.0
    maxTagPlaceholder: {
      type: Function
    },
    // 4.0.0
    allowCreate: {
      type: Boolean
    },
    // 4.0.0
    showCreateItem: {
      type: Boolean
    }
  },
  data() {
    return {
      prefixCls: prefixCls$4,
      query: '',
      inputLength: 20,
      remoteInitialLabel: this.initialLabel,
      // preventRemoteCall: false,
      searching: false // 指示是否正在搜索
    };
  },
  computed: {
    singleDisplayClasses() {
      const { multiple, showPlaceholder } = this;
      return [
        {
          [prefixCls$4 + '-head-with-prefix']: this.$slots.prefix || this.prefix,
          [prefixCls$4 + '-placeholder']: showPlaceholder /* && !filterable */,
          [prefixCls$4 + '-selected-value']: !showPlaceholder && !multiple /* && !filterable */
        }
      ];
    },
    singleDisplayValue() {
      if (this.multiple && this.values.length > 0) return '';
      return `${this.selectedSingle}` || this.localePlaceholder;
    },
    showPlaceholder() {
      let status = false;
      if (!this.multiple) {
        const value = this.values[0];
        if (typeof value === 'undefined' || String(value).trim() === '') {
          status = !this.remoteInitialLabel;
        }
      } else {
        if (!this.values.length > 0) {
          status = true;
        }
      }
      return status;
    },
    resetSelect() {
      return !this.showPlaceholder && this.clearable;
    },
    inputStyle() {
      let style = { height: this.searching ? '30px' : '0px', position: this.searching ? 'unset' : 'absolute' };

      if (this.multiple) {
        if (this.showPlaceholder) {
          style.width = '100%';
        } else {
          style.width = `${this.inputLength}px`;
        }
      }

      return style;
    },
    localePlaceholder() {
      if (this.placeholder === undefined) {
        return this.t('i.select.placeholder');
      } else {
        return this.placeholder;
      }
    },
    selectedSingle() {
      const selected = this.values[0];
      return selected ? selected.label : this.remoteInitialLabel || '';
    },
    selectedMultiple() {
      return this.multiple ? this.values : [];
    },
    // 使用 prefix 时，在 filterable
    headCls() {
      return {
        [`${prefixCls$4}-head-flex`]: this.filterable && (this.$slots.prefix || this.prefix)
      };
    },
    // 3.4.0, global setting customArrow 有值时，arrow 赋值空
    arrowType() {
      let type = 'ios-arrow-down';

      if (this.$IVIEW) {
        if (this.$IVIEW.select.customArrow) {
          type = '';
        } else if (this.$IVIEW.select.arrow) {
          type = this.$IVIEW.select.arrow;
        }
      }
      return type;
    },
    // 3.4.0, global setting
    customArrowType() {
      let type = '';

      if (this.$IVIEW) {
        if (this.$IVIEW.select.customArrow) {
          type = this.$IVIEW.select.customArrow;
        }
      }
      return type;
    },
    // 3.4.0, global setting
    arrowSize() {
      let size = '';

      if (this.$IVIEW) {
        if (this.$IVIEW.select.arrowSize) {
          size = this.$IVIEW.select.arrowSize;
        }
      }
      return size;
    }
  },
  methods: {
    onInputFocus() {
      this.$emit('on-input-focus');
    },
    onInputBlur() {
      if (this.showCreateItem) return;
      // if (!this.values.length) this.query = '';  // #5155
      this.$emit('on-input-blur');
    },
    removeTag(value) {
      if (this.disabled) return false;
      this.dispatch('fSelect', 'on-select-selected', value);
    },
    resetInputState() {
      this.inputLength = this.$refs.input.value.length * 12 + 20;
      this.$emit('on-keydown');
    },
    handleInputDelete(e) {
      const targetValue = e.target.value;
      if (this.multiple && this.selectedMultiple.length /* && this.query === '' */ && targetValue === '') {
        this.removeTag(this.selectedMultiple[this.selectedMultiple.length - 1]);
      }
    },
    handleInputEnter() {
      this.$emit('on-enter');
    },
    onHeaderClick() {
      if (this.disabled) return false;
      if (this.filterable /* && e.target === this.$el */) {
        this.searching = true;
        this.$refs.input.focus();
      }
    },
    onClear() {
      this.$emit('on-clear');
    }
  },
  watch: {
    values() {
      if (!this.filterable) return;
      this.searching = false;
      /* this.preventRemoteCall = true;
              if (this.multiple){
                  this.query = '';
                  this.preventRemoteCall = false; // this should be after the query change setter above
                  return;
              }
              // #982
              if (typeof value === 'undefined' || value === '' || value === null) this.query = '';
              else this.query = value.label;
              this.$nextTick(() => this.preventRemoteCall = false); // this should be after the query change setter above
              */
    },
    query(val) {
      /* if (this.preventRemoteCall) {
                  this.preventRemoteCall = false;
                  return;
              } */

      this.$emit('on-query-change', val);
    }
    /* queryProp(query){
              if (query !== this.query) this.query = query;
          }, */
  }
};

/* script */
const __vue_script__$J = script$J;

/* template */
var __vue_render__$J = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:_vm.headCls,staticStyle:{"height":"100%"},on:{"click":_vm.onHeaderClick}},[(_vm.$slots.prefix || _vm.prefix)?_c('span',{class:[_vm.prefixCls + '-prefix']},[_vm._t("prefix",[(_vm.prefix)?_c('Icon',{attrs:{"type":_vm.prefix}}):_vm._e()])],2):_vm._e(),_vm._v(" "),_vm._l((_vm.selectedMultiple),function(item,index){return [(_vm.maxTagCount === undefined || index < _vm.maxTagCount)?_c('div',{key:item.value,staticClass:"ivu-tag ivu-tag-checked"},[_c('span',{staticClass:"ivu-tag-text"},[_vm._v(_vm._s(item.tag !== undefined ? item.tag : item.label))]),_vm._v(" "),_c('Icon',{attrs:{"type":"ios-close"},nativeOn:{"click":function($event){$event.stopPropagation();return _vm.removeTag(item)}}})],1):_vm._e()]}),_vm._v(" "),(_vm.maxTagCount !== undefined && _vm.selectedMultiple.length > _vm.maxTagCount)?_c('div',{staticClass:"ivu-tag ivu-tag-checked"},[_c('span',{staticClass:"ivu-tag-text ivu-select-max-tag"},[(_vm.maxTagPlaceholder)?[_vm._v(_vm._s(_vm.maxTagPlaceholder(_vm.selectedMultiple.length - _vm.maxTagCount)))]:[_vm._v("+ "+_vm._s(_vm.selectedMultiple.length - _vm.maxTagCount)+"...")]],2)]):_vm._e(),_vm._v(" "),_c('span',{directives:[{name:"show",rawName:"v-show",value:(_vm.singleDisplayValue && !_vm.searching),expression:"singleDisplayValue && !searching"}],class:_vm.singleDisplayClasses},[_vm._v(_vm._s(_vm.singleDisplayValue))]),_vm._v(" "),(_vm.filterable)?_c('input',{directives:[{name:"model",rawName:"v-model",value:(_vm.query),expression:"query"}],ref:"input",class:[_vm.prefixCls + '-input'],style:(_vm.inputStyle),attrs:{"id":_vm.inputElementId,"type":"text","disabled":_vm.disabled,"autocomplete":"off","spellcheck":"false"},domProps:{"value":(_vm.query)},on:{"keydown":[_vm.resetInputState,function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"delete",[8,46],$event.key,["Backspace","Delete","Del"])){ return null; }return _vm.handleInputDelete($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"enter",13,$event.key,"Enter")){ return null; }return _vm.handleInputEnter($event)}],"focus":_vm.onInputFocus,"blur":_vm.onInputBlur,"input":function($event){if($event.target.composing){ return; }_vm.query=$event.target.value;}}}):_vm._e(),_vm._v(" "),(_vm.resetSelect)?_c('Icon',{class:[_vm.prefixCls + '-arrow'],attrs:{"type":"ios-close-circle"},nativeOn:{"click":function($event){$event.stopPropagation();return _vm.onClear($event)}}}):_vm._e(),_vm._v(" "),(!_vm.resetSelect && !_vm.remote)?_c('Icon',{class:[_vm.prefixCls + '-arrow'],attrs:{"type":_vm.arrowType,"custom":_vm.customArrowType,"size":_vm.arrowSize}}):_vm._e()],2)};
var __vue_staticRenderFns__$J = [];

  /* style */
  const __vue_inject_styles__$J = undefined;
  /* scoped */
  const __vue_scope_id__$J = undefined;
  /* module identifier */
  const __vue_module_identifier__$J = undefined;
  /* functional template */
  const __vue_is_functional_template__$J = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$J = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$J, staticRenderFns: __vue_staticRenderFns__$J },
    __vue_inject_styles__$J,
    __vue_script__$J,
    __vue_scope_id__$J,
    __vue_is_functional_template__$J,
    __vue_module_identifier__$J,
    false,
    undefined,
    undefined,
    undefined
  );

//

const prefixCls$3 = 'ivu-select-item';

const parentName = 'fSelect';

var script$I = {
  name: 'fOption',
  componentName: 'f-select-item',
  mixins: [Emitter, mixinsForm],
  props: {
    value: {
      type: [String, Number],
      required: true
    },
    label: {
      type: [String, Number],
      required: true
    },
    disabled: {
      type: Boolean,
      default: false
    },
    selected: {
      type: Boolean,
      default: false
    },
    isFocused: {
      type: Boolean,
      default: false
    },
    // 4.0.0
    tag: {
      type: [String, Number]
    }
  },
  data() {
    return {
      searchLabel: '', // the slot value (textContent)
      autoComplete: false
    };
  },
  computed: {
    classes() {
      return [
        `${prefixCls$3}`,
        {
          [`${prefixCls$3}-disabled`]: this.itemDisabled,
          [`${prefixCls$3}-selected`]: this.selected && !this.autoComplete,
          [`${prefixCls$3}-focus`]: this.isFocused
        }
      ];
    },
    showLabel() {
      return this.label ? this.label : this.value;
    },
    optionLabel() {
      return this.label || (this.$el && this.$el.textContent);
    }
  },
  methods: {
    select() {
      if (this.itemDisabled) return false;
      this.dispatch(parentName, 'on-select-selected', {
        value: this.value,
        label: this.optionLabel,
        tag: this.tag
      });
      this.$emit('on-select-selected', {
        value: this.value,
        label: this.optionLabel,
        tag: this.tag
      });
    }
  },
  mounted() {
    const Select = findComponentUpward(this, parentName);
    if (Select) this.autoComplete = Select.autoComplete;
  }
};

/* script */
const __vue_script__$I = script$I;

/* template */
var __vue_render__$I = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('li',{class:_vm.classes,on:{"click":function($event){$event.stopPropagation();return _vm.select($event)},"mousedown":function($event){$event.preventDefault();}}},[_vm._t("default",[_vm._v(_vm._s(_vm.showLabel))])],2)};
var __vue_staticRenderFns__$I = [];

  /* style */
  const __vue_inject_styles__$I = undefined;
  /* scoped */
  const __vue_scope_id__$I = undefined;
  /* module identifier */
  const __vue_module_identifier__$I = undefined;
  /* functional template */
  const __vue_is_functional_template__$I = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$I = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$I, staticRenderFns: __vue_staticRenderFns__$I },
    __vue_inject_styles__$I,
    __vue_script__$I,
    __vue_scope_id__$I,
    __vue_is_functional_template__$I,
    __vue_module_identifier__$I,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//

const prefixCls$2 = 'ivu-select-group';

var script$H = {
  name: 'fOptionGroup',
  props: {
    label: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      prefixCls: prefixCls$2,
      hidden: false // for search
    };
  },
  methods: {
    queryChange() {
      this.$nextTick(() => {
        const options = this.$refs.options.querySelectorAll('.ivu-select-item');
        let hasVisibleOption = false;
        for (let i = 0; i < options.length; i++) {
          if (options[i].style.display !== 'none') {
            hasVisibleOption = true;
            break;
          }
        }
        this.hidden = !hasVisibleOption;
      });
    }
  },
  mounted() {
    this.$on('on-query-change', () => {
      this.queryChange();
      return true;
    });
  }
};

/* script */
const __vue_script__$H = script$H;

/* template */
var __vue_render__$H = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('li',{directives:[{name:"show",rawName:"v-show",value:(!_vm.hidden),expression:"!hidden"}],class:[_vm.prefixCls + '-wrap']},[_c('div',{class:[_vm.prefixCls + '-title']},[_vm._v(_vm._s(_vm.label))]),_vm._v(" "),_c('ul',[_c('li',{ref:"options",class:[_vm.prefixCls]},[_vm._t("default")],2)])])};
var __vue_staticRenderFns__$H = [];

  /* style */
  const __vue_inject_styles__$H = undefined;
  /* scoped */
  const __vue_scope_id__$H = undefined;
  /* module identifier */
  const __vue_module_identifier__$H = undefined;
  /* functional template */
  const __vue_is_functional_template__$H = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$H = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$H, staticRenderFns: __vue_staticRenderFns__$H },
    __vue_inject_styles__$H,
    __vue_script__$H,
    __vue_scope_id__$H,
    __vue_is_functional_template__$H,
    __vue_module_identifier__$H,
    false,
    undefined,
    undefined,
    undefined
  );

//

const prefixCls$1 = 'ivu-select';
// const optionRegexp = /^i-option$|^Option$/i;
// const optionGroupRegexp = /option-?group/i;

const findChild = (instance, checkFn) => {
  let match = checkFn(instance);
  if (match) return instance;
  for (let i = 0, l = instance.$children.length; i < l; i++) {
    const child = instance.$children[i];
    match = findChild(child, checkFn);
    if (match) return match;
  }
};

/* const findOptionsInVNode = (node) => {
        const opts = node.componentOptions;
        if (opts && opts.tag.match(optionRegexp)) return [node];
        if (!node.children && (!opts || !opts.children)) return [];
        const children = [...(node.children || []), ...(opts && opts.children || [])];
        const options = children.reduce(
            (arr, el) => [...arr, ...findOptionsInVNode(el)], []
        ).filter(Boolean);
        return options.length > 0 ? options : [];
    }; */

/* const extractOptions = (options) => options.reduce((options, slotEntry) => {
        return options.concat(findOptionsInVNode(slotEntry));
    }, []); */

/* const applyProp = (node, propName, value) => {
        return {
            ...node,
            componentOptions: {
                ...node.componentOptions,
                propsData: {
                    ...node.componentOptions.propsData,
                    [propName]: value,
                }
            }
        };
    }; */

/* const getNestedProperty = (obj, path) => {
        const keys = path.split('.');
        return keys.reduce((o, key) => o && o[key] || null, obj);
    }; */

/* const getOptionLabel = option => {
        if (option.componentOptions.propsData.label) return option.componentOptions.propsData.label;
        const textContent = (option.componentOptions.children || []).reduce((str, child) => str + (child.text || ''), '');
        const innerHTML = getNestedProperty(option, 'data.domProps.innerHTML');
        return textContent || (typeof innerHTML === 'string' ? innerHTML : '');
    }; */

const checkValuesNotEqual = (value, publicValue, values) => {
  const strValue = JSON.stringify(value);
  const strPublic = JSON.stringify(publicValue);
  const strValues = JSON.stringify(
    values.map((item) => {
      return item.value;
    })
  );
  return strValue !== strPublic || strValue !== strValues || strValues !== strPublic;
};

const ANIMATION_TIMEOUT = 300;
/**
 * iview Select组件的重写，使用方式和iview唯一不同的是：选项渲染使用options属性传递内部渲染，其他属性和iview一致
 */
var script$G = {
  name: 'fSelect',
  mixins: [Emitter, Locale, mixinsForm],
  components: { Drop: __vue_component__$K, SelectHead: __vue_component__$J, Option: __vue_component__$I, OptionGroup: __vue_component__$H },
  directives: { clickOutside: directive$1, TransferDom: directive },
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: [String, Number, Array],
      default: ''
    },
    /**
     * iview Select label
     */
    label: {
      type: [String, Number, Array],
      default: ''
    },
    /**
     * 是否多选
     */
    multiple: {
      type: Boolean,
      default: false
    },
    /**
     * 是否禁用
     */
    disabled: {
      type: Boolean,
      default: false
    },
    /**
     * 是否可清除
     */
    clearable: {
      type: Boolean,
      default: false
    },
    /**
     * 占位符
     */
    placeholder: {
      type: String
    },
    /**
     * iview Select filterable
     */
    filterable: {
      type: Boolean,
      default: false
    },
    /**
     * iview Select filterMethod
     */
    filterMethod: {
      type: Function
    },
    /**
     * iview Select remoteMethod
     */
    remoteMethod: {
      type: Function
    },
    /**
     * iview Select loading
     */
    loading: {
      type: Boolean,
      default: false
    },
    /**
     * iview Select loadingText
     */
    loadingText: {
      type: String
    },
    /**
     * iview Select size
     */
    size: {
      type: String,
      validator(value) {
        return oneOf(value, ['small', 'large', 'default']);
      },
      default() {
        return !this.$IVIEW || this.$IVIEW.size === '' ? 'default' : this.$IVIEW.size;
      }
    },
    /**
     * iview Select labelInValue
     */
    labelInValue: {
      type: Boolean,
      default: false
    },
    /**
     * iview Select notFoundText
     */
    notFoundText: {
      type: String
    },
    /**
     * iview Select placement
     */
    placement: {
      validator(value) {
        return oneOf(value, ['top', 'bottom', 'top-start', 'bottom-start', 'top-end', 'bottom-end']);
      },
      default: 'bottom-start'
    },
    /**
     * iview Select transfer
     */
    transfer: {
      type: Boolean,
      default() {
        return !this.$IVIEW || this.$IVIEW.transfer === '' ? false : this.$IVIEW.transfer;
      }
    },
    /**
     * iview Select autoComplete
     */
    autoComplete: {
      type: Boolean,
      default: false
    },
    /**
     * iview Select name
     */
    name: {
      type: String
    },
    /**
     * iview Select elementId
     */
    elementId: {
      type: String
    },
    /**
     * iview Select transferClassName
     */
    transferClassName: {
      type: String
    },
    // 3.4.0
    prefix: {
      type: String
    },
    // 3.4.0
    maxTagCount: {
      type: Number
    },
    // 3.4.0
    maxTagPlaceholder: {
      type: Function
    },
    // 4.0.0
    allowCreate: {
      type: Boolean,
      default: false
    },
    // 4.0.0
    capture: {
      type: Boolean,
      default() {
        return !this.$IVIEW ? true : this.$IVIEW.capture;
      }
    },
    // 重大变化：设置Select框的数据集合，之前通过vnode去找Select下的Option在远程模式问题很多，控件经常出现数据变化界面渲染不成功，点击一下界面又显示正确了；
    // 因为vnode本身并不是响应式的，所以这里修改为依赖响应式数据来进行Option的渲染
    options: {
      type: Array,
      required: true,
      default() {
        return [];
      }
    },
    // 自定义本地查询时使用的数据匹配
    customLabel: {
      type: Function,
      default() {
        return '';
      }
    },
    // 是否开启分组：如果options中数据包含groupKey则按照groupKey分组显示
    group: {
      type: Boolean,
      default: false
    },
    // 分组属性
    groupKey: {
      type: String,
      default: 'group'
    }
  },
  mounted() {
    this.$on('on-select-selected', this.onOptionClick);

    // set the initial values if there are any
    if (!this.remote && this.options.length > 0) {
      this.values = this.getInitialValue()
        .map((value) => {
          if (typeof value !== 'number' && !value) return null;
          return this.getOptionData(value);
        })
        .filter(Boolean);
    }

    this.checkUpdateStatus();
  },
  data() {
    return {
      prefixCls: prefixCls$1,
      values: [],
      dropDownWidth: 0,
      visible: false,
      focusIndex: -1,
      isFocused: false,
      query: '',
      initialLabel: this.label,
      hasMouseHoverHead: false,
      // slotOptions: this.$slots.default,
      caretPosition: -1,
      lastRemoteQuery: '',
      unchangedQuery: true,
      hasExpectedValue: false,
      // preventRemoteCall: false,
      filterQueryChange: false // #4273
    };
  },
  computed: {
    classes() {
      return [
        `${prefixCls$1}`,
        {
          [`${prefixCls$1}-visible`]: this.visible,
          [`${prefixCls$1}-disabled`]: this.itemDisabled,
          [`${prefixCls$1}-multiple`]: this.multiple,
          [`${prefixCls$1}-single`]: !this.multiple,
          [`${prefixCls$1}-show-clear`]: this.showCloseIcon,
          [`${prefixCls$1}-${this.size}`]: !!this.size
        }
      ];
    },
    dropdownCls() {
      return {
        [prefixCls$1 + '-dropdown-transfer']: this.transfer,
        [prefixCls$1 + '-multiple']: this.multiple && this.transfer,
        'ivu-auto-complete': this.autoComplete,
        [this.transferClassName]: this.transferClassName
      };
    },
    selectionCls() {
      return {
        [`${prefixCls$1}-selection`]: !this.autoComplete,
        [`${prefixCls$1}-selection-focused`]: this.isFocused
      };
    },
    localeNotFoundText() {
      if (typeof this.notFoundText === 'undefined') {
        return this.t('i.select.noMatch');
      } else {
        return this.notFoundText;
      }
    },
    localeLoadingText() {
      if (typeof this.loadingText === 'undefined') {
        return this.t('i.select.loading');
      } else {
        return this.loadingText;
      }
    },
    showCreateItem() {
      let state = false;
      if (this.allowCreate && this.query !== '') {
        state = true;
        const $options = findComponentsDownward(this, 'iOption');
        if ($options && $options.length) {
          if ($options.find((item) => item.showLabel === this.query)) state = false;
        }
      }
      return state;
    },
    transitionName() {
      return this.placement === 'bottom' ? 'slide-up' : 'slide-down';
    },
    /* dropVisible () {
                let status = true;
                const noOptions = !this.filteredOptions || this.filteredOptions.length === 0;
                if (!this.loading && this.remote && this.query === '' && noOptions) status = false;

                if (this.autoComplete && noOptions) status = false;

                return this.visible && status;
            }, */
    showNotFoundLabel() {
      const { loading, remote } = this;
      let options = this.filteredOptions;
      return options && options.length === 0 && (!remote || (remote && !loading));
    },
    publicValue() {
      if (this.labelInValue) {
        return this.multiple ? this.values : this.values[0];
      } else {
        return this.multiple ? this.values.map((option) => option.value) : (this.values[0] || {}).value;
      }
    },
    canBeCleared() {
      const uiStateMatch = this.hasMouseHoverHead || this.active;
      const qualifiesForClear = !this.multiple && !this.itemDisabled && this.clearable;
      return uiStateMatch && qualifiesForClear && this.reset; // we return a function
    },
    /* selectOptions() {
                const selectOptions = [];
                const slotOptions = (this.slotOptions || []);
                let optionCounter = -1;
                const currentIndex = this.focusIndex;
                const selectedValues = this.values.filter(Boolean).map(({value}) => value);
                if (this.autoComplete) {
                    const copyChildren = (node, fn) => {
                        return {
                            ...node,
                            children: (node.children || []).map(fn).map(child => copyChildren(child, fn))
                        };
                    };
                    const autoCompleteOptions = extractOptions(slotOptions);
                    const selectedSlotOption = autoCompleteOptions[currentIndex];

                    return slotOptions.map(node => {
                        if (node === selectedSlotOption || getNestedProperty(node, 'componentOptions.propsData.value') === this.value) return applyProp(node, 'isFocused', true);
                        return copyChildren(node, (child) => {
                            if (child !== selectedSlotOption) return child;
                            return applyProp(child, 'isFocused', true);
                        });
                    });
                }
                for (let option of slotOptions) {

                    const cOptions = option.componentOptions;
                    if (!cOptions) continue;
                    if (cOptions.tag.match(optionGroupRegexp)){
                        let children = cOptions.children;

                        // remove filtered children
                        if (this.filterable){
                            children = children.filter(
                                ({componentOptions}) => this.validateOption(componentOptions)
                            );
                        }

                        // fix #4371
                        children = children.map(opt => {
                            optionCounter = optionCounter + 1;
                            return this.processOption(opt, selectedValues, optionCounter === currentIndex);
                        });

                        // keep the group if it still has children  // fix #4371
                        if (children.length > 0) selectOptions.push({...option,componentOptions:{...cOptions,children:children}});
                    } else {
                        // ignore option if not passing filter
                        if (this.filterQueryChange) {
                            const optionPassesFilter = this.filterable ? this.validateOption(cOptions) : option;
                            if (!optionPassesFilter) continue;
                        }

                        optionCounter = optionCounter + 1;
                        selectOptions.push(this.processOption(option, selectedValues, optionCounter === currentIndex));
                    }
                }

                return selectOptions;
            },
            flatOptions(){
                return extractOptions(this.selectOptions);
            }, */
    selectTabindex() {
      return this.itemDisabled || this.filterable ? -1 : 0;
    },
    remote() {
      return typeof this.remoteMethod === 'function';
    },
    // 本地数据过滤需要根据query过滤掉不符合条件的option，远程数据由用户自行重设options
    filteredOptions() {
      if (!this.options || this.options.length === 0) {
        return [];
      }
      let selectedValuesMap = {};
      this.values.forEach((v) => {
        selectedValuesMap[v.value] = true;
      });
      let options = this.options.map((optItem) => {
        let _optItem = Object.assign({}, optItem, {
          value: optItem.value,
          label: optItem.label,
          disabled: optItem.disabled || false,
          selected: !!selectedValuesMap[optItem.value],
          isFocused: false,
          tag: optItem.tag
        });
        return _optItem;
      });
      if (this.filterable && !this.remote) {
        if (!this.query) {
          return options;
        }
        let filteredOptions = options.filter((optItem) => {
          let value = optItem.value;
          let label = optItem.label;
          let textContent = this.customLabel(optItem);
          const stringValues = JSON.stringify([value, label, textContent]);
          const query = this.query.toLowerCase().trim();
          return stringValues.toLowerCase().includes(query);
        });
        return filteredOptions;
      } else {
        return options;
      }
    },
    hasGroup() {
      if (!this.group) {
        return false;
      }
      if (!this.options || this.options.length === 0) {
        return false;
      }
      let groupOption = this.options.find((optItem) => {
        return optItem[this.groupKey];
      });
      if (groupOption) {
        return true;
      }
      return false;
    },
    groupedFilteredOptions() {
      let filteredOptions = this.filteredOptions;

      let groupedFilteredOptions = {};
      let others = [];
      filteredOptions.forEach((optItem) => {
        let group = optItem[this.groupKey];
        if (group) {
          groupedFilteredOptions[group] = groupedFilteredOptions[group] || [];
          groupedFilteredOptions[group].push(optItem);
        } else {
          others.push(optItem);
        }
      });
      if (others.length) {
        groupedFilteredOptions['其他'] = others;
      }
      return groupedFilteredOptions;
    }
  },
  methods: {
    setQuery(query) {
      // PUBLIC API
      if (query) {
        this.onQueryChange(query);
        return;
      }
      if (query === null) {
        this.onQueryChange('');
        this.values = [];
        // #5620,修复清空搜索关键词后，重新搜索相同的关键词没有触发远程搜索
        this.lastRemoteQuery = '';
      }
    },
    clearSingleSelect() {
      // PUBLIC API
      this.$emit('on-clear');
      this.hideMenu();
      if (this.clearable) this.reset();
    },
    getOptionData(value) {
      const option = this.filteredOptions.find((optItem) => optItem.value === value);
      if (!option) return null;
      return option;
      /* const label = option.label;
                return {
                    value: value,
                    label: label,
                }; */
    },
    getInitialValue() {
      const { multiple, value } = this;
      let initialValue = Array.isArray(value) ? value : [value];
      if (
        !multiple &&
        (typeof initialValue[0] === 'undefined' ||
          (String(initialValue[0]).trim() === '' && !Number.isFinite(initialValue[0])))
      ) {
        initialValue = [];
      }

      // if (remote && !multiple && value) {
      // const data = this.getOptionData(value);
      // this.query = data ? data.label : String(value);
      // }
      return initialValue.filter((item) => {
        return Boolean(item) || item === 0;
      });
    },
    /* processOption(option, values, isFocused){
                if (!option.componentOptions) return option;
                const optionValue = option.componentOptions.propsData.value;
                const disabled = option.componentOptions.propsData.disabled;
                const isSelected = values.includes(optionValue);

                const propsData = {
                    ...option.componentOptions.propsData,
                    selected: isSelected,
                    isFocused: isFocused,
                    disabled: typeof disabled === 'undefined' ? false : disabled !== false,
                };

                return {
                    ...option,
                    componentOptions: {
                        ...option.componentOptions,
                        propsData: propsData
                    }
                };
            }, */

    /* validateOption({children, elm, propsData}){
                const value = propsData.value;
                const label = propsData.label || '';
                const textContent = (elm && elm.textContent) || (children || []).reduce((str, node) => {
                    const nodeText = node.elm ? node.elm.textContent : node.text;
                    return `${str} ${nodeText}`;
                }, '') || '';
                const stringValues = JSON.stringify([value, label, textContent]);
                const query = this.query.toLowerCase().trim();
                return stringValues.toLowerCase().includes(query);
            }, */

    toggleMenu(e, force) {
      if (this.itemDisabled) {
        return false;
      }

      this.visible = typeof force !== 'undefined' ? force : !this.visible;
      if (this.visible) {
        this.dropDownWidth = this.$el.getBoundingClientRect().width;
        this.broadcast('Drop', 'on-update-popper');
      }
    },
    hideMenu() {
      this.toggleMenu(null, false);
      setTimeout(() => (this.unchangedQuery = true), ANIMATION_TIMEOUT);
    },
    onClickOutside(event) {
      if (this.visible) {
        if (event.type === 'mousedown') {
          event.preventDefault();
          return;
        }

        if (this.transfer) {
          const { $el } = this.$refs.dropdown;
          if ($el === event.target || $el.contains(event.target)) {
            return;
          }
        }

        if (this.filterable) {
          const input = this.$el.querySelector('input[type="text"]');
          this.caretPosition = input.selectionStart;
          this.$nextTick(() => {
            const caretPosition = this.caretPosition === -1 ? input.value.length : this.caretPosition;
            input.setSelectionRange(caretPosition, caretPosition);
          });
        }

        if (!this.autoComplete) event.stopPropagation();
        event.preventDefault();
        this.hideMenu();
        this.isFocused = true;
        this.$emit('on-clickoutside', event);
      } else {
        this.caretPosition = -1;
        this.isFocused = false;
      }
    },
    reset() {
      this.query = '';
      this.focusIndex = -1;
      this.unchangedQuery = true;
      this.values = [];
      this.filterQueryChange = false;
    },
    handleKeydown(e) {
      const key = e.key || e.code;
      if (key === 'Backspace') {
        return; // so we don't call preventDefault
      }

      if (this.visible) {
        e.preventDefault();
        if (key === 'Tab') {
          e.stopPropagation();
        }

        // Esc slide-up
        if (key === 'Escape') {
          e.stopPropagation();
          this.hideMenu();
        }
        // next
        if (key === 'ArrowUp') {
          this.navigateOptions(-1);
        }
        // prev
        if (key === 'ArrowDown') {
          this.navigateOptions(1);
        }
        // enter
        if (key === 'Enter') {
          if (this.focusIndex === -1) return this.hideMenu();
          const optItem = this.filteredOptions[this.focusIndex];

          // fix a script error when searching
          if (optItem) {
            const option = this.getOptionData(optItem.value);
            this.onOptionClick(option);
          } else {
            this.hideMenu();
          }
        }
      } else {
        const keysThatCanOpenSelect = ['ArrowUp', 'ArrowDown'];
        if (keysThatCanOpenSelect.includes(e.key)) this.toggleMenu(null, true);
      }
    },
    navigateOptions(direction) {
      const optionsLength = this.filteredOptions.length - 1;

      let index = this.focusIndex + direction;
      if (index < 0) index = optionsLength;
      if (index > optionsLength) index = 0;

      // find nearest option in case of disabled options in between
      if (direction > 0) {
        let nearestActiveOption = -1;
        for (let i = 0; i < this.filteredOptions.length; i++) {
          const optionIsActive = !this.filteredOptions[i].disabled;
          if (optionIsActive) nearestActiveOption = i;
          if (nearestActiveOption >= index) break;
        }
        index = nearestActiveOption;
      } else {
        let nearestActiveOption = this.filteredOptions.length;
        for (let i = optionsLength; i >= 0; i--) {
          const optionIsActive = !this.filteredOptions[i].disabled;
          if (optionIsActive) nearestActiveOption = i;
          if (nearestActiveOption <= index) break;
        }
        index = nearestActiveOption;
      }

      this.focusIndex = index;
    },
    onOptionClick(option) {
      let filteredOptions = this.filteredOptions;
      filteredOptions.find(({ value }) => value === option.value);
      if (this.multiple) {
        // keep the query for remote select
        if (this.remote) this.lastRemoteQuery = this.lastRemoteQuery || this.query;
        else this.lastRemoteQuery = '';

        const valueIsSelected = this.values.find(({ value }) => value === option.value);
        if (valueIsSelected) {
          this.values = this.values.filter(({ value }) => value !== option.value);
        } else {
          this.values = this.values.concat(option);
        }

        this.isFocused = true; // so we put back focus after clicking with mouse on option elements
      } else {
        // this.query = String(option.label).trim();
        this.values = [option];
        this.lastRemoteQuery = '';
        this.hideMenu();
      }

      this.focusIndex = this.filteredOptions.findIndex((optItem) => {
        return optItem.value === option.value;
      });

      if (this.filterable) {
        const inputField = this.$el.querySelector('input[type="text"]');
        if (!this.autoComplete) this.$nextTick(() => inputField.focus());
      }
      this.broadcast('Drop', 'on-update-popper');
      setTimeout(() => {
        this.filterQueryChange = false;
      }, ANIMATION_TIMEOUT);
    },
    onQueryChange(query) {
      if (query.length > 0 && query !== this.query) {
        // in 'AutoComplete', when set an initial value asynchronously,
        // the 'dropdown list' should be stay hidden.
        // [issue #5150]
        if (this.autoComplete) {
          let isInputFocused =
            document.hasFocus && document.hasFocus() && document.activeElement === this.$el.querySelector('input');
          this.visible = isInputFocused;
        } else {
          this.visible = true;
        }
      }
      this.query = query;
      this.unchangedQuery = this.visible;
      this.filterQueryChange = true;
    },
    toggleHeaderFocus({ type }) {
      if (this.itemDisabled) {
        return;
      }
      this.isFocused = type === 'focus';
    },
    /* updateSlotOptions(){
                this.slotOptions = this.$slots.default;
            }, */
    checkUpdateStatus() {
      if (this.getInitialValue().length > 0 && this.options.length === 0) {
        this.hasExpectedValue = true;
      }
    },
    // 4.0.0 create new item
    handleCreateItem() {
      if (this.allowCreate && this.query !== '' && this.showCreateItem) {
        const query = this.query;
        this.$emit('on-create', query);
        this.query = '';

        const option = {
          value: query,
          label: query,
          tag: undefined
        };
        if (this.multiple) {
          this.onOptionClick(option);
        } else {
          // 单选时如果不在 nextTick 里执行，无法赋值
          this.$nextTick(() => this.onOptionClick(option));
        }
      }
    }
  },
  watch: {
    value(value) {
      const { getInitialValue, getOptionData, publicValue, values } = this;

      this.checkUpdateStatus();

      if (value === '') this.values = [];
      else if (checkValuesNotEqual(value, publicValue, values)) {
        this.$nextTick(() => {
          this.values = getInitialValue().map(getOptionData).filter(Boolean);
          if (!this.multiple) this.dispatch('FormItem', 'on-form-change', this.publicValue);
        });
      }
    },
    values(now, before) {
      const newValue = JSON.stringify(now);
      const oldValue = JSON.stringify(before);
      // v-model is always just the value, event with labelInValue === true
      const vModelValue =
        this.publicValue && this.labelInValue
          ? this.multiple
            ? this.publicValue.map(({ value }) => value)
            : this.publicValue.value
          : this.publicValue;
      const shouldEmitInput = newValue !== oldValue && vModelValue !== this.value;
      if (shouldEmitInput) {
        this.$emit('input', vModelValue); // to update v-model
        this.$emit('on-change', this.publicValue);
        this.dispatch('FormItem', 'on-form-change', this.publicValue);
      }
    },
    query(query) {
      this.$emit('on-query-change', query);
      const { remoteMethod } = this;
      // const hasValidQuery = query !== '' && (query !== lastRemoteQuery || !lastRemoteQuery);
      const shouldCallRemoteMethod = remoteMethod;
      // this.preventRemoteCall = false; // remove the flag

      if (shouldCallRemoteMethod) {
        this.focusIndex = -1;
        // const promise = this.remoteMethod(query);
        this.remoteMethod(query);
        this.initialLabel = '';
        /* if (promise && promise.then){
                        promise.then(options => {
                            if (options) this.options = options;
                        });
                    } */
      }
      if (query !== '' && this.remote) this.lastRemoteQuery = query;
    },
    /* loading(state){
                if (state === false){
                    this.updateSlotOptions();
                }
            }, */
    isFocused() {
      const el = this.filterable ? this.$el.querySelector('input[type="text"]') : this.$el;
      el[this.isFocused ? 'focus' : 'blur']();

      // restore query value in filterable single selects
      /* const [selectedOption] = this.values;
                if (selectedOption && this.filterable && !this.multiple && !focused){
                    const selectedLabel = String(selectedOption.label || selectedOption.value).trim();
                    if (selectedLabel && this.query !== selectedLabel) {
                        this.preventRemoteCall = true;
                        this.query = selectedLabel;
                    }
                } */
    },
    focusIndex(index) {
      if (index < 0 || this.autoComplete) return;
      // update scroll
      const optionValue = this.filteredOptions[index].value;
      const optionInstance = findChild(this, ({ $options }) => {
        return $options.componentName === 'f-select-item' && $options.propsData.value === optionValue;
      });

      let bottomOverflowDistance =
        optionInstance.$el.getBoundingClientRect().bottom - this.$refs.dropdown.$el.getBoundingClientRect().bottom;
      let topOverflowDistance =
        optionInstance.$el.getBoundingClientRect().top - this.$refs.dropdown.$el.getBoundingClientRect().top;
      if (bottomOverflowDistance > 0) {
        this.$refs.dropdown.$el.scrollTop += bottomOverflowDistance;
      }
      if (topOverflowDistance < 0) {
        this.$refs.dropdown.$el.scrollTop += topOverflowDistance;
      }
    },
    dropVisible(open) {
      this.broadcast('Drop', open ? 'on-update-popper' : 'on-destroy-popper');
    },
    options() {
      if (this.hasExpectedValue && this.options.length > 0) {
        if (this.values.length === 0) {
          this.values = this.getInitialValue();
        }
        this.values = this.values.map(this.getOptionData).filter(Boolean);
        this.hasExpectedValue = false;
      }

      if (this.options && this.options.length === 0) ;

      // 当 dropdown 一开始在控件下部显示，而滚动页面后变成在上部显示，如果选项列表的长度由内部动态变更了(搜索情况)
      // dropdown 的位置不会重新计算，需要重新计算
      this.broadcast('Drop', 'on-update-popper');
    },
    visible(state) {
      if (!this.visible) {
        // 关闭下拉框时，取消搜索模式
        this.$refs.selectHeadRef.searching = false;
      }
      this.$emit('on-open-change', state);
    }
    /* slotOptions(options, old){
                // #4626，当 Options 的 label 更新时，v-model 的值未更新
                // remote 下，调用 getInitialValue 有 bug
                if (!this.remote) {
                    const values = this.getInitialValue();
                    if (this.flatOptions && this.flatOptions.length && values.length && !this.multiple) {
                        this.values = values.map(this.getOptionData).filter(Boolean);
                    }
                }

                // 当 dropdown 在控件上部显示时，如果选项列表的长度由外部动态变更了，
                // dropdown 的位置会有点问题，需要重新计算
                if (options && old && options.length !== old.length) {
                    this.broadcast('Drop', 'on-update-popper');
                }
            }, */
  }
};

/* script */
const __vue_script__$G = script$G;

/* template */
var __vue_render__$G = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{directives:[{name:"click-outside",rawName:"v-click-outside:[capture]",value:(_vm.onClickOutside),expression:"onClickOutside",arg:_vm.capture},{name:"click-outside",rawName:"v-click-outside:[capture].mousedown",value:(_vm.onClickOutside),expression:"onClickOutside",arg:_vm.capture,modifiers:{"mousedown":true}},{name:"click-outside",rawName:"v-click-outside:[capture].touchstart",value:(_vm.onClickOutside),expression:"onClickOutside",arg:_vm.capture,modifiers:{"touchstart":true}}],class:_vm.classes},[_c('div',{ref:"reference",class:_vm.selectionCls,attrs:{"tabindex":_vm.selectTabindex},on:{"blur":_vm.toggleHeaderFocus,"focus":_vm.toggleHeaderFocus,"click":_vm.toggleMenu,"keydown":[function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"esc",27,$event.key,["Esc","Escape"])){ return null; }return _vm.handleKeydown($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"enter",13,$event.key,"Enter")){ return null; }return _vm.handleKeydown($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"up",38,$event.key,["Up","ArrowUp"])){ return null; }$event.preventDefault();return _vm.handleKeydown($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"down",40,$event.key,["Down","ArrowDown"])){ return null; }$event.preventDefault();return _vm.handleKeydown($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"tab",9,$event.key,"Tab")){ return null; }return _vm.handleKeydown($event)},function($event){if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"delete",[8,46],$event.key,["Backspace","Delete","Del"])){ return null; }return _vm.handleKeydown($event)}],"mouseenter":function($event){_vm.hasMouseHoverHead = true;},"mouseleave":function($event){_vm.hasMouseHoverHead = false;}}},[_vm._t("input",[_c('input',{attrs:{"type":"hidden","name":_vm.name},domProps:{"value":_vm.publicValue}}),_vm._v(" "),_c('select-head',{ref:"selectHeadRef",attrs:{"filterable":_vm.filterable,"multiple":_vm.multiple,"values":_vm.values,"clearable":_vm.canBeCleared,"prefix":_vm.prefix,"disabled":_vm.itemDisabled,"remote":_vm.remote,"input-element-id":_vm.elementId,"initial-label":_vm.initialLabel,"placeholder":_vm.placeholder,"max-tag-count":_vm.maxTagCount,"max-tag-placeholder":_vm.maxTagPlaceholder,"allow-create":_vm.allowCreate,"show-create-item":_vm.showCreateItem},on:{"on-query-change":_vm.onQueryChange,"on-input-focus":function($event){_vm.isFocused = true;},"on-input-blur":function($event){_vm.isFocused = false;},"on-clear":_vm.clearSingleSelect,"on-enter":_vm.handleCreateItem}},[_vm._t("prefix",null,{"slot":"prefix"})],2)])],2),_vm._v(" "),_c('transition',{attrs:{"name":"transition-drop"}},[_c('Drop',{directives:[{name:"show",rawName:"v-show",value:(_vm.visible),expression:"visible"},{name:"transfer-dom",rawName:"v-transfer-dom"}],ref:"dropdown",class:_vm.dropdownCls,attrs:{"placement":_vm.placement,"data-transfer":_vm.transfer,"transfer":_vm.transfer}},[_c('ul',{directives:[{name:"show",rawName:"v-show",value:(_vm.showNotFoundLabel && !_vm.allowCreate),expression:"showNotFoundLabel && !allowCreate"}],class:[_vm.prefixCls + '-not-found']},[_c('li',[_vm._v(_vm._s(_vm.localeNotFoundText))])]),_vm._v(" "),_c('ul',{class:_vm.prefixCls + '-dropdown-list'},[(_vm.showCreateItem)?_c('li',{class:_vm.prefixCls + '-item',on:{"click":_vm.handleCreateItem}},[_vm._v("\n          "+_vm._s(_vm.query)+"\n          "),_c('Icon',{class:_vm.prefixCls + '-item-enter',attrs:{"type":"md-return-left"}})],1):_vm._e(),_vm._v(" "),(!_vm.remote || (_vm.remote && !_vm.loading))?[(_vm.hasGroup)?[_vm._l((_vm.groupedFilteredOptions),function(optItems,group){return [_c('OptionGroup',{key:group,attrs:{"label":group}},[_vm._l((optItems),function(optItem){return [_vm._t("option",[_c('Option',{key:optItem.value,attrs:{"selected":optItem.selected,"tag":optItem.tag,"disabled":optItem.disabled,"value":optItem.value,"label":optItem.label}})],{"option":optItem})]})],2)]})]:[_vm._l((_vm.filteredOptions),function(optItem){return [_vm._t("option",[_c('Option',{key:optItem.value,attrs:{"selected":optItem.selected,"tag":optItem.tag,"disabled":optItem.disabled,"value":optItem.value,"label":optItem.label}})],{"option":optItem})]})]]:_vm._e()],2),_vm._v(" "),_c('ul',{directives:[{name:"show",rawName:"v-show",value:(_vm.loading),expression:"loading"}],class:[_vm.prefixCls + '-loading']},[_vm._v("\n        "+_vm._s(_vm.localeLoadingText)+"\n      ")])])],1)],1)};
var __vue_staticRenderFns__$G = [];

  /* style */
  const __vue_inject_styles__$G = undefined;
  /* scoped */
  const __vue_scope_id__$G = undefined;
  /* module identifier */
  const __vue_module_identifier__$G = undefined;
  /* functional template */
  const __vue_is_functional_template__$G = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$G = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$G, staticRenderFns: __vue_staticRenderFns__$G },
    __vue_inject_styles__$G,
    __vue_script__$G,
    __vue_scope_id__$G,
    __vue_is_functional_template__$G,
    __vue_module_identifier__$G,
    false,
    undefined,
    undefined,
    undefined
  );

function build(resourceBase) {
  const entityService = new RestService(resourceBase);
  return {
    async query(queryOptions) {
      return entityService.query(queryOptions);
    }
  };
}

function isEmpty(value) {
  // null 和 undefined
  if (_$1.isNil(value)) {
    return true;
  }
  // 空串
  if (value === '') {
    return true;
  }
  // 空数组
  if (_$1.isArray(value) && value.length === 0) {
    return true;
  }
  return false;
}

function encodeValue(value) {
  // leap 框架查询值单引号需要转义
  if (value) {
    value = value + '';
    value = value.replace(/'/g, '%27');
    value = value.replace(/\(/g, '%28');
    value = value.replace(/\)/g, '%29');
    value = value.replace(/\[/g, '%5B');
    value = value.replace(/\]/g, '%5D');
  }
  return value;
}

/**
 * 专用于选择列表单选列的render函数
 * @param {Object} context
 */
function singleSelectRadioRender(context) {
    return function (h, params) {
        var row = params.row;
        var selectedItem = context.target.selectedItem;
        var valueKey = context.target.valueKey;
        return h('Radio', {
            props: {
                value: !!(selectedItem && row[valueKey] === selectedItem[valueKey])
            },
            style: {
                marginRight: '0px'
            }
        });
    };
}
/**
 * 日期时间列render函数
 * {format}
 * @param {Object} context
 */
function dateRender(context) {
    var _format = (context && context.format) || 'YYYY-MM-DD HH:mm:ss';
    return function (h, params) {
        var fieldVal = params.row[params.column.key];
        if (!fieldVal) {
            return '';
        }
        var _d = dayjs(fieldVal);
        var _s = _d.format(_format);
        return h('span', {
            attrs: {
                title: _s
            }
        }, _s);
    };
}
/**
 * 操作列render函数
 * {operations:[{onclick,icon,title,type,color}]}
 * @param {Object} context
 */
function actionRender(context) {
    return function (h, params) {
        var row = params.row;
        var operations = context.operations || [];
        return h('div', operations.map(function (operation) {
            var props = {
                on: {
                    click: function () {
                        operation.onclick(row);
                    }
                },
                style: {
                    marginRight: '8px'
                }
            };
            if (operation.icon) {
                var icon = h('Icon', {
                    props: {
                        type: operation.icon,
                        color: operation.color
                    }
                });
                return h('a', __assign(__assign({}, props), { attrs: {
                        title: operation.title
                    } }), [icon]);
            }
            return h('Button', __assign(__assign({}, props), { props: {
                    size: 'small',
                    type: operation.type
                } }), operation.title);
        }));
    };
}
/**
 * a标签render函数，可自定义onclick操作：可用于标题列的render函数
 * {operation:{onclick,title}}
 * @param {Object} context
 */
function linkRender(context) {
    return function (h, params) {
        var row = params.row;
        var key = params.column.key;
        var operation = context.operation;
        var align = params.column.align;
        var props = {
            on: {
                click: function () {
                    operation.onclick(row);
                }
            }
        };
        var title = row[key];
        if (_$1.isFunction(operation.title)) {
            title = operation.title(row);
        }
        if (operation.tooltip) {
            var placement = 'bottom-start';
            if (align === 'right') {
                placement = 'bottom-end';
            }
            else if (align === 'center') {
                placement = 'bottom';
            }
            return h('Tooltip', {
                props: {
                    content: title,
                    transfer: true,
                    maxWidth: 300,
                    placement: placement
                },
                class: 'ivu-table-cell-tooltip'
            }, [
                h('a', __assign(__assign({}, props), { class: 'ivu-table-cell-tooltip-content' }), title)
            ]);
        }
        return h('a', __assign(__assign({}, props), { attrs: {
                title: title
            } }), title);
    };
}
/**
 * 用于状态选项列的tag式渲染
 * {tags:[{title,name,type,color,size}],tag:true|false}
 * @param {Object} context
 */
function tagRender(context) {
    return function (h, params) {
        var row = params.row;
        var key = params.column.key;
        var tagName = row[key];
        var tagsMap = _$1.keyBy(context.tags, function (t) { return t.name; });
        var currentTag = tagsMap[tagName] || {};
        var useTag = context.tag !== false;
        if (!useTag) {
            return h('span', currentTag.title || tagName);
        }
        return h('Tag', {
            props: {
                type: currentTag.type,
                color: currentTag.color,
                size: currentTag.size
            }
        }, currentTag.title || tagName);
    };
}

var basePropsMixin = {
  props: {
    /**
     * 是否多选：默认单选
     */
    multiple: {
      type: Boolean,
      default: false
    },
    /**
     * 是否可以清空选项，只在单选时有效：默认false
     */
    clearable: {
      type: Boolean,
      default: false
    },
    /**
     * 引用数据标志key
     */
    valueKey: {
      type: String,
      default: 'id'
    },
    /**
     * 引用数据显示key
     */
    labelKey: {
      type: String,
      default: 'title'
    },
    /**
     * m-table的columns属性: 同iview table的columns属性，指定引用数据显示哪些列
     */
    columns: {
      type: Array,
      required: true
    },
    /**
     * m-table的toolbar属性
     */
    toolbar: {
      type: Object
    },
    /**
     * m-table的其他属性设置
     */
    popupSettings: {
      type: Object
    },
    /**
     * 查询的queryOptions
     */
    queryOptions: {
      type: Object,
      default: () => {
        return {};
      }
    }
  }
};

//
var script$F = {
  mixins: [basePropsMixin],
  props: {
    query: {
      type: Function,
      required: true
    },
    selectedData: {
      type: Array
    },
    modalHeight: {
      type: Number
    }
  },
  data() {
    let innerColumns = this.convertedColumns();
    let selectedItem = this.convertedSelectItem();
    let innerToolbar = this.convertedToolbar();
    return {
      currentHighlightRow: null,
      selectedItem: selectedItem, // 标记当前table选中的行数据，单选为一条，多选为数组
      innerColumns: innerColumns,
      innerToolbar: innerToolbar
    };
  },
  watch: {
    selectedItem: function () {
      this.$emit('on-change', this.selectedItem);
    }
  },
  methods: {
    convertedToolbar() {
      let { toolbar } = this.popupSettings || {};
      let innerToolbar = Object.assign({}, _$1.cloneDeep(this.toolbar), _$1.cloneDeep(toolbar));
      return innerToolbar;
    },
    convertedSelectItem() {
      if (!this.multiple && !_$1.isEmpty(this.selectedData)) {
        return this.selectedData[0];
      }
      if (_$1.isEmpty(this.selectedData)) {
        return null;
      }
      return this.selectedData;
    },
    convertedColumns() {
      let innerColumns = _$1.cloneDeep(this.columns);
      innerColumns.forEach((col) => {
        if (col.type === 'index') {
          col.key = '__index__';
          col.width = col.width || 60;
        } else if (col.type === 'selection') {
          col.key = '__selection__';
          if (!this.multiple) {
            col.title = col.title || ' ';
            delete col.type;
            col.render = singleSelectRadioRender({ target: this });
          }
          col.width = col.width || 60;
        }
      });
      return innerColumns;
    },
    // 单选时生效
    handleOnCurrentChange(currentRow, _oldCurrentRow) {
      // 多选不走这里
      if (this.multiple) {
        return;
      }
      this.selectedItem = currentRow;
    },
    // 多选时生效，这里不是直接赋值，而是只考虑添加选中，在handleOnSelectCancel考虑取消选中
    handleOnSelectionChange(selection) {
      if (_$1.isEmpty(this.selectedItem)) {
        this.selectedItem = selection;
      } else if (!_$1.isEmpty(selection)) {
        let idField = this.valueKey;
        let siMap = _$1.keyBy(this.selectedItem, (si) => {
          return si[idField];
        });
        _$1.forEach(selection, (sel) => {
          let id = sel[idField];
          if (!siMap[id]) {
            this.selectedItem.push(sel);
          }
        });
      } else if (_$1.isEmpty(selection)) {
        let currentData = this.$refs.tableRef.$refs.iviewTableRef.data;
        let _selectedItem = [];
        let idField = this.valueKey;
        let currentDataMap = _$1.keyBy(currentData || [], idField);
        //这里只清除掉当前页中包含在selectedItem的数据，其他页选中的数据不能清除
        _$1.forEach(this.selectedItem, (item) => {
          if (!currentDataMap[item[idField]]) {
            _selectedItem.push(item);
          }
        });
        this.selectedItem = _$1.cloneDeep(_selectedItem);
      }
    },
    // 多选时生效，这里考虑取消选中
    handleOnSelectCancel(selection, row) {
      this.handleTagClose(row);
    },
    // 点击tab删除
    handleTagClose(item) {
      let idField = this.valueKey;
      let newSelectedItem = [];
      _$1.forEach(this.selectedItem, (si) => {
        if (si[idField] !== item[idField]) {
          newSelectedItem.push(si);
        }
      });
      this.selectedItem = newSelectedItem;
    },
    handleOnDataLoaded(evtParams) {
      // 当第一次加载数据后，如果有选中数据，则选中
      if (!this.multiple && this.selectedItem) {
        let data = evtParams.target.data;

        let index = data.findIndex((item) => {
          return item[this.valueKey] === this.selectedItem[this.valueKey];
        });
        if (index > -1) {
          this.$nextTick(() => {
            let iviewTableRef = evtParams.target.getTableRef();
            iviewTableRef.cloneData = _$1.cloneDeep(iviewTableRef.data);
            iviewTableRef.highlightCurrentRow(index);
          });
        }
      } else if (this.multiple && this.selectedItem) {
        let data = evtParams.target.data;
        this.$nextTick(() => {
          let iviewTableRef = evtParams.target.getTableRef();
          _$1.forEach(this.selectedItem, (sItem) => {
            let index = data.findIndex((item) => {
              return item[this.valueKey] === sItem[this.valueKey];
            });
            if (index > -1) {
              let objData = iviewTableRef.objData[index];
              objData._isChecked = true;
            }
          });
        });
      }
    },
    shortTitle(item) {
      let title = item[this.labelKey];
      if (!title) {
        console.error(`引用数据不存在属性：${this.labelKey}`);
      }
      if (title && title.length > 10) {
        return title.substring(0, 10) + '...';
      }
      return title;
    },
    doQuery(ctx) {
      return leapQueryConvertor.exec(this.query, ctx, (queryOptions) => {
        let filters = queryOptions.filters || this.queryOptions.filters;
        if (queryOptions.filters && this.queryOptions.filters) {
          filters = queryOptions.filters + ' and ' + this.queryOptions.filters;
        }
        queryOptions = Object.assign(queryOptions, this.queryOptions, { filters });
      });
    }
  }
};

/* script */
const __vue_script__$F = script$F;

/* template */
var __vue_render__$F = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"fuse-flex-left"},[_c('div',{staticClass:"left",style:({ height: _vm.modalHeight ? _vm.modalHeight + 'px' : '100px', overflow: 'auto' })},[_c('m-table',{ref:"tableRef",attrs:{"show-config-columns-btn":false,"highlight-row":!_vm.multiple,"query":_vm.doQuery,"columns":_vm.innerColumns,"toolbar":_vm.innerToolbar},on:{"on-select-cancel":_vm.handleOnSelectCancel,"on-current-change":_vm.handleOnCurrentChange,"on-selection-change":_vm.handleOnSelectionChange,"on-data-loaded":_vm.handleOnDataLoaded}})],1),_vm._v(" "),_c('div',{staticClass:"right",staticStyle:{"width":"200px"},style:({ height: _vm.modalHeight ? _vm.modalHeight + 'px' : '100px', overflow: 'auto' })},[_vm._m(0),_vm._v(" "),_c('div',{staticClass:"ref-entity-list-body"},[(_vm.multiple && _vm.selectedItem)?_vm._l((_vm.selectedItem),function(item){return _c('Tag',{key:item[_vm.valueKey],attrs:{"color":"success","title":item[_vm.labelKey],"closable":""},on:{"on-close":function($event){return _vm.handleTagClose(item)}}},[_vm._v(_vm._s(_vm.shortTitle(item)))])}):_vm._e(),_vm._v(" "),(!_vm.multiple && _vm.selectedItem)?_c('Tag',{attrs:{"color":"success","title":_vm.selectedItem[_vm.labelKey]}},[_vm._v(_vm._s(_vm.shortTitle(_vm.selectedItem)))]):_vm._e()],2)])])};
var __vue_staticRenderFns__$F = [function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"ref-entity-list-header"},[_c('h4',[_vm._v("已选")])])}];

  /* style */
  const __vue_inject_styles__$F = function (inject) {
    if (!inject) return
    inject("data-v-3fa70686_0", { source: ".ref-entity-list-header[data-v-3fa70686]{padding:8px 16px;background:#f9fafc;color:rgba(0,0,0,.65);border-bottom:1px solid #e8e8e8;overflow:hidden;width:100%}.ref-entity-list-body[data-v-3fa70686]{padding:16px 0 0 16px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$F = "data-v-3fa70686";
  /* module identifier */
  const __vue_module_identifier__$F = undefined;
  /* functional template */
  const __vue_is_functional_template__$F = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$F = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$F, staticRenderFns: __vue_staticRenderFns__$F },
    __vue_inject_styles__$F,
    __vue_script__$F,
    __vue_scope_id__$F,
    __vue_is_functional_template__$F,
    __vue_module_identifier__$F,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$E = {
  mixins: [basePropsMixin, ModalMixin],
  components: {
    RefEntitySelect: __vue_component__$F
  },
  props: {
    query: {
      type: Function,
      required: true
    },
    selectedData: {
      type: Array
    }
  },
  data() {
    return {};
  },
  methods: {
    confirmSelect() {
      var selectedItem = this.$refs.selectRef.selectedItem;
      this.$emit('on-confirm', selectedItem);
      this.close();
    }
  }
};

/* script */
const __vue_script__$E = script$E;

/* template */
var __vue_render__$E = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.innerModalWidth,"title":_vm.modalTitle,"scrollable":true,"mask-closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[(_vm.modalVisible)?_c('ref-entity-select',{ref:"selectRef",attrs:{"multiple":_vm.multiple,"selected-data":_vm.selectedData,"query":_vm.query,"modal-height":_vm.innerModalHeight,"value-key":_vm.valueKey,"label-key":_vm.labelKey,"columns":_vm.columns,"toolbar":_vm.toolbar,"popup-settings":_vm.popupSettings,"query-options":_vm.queryOptions}}):_vm._e()],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.confirmSelect}},[_vm._v("确定")])],1)])};
var __vue_staticRenderFns__$E = [];

  /* style */
  const __vue_inject_styles__$E = undefined;
  /* scoped */
  const __vue_scope_id__$E = undefined;
  /* module identifier */
  const __vue_module_identifier__$E = undefined;
  /* functional template */
  const __vue_is_functional_template__$E = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$E = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$E, staticRenderFns: __vue_staticRenderFns__$E },
    __vue_inject_styles__$E,
    __vue_script__$E,
    __vue_scope_id__$E,
    __vue_is_functional_template__$E,
    __vue_module_identifier__$E,
    false,
    undefined,
    undefined,
    undefined
  );

function leapQueryValueEncode(value) {
    // leap 框架查询值单引号需要转义
    if (value) {
        value = value + '';
        value = value.replace(/'/g, '%27');
        value = value.replace(/\(/g, '%28');
        value = value.replace(/\)/g, '%29');
        value = value.replace(/\[/g, '%5B');
        value = value.replace(/\]/g, '%5D');
    }
    return value;
}

//
/**
 * 选择引用数据组件，例如选择应用
 */
var script$D = {
  mixins: [basePropsMixin],
  components: {
    EntitySelectModal: __vue_component__$E,
    FSelect: __vue_component__$G
  },
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: [String, Number, Array]
    },
    /**
     * 应用数据获取地址
     */
    url: {
      type: String,
      required: true
    },
    /**
     * 下拉框默认查询数量
     */
    limit: {
      type: Number,
      default: 10
    },
    /**
     * 是否禁用
     */
    disabled: {
      type: Boolean,
      default: false
    },
    /**
     * 占位符
     */
    placeholder: {
      type: String
    },
    /**
     * label渲染自定义函数
     */
    labelFunc: {
      type: Function
    },
    /**指定固定的可选项，附加在选项最上面 */
    fixedOptions: {
      type: Array
    },
    /**是否将弹层放置于 body 内 */
    transfer: {
      type: Boolean,
      default: false
    },
    /**是否默认选中第一项 */
    selectFirstOnMounted: {
      type: Boolean,
      default: false
    }
  },
  data() {
    let { query } = build(this.url);
    return {
      innerValue: _$1.cloneDeep(this.value),
      refData: [],
      loading: false,
      query: query,
      smartQuery: _$1.debounce(this.innerQuery, 300),
      selectedData: null
    };
  },
  watch: {
    value: function () {
      if (!_$1.isEqual(this.value, this.innerValue)) {
        this.innerValue = _$1.cloneDeep(this.value);
      }
    }
  },
  async mounted() {
    let selectedData = await this.queryForSelected();
    this.selectedData = selectedData;
    this.innerQuery(null, this.selectFirstOnMounted);
  },
  methods: {
    updateValue() {
      this.selectedData = this.refData.filter((item) => {
        let id = item[this.valueKey];
        return id === this.innerValue || _$1.includes(this.innerValue, id);
      });
      //单选清空的时候返回的是undefined 需要返回null
      this.$emit('input', this.innerValue || null);
      /**
       * 选择数据变化后执行
       *
       * @event on-change
       */
      this.$emit('on-change', this.selectedData);
    },
    // 根据当前value的值，查询对应的详情数据
    async queryForSelected() {
      let data = null;
      if (!isEmpty(this.value)) {
        let ids = this.value;
        if (!_$1.isArray(this.value)) {
          ids = [this.value];
        }
        ids = ids.map((id) => `'${encodeValue(id)}'`);
        let queryOptions = Object.assign({}, this.queryOptions);
        if (queryOptions.filters) {
          queryOptions.filters += ` and ${this.valueKey} in (${ids.join(',')})`;
        } else {
          queryOptions.filters = `${this.valueKey} in (${ids.join(',')})`;
        }
        let res = await this.query(queryOptions).catch((err) => {
          console.error(err);
        });
        if (res && res.data) {
          data = res.data;
        }
      }
      return data;
    },
    /**
     * 确保已选中的数据记录selectedData，在数据集合data中
     */
    ensureSelectedData(_selectedData, data) {
      let selectedData = _$1.cloneDeep(_selectedData) || [];
      if (this.fixedOptions) {
        let fixedOptionList = [];
        let selectedDataMap = _$1.keyBy(selectedData, (s) => {
          return s[this.valueKey];
        });
        this.fixedOptions.forEach((fixedItem) => {
          if (!selectedDataMap[fixedItem[this.valueKey]]) {
            fixedOptionList.push(fixedItem);
          }
        });
        selectedData = selectedData.concat(fixedOptionList);
      }
      // 选中的数据一定包含进来
      if (selectedData) {
        let dataMap = _$1.keyBy(data, (o) => {
          return o[this.valueKey];
        });
        selectedData.forEach((sItem) => {
          let item = Object.assign({}, sItem, {
            value: sItem[this.valueKey],
            label: sItem[this.labelKey]
          });
          let id = item[this.valueKey];
          if (!dataMap[id]) {
            data.unshift(item);
          }
        });
      }
    },
    async innerQuery(keyword, selectFirstOnMounted) {
      // 多查询一条数据，如果返回的数据刚好等于queryOptions.limit，则代表还有数据，用...显示，需要进一步搜索关键字
      let queryOptions = Object.assign({}, this.queryOptions, { limit: this.limit + 1 });
      if (keyword) {
        let _k = leapQueryValueEncode(keyword);
        if (queryOptions.filters) {
          queryOptions.filters += ` and ${this.labelKey} like '%${_k}%'`;
        } else {
          queryOptions.filters = `${this.labelKey} like '%${_k}%'`;
        }
      }
      this.loading = true;
      let res = await this.query(queryOptions).catch((err) => {
        console.error(err);
        this.loading = false;
      });
      this.loading = false;
      if (res && res.data) {
        let data = res.data;
        if (data.length > this.limit) {
          data[data.length - 1] = {
            value: '...',
            [this.labelKey]: '...',
            [this.valueKey]: '...',
            disabled: true
          };
        }
        this.ensureSelectedData(this.selectedData, data);
        let refData = data.map((item) => {
          return Object.assign(item, {
            value: item[this.valueKey],
            label: this.labelFunc ? this.labelFunc(item) : item[this.labelKey]
          });
        });
        this.refData = refData;

        //判断是否需要默认选中列表的第一项
        if (selectFirstOnMounted) {
          this.innerValue = this.refData[0][this.valueKey];
          this.updateValue();
        }
      }
    },
    toggle() {
      this.$refs.modalRef.toggleModal();
    },
    handleOnConfirm(selectedItem) {
      let innerValue = null;
      if (_$1.isEmpty(selectedItem)) {
        innerValue = null;
      } else {
        if (this.multiple) {
          innerValue = selectedItem.map((item) => {
            return item[this.valueKey];
          });
        } else {
          innerValue = selectedItem[this.valueKey];
        }
      }
      let selectedData = this.multiple ? selectedItem : [selectedItem];
      this.ensureSelectedData(selectedData, this.refData);
      this.innerValue = innerValue;
      this.updateValue();
    }
  }
};

/* script */
const __vue_script__$D = script$D;

/* template */
var __vue_render__$D = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"fuse-input-group"},[_vm._t("default",[_c('f-select',{ref:"selectRef",staticClass:"fuse-input-group-content",attrs:{"filterable":"","clearable":_vm.clearable,"placeholder":_vm.placeholder,"disabled":_vm.disabled,"loading":_vm.loading,"multiple":_vm.multiple,"remote-method":_vm.smartQuery,"options":_vm.refData,"transfer":_vm.transfer},on:{"on-change":_vm.updateValue},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}}),_vm._v(" "),_c('Button',{staticClass:"fuse-input-group-append",attrs:{"disabled":_vm.disabled,"type":"primary"},on:{"click":function($event){return _vm.toggle()}}},[_c('Icon',{attrs:{"type":"ios-search"}})],1)],{"disabled":_vm.disabled}),_vm._v(" "),_c('EntitySelectModal',{ref:"modalRef",attrs:{"multiple":_vm.multiple,"columns":_vm.columns,"toolbar":_vm.toolbar,"popup-settings":_vm.popupSettings,"selected-data":_vm.selectedData,"value-key":_vm.valueKey,"label-key":_vm.labelKey,"query":_vm.query,"query-options":_vm.queryOptions},on:{"on-confirm":_vm.handleOnConfirm}})],2)};
var __vue_staticRenderFns__$D = [];

  /* style */
  const __vue_inject_styles__$D = undefined;
  /* scoped */
  const __vue_scope_id__$D = undefined;
  /* module identifier */
  const __vue_module_identifier__$D = undefined;
  /* functional template */
  const __vue_is_functional_template__$D = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$D = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$D, staticRenderFns: __vue_staticRenderFns__$D },
    __vue_inject_styles__$D,
    __vue_script__$D,
    __vue_scope_id__$D,
    __vue_is_functional_template__$D,
    __vue_module_identifier__$D,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 多图片上传组件
 */
var script$C = {
  mixins: [vModelMixin],
  props: {
    /**
     * 图片显示宽度
     */
    width: {
      type: Number,
      default: 130
    },
    /**
     * 图片显示高度
     */
    height: {
      type: Number,
      default: 150
    },
    /**
     * 上传图标
     */
    icon: {
      type: String,
      default: 'ios-image-outline'
    },
    maxSize: {
      type: Number,
      default: 1 // 默认1M
    }
  }
};

/* script */
const __vue_script__$C = script$C;

/* template */
var __vue_render__$C = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('MMultiImageUpload',{attrs:{"upload-policy":_vm.getUploadPolicy(),"width":_vm.width,"disabled":_vm.disabled,"height":_vm.height,"format":_vm.format,"icon":_vm.icon,"max-size":_vm.maxSize,"error-callback":_vm.errorCallback},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}})};
var __vue_staticRenderFns__$C = [];

  /* style */
  const __vue_inject_styles__$C = undefined;
  /* scoped */
  const __vue_scope_id__$C = undefined;
  /* module identifier */
  const __vue_module_identifier__$C = undefined;
  /* functional template */
  const __vue_is_functional_template__$C = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$C = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$C, staticRenderFns: __vue_staticRenderFns__$C },
    __vue_inject_styles__$C,
    __vue_script__$C,
    __vue_scope_id__$C,
    __vue_is_functional_template__$C,
    __vue_module_identifier__$C,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 单文件上传组件
 */
var script$B = {
  mixins: [vModelMixin]
};

/* script */
const __vue_script__$B = script$B;

/* template */
var __vue_render__$B = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('m-upload',{attrs:{"upload-policy":_vm.getUploadPolicy(),"multiple":false,"disabled":_vm.disabled,"format":_vm.format,"max-size":_vm.maxSize,"error-callback":_vm.errorCallback},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}})};
var __vue_staticRenderFns__$B = [];

  /* style */
  const __vue_inject_styles__$B = undefined;
  /* scoped */
  const __vue_scope_id__$B = undefined;
  /* module identifier */
  const __vue_module_identifier__$B = undefined;
  /* functional template */
  const __vue_is_functional_template__$B = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$B = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$B, staticRenderFns: __vue_staticRenderFns__$B },
    __vue_inject_styles__$B,
    __vue_script__$B,
    __vue_scope_id__$B,
    __vue_is_functional_template__$B,
    __vue_module_identifier__$B,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 多文件上传组件
 */
var script$A = {
  mixins: [vModelMixin]
};

/* script */
const __vue_script__$A = script$A;

/* template */
var __vue_render__$A = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('m-upload',{attrs:{"upload-policy":_vm.getUploadPolicy(),"multiple":true,"disabled":_vm.disabled,"max-length":_vm.maxLength,"format":_vm.format,"max-size":_vm.maxSize,"error-callback":_vm.errorCallback},model:{value:(_vm.innerValue),callback:function ($$v) {_vm.innerValue=$$v;},expression:"innerValue"}})};
var __vue_staticRenderFns__$A = [];

  /* style */
  const __vue_inject_styles__$A = undefined;
  /* scoped */
  const __vue_scope_id__$A = undefined;
  /* module identifier */
  const __vue_module_identifier__$A = undefined;
  /* functional template */
  const __vue_is_functional_template__$A = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$A = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$A, staticRenderFns: __vue_staticRenderFns__$A },
    __vue_inject_styles__$A,
    __vue_script__$A,
    __vue_scope_id__$A,
    __vue_is_functional_template__$A,
    __vue_module_identifier__$A,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 组织选择组件
 */
var script$z = {
  mixins: [ModalMixin, Emitter],
  props: {
    value: {
      type: [String, Number, Array]
    },
    multiple: {
      type: Boolean,
      default: false
    },
    queryMethods: {
      type: Object
    },
    labelKey: {
      type: String
    },
    valueKey: {
      type: String
    },
    disabled: {
      type: Boolean,
      default: false
    },
    //不能选择子组织（防止形成环）
    disabledChild: {
      type: Boolean,
      default: false
    },
    disabledId: {
      type: [String, Array]
    }
  },
  data() {
    return {
      innerValue: _.cloneDeep(this.value)
    };
  },
  watch: {
    value: function () {
      if (!_.isEqual(this.value, this.innerValue)) {
        this.innerValue = _.cloneDeep(this.value);
      }
    }
  },
  methods: {
    // 弹出选择组件后，选完数据后回调函数
    confirmSelect() {
      var selectRef = this.$refs.selectRef;
      var selectedIds = selectRef.selectedIds || [];
      var value = null;
      if (selectedIds.length > 0 && !this.multiple) {
        value = selectedIds[0];
      } else if (selectedIds.length > 0) {
        value = selectedIds;
      }
      this.$emit('input', value);
      this.$emit('on-change', value, selectRef.selectedOrgDetails);
      this.dispatch('FormItem', 'on-form-change', value);
      this.close();
    },
    handleOnInited(selectedOrgDetails) {
      this.$emit('on-change', this.innerValue, selectedOrgDetails);
    }
  }
};

/* script */
const __vue_script__$z = script$z;

/* template */
var __vue_render__$z = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('div',{on:{"click":function($event){return _vm.toggleModal()}}},[_vm._t("default",[_c('Button',{attrs:{"shape":"circle","icon":"md-add","disabled":_vm.disabled}})],{"disabled":_vm.disabled})],2),_vm._v(" "),_c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.innerModalWidth,"title":_vm.modalTitle,"scrollable":true,"mask-closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[_vm._t("header"),_vm._v(" "),_c('m-org-selector',{ref:"selectRef",attrs:{"initial-value":_vm.innerValue,"multiple":_vm.multiple,"height":_vm.innerModalHeight,"label-key":_vm.labelKey,"value-key":_vm.valueKey,"disabled-child":_vm.disabledChild,"disabled-id":_vm.disabledId,"query-methods":_vm.queryMethods},on:{"on-inited":_vm.handleOnInited}})],2),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.confirmSelect}},[_vm._v("确定")])],1)])],1)};
var __vue_staticRenderFns__$z = [];

  /* style */
  const __vue_inject_styles__$z = undefined;
  /* scoped */
  const __vue_scope_id__$z = undefined;
  /* module identifier */
  const __vue_module_identifier__$z = undefined;
  /* functional template */
  const __vue_is_functional_template__$z = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$z = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$z, staticRenderFns: __vue_staticRenderFns__$z },
    __vue_inject_styles__$z,
    __vue_script__$z,
    __vue_scope_id__$z,
    __vue_is_functional_template__$z,
    __vue_module_identifier__$z,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$y = {
  props: {
    context: {
      type: Object,
      required: true
    },
    renderFormat: {
      type: Function
    },
    parentSelect: {
      type: Object
    },
    search: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      loading: false
    };
  },
  computed: {
    isOrg: function () {
      return this.context.data._actor_type_ === 'org';
    },
    isUser: function () {
      return this.context.data._actor_type_ === 'user';
    },
    lastChar: function () {
      let title = this.context.data.title || '';
      return title.substr(title.length - 1);
    },
    // 待选数据的subtitle
    subtitle: function () {
      if (this.renderFormat) {
        return this.renderFormat(this.context.data.originData, this.search, false);
      }
      let org = this.context.data.originData.org;
      if (this.search && org && org[this.parentSelect.orgLabelKey]) {
        return `- ${org[this.parentSelect.orgLabelKey]}`;
      }
      return '';
    }
  },
  watch: {
    context: {
      handler() {
        if (this.loading) {
          if (this.context.data.expand) {
            this.emitActor();
            this.loading = false;
          }
        }
      }
    }
  },
  methods: {
    emitActor() {
      let users = this.context.data.children.filter((o) => {
        return o._actor_type_ === 'user' && !o.disabled;
      });
      this.$emit('on-add-actor', users);
    },
    handleExpand() {
      if (this.isUser) {
        return;
      }
      let parent = this.$parent;
      parent.handleExpand();
    },
    handleOnAddOrgUsers() {
      if (!this.context.data.expand) {
        this.handleExpand();
        this.loading = true;
        return;
      }
      this.emitActor();
    }
  }
};

/* script */
const __vue_script__$y = script$y;

/* template */
var __vue_render__$y = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:{ 'tree-item-disabled': _vm.context.data.disabled && _vm.isUser },on:{"click":_vm.handleExpand}},[(_vm.isUser)?_c('span',{staticClass:"tree-item-avatar-title"},[_c('Avatar',{attrs:{"size":"22"}},[_vm._v(_vm._s(_vm.lastChar))]),_vm._v(" "),_c('Ellipsis',{attrs:{"text":_vm.context.data.title,"length":10,"title":_vm.context.data.title}}),_vm._v(" "),_c('Ellipsis',{staticClass:"subtitle",attrs:{"text":_vm.subtitle,"length":10,"title":_vm.subtitle}})],1):_c('Ellipsis',{staticClass:"title",attrs:{"text":_vm.context.data.title,"length":13,"title":_vm.context.data.title}}),_vm._v(" "),(_vm.isOrg && _vm.parentSelect.multiple)?_c('span',{staticClass:"right-toolbar"},[_c('Icon',{attrs:{"type":"md-add","title":"选择组织内所有用户"},on:{"click":function($event){$event.stopPropagation();return _vm.handleOnAddOrgUsers($event)}}})],1):_vm._e()],1)};
var __vue_staticRenderFns__$y = [];

  /* style */
  const __vue_inject_styles__$y = undefined;
  /* scoped */
  const __vue_scope_id__$y = undefined;
  /* module identifier */
  const __vue_module_identifier__$y = undefined;
  /* functional template */
  const __vue_is_functional_template__$y = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$y = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$y, staticRenderFns: __vue_staticRenderFns__$y },
    __vue_inject_styles__$y,
    __vue_script__$y,
    __vue_scope_id__$y,
    __vue_is_functional_template__$y,
    __vue_module_identifier__$y,
    false,
    undefined,
    undefined,
    undefined
  );

var baseMixin = {
  mixins: [buildQueryMethodsMixin, Emitter],
  props: {
    /**
     * 占位符
     */
    placeholder: {
      type: String
    },
    /**
     * 数据量较大时提示语
     */
    moreDataTips: {
      type: String,
      default: '数据量较大，未展示所有数据，请使用搜索过滤'
    },
    /**
     * 查询默认最大数量
     */
    limit: {
      type: Number,
      default: 50
    },
    /**
     * 查询函数
     */
    queryMethods: {
      type: Object
    },
    /**
     * 用户显示key
     */
    labelKey: {
      type: String,
      default() {
        return userSelectSetting().nameField;
      }
    },
    /**
     * 用户标志key
     */
    valueKey: {
      type: String,
      default() {
        return userSelectSetting().idField;
      }
    },
    /**
     * 组织显示key
     */
    orgLabelKey: {
      type: String,
      default() {
        return orgSelectSetting().nameField;
      }
    },
    /**
     * 组织标志key
     */
    orgValueKey: {
      type: String,
      default() {
        return orgSelectSetting().idField;
      }
    },
    /**
     * 需要被禁用的值
     */
    disabledValue: {
      type: Array
    },
    /**
     * 只读的值，不可删除
     */
    readonlyValue: {
      type: Array
    },
    /**
     * 设置多选：默认多选
     */
    multiple: {
      type: Boolean,
      default: true
    },
    /**
     * 每行数据自定义渲染器
     */
    renderFormat: {
      type: Function
      /* default:function(item,search,isSelected){
        if(search){
          if(item.org){

            return ` - ${item.org.name}`;
          }
          return ''
        }
        if(isSelected){
          return ' - ${item.org.name}'
        }
        return ` - ${item.tenantId?item.tenantId:''}`
      } */
    },
    /**
     * 默认显示未知部门属性
     */
    unknownOrgUserSettings: {
      type: Object,
      default() {
        return {
          show: true, //默认显示未知部门用户
          label: '未设置' //未知部门节点标题
        };
      }
    },
    /**
     * 全局查询参数
     */
    globalQueryOptions: {
      type: Object,
      default: () => {
        return {};
      }
    },
    /**
     * 全局config HttpRequest第三个参数
     */
    globalConfig: {
      type: Object,
      default: () => {
        return {};
      }
    }
  },
  data() {
    let innerQueryMethods = this.buildQueryMethods(this.globalQueryOptions, this.globalConfig);
    return {
      innerQueryMethods: innerQueryMethods
    };
  }
};

var selectMixin = {
  mixins: [baseMixin],
  props: {
    height: {
      type: Number,
      default: 370
    },
    initialValue: {
      type: Array
    }
  },
  data() {
    let curUserOrgId = Session.getCurrentUser().org_id;
    let myOrg = { _actor_type_: 'org' };
    myOrg[this.orgValueKey] = curUserOrgId;
    myOrg[this.orgLabelKey] = '我的部门';
    return {
      selectedData: [],
      queryKeyword: '',
      hasMoreData: false,
      hasMoreSearchedData: false,
      myOrgTreeData: {
        id: curUserOrgId,
        title: '我的部门',
        _actor_type_: 'org',
        children: [],
        expand: false,
        disabled: true,
        originData: myOrg
      },
      allOrgTreeData: [],
      curUserOrgId: curUserOrgId,
      searchedTreeData: [], // 输入搜索关键字后，查询到数据
      smartQuery: _$1.debounce(this.query, 300),
      treeData: []
    };
  },
  computed: {
    // treeData: function () {

    // },
    innerHeight: function () {
      return this.height - 72;
    }
  },
  watch: {
    queryKeyword: function () {
      this.smartQuery();
    },
    selectedData: function () {
      this.$emit('on-change', this.selectedData);
    }
  },
  async mounted() {
    // 首先查询'我的部门'的用户和部门
    let { hasMoreUsers, userTreeData } = await this.getOrgUsers(this.curUserOrgId);
    let myOrgRes = await this.innerQueryMethods.queryOrgByIds([this.curUserOrgId]);
    if (!_$1.isEmpty(myOrgRes)) {
      let myOrg = myOrgRes[0];
      myOrg._actor_type_ = 'org';
      this.myOrgTreeData.originData = myOrg;
    }
    // 查询所有部门数据
    let hasMoreOrgs = false;
    let rootRes = await this.innerQueryMethods.queryRootOrg();
    let rootOrgs = rootRes.data;
    hasMoreOrgs = rootRes.hasMoreData;
    let orgTreeData = this.toOrgTreeData(rootOrgs);
    this.hasMoreData = hasMoreUsers || hasMoreOrgs;
    this.myOrgTreeData.children = userTreeData;
    this.myOrgTreeData.expand = true;
    this.allOrgTreeData = orgTreeData;
    this.buildTreeData();
  },
  methods: {
    buildTreeData() {
      let treeData = [];
      // 我的部门不存在，不加入
      if (this.myOrgTreeData.id) {
        treeData.push(this.myOrgTreeData);
      }
      treeData = treeData.concat(this.allOrgTreeData);
      //未知部门用户节点添加
      if (this.unknownOrgUserSettings.show) {
        treeData.push({
          id: null,
          title: this.unknownOrgUserSettings.label,
          _actor_type_: 'org',
          children: [],
          loading: false,
          expand: false,
          disabled: true,
          originData: null
        });
      }
      this.treeData = treeData;
    },
    getStateValue(stateValue, type) {
      let values = [];
      _$1.forEach(stateValue, (dv) => {
        if (_$1.isPlainObject(dv) && dv.type === type) {
          values.push(dv.value);
        } else if (type === 'user') {
          values.push(dv);
        }
      });
      return values;
    },
    getUserDisabledValue() {
      return this.getStateValue(this.disabledValue, 'user');
    },
    getOrgDisabledValue() {
      return this.getStateValue(this.disabledValue, 'org');
    },
    getReadonlyValue(type) {
      return this.getStateValue(this.readonlyValue, type || 'user');
    },
    getItemKey(item) {
      let type = item._actor_type_;
      if (type === 'user') {
        return this.valueKey;
      } else if (type === 'org') {
        return this.orgValueKey;
      }
      return this.valueKey;
    },
    isReadonlyItem(item) {
      let readonlyValue = this.getReadonlyValue(item._actor_type_);
      let itemKey = this.getItemKey(item);
      return _$1.includes(readonlyValue, item[itemKey]);
    },
    toUserTreeData(users) {
      let disabledValue = this.getUserDisabledValue();
      let userTreeData = treeUtils.toTreeData(
        users,
        {
          treeLeafKey: 'isLeaf'
        },
        (item) => {
          item.isLeaf = true;
          let id = item[this.valueKey];
          let treeItem = {
            id: id,
            title: item[this.labelKey],
            _actor_type_: 'user',
            originData: item
          };
          if (_$1.includes(disabledValue, id)) {
            treeItem.disabled = true;
          }
          return treeItem;
        }
      );
      return userTreeData;
    },
    toOrgTreeData(orgs) {
      let orgTreeData = treeUtils.toTreeData(orgs, {}, (item) => {
        let id = item[this.orgValueKey];
        let treeItem = {
          id: id,
          title: item[this.orgLabelKey],
          _actor_type_: 'org',
          originData: item,
          children: [],
          disabled: true
        };
        return treeItem;
      });
      return orgTreeData;
    },
    async getOrgUsers(orgId) {
      let params = null;
      if (orgId) {
        params = [orgId];
      }
      let res = await this.innerQueryMethods.pageQueryUserByOrg(params, null, {
        page: 1,
        pageSize: this.limit
      });
      let orgUsers = res.data;
      let hasMoreUsers = res.hasMoreData;
      let userTreeData = this.toUserTreeData(orgUsers);
      return {
        hasMoreUsers,
        userTreeData
      };
    },
    async queryByParent(item, callback) {
      // 先获取部门下的所属部门
      let orgTreeData = [];
      let hasMoreOrgs = false;
      if (item.id) {
        let res = await this.innerQueryMethods.queryOrgByParent(item.id);
        let orgs = res.data;
        hasMoreOrgs = res.hasMoreData;
        orgTreeData = this.toOrgTreeData(orgs);
      }
      // 再获取部门下的用户
      let { hasMoreUsers, userTreeData } = await this.getOrgUsers(item.id);
      this.hasMoreData = hasMoreUsers || hasMoreOrgs;

      let treeData = userTreeData.concat(orgTreeData);
      // 如果无子部门和用户，则去掉可展开图标，变为叶子节点
      if (treeData.length === 0) {
        item.expand = false;
        item.loading = false;
        delete item.loading;
        return;
      }
      callback(treeData);
    },
    clearAll() {
      let readonlyData = this.selectedData.filter((item) => {
        return this.isReadonlyItem(item);
      });
      if (!_$1.isEmpty(readonlyData)) {
        this.selectedData = readonlyData;
      } else {
        this.selectedData = [];
      }
    },
    removeActor(index) {
      this.selectedData.splice(index, 1);
    },
    lastChar(item) {
      let title = item[this.labelKey] || '';
      return title.substr(title.length - 1);
    }
  }
};

//
var script$x = {
  mixins: [selectMixin],
  data() {
    return {
      prefixCls: 'fuse-member-select'
    };
  },
  computed: {
    selectedIds: function () {
      let selectedIds = _$1.map(this.selectedData, (item) => {
        return item[this.valueKey];
      });
      return selectedIds;
    },
    selectedUsers: function () {
      let selectedUsers = _$1.keyBy(this.selectedData, (item) => {
        return item[this.valueKey];
      });
      return selectedUsers;
    }
  },
  watch: {
    initialValue: {
      handler() {
        if (!_$1.isEmpty(this.initialValue) && !_$1.isEqual(this.initialValue, this.selectedIds)) {
          this.innerQueryMethods.queryUserByIds(this.initialValue).then((users) => {
            this.addActor(users, true);
            this.$emit('on-inited', this.selectedUsers);
          });
        }
      },
      immediate: true
    }
  },

  methods: {
    query() {
      if (this.queryKeyword) {
        this.innerQueryMethods
          .pageQueryUserByKeyword(this.queryKeyword, null, {
            page: 1,
            pageSize: this.limit
          })
          .then((res) => {
            let users = res.data;
            let hasMoreData = res.hasMoreData;
            this.hasMoreSearchedData = hasMoreData;
            let searchedTreeData = this.toUserTreeData(users);
            this.searchedTreeData = searchedTreeData;
          });
      } else {
        this.hasMoreSearchedData = false;
      }
    },
    handleTreeSelectChange(selected, current) {
      if (selected.length && current._actor_type_ === 'user') {
        this.addActor(selected);
      }
    },
    addActor(users, isOrigin) {
      let selectedMap = _$1.keyBy(this.selectedData, (o) => {
        return o[this.valueKey];
      });
      let toAddedUsers = [];
      // 表示是初始赋值，直接使用原始用户数据模型
      if (isOrigin) {
        toAddedUsers = users;
      } else {
        // tree 节点返回的用户数据模型，真实用户数据模型在originData中
        // 单选直接覆盖
        if (this.multiple === false && !_$1.isEmpty(users)) {
          toAddedUsers = [users[0].originData];
        } else {
          _$1.forEach(users, (user) => {
            if (!selectedMap[user.id]) {
              toAddedUsers.push(user.originData);
            }
          });
        }
      }
      if (this.multiple === false) {
        this.selectedData = toAddedUsers;
      } else {
        this.selectedData = this.selectedData.concat(toAddedUsers);
      }
    },
    // 已选数据的subtitle
    subtitle(item) {
      if (this.renderFormat) {
        return this.renderFormat(item, false, true);
      }
      let org = item.org;
      if (org && org[this.orgLabelKey]) {
        return `- ${org[this.orgLabelKey]}`;
      }
      return '';
    },
    treeItemRender(h, context) {
      return h(__vue_component__$y, {
        props: {
          context,
          search: !!this.queryKeyword,
          renderFormat: this.renderFormat,
          parentSelect: this
        },
        on: {
          'on-add-actor': (actor) => {
            this.addActor(actor);
          }
        }
      });
    }
  }
};

/* script */
const __vue_script__$x = script$x;

/* template */
var __vue_render__$x = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:_vm.prefixCls},[_c('div',{class:_vm.prefixCls + '-left'},[_c('Input',{staticStyle:{"margin-bottom":"12px","max-width":"200px"},attrs:{"search":"","clearable":"","placeholder":_vm.placeholder},model:{value:(_vm.queryKeyword),callback:function ($$v) {_vm.queryKeyword=$$v;},expression:"queryKeyword"}}),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-left-body',style:({ height: _vm.innerHeight + 'px', overflow: 'auto' })},[(_vm.hasMoreData || _vm.hasMoreSearchedData)?_c('Alert',{staticClass:"p-sm",staticStyle:{"margin-top":"4px"}},[_vm._v(_vm._s(_vm.moreDataTips))]):_vm._e(),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(!_vm.queryKeyword),expression:"!queryKeyword"}],attrs:{"multiple":false,"data":_vm.treeData,"load-data":_vm.queryByParent,"render":_vm.treeItemRender},on:{"on-select-change":_vm.handleTreeSelectChange}}),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(_vm.queryKeyword),expression:"queryKeyword"}],attrs:{"multiple":false,"data":_vm.searchedTreeData,"render":_vm.treeItemRender},on:{"on-select-change":_vm.handleTreeSelectChange}})],1)],1),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-right'},[_c('div',{class:_vm.prefixCls + '-right-header'},[_c('span',{class:_vm.prefixCls + '-right-header-title'},[_vm._v("已选("+_vm._s(_vm.selectedData.length)+")")]),_vm._v(" "),_c('span',{class:_vm.prefixCls + '-right-header-middle'}),_vm._v(" "),_c('Button',{class:_vm.prefixCls + '-right-header-btn',attrs:{"type":"text","size":"small"},on:{"click":_vm.clearAll}},[_vm._v("清空")])],1),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-right-body',style:({ height: _vm.innerHeight + 'px', overflow: 'auto' })},[_vm._l((_vm.selectedData),function(item,index){return [_c('div',{key:item[_vm.valueKey],class:_vm.prefixCls + '-selected-item'},[_c('Avatar',{attrs:{"size":"22"}},[_vm._v(_vm._s(_vm.lastChar(item)))]),_vm._v(" "),_c('span',{class:_vm.prefixCls + '-selected-item-title'},[_c('Ellipsis',{staticClass:"title",attrs:{"text":item[_vm.labelKey],"length":10,"title":item[_vm.labelKey]}}),_vm._v(" "),_c('Ellipsis',{staticClass:"subtitle",attrs:{"text":_vm.subtitle(item),"length":10,"title":_vm.subtitle(item)}})],1),_vm._v(" "),(!_vm.isReadonlyItem(item))?_c('Icon',{attrs:{"type":"ios-close","size":"20","title":"移除"},on:{"click":function($event){return _vm.removeActor(index)}}}):_vm._e()],1)]})],2)])])};
var __vue_staticRenderFns__$x = [];

  /* style */
  const __vue_inject_styles__$x = undefined;
  /* scoped */
  const __vue_scope_id__$x = undefined;
  /* module identifier */
  const __vue_module_identifier__$x = undefined;
  /* functional template */
  const __vue_is_functional_template__$x = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$x = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$x, staticRenderFns: __vue_staticRenderFns__$x },
    __vue_inject_styles__$x,
    __vue_script__$x,
    __vue_scope_id__$x,
    __vue_is_functional_template__$x,
    __vue_module_identifier__$x,
    false,
    undefined,
    undefined,
    undefined
  );

var indexMixin = {
  mixins: [ModalMixin, baseMixin],
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: [String, Number, Array]
    },
    /**
     * 弹出选择框宽度
     */
    modalWidth: {
      type: Number,
      default: 650
    },
    /**
     * 是否禁用
     */
    disabled: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      innerValue: this.convertedValue()
    };
  },
  watch: {
    value: function () {
      let _value = this.convertedValue();
      if (!_.isEqual(_value, this.innerValue)) {
        this.innerValue = _value;
      }
    }
  },
  methods: {
    convertedValue() {
      let _value = !_.isNil(this.value) && this.multiple === false ? [this.value] : this.value;
      return _.cloneDeep(_value);
    },
    /**
     * 删除可以清理掉的数据，readonlyValue的数据不可以删除
     */
    clear() {
      var selectRef = this.$refs.selectRef;
      selectRef ? selectRef.clearAll() : this.confirmSelect();
    }
  }
};

//
/**
 * 成员选择组件，即选择用户组件
 */
var script$w = {
  mixins: [indexMixin],
  components: {
    MemberSelector: __vue_component__$x
  },
  props: {
    modalTitle: {
      type: String,
      default: '选择成员'
    }
  },
  mounted() {
    if (!_$1.isEmpty(this.innerValue)) {
      this.getInitialData(this.innerValue);
    }
  },
  methods: {
    // 弹出选择组件后，选完数据后回调函数
    confirmSelect() {
      var selectRef = this.$refs.selectRef;
      var selectedIds = (selectRef && selectRef.selectedIds) || [];
      var value = selectedIds;
      if (this.multiple === false) {
        if (!_$1.isEmpty(value)) {
          value = value[0];
        } else {
          value = null;
        }
      }
      this.$emit('input', value);
      /**
       * 选择数据变化后执行
       *
       * @event on-change
       */
      this.$emit('on-change', value, (selectRef && selectRef.selectedUsers) || {});
      this.dispatch('FormItem', 'on-form-change', value);
      this.close();
    },
    // 仅在mounted时执行一次：获取初始时选中数据的详情，方便外部使用详情数据，对组件内部无影响
    getInitialData(initialValue) {
      this.innerQueryMethods.queryUserByIds(initialValue).then((users) => {
        let selectedUsers = _$1.keyBy(users, (o) => {
          return o[this.valueKey];
        });
        this.$emit('on-change', this.innerValue, selectedUsers);
      });
    },
    handleOnInited(selectedUsers) {
      this.$emit('on-change', this.innerValue, selectedUsers);
    }
  }
};

/* script */
const __vue_script__$w = script$w;

/* template */
var __vue_render__$w = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('div',{on:{"click":function($event){return _vm.toggleModal()}}},[_vm._t("default",[_c('Button',{attrs:{"shape":"circle","icon":"md-add","disabled":_vm.disabled}})],{"disabled":_vm.disabled})],2),_vm._v(" "),_c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.innerModalWidth,"title":_vm.modalTitle,"scrollable":true,"mask-closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[(_vm.modalVisible)?_c('MemberSelector',{ref:"selectRef",attrs:{"initial-value":_vm.innerValue,"disabled-value":_vm.disabledValue,"readonly-value":_vm.readonlyValue,"multiple":_vm.multiple,"placeholder":_vm.placeholder,"height":_vm.innerModalHeight,"limit":_vm.limit,"more-data-tips":_vm.moreDataTips,"label-key":_vm.labelKey,"value-key":_vm.valueKey,"org-label-key":_vm.orgLabelKey,"org-value-key":_vm.orgValueKey,"global-query-options":_vm.globalQueryOptions,"render-format":_vm.renderFormat,"query-methods":_vm.innerQueryMethods,"unknown-org-user-settings":_vm.unknownOrgUserSettings},on:{"on-inited":_vm.handleOnInited}}):_vm._e()],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.confirmSelect}},[_vm._v("确定")])],1)])],1)};
var __vue_staticRenderFns__$w = [];

  /* style */
  const __vue_inject_styles__$w = undefined;
  /* scoped */
  const __vue_scope_id__$w = undefined;
  /* module identifier */
  const __vue_module_identifier__$w = undefined;
  /* functional template */
  const __vue_is_functional_template__$w = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$w = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$w, staticRenderFns: __vue_staticRenderFns__$w },
    __vue_inject_styles__$w,
    __vue_script__$w,
    __vue_scope_id__$w,
    __vue_is_functional_template__$w,
    __vue_module_identifier__$w,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 成员选择组件，即选择用户组件
 */
var script$v = {
  mixins: [indexMixin],
  components: {
    MemberSelector: __vue_component__$x
  },
  mounted() {
    if (!_$1.isEmpty(this.innerValue)) {
      this.getInitialData(this.innerValue);
    }
  },
  methods: {
    // 弹出选择组件后，选完数据后回调函数
    confirmSelect() {
      var selectRef = this.$refs.selectRef;
      var selectedIds = (selectRef && selectRef.selectedIds) || [];
      var value = selectedIds;
      if (this.multiple === false) {
        if (!_$1.isEmpty(value)) {
          value = value[0];
        } else {
          value = null;
        }
      }
      this.$emit('input', value);
      /**
       * 选择数据变化后执行
       *
       * @event on-change
       */
      this.$emit('on-change', value, (selectRef && selectRef.selectedUsers) || {});
      this.dispatch('FormItem', 'on-form-change', value);
    },
    // 仅在mounted时执行一次：获取初始时选中数据的详情，方便外部使用详情数据，对组件内部无影响
    getInitialData(initialValue) {
      this.innerQueryMethods.queryUserByIds(initialValue).then((users) => {
        let selectedUsers = _$1.keyBy(users, (o) => {
          return o[this.valueKey];
        });
        this.$emit('on-change', this.innerValue, selectedUsers);
      });
    },
    handleOnInited(selectedUsers) {
      this.$emit('on-change', this.innerValue, selectedUsers);
    }
  }
};

/* script */
const __vue_script__$v = script$v;

/* template */
var __vue_render__$v = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('MemberSelector',{ref:"selectRef",attrs:{"initial-value":_vm.innerValue,"disabled-value":_vm.disabledValue,"readonly-value":_vm.readonlyValue,"multiple":_vm.multiple,"placeholder":_vm.placeholder,"height":_vm.innerModalHeight,"limit":_vm.limit,"more-data-tips":_vm.moreDataTips,"label-key":_vm.labelKey,"value-key":_vm.valueKey,"org-label-key":_vm.orgLabelKey,"org-value-key":_vm.orgValueKey,"render-format":_vm.renderFormat,"query-methods":_vm.queryMethods,"unknown-org-user-settings":_vm.unknownOrgUserSettings},on:{"on-inited":_vm.handleOnInited}})};
var __vue_staticRenderFns__$v = [];

  /* style */
  const __vue_inject_styles__$v = undefined;
  /* scoped */
  const __vue_scope_id__$v = undefined;
  /* module identifier */
  const __vue_module_identifier__$v = undefined;
  /* functional template */
  const __vue_is_functional_template__$v = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$v = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$v, staticRenderFns: __vue_staticRenderFns__$v },
    __vue_inject_styles__$v,
    __vue_script__$v,
    __vue_scope_id__$v,
    __vue_is_functional_template__$v,
    __vue_module_identifier__$v,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 组织选择组件
 */
var script$u = {
  mixins: [ModalMixin, Emitter],
  props: {
    value: {
      type: [String, Number, Array]
    },
    multiple: {
      type: Boolean,
      default: false
    },
    queryMethods: {
      type: Object
    },
    labelKey: {
      type: String
    },
    valueKey: {
      type: String
    },
    disabled: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      innerValue: _.cloneDeep(this.value)
    };
  },
  watch: {
    value: function () {
      if (!_.isEqual(this.value, this.innerValue)) {
        this.innerValue = _.cloneDeep(this.value);
      }
    }
  },
  methods: {
    // 弹出选择组件后，选完数据后回调函数
    confirmSelect() {
      var selectRef = this.$refs.selectRef;
      var selectedIds = selectRef.selectedIds || [];
      var value = null;
      if (selectedIds.length > 0 && !this.multiple) {
        value = selectedIds[0];
      } else if (selectedIds.length > 0) {
        value = selectedIds;
      }
      this.$emit('input', value);
      this.$emit('on-change', value, selectRef.selectedOrgDetails);
      this.dispatch('FormItem', 'on-form-change', value);
    },
    handleOnInited(selectedOrgDetails) {
      this.$emit('on-change', this.innerValue, selectedOrgDetails);
    }
  }
};

/* script */
const __vue_script__$u = script$u;

/* template */
var __vue_render__$u = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('m-org-selector',{ref:"selectRef",attrs:{"initial-value":_vm.innerValue,"multiple":_vm.multiple,"height":_vm.innerModalHeight,"label-key":_vm.labelKey,"value-key":_vm.valueKey,"query-methods":_vm.queryMethods},on:{"on-inited":_vm.handleOnInited}})};
var __vue_staticRenderFns__$u = [];

  /* style */
  const __vue_inject_styles__$u = undefined;
  /* scoped */
  const __vue_scope_id__$u = undefined;
  /* module identifier */
  const __vue_module_identifier__$u = undefined;
  /* functional template */
  const __vue_is_functional_template__$u = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$u = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$u, staticRenderFns: __vue_staticRenderFns__$u },
    __vue_inject_styles__$u,
    __vue_script__$u,
    __vue_scope_id__$u,
    __vue_is_functional_template__$u,
    __vue_module_identifier__$u,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 成员选取和组织（部门）选取合并组件，props传入参照member-select和org-select
 * <f-member-org-select
          :disabled-member-value="[]"
          :readonly-member-value="['readonly-member-value']"
          :member-value.sync="memberValue"
          :disabled-org-value="['disabled-org-value']"
          :readonly-org-value="['readonly-org-value']"
          :org-value.sync="orgValue"
          @on-change="handleOnMemberChanged"
          ref="memberOrgRef"
        ></f-member-org-select>
  props在组件内部通过处理（member和org前缀）传给真实的组件
 */
var script$t = {
  mixins: [ModalMixin],
  components: { MemberSelector: __vue_component__$v, OrgSelector: __vue_component__$u },
  props: {
    /**
     * 弹出选择框宽度
     */
    modalWidth: {
      type: Number,
      default: 650
    }
  },
  data() {
    //去掉前缀 传进去给真实的组件
    let memberSelectorAttrs = this.buildAttrs('member');
    let orgSelectorAttrs = this.buildAttrs('org');
    return {
      current: 0,
      memberSelectorAttrs: memberSelectorAttrs,
      orgSelectorAttrs: orgSelectorAttrs,
      memberVal: null,
      memberDetail: null,
      orgVal: null,
      orgDetail: null,
      hasRender: false
    };
  },
  watch: {
    $attrs: function () {
      let memberSelectorAttrs = this.buildAttrs('member');
      let orgSelectorAttrs = this.buildAttrs('org');
      this.memberSelectorAttrs = memberSelectorAttrs;
      this.orgSelectorAttrs = orgSelectorAttrs;
    }
  },
  methods: {
    buildAttrs(preKey) {
      let ret = {};
      for (let key in this.$attrs) {
        if (key.includes(preKey)) {
          let trueKey = key.replace(`${preKey}-`, '');
          ret[trueKey] = this.$attrs[key];
        }
      }
      return ret;
    },
    toggleModal() {
      if (this.disabled) {
        return false;
      }
      if (!this.hasRender) {
        this.hasRender = true;
      }
      this.modalVisible = !this.modalVisible;
    },
    handleOnMemberChanged(val, detail) {
      this.memberVal = val;
      this.memberDetail = detail;
      //选中第一个用户的所属组织
      this.orgSelectorAttrs.value = detail[Object.keys(detail)[0]].orgId;
    },
    handleOnOrgChanged(val, detail) {
      this.orgVal = val;
      this.orgDetail = detail;
    },
    confirmSelect() {
      if (this.current === 0) {
        this.$refs.membersRef.confirmSelect();
        if (!this.memberVal || Object.keys(this.memberVal).length == 0 || this.memberVal.length == 0) {
          this.$Message.error('请选择成员！');
          return;
        }
        this.current++;
        return;
      } else {
        this.$refs.orgsRef.confirmSelect();
        //   if (!this.orgVal || Object.keys(this.orgVal).length == 0 || this.orgVal.length == 0) {
        //     this.$Message.error('请选择组织！');
        //     return;
        //   }
      }
      //通过sync改变值
      this.$emit('update:member-value', this.memberVal);
      this.$emit('update:org-value', this.orgVal);
      /**
       * 点击最后确定后执行
       *
       * @event on-change
       */
      this.$emit('on-change', {
        member: { value: this.memberVal, detail: this.memberDetail },
        org: { value: this.orgVal, detail: this.orgDetail }
      });
      this.close();
      this.current = 0;
    }
  }
};

/* script */
const __vue_script__$t = script$t;

/* template */
var __vue_render__$t = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.innerModalWidth,"title":_vm.modalTitle,"scrollable":true,"mask-closable":false,"closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"ml-lg mr-lg",attrs:{"slot":"header"},slot:"header"},[_c('Steps',{attrs:{"current":_vm.current}},[_c('Step',{attrs:{"title":"添加角色用户"}}),_vm._v(" "),_c('Step',{attrs:{"title":"管理组织（可选）"}})],1)],1),_vm._v(" "),(_vm.modalVisible)?_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[_c('MemberSelector',_vm._b({directives:[{name:"show",rawName:"v-show",value:(_vm.current == 0),expression:"current == 0"}],ref:"membersRef",on:{"on-change":_vm.handleOnMemberChanged},model:{value:(_vm.memberSelectorAttrs.value),callback:function ($$v) {_vm.$set(_vm.memberSelectorAttrs, "value", $$v);},expression:"memberSelectorAttrs.value"}},'MemberSelector',_vm.memberSelectorAttrs,false)),_vm._v(" "),_c('Alert',{directives:[{name:"show",rawName:"v-show",value:(_vm.current == 1),expression:"current == 1"}],staticClass:"m-sm",attrs:{"show-icon":""}},[_c('Icon',{attrs:{"slot":"icon","type":"ios-bulb-outline"},slot:"icon"}),_vm._v(" "),_c('template',{slot:"desc"},[_vm._v("举例：面对不同部门的管理员角色，仅创建一个部门管理员角色，然后选择不同的角色用户关联对应的部门，即可达到分别创建多个部门管理员角色的目的，"),_c('strong',[_vm._v("可不选择管理组织。")])])],2),_vm._v(" "),_c('OrgSelector',_vm._b({directives:[{name:"show",rawName:"v-show",value:(_vm.current == 1),expression:"current == 1"}],ref:"orgsRef",on:{"on-change":_vm.handleOnOrgChanged},model:{value:(_vm.orgSelectorAttrs.value),callback:function ($$v) {_vm.$set(_vm.orgSelectorAttrs, "value", $$v);},expression:"orgSelectorAttrs.value"}},'OrgSelector',_vm.orgSelectorAttrs,false))],1):_vm._e(),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{directives:[{name:"show",rawName:"v-show",value:(_vm.current !== 0),expression:"current !== 0"}],attrs:{"type":"warning"},on:{"click":function($event){_vm.current--;}}},[_vm._v("上一步")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.confirmSelect}},[_vm._v(_vm._s(_vm.current === 0 ? '下一步' : '确定'))])],1)])};
var __vue_staticRenderFns__$t = [];

  /* style */
  const __vue_inject_styles__$t = undefined;
  /* scoped */
  const __vue_scope_id__$t = undefined;
  /* module identifier */
  const __vue_module_identifier__$t = undefined;
  /* functional template */
  const __vue_is_functional_template__$t = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$t = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$t, staticRenderFns: __vue_staticRenderFns__$t },
    __vue_inject_styles__$t,
    __vue_script__$t,
    __vue_scope_id__$t,
    __vue_is_functional_template__$t,
    __vue_module_identifier__$t,
    false,
    undefined,
    undefined,
    undefined
  );

async function getInitialData(initialValue, queryMethods, valueKey, orgValueKey) {
  let orgIds = [];
  let userIds = [];
  _.forEach(initialValue, (v) => {
    if (v.type === 'org') {
      orgIds.push(v.value);
    } else if (v.type === 'user') {
      userIds.push(v.value);
    }
  });
  let users = null;
  let orgs = null;
  if (!_.isEmpty(userIds)) {
    users = await queryMethods.queryUserByIds(userIds);
  }
  if (!_.isEmpty(orgIds)) {
    orgs = await queryMethods.queryOrgByIds(orgIds);
  }
  let selectedDataMap = { user: null, org: null };
  let selectedData = [];
  if (!_.isEmpty(users)) {
    let selectedUsers = _.keyBy(users, (o) => {
      return o[valueKey];
    });
    selectedDataMap.user = selectedUsers;
  }
  if (!_.isEmpty(orgs)) {
    let selectedOrgs = _.keyBy(orgs, (o) => {
      return o[orgValueKey];
    });
    selectedDataMap.org = selectedOrgs;
  }
  _.forEach(initialValue, (v) => {
    if (v.type === 'org') {
      let org = selectedDataMap.org[v.value];
      org._actor_type_ = v.type;
      selectedData.push(org);
    } else if (v.type === 'user') {
      let user = selectedDataMap.user[v.value];
      user._actor_type_ = v.type;
      selectedData.push(user);
    }
  });
  return { selectedData, selectedDataMap };
}

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$s = {
  props: {
    context: {
      type: Object,
      required: true
    },
    renderFormat: {
      type: Function
    },
    parentSelect: {
      type: Object
    },
    search: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      loading: false
    };
  },
  watch: {
    context: {
      handler() {
        if (this.loading) {
          if (this.context.data.expand) {
            this.emitUserActor();
            this.loading = false;
          }
        }
      }
    }
  },
  computed: {
    isOrgDisabled: function () {
      let orgId = this.context.data.id;
      if (!orgId) {
        return true;
      }
      let orgDisabledValue = this.parentSelect.getOrgDisabledValue();
      return _.includes(orgDisabledValue, orgId);
    },
    isOrg: function () {
      return this.context.data._actor_type_ === 'org';
    },
    isUser: function () {
      return this.context.data._actor_type_ === 'user';
    },
    lastChar: function () {
      let title = this.context.data.title || '';
      return title.substr(title.length - 1);
    },
    // 待选数据的subtitle
    subtitle: function () {
      if (this.renderFormat) {
        return this.renderFormat(this.context.data.originData, this.search, false);
      }
      let org = this.context.data.originData.org;
      if (this.search && org) {
        return `- ${org[this.parentSelect.orgLabelKey]}`;
      }
      return '';
    }
  },
  methods: {
    emitUserActor() {
      let users = this.context.data.children.filter((o) => {
        return o._actor_type_ === 'user' && !o.disabled;
      });
      this.$emit('on-add-actor', users);
    },
    handleExpand() {
      if (this.isUser) {
        return;
      }
      let parent = this.$parent;
      parent.handleExpand();
    },
    handleOnAddOrgUsers() {
      if (!this.context.data.expand) {
        this.handleExpand();
        this.loading = true;
        return;
      }
      this.emitUserActor();
    },
    handleOnAddActor(type) {
      let actor = null;
      if (type === 'user') {
        this.handleOnAddOrgUsers();
        return;
      } else if (type === 'org') {
        actor = [this.context.data];
      }
      actor.forEach((o) => {
        o._actor_type_ = type;
      });
      this.$emit('on-add-actor', actor);
    }
  }
};

/* script */
const __vue_script__$s = script$s;

/* template */
var __vue_render__$s = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:{ 'tree-item-disabled': _vm.context.data.disabled && _vm.isUser },on:{"click":_vm.handleExpand}},[(_vm.isUser)?_c('span',{staticClass:"tree-item-avatar-title"},[_c('Avatar',{attrs:{"size":"22"}},[_vm._v(_vm._s(_vm.lastChar))]),_vm._v(" "),_c('Ellipsis',{attrs:{"text":_vm.context.data.title,"length":10,"title":_vm.context.data.title}}),_vm._v(" "),_c('Ellipsis',{staticClass:"subtitle",attrs:{"text":_vm.subtitle,"length":10,"title":_vm.subtitle}})],1):_c('Ellipsis',{staticClass:"title",attrs:{"text":_vm.context.data.title,"length":13,"title":_vm.context.data.title}}),_vm._v(" "),(_vm.isOrg && !(_vm.isOrgDisabled && _vm.parentSelect.multiple === false))?_c('span',{staticClass:"right-toolbar"},[_c('Dropdown',{attrs:{"transfer":""},on:{"on-click":_vm.handleOnAddActor}},[_c('a',{attrs:{"href":"javascript:void(0)"},on:{"click":function($event){$event.stopPropagation();}}},[_c('Icon',{attrs:{"type":"md-add","title":"选择组织或组织内所有用户"}})],1),_vm._v(" "),_c('DropdownMenu',{attrs:{"slot":"list"},slot:"list"},[_c('DropdownItem',{attrs:{"name":"org","disabled":_vm.isOrgDisabled}},[_vm._v("选择组织")]),_vm._v(" "),_c('DropdownItem',{attrs:{"name":"user","disabled":_vm.parentSelect.multiple === false}},[_vm._v("选择组织内所有用户")])],1)],1)],1):_vm._e()],1)};
var __vue_staticRenderFns__$s = [];

  /* style */
  const __vue_inject_styles__$s = undefined;
  /* scoped */
  const __vue_scope_id__$s = undefined;
  /* module identifier */
  const __vue_module_identifier__$s = undefined;
  /* functional template */
  const __vue_is_functional_template__$s = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$s = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$s, staticRenderFns: __vue_staticRenderFns__$s },
    __vue_inject_styles__$s,
    __vue_script__$s,
    __vue_scope_id__$s,
    __vue_is_functional_template__$s,
    __vue_module_identifier__$s,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$r = {
  mixins: [selectMixin],
  data() {
    return {
      prefixCls: 'fuse-member-select'
    };
  },
  computed: {
    selectedIds: function () {
      let selectedIds = _$1.map(this.selectedData, (item) => {
        if (item._actor_type_ === 'org') {
          return { type: 'org', value: item[this.orgValueKey] };
        } else if (item._actor_type_ === 'user') {
          return { type: 'user', value: item[this.valueKey] };
        }
      });
      return selectedIds;
    },
    selectedDataMap: function () {
      let selectedDataMap = { user: {}, org: {} };
      let orgs = [];
      let users = [];
      _$1.forEach(this.selectedData, (o) => {
        if (o._actor_type_ === 'org') {
          orgs.push(o);
        } else if (o._actor_type_ === 'user') {
          users.push(o);
        }
      });
      if (!_$1.isEmpty(users)) {
        selectedDataMap.user = _$1.keyBy(users, (o) => {
          return o[this.valueKey];
        });
      }
      if (!_$1.isEmpty(orgs)) {
        selectedDataMap.org = _$1.keyBy(orgs, (o) => {
          return o[this.orgValueKey];
        });
      }
      return selectedDataMap;
    }
  },
  watch: {
    initialValue: {
      handler() {
        if (!_$1.isEmpty(this.initialValue) && !_$1.isEqual(this.initialValue, this.selectedIds)) {
          getInitialData(this.initialValue, this.innerQueryMethods, this.valueKey, this.orgValueKey).then(
            ({ selectedData, selectedDataMap }) => {
              this.addActor(selectedData, true);
              this.$emit('on-inited', selectedDataMap);
            }
          );
        }
      },
      immediate: true
    }
  },

  methods: {
    async query() {
      if (this.queryKeyword) {
        let userRes = await this.innerQueryMethods.pageQueryUserByKeyword(this.queryKeyword, null, {
          page: 1,
          pageSize: this.limit
        });
        let users = userRes.data;
        let hasMoreUsers = userRes.hasMoreData;
        let searchedUserTreeData = this.toUserTreeData(users);

        let orgRes = await this.innerQueryMethods.queryOrgByKeyword(this.queryKeyword);
        let orgs = orgRes.data;
        let hasMoreOrgs = orgRes.hasMoreData;
        let searchedOrgTreeData = this.toOrgTreeData(orgs);
        this.hasMoreSearchedData = hasMoreUsers || hasMoreOrgs;
        this.searchedTreeData = searchedUserTreeData.concat(searchedOrgTreeData);
      } else {
        this.hasMoreSearchedData = false;
      }
    },
    handleTreeSelectChange(selected, current) {
      if (selected.length && current._actor_type_ === 'user') {
        this.addActor(selected);
      }
    },
    getActorKey(o) {
      if (o._actor_type_ === 'user') {
        return `user-` + o[this.valueKey];
      } else if (o._actor_type_ === 'org') {
        return `org-` + o[this.orgValueKey];
      }
    },
    addActor(actor, isOrigin) {
      let selectedMap = _$1.keyBy(this.selectedData, (o) => {
        return this.getActorKey(o);
      });
      let toAddedActor = [];
      // 表示是初始赋值，直接使用原始用户数据模型
      if (isOrigin) {
        toAddedActor = actor;
      } else {
        // tree 节点返回的用户数据模型，真实用户数据模型在originData中
        if (this.multiple === false && !_$1.isEmpty(actor)) {
          toAddedActor = [actor[0].originData];
        } else {
          _$1.forEach(actor, (o) => {
            let actorKey = this.getActorKey(o);
            if (!selectedMap[actorKey]) {
              o.originData._actor_type_ = o._actor_type_;
              toAddedActor.push(o.originData);
            }
          });
        }
      }
      if (this.multiple === false) {
        this.selectedData = toAddedActor;
      } else {
        this.selectedData = this.selectedData.concat(toAddedActor);
      }
    },
    // 已选数据的subtitle
    subtitle(item) {
      if (this.renderFormat) {
        return this.renderFormat(item, false, true);
      }
      if (item._actor_type_ === 'org') {
        return '';
      }
      let org = item.org;
      if (org) {
        return `- ${org[this.orgLabelKey]}`;
      }
      return '';
    },
    treeItemRender(h, context) {
      return h(__vue_component__$s, {
        props: {
          context,
          search: !!this.queryKeyword,
          renderFormat: this.renderFormat,
          parentSelect: this
        },
        on: {
          'on-add-actor': (actor) => {
            this.addActor(actor);
          }
        }
      });
    }
  }
};

/* script */
const __vue_script__$r = script$r;

/* template */
var __vue_render__$r = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:_vm.prefixCls},[_c('div',{class:_vm.prefixCls + '-left'},[_c('Input',{staticStyle:{"margin-bottom":"12px","max-width":"200px"},attrs:{"search":"","clearable":"","placeholder":_vm.placeholder},model:{value:(_vm.queryKeyword),callback:function ($$v) {_vm.queryKeyword=$$v;},expression:"queryKeyword"}}),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-left-body',style:({ height: _vm.innerHeight + 'px', overflow: 'auto' })},[(_vm.hasMoreData || _vm.hasMoreSearchedData)?_c('Alert',{staticClass:"p-sm",staticStyle:{"margin-top":"4px"}},[_vm._v(_vm._s(_vm.moreDataTips))]):_vm._e(),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(!_vm.queryKeyword),expression:"!queryKeyword"}],attrs:{"multiple":false,"data":_vm.treeData,"load-data":_vm.queryByParent,"render":_vm.treeItemRender},on:{"on-select-change":_vm.handleTreeSelectChange}}),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(_vm.queryKeyword),expression:"queryKeyword"}],attrs:{"multiple":false,"data":_vm.searchedTreeData,"render":_vm.treeItemRender},on:{"on-select-change":_vm.handleTreeSelectChange}})],1)],1),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-right'},[_c('div',{class:_vm.prefixCls + '-right-header'},[_c('span',{class:_vm.prefixCls + '-right-header-title'},[_vm._v("已选("+_vm._s(_vm.selectedData.length)+")")]),_vm._v(" "),_c('span',{class:_vm.prefixCls + '-right-header-middle'}),_vm._v(" "),_c('Button',{class:_vm.prefixCls + '-right-header-btn',attrs:{"type":"text","size":"small"},on:{"click":_vm.clearAll}},[_vm._v("清空")])],1),_vm._v(" "),_c('div',{class:_vm.prefixCls + '-right-body',style:({ height: _vm.innerHeight + 'px', overflow: 'auto' })},[_vm._l((_vm.selectedData),function(item,index){return [_c('div',{key:item[_vm.valueKey],class:_vm.prefixCls + '-selected-item'},[(item._actor_type_ === 'org')?_c('Avatar',{staticClass:"org-actor-first-char",attrs:{"size":"22"}},[_c('Icon',{attrs:{"type":"ios-git-network"}})],1):_c('Avatar',{attrs:{"size":"22"}},[_vm._v(_vm._s(_vm.lastChar(item)))]),_vm._v(" "),_c('span',{class:_vm.prefixCls + '-selected-item-title'},[_c('Ellipsis',{staticClass:"title",attrs:{"text":item[_vm.labelKey],"length":13,"title":item[_vm.labelKey]}}),_vm._v(" "),_c('Ellipsis',{staticClass:"subtitle",attrs:{"text":_vm.subtitle(item),"length":10,"title":_vm.subtitle(item)}})],1),_vm._v(" "),(!_vm.isReadonlyItem(item))?_c('Icon',{attrs:{"type":"ios-close","size":"20","title":"移除"},on:{"click":function($event){return _vm.removeActor(index)}}}):_vm._e()],1)]})],2)])])};
var __vue_staticRenderFns__$r = [];

  /* style */
  const __vue_inject_styles__$r = undefined;
  /* scoped */
  const __vue_scope_id__$r = undefined;
  /* module identifier */
  const __vue_module_identifier__$r = undefined;
  /* functional template */
  const __vue_is_functional_template__$r = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$r = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$r, staticRenderFns: __vue_staticRenderFns__$r },
    __vue_inject_styles__$r,
    __vue_script__$r,
    __vue_scope_id__$r,
    __vue_is_functional_template__$r,
    __vue_module_identifier__$r,
    false,
    undefined,
    undefined,
    undefined
  );

//
/**
 * 参与者选择组件，例如同时选择组织和用户
 */
var script$q = {
  mixins: [indexMixin],
  components: {
    MemberSelector: __vue_component__$r
  },
  props: {
    modalTitle: {
      type: String,
      default: '选择组织或用户'
    }
  },
  mounted() {
    if (!_$1.isEmpty(this.innerValue)) {
      this.getInitialData(this.innerValue);
    }
  },
  methods: {
    // 弹出选择组件后，选完数据后回调函数
    confirmSelect() {
      var selectRef = this.$refs.selectRef;
      var selectedIds = (selectRef && selectRef.selectedIds) || [];
      var value = selectedIds;
      if (this.multiple === false) {
        if (!_$1.isEmpty(value)) {
          value = value[0];
        } else {
          value = null;
        }
      }
      this.$emit('input', value);
      /**
       * 选择数据变化后执行
       *
       * @event on-change
       */
      this.$emit('on-change', value, (selectRef && selectRef.selectedDataMap) || {});
      this.dispatch('FormItem', 'on-form-change', value);
      this.close();
    },
    // 仅在mounted时执行一次：获取初始时选中数据的详情，方便外部使用详情数据，对组件内部无影响
    async getInitialData(initialValue) {
      let { selectedDataMap } = await getInitialData(
        initialValue,
        this.innerQueryMethods,
        this.valueKey,
        this.orgValueKey
      );
      this.$emit('on-change', this.innerValue, selectedDataMap);
    },
    handleOnInited(selectedDataMap) {
      this.$emit('on-change', this.innerValue, selectedDataMap);
    }
  }
};

/* script */
const __vue_script__$q = script$q;

/* template */
var __vue_render__$q = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('div',{on:{"click":function($event){return _vm.toggleModal()}}},[_vm._t("default",[_c('Button',{attrs:{"shape":"circle","icon":"md-add","disabled":_vm.disabled}})],{"disabled":_vm.disabled})],2),_vm._v(" "),_c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.innerModalWidth,"title":_vm.modalTitle,"scrollable":true,"mask-closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[(_vm.modalVisible)?_c('MemberSelector',{ref:"selectRef",attrs:{"initial-value":_vm.innerValue,"disabled-value":_vm.disabledValue,"readonly-value":_vm.readonlyValue,"placeholder":_vm.placeholder,"height":_vm.innerModalHeight,"limit":_vm.limit,"more-data-tips":_vm.moreDataTips,"label-key":_vm.labelKey,"value-key":_vm.valueKey,"org-label-key":_vm.orgLabelKey,"org-value-key":_vm.orgValueKey,"render-format":_vm.renderFormat,"query-methods":_vm.innerQueryMethods,"unknown-org-user-settings":_vm.unknownOrgUserSettings},on:{"on-inited":_vm.handleOnInited}}):_vm._e()],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.confirmSelect}},[_vm._v("确定")])],1)])],1)};
var __vue_staticRenderFns__$q = [];

  /* style */
  const __vue_inject_styles__$q = undefined;
  /* scoped */
  const __vue_scope_id__$q = undefined;
  /* module identifier */
  const __vue_module_identifier__$q = undefined;
  /* functional template */
  const __vue_is_functional_template__$q = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$q = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$q, staticRenderFns: __vue_staticRenderFns__$q },
    __vue_inject_styles__$q,
    __vue_script__$q,
    __vue_scope_id__$q,
    __vue_is_functional_template__$q,
    __vue_module_identifier__$q,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$p = {
  mixins: [ModalMixin, Emitter],
  props: {
    /**
     * v-model绑定
     */
    value: {
      type: [Array]
    },
    /**
     * 弹出选择框宽度
     */
    modalWidth: {
      type: Number,
      default: 650
    },
    resourceAppId: {
      type: String,
      required: true
    },
    serviceId: {
      type: String,
      required: true
    }
  },
  data() {
    return {
      innerValue: this.convertedValue(),
      modalVisible: false,
      inputVal: '',
      loadingApp: true,
      loadingClients: false,
      apps: [],
      clients: [],
      selectAppId: null,
      selectClients: [],
      externalClients: [],
      clientCache: {},
      disableCache: {}, //应用的已授权客户端
      rawApps: [],
      appTotal: -1,
      limit: 1000
    };
  },
  watch: {
    value: function () {
      let _value = this.convertedValue();
      if (!_.isEqual(_value, this.innerValue)) {
        this.innerValue = _value;
      }
    }
  },
  created() {
    this.loadApp();
  },
  methods: {
    showModal() {
      //以外部的数据为准
      this.selectClients = _.cloneDeep(this.externalClients);
      this.modalVisible = true;
    },
    convertedValue() {
      return _.cloneDeep(this.value);
    },
    confirmSelect() {
      let value = this.selectClients.map((item) => item.id);
      this.$emit('input', value);
      /**
       * 选择数据变化后执行
       *
       * @event on-change
       */
      this.externalClients = _.cloneDeep(this.selectClients);
      this.$emit('on-change', this.selectClients);
      this.dispatch('FormItem', 'on-form-change', value);
      this.close();
    },
    close() {
      this.modalVisible = false;
    },
    async loadApp() {
      this.loadingApp = true;
      let params = {
        limit: this.limit,
        total: true,
        filters: `title like '%${this.inputVal}%' and id not in ('${this.resourceAppId}')`
      };
      const { data, headers } = await appService$2.query(params);
      this.apps = data;
      this.rawApps = _.cloneDeep(this.apps);
      if (this.appTotal === -1) {
        this.appTotal = Number(headers['x-total-count']);
      }
      this.loadingApp = false;
    },
    onAppSelect(appId) {
      if (appId === this.selectAppId) return;
      this.selectAppId = appId;
      this.initClients(appId);
    },
    async initClients(appId) {
      if (this.clientCache[appId]) {
        this.clients = this.clientCache[appId];
        return;
      }
      this.loadingClients = true;
      const { data } = await appService$2.getClients(appId, { limit: 1000 });
      const { data: disableData } = await appService$2.getAuthService({
        filters: `authObjectType eq app and appId eq ${appId} and serviceId eq ${this.serviceId} and authStatus eq 1`,
        limit: 100
      });
      this.clients = data;
      this.clientCache[appId] = data;
      this.disableCache[appId] = disableData.map((item) => item.client.id);
      this.loadingClients = false;
    },
    onClientSelect(clientId) {
      if (this.disableCache[this.selectAppId].includes(clientId)) return;
      let hasClientId = this.selectClients.some((item) => item.id === clientId);
      //if (hasClientId) return;
      let targetClient = this.clients.find((item) => item.id === clientId);
      let targetApp = this.apps.find((item) => item.id === this.selectAppId);
      if (hasClientId) {
        this.selectClients = this.selectClients.filter((item) => item.id !== clientId);
      } else {
        this.selectClients.push(Object.assign(targetClient, { app: targetApp }));
      }
      //这里是单选逻辑
      // if (hasAppId) {
      //   if (!hasClientId) {
      //     //替换
      //     this.selectClients = this.selectClients
      //       .filter((item) => item.appId !== targetClient.appId)
      //       .concat([Object.assign(targetClient, { app: targetApp })]);
      //   }
      // } else {
      //   this.selectClients.push(Object.assign(targetClient, { app: targetApp }));
      // }
    },
    onClientDel(e, id) {
      this.selectClients = this.selectClients.filter((item) => item.id !== id);
    },
    onClientDelExternal(e, id) {
      this.selectClients = this.selectClients.filter((item) => item.id !== id);
      this.externalClients = this.externalClients.filter((item) => item.id !== id);
      this.confirmSelect();
    },
    onSearch: debounce(function () {
      if (this.appTotal > this.limit) {
        this.loadApp();
      } else {
        this.apps = _.cloneDeep(this.rawApps.filter((item) => item.title.includes(this.inputVal)));
      }
    }, 300)
  }
};

/* script */
const __vue_script__$p = script$p;

/* template */
var __vue_render__$p = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_vm._l((_vm.externalClients),function(item){return _c('Tag',{key:item.id,attrs:{"fade":false,"name":item.id,"type":"border","closable":"","size":"large"},on:{"on-close":_vm.onClientDelExternal}},[_vm._v(_vm._s(((item.app.title) + "(" + (item.name) + ")")))])}),_vm._v(" "),_c('Button',{attrs:{"shape":"circle","icon":"md-add"},on:{"click":_vm.showModal}}),_vm._v(" "),_c('Modal',{staticClass:"fuse-popup-modal",attrs:{"transfer":"","width":_vm.modalWidth,"title":"授权应用","scrollable":true,"mask-closable":false},model:{value:(_vm.modalVisible),callback:function ($$v) {_vm.modalVisible=$$v;},expression:"modalVisible"}},[_c('div',{staticClass:"fuse-popup-modal-body",style:({ height: _vm.innerModalHeight + 'px' })},[_c('div',{staticClass:"fuse-select-client-container"},[_c('Input',{directives:[{name:"width",rawName:"v-width",value:(250),expression:"250"}],attrs:{"placeholder":"根据应用名称搜索应用"},on:{"on-change":_vm.onSearch},model:{value:(_vm.inputVal),callback:function ($$v) {_vm.inputVal=$$v;},expression:"inputVal"}}),_vm._v(" "),_c('div',{staticClass:"fuse-client-select-card"},[_c('Card',{staticClass:"fuse-client-select-left",attrs:{"dis-hover":""}},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("应用列表")]),_vm._v(" "),(_vm.loadingApp)?_c('Spin',{attrs:{"size":"large","fix":""}}):_vm._e(),_vm._v(" "),_c('CellGroup',{on:{"on-click":_vm.onAppSelect}},_vm._l((_vm.apps),function(item){return _c('Cell',{key:item.id,attrs:{"selected":_vm.selectAppId === item.id,"title":item.title,"name":item.id}})}),1),_vm._v(" "),_c('div',{directives:[{name:"show",rawName:"v-show",value:(_vm.apps.length === 0),expression:"apps.length === 0"}],staticClass:"ivu-cell",staticStyle:{"text-align":"center"}},[_vm._v("暂无数据")])],1),_vm._v(" "),_c('Card',{staticClass:"fuse-client-select-right",attrs:{"dis-hover":""}},[_c('div',{attrs:{"slot":"title"},slot:"title"},[_vm._v("应用客户端")]),_vm._v(" "),(_vm.loadingClients)?_c('Spin',{attrs:{"size":"large","fix":""}}):_vm._e(),_vm._v(" "),(_vm.disableCache[_vm.selectAppId])?_c('CellGroup',{on:{"on-click":_vm.onClientSelect}},_vm._l((_vm.clients),function(item){return _c('Cell',{key:item.id,attrs:{"selected":_vm.selectClients.some(function (innerItem) { return item.id === innerItem.id; }),"title":_vm.disableCache[_vm.selectAppId].includes(item.id) ? item.name + '（已授权）' : item.name,"name":item.id,"disabled":_vm.disableCache[_vm.selectAppId].includes(item.id)}})}),1):_vm._e()],1)],1),_vm._v(" "),_c('div',[_c('div',{staticClass:"mb-sm"},[_vm._v("已选择的应用及其客户端：")]),_vm._v(" "),_vm._l((_vm.selectClients),function(item){return _c('Tag',{key:item.id,attrs:{"fade":false,"name":item.id,"type":"border","closable":"","size":"medium"},on:{"on-close":_vm.onClientDel}},[_vm._v(_vm._s(((item.app.title) + "(" + (item.name) + ")")))])})],2)],1)]),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"default"},on:{"click":_vm.close}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary","disabled":!_vm.selectClients.length},on:{"click":_vm.confirmSelect}},[_vm._v("确定")])],1)])],2)};
var __vue_staticRenderFns__$p = [];

  /* style */
  const __vue_inject_styles__$p = function (inject) {
    if (!inject) return
    inject("data-v-4cc5a9f7_0", { source: ".fuse-client-select-left[data-v-4cc5a9f7]{flex:1;height:100%;margin-right:16px;display:flex;flex-direction:column}.fuse-client-select-right[data-v-4cc5a9f7]{flex:1;height:100%;display:flex;flex-direction:column}.fuse-client-select-card[data-v-4cc5a9f7]{flex:1;display:flex;margin:12px 0;overflow:hidden}.fuse-client-select-card[data-v-4cc5a9f7] .ivu-card-head{background:#f9fafc}.fuse-client-select-card[data-v-4cc5a9f7] .ivu-card-body{padding:0;flex:1;overflow:auto;position:relative}.fuse-select-client-container[data-v-4cc5a9f7]{display:flex;flex-direction:column;height:100%;padding:12px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$p = "data-v-4cc5a9f7";
  /* module identifier */
  const __vue_module_identifier__$p = undefined;
  /* functional template */
  const __vue_is_functional_template__$p = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$p = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$p, staticRenderFns: __vue_staticRenderFns__$p },
    __vue_inject_styles__$p,
    __vue_script__$p,
    __vue_scope_id__$p,
    __vue_is_functional_template__$p,
    __vue_module_identifier__$p,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

/**
 * 可折叠的面板容器，用来动态显示和隐藏内容区
 **/
var script$o = {
  props: {
    /**
     * 折叠状态
     */
    collapse: {
      type: Boolean,
      default: false
    },
    /**
     * 主标题
     */
    title: {
      type: String
    },
    /**
     * 子标题
     */
    subtitle: {
      type: String
    },
    /**
     * 内容样式
     */
    bodyStyle: {
      type: [Array, Object, String],
      default() {
        return {};
      }
    },
    /**
     * 主标题样式
     */
    titleStyle: {
      type: [Array, Object, String],
      default() {
        return {
          fontSize: '18px',
          color: 'black'
        };
      }
    },
    /**
     * 子标题样式
     */
    subtitleStyle: {
      type: [Array, Object, String],
      default() {
        return {
          fontSize: '13px'
        };
      }
    },
    /**
     * 是否显示分割线
     */
    separator: {
      type: Boolean,
      default: true
    }
  },
  data() {
    return {
      prefixClass: 'f-toggle-panel',
      innerCollapseValue: this.collapse
    };
  },
  computed: {
    toggleText() {
      return this.innerCollapseValue ? '展开' : '收起';
    }
  },
  watch: {
    collapse: function () {
      this.innerCollapseValue = this.collapse;
    }
  },
  methods: {
    toggle() {
      this.innerCollapseValue = !this.innerCollapseValue;
      this.$emit('on-change', this.innerCollapseValue);
    }
  }
};

/* script */
const __vue_script__$o = script$o;

/* template */
var __vue_render__$o = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:_vm.prefixClass},[_c('div',{class:[_vm.prefixClass + '-header']},[_c('div',{class:_vm.prefixClass + '-title'},[_vm._t("header",[(_vm.title)?_c('div',{staticClass:"title",style:(_vm.titleStyle)},[_vm._v(_vm._s(_vm.title))]):_vm._e(),_vm._v(" "),(_vm.subtitle)?_c('div',{staticClass:"subtitle",style:(_vm.subtitleStyle)},[_vm._v(_vm._s(_vm.subtitle))]):_vm._e()])],2),_vm._v(" "),_c('div',{class:_vm.prefixClass + '-collapse',on:{"click":_vm.toggle}},[_vm._t("button",[_c('Button',[_vm._v(_vm._s(_vm.toggleText))])])],2)]),_vm._v(" "),(_vm.separator)?_c('Divider',{attrs:{"size":"small"}}):_vm._e(),_vm._v(" "),_c('div',{directives:[{name:"show",rawName:"v-show",value:(!_vm.innerCollapseValue),expression:"!innerCollapseValue"}],class:[_vm.prefixClass + '-body', _vm.separator ? _vm.prefixClass + '-body-has-separator' : ''],style:(_vm.bodyStyle)},[_vm._t("default")],2)],1)};
var __vue_staticRenderFns__$o = [];

  /* style */
  const __vue_inject_styles__$o = undefined;
  /* scoped */
  const __vue_scope_id__$o = undefined;
  /* module identifier */
  const __vue_module_identifier__$o = undefined;
  /* functional template */
  const __vue_is_functional_template__$o = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$o = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$o, staticRenderFns: __vue_staticRenderFns__$o },
    __vue_inject_styles__$o,
    __vue_script__$o,
    __vue_scope_id__$o,
    __vue_is_functional_template__$o,
    __vue_module_identifier__$o,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//

/**
 * 提示图标，鼠标移上去会显示提示内容
 */
var script$n = {
  props: {
    /**
     * 提示内容
     */
    content: {
      type: String
    },
    /**
     * 图标背景和内容背景是否反向
     */
    outline: {
      type: Boolean,
      default: true
    }
  },
  data: function () {
    return {};
  }
};

/* script */
const __vue_script__$n = script$n;

/* template */
var __vue_render__$n = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"info-tip"},[_c('Poptip',{attrs:{"trigger":"hover","placement":"bottom-start"}},[_c('Icon',{attrs:{"type":_vm.outline ? 'ios-information-circle-outline' : 'ios-information-circle',"color":"#2d8cf0"}}),_vm._v(" "),_c('div',{staticStyle:{"width":"400px","white-space":"normal"},attrs:{"slot":"content"},slot:"content"},[_c('p',[_vm._v(_vm._s(_vm.content))])])],1)],1)};
var __vue_staticRenderFns__$n = [];

  /* style */
  const __vue_inject_styles__$n = function (inject) {
    if (!inject) return
    inject("data-v-441a5a6a_0", { source: ".info-tip[data-v-441a5a6a]{text-align:left;display:inline-block;position:relative}.info-tip .info-icon[data-v-441a5a6a]{font-size:15px;cursor:pointer;color:grey}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$n = "data-v-441a5a6a";
  /* module identifier */
  const __vue_module_identifier__$n = undefined;
  /* functional template */
  const __vue_is_functional_template__$n = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$n = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$n, staticRenderFns: __vue_staticRenderFns__$n },
    __vue_inject_styles__$n,
    __vue_script__$n,
    __vue_scope_id__$n,
    __vue_is_functional_template__$n,
    __vue_module_identifier__$n,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//

/**
 * 高级设置面板：用来做一些危险操作的提示
 */
var script$m = {
  props: {
    /**
     * 标题
     */
    title: {
      type: String
    },
    /**
     * 主题内容
     */
    content: {
      type: String
    },
    /**
     * 着重提示
     */
    tips: {
      type: String
    }
  }
};

/* script */
const __vue_script__$m = script$m;

/* template */
var __vue_render__$m = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"fuse-advanced-settings"},[_c('div',{staticClass:"fuse-advanced-settings-title"},[_vm._v(_vm._s(_vm.title))]),_vm._v(" "),_c('div',{staticClass:"fuse-advanced-settings-content"},[_vm._v(_vm._s(_vm.content))]),_vm._v(" "),_c('div',{staticClass:"fuse-advanced-settings-tips"},[_vm._v(_vm._s(_vm.tips))]),_vm._v(" "),_vm._t("action")],2)};
var __vue_staticRenderFns__$m = [];

  /* style */
  const __vue_inject_styles__$m = function (inject) {
    if (!inject) return
    inject("data-v-7b538dd0_0", { source: ".fuse-advanced-settings{background-color:#fafafa;padding:16px}.fuse-advanced-settings-title{color:red;font-weight:700}.fuse-advanced-settings-content{margin:5px 0 5px 0}.fuse-advanced-settings-tips{font-weight:700;color:#000;font-size:15px;margin:5px 0 5px 0}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$m = undefined;
  /* module identifier */
  const __vue_module_identifier__$m = undefined;
  /* functional template */
  const __vue_is_functional_template__$m = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$m = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$m, staticRenderFns: __vue_staticRenderFns__$m },
    __vue_inject_styles__$m,
    __vue_script__$m,
    __vue_scope_id__$m,
    __vue_is_functional_template__$m,
    __vue_module_identifier__$m,
    false,
    createInjector,
    undefined,
    undefined
  );

var mixins$3 = {
  props: {
    showCreateBtn: {
      type: Boolean,
      default: false
    }, // 是否显示创建指标
    loading: {
      type: Boolean,
      default: false
    }, // 表格loading
    createMetricLoading: {
      type: Boolean,
      default: false
    }, // 创建指标按钮loading
    editMetricLoading: {
      type: Boolean,
      default: false
    },
    columns: {
      type: Array,
      default: function () {
        return [
          {
            type: 'index',
            width: 60,
            align: 'center'
          },
          { title: '监控指标', key: 'name', width: 200 },
          { title: '指标编码', key: 'key', width: 200 },
          {
            title: '指标类型',
            key: 'type',
            width: 200,
            sortable: true,
            render: (h, params) => {
              if (params.row.type === 'CUSTOM') {
                return h('span', {}, '自定义指标');
              } else if (params.row.type === 'BUILDIN') {
                return h('span', {}, '标准指标');
              }
            }
          },
          { title: '指标描述', key: 'description' },
          {
            title: '操作',
            width: 100,
            render: (h, params) => {
              return h(
                'div',
                params.row.type === 'CUSTOM'
                  ? [
                      h('Icon', {
                        props: {
                          type: 'md-create',
                          size: 'small'
                        },
                        attrs: {
                          title: '编辑'
                        },
                        style: {
                          marginRight: '10px',
                          color: '#2d8cf0',
                          fontSize: '16px',
                          cursor: 'pointer'
                        },
                        on: {
                          click: () => {
                            this.handleEdit(params.row);
                          }
                        }
                      }),
                      h('Icon', {
                        props: {
                          type: 'ios-trash',
                          size: 'small'
                        },
                        attrs: {
                          title: '删除'
                        },
                        style: {
                          color: '#2d8cf0',
                          fontSize: '16px',
                          cursor: 'pointer'
                        },
                        on: {
                          click: () => {
                            this.handleDelete(params.row);
                          }
                        }
                      })
                    ]
                  : []
              );
            }
          }
        ];
      }
    }, // 表格列头
    data: {
      type: Array,
      default: () => []
    } // 表格数据
  },
  data() {
    return {
      compareOperators: [
        { value: 'EQ', title: '等于', description: null },
        { value: 'GTE', title: '大于等于', description: null },
        { value: 'GT', title: '大于', description: null },
        { value: 'LT', title: '小于', description: null },
        { value: 'LTE', title: '小于等于', description: null }
      ],
      aggregationOperators: [
        { value: 'AVG', title: '平均值', description: null },
        { value: 'SUM', title: '总和', description: '一定时间内所有告警检查周期获取的值相加' },
        { value: 'MAX', title: '最大值', description: null },
        { value: 'MIN', title: '最小值', description: null },
        { value: 'COUNT', title: '数量', description: '一定时间内所有告警检查的记录数' },
        { value: 'DIFFERENCE', title: '差值', description: '最大值减去最小值' },
        { value: 'SCRIPTED', title: '脚本', description: null },
        { value: 'RAW', title: '原始值', description: '单个告警检查周期获取的值' }
      ]
    };
  }
};

//
var script$l = {
  mixins: [mixins$3],
  data() {
    return {
      prefixClass: 'f-metric',
      createMetricModalFlag: false,
      editMetricModalFlag: false,
      typeList: [
        {
          label: '全部',
          value: '-99'
        },
        {
          label: '标准指标',
          value: 'BUILDIN'
        },
        {
          label: '自定义指标',
          value: 'CUSTOM'
        }
      ],
      search: '',
      type: '',
      tableData: '',
      createMetricForm: {
        name: '',
        key: '',
        description: ''
      },
      createMetricFormRules: {
        name: [{ required: true, message: '请输入', trigger: 'change' }],
        key: [{ required: true, message: '请输入', trigger: 'change' }]
      },
      editMetricForm: {}
    };
  },

  watch: {
    search() {
      this.searchData();
    },
    data: {
      handler(newValue, _oldValue) {
        this.tableData = newValue;
      },
      immediate: true
    }
  },

  created() {
    this.searchData = debounce(this.getData, 600);
  },

  methods: {
    handleClickCreateMetric(data) {
      this.$emit('handleClickCreateMetric', data);
    }, // 新增指标
    doReload() {
      let options = {
        search: this.search,
        type: this.type === '-99' ? '' : this.type
      };
      this.$emit('doReload', options);
    },
    getData() {
      this.filterFunc(this.search, this.type);
    },
    handleChangeType() {
      this.filterFunc(this.search, this.type);
    },
    filterFunc(search, type) {
      this.tableData = this.data.filter((item) => {
        if (search && type && type !== '-99') {
          return item.type === type && (item.name.indexOf(search) > -1 || item.key.indexOf(search) > -1);
        }
        if (!type) {
          return item.name.indexOf(search) > -1 || item.key.indexOf(search) > -1;
        }
        if (type === '-99') {
          return item.name.indexOf(search) > -1 || item.key.indexOf(search) > -1;
        } else {
          return item.type === type;
        }
      });
    },
    handleAdd(name) {
      this.$refs[name].validate((valid) => {
        if (valid) {
          this.$emit('handleClickCreateMetric', this.createMetricForm);
        }
      });
    }, // 新增指标
    handleEdit(params) {
      this.editMetricForm = _.cloneDeep(params);
      this.editMetricModalFlag = true;
    }, // 修改指标
    handleCompleteEdit(name) {
      this.$refs[name].validate((valid) => {
        if (valid) {
          this.$emit('handleClickEditMetric', this.editMetricForm);
        }
      });
    }, // 修改指标
    handleDelete(params) {
      this.$emit('handleClickDeleteMetric', params);
    }, // 删除指标
    editModalClose() {
      this.$refs.editMetricFormRef.resetFields();
      this.editMetricModalFlag = false;
    },
    visibleEditChange(val) {
      setTimeout(() => {
        if (val) {
          this.$refs.autoFocusEditInput.$refs.input.focus();
        }
      }, 200);
    },

    modalClose() {
      this.$refs.createMetricFormRef.resetFields();
      this.createMetricModalFlag = false;
    },
    visibleChange(val) {
      setTimeout(() => {
        if (val) {
          this.$refs.autoFocusInput.$refs.input.focus();
        }
      }, 200);
    } // 默认聚焦
  }
};

/* script */
const __vue_script__$l = script$l;

/* template */
var __vue_render__$l = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"b-list default-list-wrapper",class:_vm.prefixClass},[(_vm.loading)?_c('Spin',{attrs:{"fix":""}}):_vm._e(),_vm._v(" "),_c('div',{staticClass:"b-list-header"},[_c('Button',{attrs:{"icon":"md-refresh"},on:{"click":function($event){return _vm.doReload()}}}),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){_vm.createMetricModalFlag = true;}}},[_vm._v("创建指标")]),_vm._v(" "),_c('Input',{staticStyle:{"width":"200px"},attrs:{"clearable":"","placeholder":"按名称与编码搜索"},model:{value:(_vm.search),callback:function ($$v) {_vm.search=$$v;},expression:"search"}}),_vm._v(" "),_c('Select',{staticStyle:{"width":"200px"},attrs:{"clearable":"","placeholder":"指标类型"},on:{"on-change":_vm.handleChangeType},model:{value:(_vm.type),callback:function ($$v) {_vm.type=$$v;},expression:"type"}},_vm._l((_vm.typeList),function(item){return _c('Option',{key:item.value,attrs:{"value":item.value}},[_vm._v(_vm._s(item.label))])}),1)],1),_vm._v(" "),_c('Table',{attrs:{"columns":_vm.columns,"data":_vm.tableData}}),_vm._v(" "),_c('Modal',{attrs:{"width":"760"},on:{"on-cancel":_vm.modalClose,"on-visible-change":_vm.visibleChange},model:{value:(_vm.createMetricModalFlag),callback:function ($$v) {_vm.createMetricModalFlag=$$v;},expression:"createMetricModalFlag"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("创建指标")]),_vm._v(" "),_c('Form',{ref:"createMetricFormRef",attrs:{"rules":_vm.createMetricFormRules,"model":_vm.createMetricForm,"label-width":120}},[_c('FormItem',{attrs:{"label":"监控指标","prop":"name"}},[_c('Input',{ref:"autoFocusInput",attrs:{"placeholder":"请输入监控指标名称，如：CPU占用率"},model:{value:(_vm.createMetricForm.name),callback:function ($$v) {_vm.$set(_vm.createMetricForm, "name", $$v);},expression:"createMetricForm.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"指标编码","prop":"key"}},[_c('Input',{attrs:{"placeholder":"请输入指标编码，如：overtime"},model:{value:(_vm.createMetricForm.key),callback:function ($$v) {_vm.$set(_vm.createMetricForm, "key", $$v);},expression:"createMetricForm.key"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"指标描述","prop":"description"}},[_c('Input',{attrs:{"type":"textarea","autosize":{ minRows: 5, maxRows: 8 },"placeholder":"请简要描述当前监控指标，如：请求时间超过30s，则需记录并给出中级告警"},model:{value:(_vm.createMetricForm.description),callback:function ($$v) {_vm.$set(_vm.createMetricForm, "description", $$v);},expression:"createMetricForm.description"}})],1)],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":_vm.modalClose}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary","loading":_vm.createMetricLoading},on:{"click":function($event){return _vm.handleAdd('createMetricFormRef')}}},[_vm._v("确定")])],1)],1),_vm._v(" "),_c('Modal',{attrs:{"width":"760"},on:{"on-cancel":_vm.editModalClose,"on-visible-change":_vm.visibleEditChange},model:{value:(_vm.editMetricModalFlag),callback:function ($$v) {_vm.editMetricModalFlag=$$v;},expression:"editMetricModalFlag"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("编辑指标")]),_vm._v(" "),_c('Form',{ref:"editMetricFormRef",attrs:{"rules":_vm.createMetricFormRules,"model":_vm.editMetricForm,"label-width":120}},[_c('FormItem',{attrs:{"label":"监控指标","prop":"name"}},[_c('Input',{ref:"autoFocusEditInput",attrs:{"placeholder":"请输入监控指标名称，如：CPU占用率"},model:{value:(_vm.editMetricForm.name),callback:function ($$v) {_vm.$set(_vm.editMetricForm, "name", $$v);},expression:"editMetricForm.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"指标编码","prop":"key"}},[_c('Input',{attrs:{"placeholder":"请输入指标编码，如：overtime"},model:{value:(_vm.editMetricForm.key),callback:function ($$v) {_vm.$set(_vm.editMetricForm, "key", $$v);},expression:"editMetricForm.key"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"指标描述","prop":"description"}},[_c('Input',{attrs:{"type":"textarea","autosize":{ minRows: 5, maxRows: 8 },"placeholder":"请简要描述当前监控指标，如：请求时间超过30s，则需记录并给出中级告警"},model:{value:(_vm.editMetricForm.description),callback:function ($$v) {_vm.$set(_vm.editMetricForm, "description", $$v);},expression:"editMetricForm.description"}})],1)],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":_vm.editModalClose}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary","loading":_vm.editMetricLoading},on:{"click":function($event){return _vm.handleCompleteEdit('editMetricFormRef')}}},[_vm._v("确定")])],1)],1)],1)};
var __vue_staticRenderFns__$l = [];

  /* style */
  const __vue_inject_styles__$l = function (inject) {
    if (!inject) return
    inject("data-v-3c5f584e_0", { source: ".f-metric{position:relative}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$l = undefined;
  /* module identifier */
  const __vue_module_identifier__$l = undefined;
  /* functional template */
  const __vue_is_functional_template__$l = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$l = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$l, staticRenderFns: __vue_staticRenderFns__$l },
    __vue_inject_styles__$l,
    __vue_script__$l,
    __vue_scope_id__$l,
    __vue_is_functional_template__$l,
    __vue_module_identifier__$l,
    false,
    createInjector,
    undefined,
    undefined
  );

var mixins$2 = {
  props: {
    meta: {
      type: Object,
      required: true
    }, // 元数据
    monitoringType: {
      type: String,
      required: true
    }, // 告警类型
    showNotifyDocs: {
      type: Boolean,
      default: false
    }, // 是否需要展示查看通知详情自定义配置文档 点击查看文档抛出事件handleClickNotifyDocs

    type: {
      type: String,
      default: 'default'
    },
    showActions: {
      type: Boolean,
      default: true
    },
    addActionTypes: {
      type: Array,
      default: () => [
        {
          type: 'WEBHOOK',
          label: 'WEBHOOK告警'
        },
        {
          type: 'EMAIL',
          label: '邮件告警'
        }
      ]
    },
    value: {
      type: Object,
      default: () => {
        return {
          name: '', // 告警名称
          groupBy: '', // 监控对象
          level: '', // 告警级别
          timeStart: '', // 检查时段开始时间
          timeEnd: '', // 检查时段结束时间
          enabled: true, // 是否启用
          conditionBoolFilter: '1', // 条件组合关系
          scheduleInterval: 2, // 检查周期数值
          scheduleIntervalUnit: 'MINUTES', // 检查周期单位
          notifyId: '', // 通知id(可忽略)
          notifyTypes: ['alert'], // 通知类型(可忽略)
          notifyFrequency: {
            timeWindowSize: '', // 值
            timeWindowUnit: null // 单位
          }, // 重复频率
          summary: '', // 告警概述
          description: '', // 告警详情
          restoreSummary: '', // 恢复概述
          restoreDescription: '', // 恢复详情
          conditions: []
        };
      }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    metrics: {
      type: Array,
      default: () => []
    },
    metricTableColumns: {
      type: Array,
      default: () => []
    }
  },

  data() {
    const validateTitleRules = (rule, value, callback) => {
      this.titleRules(rule, value, callback);
    };
    return {
      formRules: {
        name: [
          { required: true, message: '请输入', trigger: 'change' },
          { validator: validateTitleRules, trigger: 'change' }
        ],
        level: [{ required: true, message: '请选择', trigger: 'change' }],
        enabled: [{ required: true, type: 'boolean', message: '请选择', trigger: 'change' }],
        groupBy: [{ required: true, message: '请选择', trigger: 'change' }],
        scheduleInterval: [{ required: true, type: 'number', message: '请输入', trigger: 'change' }],
        scheduleIntervalUnit: [{ required: true, message: '请选择', trigger: 'change' }],
        summary: [{ required: true, message: '请输入', trigger: 'change' }],
        description: [{ required: true, message: '请输入', trigger: 'change' }],
        restoreSummary: [{ required: true, message: '请输入', trigger: 'change' }],
        restoreDescription: [{ required: true, message: '请输入', trigger: 'change' }],
        notifyTypes: [{ required: true, type: 'array', message: '请填写', trigger: 'change' }],
        'notifyFrequency.timeWindowSize': [{ required: true, type: 'number', message: '请输入', trigger: 'change' }],
        'notifyFrequency.timeWindowUnit': [{ required: true, message: '请选择', trigger: 'change' }]
      },
      currentMonitoringType: '' // 指定类型下的告警meta
    };
  },
  computed: {
    scheduleIntervalMinLimit() {
      if (this.value.scheduleIntervalUnit === 'SECONDS') {
        return 30;
      } else {
        return 1;
      }
    },
    scheduleIntervalMaxLimit() {
      if (this.value.scheduleIntervalUnit === 'HOURS') {
        return 12;
      } else {
        return 9999;
      }
    },
    scheduleIntervalStep() {
      if (this.value.scheduleIntervalUnit === 'SECONDS') {
        return 10;
      } else {
        return 1;
      }
    }
  },
  watch: {
    time() {
      if (_.isEmpty(this.time) || this.time[0] === '') {
        this.timeFlag = 'all';
      } else {
        this.timeFlag = 'diy';
      }
    },
    timeFlag() {
      if (this.timeFlag === 'all') {
        this.time = [];
        this.value.timeStart = '';
        this.value.timeEnd = '';
      }
    },
    meta: {
      handler(newVal, _oldVal) {
        if (newVal) {
          this.currentMonitoringType = newVal.monitoringTypes.find((item) => item.code === this.monitoringType);
          if (!this.value.groupBy) {
            this.value.groupBy = this.meta.groupByOptions[0].value;
          }
        }
      },
      immediate: true
    }
  },
  methods: {
    titleRules: debounce(async function (rule, value, callback) {
      if (value && !this.validateSpecialKey(value)) {
        callback(new Error('不能输入特殊字符'));
        return;
      }
      if (value && this.validateSpace(value)) {
        callback(new Error('不能输入空格'));
      } else {
        callback();
      }
    }, 400),
    validateSpecialKey(str) {
      var specialKey = "[`~!#$^&*()=|{}':;'\\[\\]<>/?~！#￥……&*（）——|{}【】‘；：”“'。，、？%@]‘'";
      for (var i = 0; i < str.length; i++) {
        if (specialKey.indexOf(str.substr(i, 1)) !== -1) {
          return false;
        }
      }
      return true;
    }, // 校验是否存在特殊字符

    validateSpace(str) {
      var patrn = /^ +| +$/g; // 匹配空格
      if (patrn.test(str)) {
        return true;
      } else {
        return false;
      }
    } // 校验是否有空格
  }
};

var mixins$1 = {
  data() {
    const commonRule = { required: true, message: '请输入', trigger: 'change' };
    const selectRule = { required: true, message: '请选择', trigger: 'change' };
    const numberRule = { required: true, type: 'number', message: '请输入', trigger: 'change' };
    return {
      conditionDefault: {
        metricKey: '',
        timeWindowSize: '',
        aggType: '',
        timeType: '',
        comparer: '',
        threshold: '',
        aggregateOperators: []
      },
      scriptedFormRules: {
        initScript: [commonRule],
        mapScript: [commonRule],
        combineScript: [commonRule],
        reduceScript: [commonRule]
      },
      commonRule: [commonRule],
      numberRule: numberRule,
      selectCommonRule: selectRule,

      defaultMetricColumns: [
        { type: 'index', width: 40, align: 'center' },
        { title: '指标名称', key: 'title', width: 140 },
        { title: '指标编码', key: 'code', width: 140 },
        {
          title: '监控对象',
          key: 'groupByOptions',
          width: 140,
          render: (h, params) => {
            const groupByTitleArr = [];
            params.row.groupByOptions.forEach((v) => {
              let cgb = this.meta.groupByOptions.find((item) => item.value === v);
              groupByTitleArr.push(cgb.title);
            });
            const groupByTitleDesc = groupByTitleArr.join('、');
            return h('span', {}, groupByTitleDesc);
          }
        },
        { title: '指标描述', key: 'description' }
      ],
      conditionDetailRules: {
        initScript: [commonRule],
        mapScript: [commonRule],
        combineScript: [commonRule],
        reduceScript: [commonRule],
        timeWindowSize: [numberRule],
        timeWindowUnit: [selectRule],
        aggType: [selectRule],
        comparer: [selectRule],
        threshold: [numberRule]
      },
      aggregateOperatorsColumns: [
        { type: 'index', width: 40, align: 'center' },
        { title: '聚合函数名称', key: 'title', width: 140 },
        { title: '聚合函数编码', key: 'value', width: 140 },
        { title: '函数描述', key: 'description' }
      ]
    };
  },
  computed: {
    conditionsLength() {
      if (this.value.conditions) {
        return this.value.conditions.length;
      }
    },
    commonMetricColumns() {
      if (this.metrics && this.metrics.length) {
        return this.defaultMetricColumns;
      } else {
        return this.metricTableColumns;
      }
    }
  },
  watch: {
    conditionsLength: {
      handler: function () {
        if (this.value.conditions && this.value.conditions.length) {
          const conditionFilter = this.getConditionFilter(this.filterType);
          this.$set(this.value, 'conditionBoolFilter', conditionFilter);
        } else {
          this.value.conditionBoolFilter = '';
        }
      }
    } // 条件的个数改变 重新组合filterbool
  }
};

//

const prefixCls = 'ivu-input-number';
const iconPrefixCls = 'ivu-icon';

function addNum(num1, num2) {
  let sq1, sq2, m;
  try {
    sq1 = num1.toString().split('.')[1].length;
  } catch (e) {
    sq1 = 0;
  }
  try {
    sq2 = num2.toString().split('.')[1].length;
  } catch (e) {
    sq2 = 0;
  }
  //        if (sq1 === 0 || sq2 === 0) {
  //            return num1 + num2;
  //        } else {
  //            m = Math.pow(10, Math.max(sq1, sq2));
  //            return (num1 * m + num2 * m) / m;
  //        }
  m = Math.pow(10, Math.max(sq1, sq2));
  return (Math.round(num1 * m) + Math.round(num2 * m)) / m;
}

var script$k = {
  name: 'InputNumber',
  mixins: [Emitter],
  props: {
    max: {
      type: Number,
      default: Infinity
    },
    min: {
      type: Number,
      default: -Infinity
    },
    step: {
      type: Number,
      default: 1
    },
    activeChange: {
      type: Boolean,
      default: true
    },
    value: {
      default: 1
    },
    size: {
      validator(value) {
        return ['small', 'large', 'default'].some((item) => item == value);
      },
      default() {
        return !this.$IVIEW || this.$IVIEW.size === '' ? 'default' : this.$IVIEW.size;
      }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    autofocus: {
      type: Boolean,
      default: false
    },
    readonly: {
      type: Boolean,
      default: false
    },
    editable: {
      type: Boolean,
      default: true
    },
    name: {
      type: String
    },
    precision: {
      type: Number
    },
    elementId: {
      type: String
    },
    formatter: {
      type: Function
    },
    parser: {
      type: Function
    },
    placeholder: {
      type: String,
      default: ''
    },
    // 4.5.0
    controlsOutside: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      focused: false,
      upDisabled: false,
      downDisabled: false,
      currentValue: this.value
    };
  },
  computed: {
    wrapClasses() {
      return [
        `${prefixCls}`,
        {
          [`${prefixCls}-${this.size}`]: !!this.size,
          [`${prefixCls}-disabled`]: this.disabled,
          [`${prefixCls}-focused`]: this.focused,
          [`${prefixCls}-controls-outside`]: this.controlsOutside
        }
      ];
    },
    handlerClasses() {
      return `${prefixCls}-handler-wrap`;
    },
    upClasses() {
      return [
        `${prefixCls}-handler`,
        `${prefixCls}-handler-up`,
        {
          [`${prefixCls}-handler-up-disabled`]: this.upDisabled
        }
      ];
    },
    innerUpClasses() {
      return `${prefixCls}-handler-up-inner ${iconPrefixCls} ${iconPrefixCls}-ios-arrow-up`;
    },
    downClasses() {
      return [
        `${prefixCls}-handler`,
        `${prefixCls}-handler-down`,
        {
          [`${prefixCls}-handler-down-disabled`]: this.downDisabled
        }
      ];
    },
    innerDownClasses() {
      return `${prefixCls}-handler-down-inner ${iconPrefixCls} ${iconPrefixCls}-ios-arrow-down`;
    },
    inputWrapClasses() {
      return `${prefixCls}-input-wrap`;
    },
    inputClasses() {
      return `${prefixCls}-input`;
    },
    precisionValue() {
      // can not display 1.0
      if (!this.currentValue) return this.currentValue;
      return this.precision ? this.currentValue.toFixed(this.precision) : this.currentValue;
    },
    formatterValue() {
      if (this.formatter && this.precisionValue !== null) {
        return this.formatter(this.precisionValue);
      } else {
        return this.precisionValue;
      }
    }
  },
  methods: {
    preventDefault(e) {
      e.preventDefault();
    },
    up(e) {
      const targetVal = Number(e.target.value);
      if (this.upDisabled && isNaN(targetVal)) {
        return false;
      }
      this.changeStep('up', e);
    },
    down(e) {
      const targetVal = Number(e.target.value);
      if (this.downDisabled && isNaN(targetVal)) {
        return false;
      }
      this.changeStep('down', e);
    },
    changeStep(type, e) {
      if (this.disabled || this.readonly) {
        return false;
      }

      const targetVal = Number(e.target.value);
      let val = Number(this.currentValue);
      const step = Number(this.step);
      if (isNaN(val)) {
        return false;
      }

      // input a number, and key up or down
      if (!isNaN(targetVal)) {
        if (type === 'up') {
          if (addNum(targetVal, step) <= this.max) {
            val = targetVal;
          } else {
            return false;
          }
        } else if (type === 'down') {
          if (addNum(targetVal, -step) >= this.min) {
            val = targetVal;
          } else {
            return false;
          }
        }
      }

      if (type === 'up') {
        val = addNum(val, step);
      } else if (type === 'down') {
        val = addNum(val, -step);
      }
      this.setValue(val);
    },
    setValue(val) {
      // 如果 step 是小数，且没有设置 precision，是有问题的
      if (val && !isNaN(this.precision)) val = Number(Number(val).toFixed(this.precision));

      const { min, max } = this;
      if (val !== null) {
        if (val > max) {
          val = max;
        } else if (val < min) {
          val = min;
        }
      }

      this.$nextTick(() => {
        this.currentValue = val;
        this.$emit('input', val);
        this.$emit('on-change', val);
        this.dispatch('FormItem', 'on-form-change', val);
      });
    },
    focus(event) {
      this.focused = true;
      this.$emit('on-focus', event);
    },
    blur() {
      this.focused = false;
      this.$emit('on-blur');
      if (!this.findComponentUpward(this, ['DatePicker', 'TimePicker', 'Cascader', 'Search'])) ;
    },
    keyDown(e) {
      if (e.keyCode === 38) {
        e.preventDefault();
        this.up(e);
      } else if (e.keyCode === 40) {
        e.preventDefault();
        this.down(e);
      }
    },
    change(event) {
      if (event.type == 'change' && this.activeChange) return;

      if (event.type == 'input' && !this.activeChange) return;
      let val = event.target.value.trim();
      if (this.parser) {
        val = this.parser(val);
      }

      const isEmptyString = val.length === 0;
      if (isEmptyString) {
        this.setValue(null);
        return;
      }
      if (val.indexOf('.') > -1) {
        event.target.value = this.currentValue;
        return;
      }
      // if (event.type == 'input' && val.match(/^\-?\.?$|\.$/)) return; // prevent fire early if decimal. If no more input the change event will fire later

      val = Number(val);

      if (!isNaN(val)) {
        this.currentValue = val;
        this.setValue(val);
      } else {
        event.target.value = this.currentValue;
      }
    },
    changeVal(val) {
      val = Number(val);
      if (!isNaN(val)) {
        const step = this.step;

        this.upDisabled = val + step > this.max;
        this.downDisabled = val - step < this.min;
      } else {
        this.upDisabled = true;
        this.downDisabled = true;
      }
    },
    findComponentUpward(context, componentName, componentNames) {
      if (typeof componentName === 'string') {
        componentNames = [componentName];
      } else {
        componentNames = componentName;
      }

      let parent = context.$parent;
      let name = parent.$options.name;
      while (parent && (!name || componentNames.indexOf(name) < 0)) {
        parent = parent.$parent;
        if (parent) name = parent.$options.name;
      }
      return parent;
    }
  },
  mounted() {
    this.changeVal(this.currentValue);
  },
  watch: {
    value(val) {
      this.currentValue = val;
    },
    currentValue(val) {
      this.changeVal(val);
    },
    min() {
      this.changeVal(this.currentValue);
    },
    max() {
      this.changeVal(this.currentValue);
    }
  }
};

/* script */
const __vue_script__$k = script$k;

/* template */
var __vue_render__$k = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{class:_vm.wrapClasses},[(!_vm.controlsOutside)?_c('div',{class:_vm.handlerClasses},[_c('a',{class:_vm.upClasses,on:{"click":_vm.up}},[_c('span',{class:_vm.innerUpClasses,on:{"click":_vm.preventDefault}})]),_vm._v(" "),_c('a',{class:_vm.downClasses,on:{"click":_vm.down}},[_c('span',{class:_vm.innerDownClasses,on:{"click":_vm.preventDefault}})])]):_vm._e(),_vm._v(" "),(_vm.controlsOutside)?_c('div',{staticClass:"ivu-input-number-controls-outside-btn ivu-input-number-controls-outside-down",class:{ 'ivu-input-number-controls-outside-btn-disabled': _vm.downDisabled },on:{"click":_vm.down}},[_c('i',{staticClass:"ivu-icon ivu-icon-ios-remove"})]):_vm._e(),_vm._v(" "),(_vm.controlsOutside)?_c('div',{staticClass:"ivu-input-number-controls-outside-btn ivu-input-number-controls-outside-up",class:{ 'ivu-input-number-controls-outside-btn-disabled': _vm.upDisabled },on:{"click":_vm.up}},[_c('i',{staticClass:"ivu-icon ivu-icon-ios-add"})]):_vm._e(),_vm._v(" "),_c('div',{class:_vm.inputWrapClasses},[_c('input',{class:_vm.inputClasses,attrs:{"id":_vm.elementId,"disabled":_vm.disabled,"autocomplete":"off","spellcheck":"false","autofocus":_vm.autofocus,"readonly":_vm.readonly || !_vm.editable,"name":_vm.name,"placeholder":_vm.placeholder},domProps:{"value":_vm.formatterValue},on:{"focus":_vm.focus,"blur":_vm.blur,"keydown":function($event){$event.stopPropagation();return _vm.keyDown($event)},"input":_vm.change,"mouseup":_vm.preventDefault,"change":_vm.change}})])])};
var __vue_staticRenderFns__$k = [];

  /* style */
  const __vue_inject_styles__$k = undefined;
  /* scoped */
  const __vue_scope_id__$k = undefined;
  /* module identifier */
  const __vue_module_identifier__$k = undefined;
  /* functional template */
  const __vue_is_functional_template__$k = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$k = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$k, staticRenderFns: __vue_staticRenderFns__$k },
    __vue_inject_styles__$k,
    __vue_script__$k,
    __vue_scope_id__$k,
    __vue_is_functional_template__$k,
    __vue_module_identifier__$k,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$j = {
  mixins: [mixins$1],
  props: {
    value: {
      type: Object,
      default: () => ({})
    },
    disabled: {
      type: Boolean,
      default: false
    }
  },
  components: { inputInteger: __vue_component__$k },
  inject: ['currentMonitoringType', 'meta', 'monitoringType', 'showActions', 'type', 'metrics', 'metricTableColumns'],
  data() {
    return {
      filterType: '', // 默认or自定义
      currentCondition: {}, // 当前编辑的条件项
      currentConditionIndex: '', // 当前编辑的条件项的索引
      detailModal: false,
      timeUnitsMap: {
        SECONDS: 1,
        MINUTES: 60,
        HOURS: 3600,
        DAYS: 86400
      }
    };
  },

  computed: {
    filterMetrics() {
      const arr = this.currentMonitoringType.metrics.filter((item) => {
        if (item.groupByOptions.includes(this.value.groupBy)) {
          return item;
        }
      });
      if (arr && arr.length) {
        return arr;
      } else {
        return [];
      }
    }, // 过滤当前monitoringType和groupby条件下的指标
    showMetrics() {
      if (this.metrics && this.metrics.length) {
        return this.metrics;
      } else {
        return this.currentMonitoringType.metrics;
      }
    }
  },

  mounted() {
    if (!this.value.conditions || this.value.conditions.length === 0) {
      this.initCondition();
    } else {
      this.value.conditions.forEach((item) => {
        this.metricKeyChange(item);
      });
    }
    this.setFilterType();
  },

  methods: {
    setFilterType() {
      if (_.isEmpty(this.value.conditionBoolFilter)) {
        this.filterType = this.meta.conditionOperators[0].value;
      } else {
        let targetTypeObj = this.meta.conditionOperators.find(
          (item) => this.value.conditionBoolFilter.indexOf(item.value) > -1
        );
        if (targetTypeObj) {
          this.filterType = targetTypeObj.value;
        } else {
          this.filterType = this.meta.conditionOperators[0].value;
        }
      }
    }, // 设置and or

    getConditionFilter(type) {
      const key = type || this.meta.conditionOperators[0].value;
      let filter = [];
      this.value.conditions.forEach((item, index) => {
        filter.push(index + 1);
      });
      let conditionFilter = filter.join(` ${key} `);
      return conditionFilter;
    }, // 条件组合结果
    metricKeyChange(v, flag) {
      var self = this;
      if (flag) {
        v.aggType = '';
        v.comparer = '';
      }
      setTimeout(function () {
        self.initConditionParams(v);
      }, 200);
    }, // 指标变化
    initCondition() {
      let copyCondition = _.cloneDeep(this.conditionDefault);
      this.$set(this.value, 'conditions', [copyCondition]);
    }, //条件初始化赋值
    initConditionParams(v) {
      if (v.metricKey) {
        const currentMetric = this.currentMonitoringType.metrics.find((item) => item.code === v.metricKey);
        const currentAggregateOperators = currentMetric.aggregateOperators;
        const currentCompareOperators = currentMetric.compareOperators;
        this.$set(v, 'metricKeyUnit', currentMetric.unit);
        if (currentCompareOperators) {
          let compareOperators = [];
          currentCompareOperators.forEach((item) => {
            let comp = this.meta.compareOperators.find((v) => v.value === item);
            compareOperators.push(comp);
          });
          this.$set(v, 'compareOperators', compareOperators);
        } else {
          this.$set(v, 'compareOperators', this.meta.compareOperators);
        }
        if (currentAggregateOperators) {
          let aggregateOperators = [];
          currentAggregateOperators.forEach((item) => {
            let comp = this.meta.aggregationOperators.find((v) => v.value === item);
            aggregateOperators.push(comp);
          });
          this.$set(v, 'aggregateOperators', aggregateOperators);
        } else {
          this.$set(v, 'aggregateOperators', this.meta.aggregateOperators);
        }
      }
    }, //初始化当前指标下的参数
    addCondition(item, index) {
      if (typeof index === 'number') {
        this.value.conditions.splice(index + 1, 0, _.cloneDeep(this.conditionDefault)); //
      } else {
        if (!this.value.conditions) {
          this.$set(this.value, 'conditions', []);
        }
        this.value.conditions.push(_.cloneDeep(this.conditionDefault));
      }
    }, // 添加条件
    handleRemove(item, index) {
      this.value.conditions.splice(index, 1);
    }, // 删除条件
    handleDetail(condition, index) {
      this.currentConditionIndex = index;
      this.currentCondition = _.cloneDeep(condition);
      this.detailModal = true;
    }, //条件详情
    confirmEdit() {
      this.$refs.conditionDetailRef.validate((valid) => {
        if (valid) {
          const flag = this.confirmFilters();
          if (flag) {
            this.$set(this.value.conditions, this.currentConditionIndex, this.currentCondition);
            this.detailModal = false;
          }
        }
      });
    }, //确认编辑
    detailModalClose() {
      this.detailModal = false;
      this.$refs.conditionDetailRef.resetFields();
    },
    handleElementItemMouseover($event) {
      $event.currentTarget.classList.add('condition-item-mouseover');
    }, // 鼠标移出移入事件
    handleElementItemMouseout($event) {
      $event.currentTarget.classList.remove('condition-item-mouseover');
    }, // 鼠标移出移入事件
    aggTypeOnChange(item) {
      if (item.aggType === 'SCRIPTED') {
        item.metricKey = '';
      }
    }, // 聚合函数发生改变时
    filterTypeChange(type) {
      const conditionFilter = this.getConditionFilter(type);
      this.value.conditionBoolFilter = conditionFilter;
    }, // and / or 改变时

    filtersVisible(val) {
      var that = this;
      setTimeout(function () {
        if (val) {
          that.$refs.autoFocusInput.focus();
        }
      }, 200);
    },
    confirmFilters() {
      if (this.currentCondition.filters) {
        try {
          let arr = JSON.parse(this.currentCondition.filters);
          if (!Array.isArray(arr)) {
            this.$Message.warning({
              content: '聚合数据过滤条件格式不正确',
              duration: '2.5'
            });
            return false;
          }
          arr.forEach((item) => {
            if (typeof item !== 'object' && JSON.stringify(item).indexOf('{') !== 0) {
              this.$Message.warning({
                content: '聚合数据过滤条件格式不正确',
                duration: '2.5'
              });
              return false;
            }
          });
          return true;
        } catch (error) {
          this.$Message.warning({
            content: '聚合数据过滤条件格式不正确',
            duration: '2.5'
          });
          return false;
        }
      } else {
        return true;
      }
      // this.$set(this.currentCondition, 'filters', this.currentCondition.filters);
    }, // 高级过滤
    comparerTimeWindow(condition) {
      const scheduleInterval = this.value.scheduleInterval;
      const scheduleIntervalUnit = this.value.scheduleIntervalUnit;
      const timeWindowSize = condition.timeWindowSize;
      const timeWindowUnit = condition.timeWindowUnit;
      if (scheduleInterval && scheduleIntervalUnit && timeWindowSize && timeWindowUnit) {
        if (timeWindowUnit === scheduleIntervalUnit) {
          if (timeWindowSize <= scheduleInterval) {
            return 'warning-bg';
          } else {
            return '';
          }
        } else {
          if (
            timeWindowSize * this.timeUnitsMap[timeWindowUnit] <=
            scheduleInterval * this.timeUnitsMap[scheduleIntervalUnit]
          ) {
            return 'warning-bg';
          } else {
            return '';
          }
        }
      } else {
        return '';
      }
    } //判断检查周期是否大于条件的检查周期 否则增加黄色背景进行提醒
  }
};

/* script */
const __vue_script__$j = script$j;

/* template */
var __vue_render__$j = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"alert-condition"},[(_vm.value.groupBy)?[_c('span',{staticClass:"section-title"},[_vm._v("告警条件")]),_vm._v(" "),(!_vm.disabled)?_c('Poptip',{attrs:{"width":"680","transfer":""}},[_c('div',{attrs:{"slot":"content"},slot:"content"},[_c('Table',{attrs:{"size":"small","height":460,"columns":_vm.commonMetricColumns,"data":_vm.showMetrics}})],1),_vm._v(" "),_c('span',{staticClass:"form-item-tips",staticStyle:{"cursor":"pointer"}},[_c('Icon',{attrs:{"type":"ios-information-circle-outline"}}),_vm._v("查看所有告警指标\n      ")],1)]):_vm._e(),_vm._v(" "),(!_vm.disabled)?_c('Poptip',{staticClass:"ml-sm",attrs:{"width":"680","transfer":""}},[_c('div',{attrs:{"slot":"content"},slot:"content"},[_c('Table',{attrs:{"size":"small","height":460,"columns":_vm.aggregateOperatorsColumns,"data":_vm.meta.aggregationOperators}})],1),_vm._v(" "),_c('span',{staticClass:"form-item-tips",staticStyle:{"cursor":"pointer"}},[_c('Icon',{staticStyle:{"cursor":"pointer"},attrs:{"type":"ios-information-circle-outline"}}),_vm._v("查看所有聚合函数\n      ")],1)]):_vm._e(),_vm._v(" "),_c('Divider',{staticStyle:{"margin":"16px 0px"}}),_vm._v(" "),_c('FormItem',{attrs:{"label":"条件组合关系","prop":"conditionBoolFilter"}},[(!_vm.disabled)?[_c('RadioGroup',{on:{"on-change":_vm.filterTypeChange},model:{value:(_vm.filterType),callback:function ($$v) {_vm.filterType=$$v;},expression:"filterType"}},_vm._l((_vm.meta.conditionOperators),function(item,index){return _c('Radio',{key:index,attrs:{"label":item.value}},[_vm._v(_vm._s(item.value))])}),1),_vm._v(" "),_c('Input',{staticClass:"mt-sm",attrs:{"disabled":"","placeholder":"请添加监控条件再进行条件组合"},model:{value:(_vm.value.conditionBoolFilter),callback:function ($$v) {_vm.$set(_vm.value, "conditionBoolFilter", $$v);},expression:"value.conditionBoolFilter"}})]:[_vm._v("\n        "+_vm._s(_vm.value.conditionBoolFilter)+"\n      ")]],2),_vm._v(" "),_c('Row',{staticClass:"ivu-mt condition-list",attrs:{"type":"flex","gutter":12,"prop":"conditions"}},[_c('FormItem',{staticStyle:{"margin-bottom":"0px"},attrs:{"label-width":0}},_vm._l((_vm.value.conditions),function(item,index){return _c('Col',{key:index,staticClass:"condition-item",staticStyle:{"display":"flex"},attrs:{"xl":24,"lg":24,"md":24,"sm":24,"xs":24},nativeOn:{"mouseover":function($event){$event.stopPropagation();return _vm.handleElementItemMouseover($event)},"mouseout":function($event){$event.stopPropagation();return _vm.handleElementItemMouseout($event)}}},[_c('div',{staticClass:"fuse-monitor-rule-condition-button"},[_c('span',[_vm._v(" "+_vm._s(index + 1))])]),_vm._v(" "),_c('div',{staticClass:"fuse-monitor-rule-condition-button hide-border-left hide-border-right"},[_c('span',[_vm._v("当")])]),_vm._v(" "),_c('FormItem',{attrs:{"prop":'conditions.' + index + '.metricKey',"rules":item.aggType === 'SCRIPTED' ? '' : _vm.selectCommonRule}},[_c('Select',{staticStyle:{"width":"140px"},attrs:{"disabled":item.aggType === 'SCRIPTED' || _vm.disabled,"placeholder":"告警指标"},on:{"on-select":function($event){return _vm.metricKeyChange(item, true)}},model:{value:(item.metricKey),callback:function ($$v) {_vm.$set(item, "metricKey", $$v);},expression:"item.metricKey"}},_vm._l((_vm.filterMetrics),function(item,index){return _c('Option',{key:index,attrs:{"disabled":item.enabled === false,"value":item.code}},[_vm._v(_vm._s(item.title))])}),1)],1),_vm._v(" "),_c('div',{staticClass:"fuse-monitor-rule-condition-button hide-border-left hide-border-right"},[_c('span',[_vm._v("在")])]),_vm._v(" "),_c('Tooltip',{attrs:{"transfer":"","content":"建议您设置为检查周期+1分钟"}},[_c('FormItem',{attrs:{"prop":'conditions.' + index + '.timeWindowSize',"rules":_vm.numberRule}},[_c('input-integer',{class:_vm.comparerTimeWindow(item),attrs:{"min":1,"disabled":_vm.disabled,"placeholder":"时间"},model:{value:(item.timeWindowSize),callback:function ($$v) {_vm.$set(item, "timeWindowSize", $$v);},expression:"item.timeWindowSize"}})],1)],1),_vm._v(" "),_c('div',{staticClass:"compose-cell"},[_c('FormItem',{attrs:{"prop":'conditions.' + index + '.timeWindowUnit',"rules":_vm.selectCommonRule}},[_c('Select',{staticClass:"unset-border-left",class:_vm.comparerTimeWindow(item),staticStyle:{"width":"90px"},attrs:{"disabled":_vm.disabled,"placeholder":"时间单位"},model:{value:(item.timeWindowUnit),callback:function ($$v) {_vm.$set(item, "timeWindowUnit", $$v);},expression:"item.timeWindowUnit"}},_vm._l((_vm.meta.timeWindowUnits),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],1),_vm._v(" "),_c('div',{staticClass:"compose-cell"},[_c('FormItem',{attrs:{"prop":'conditions.' + index + '.aggType',"rules":_vm.selectCommonRule}},[_c('Select',{staticClass:"unset-border-left",staticStyle:{"width":"90px"},attrs:{"label-in-value":"","placeholder":"聚合函数","disabled":_vm.disabled},on:{"on-change":function($event){return _vm.aggTypeOnChange(item, index)}},model:{value:(item.aggType),callback:function ($$v) {_vm.$set(item, "aggType", $$v);},expression:"item.aggType"}},_vm._l((item.aggregateOperators),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],1),_vm._v(" "),_c('div',{staticClass:"compose-cell"},[_c('FormItem',{attrs:{"prop":'conditions.' + index + '.comparer',"rules":_vm.selectCommonRule}},[_c('Select',{staticClass:"unset-border-left",staticStyle:{"width":"100px"},attrs:{"label-in-value":"","disabled":_vm.disabled,"placeholder":"比较关系"},model:{value:(item.comparer),callback:function ($$v) {_vm.$set(item, "comparer", $$v);},expression:"item.comparer"}},_vm._l((item.compareOperators),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],1),_vm._v(" "),_c('div',{staticClass:"compose-cell"},[_c('FormItem',{attrs:{"prop":'conditions.' + index + '.threshold',"rules":_vm.numberRule}},[_c('input-integer',{attrs:{"min":0,"disabled":_vm.disabled,"placeholder":"阈值"},model:{value:(item.threshold),callback:function ($$v) {_vm.$set(item, "threshold", $$v);},expression:"item.threshold"}})],1)],1),_vm._v(" "),(item.metricKey && item.metricKeyUnit)?_c('div',{staticClass:"fuse-monitor-rule-condition-button hide-border-left"},[_c('span',[_vm._v(_vm._s(item.metricKeyUnit))])]):_vm._e(),_vm._v(" "),_c('div',{staticClass:"fuse-monitor-rule-condition-button hide-border-left"},[_c('span',[_vm._v("时")])]),_vm._v(" "),(!_vm.disabled)?_c('div',{staticClass:"condition-editor-right-toolbar"},[_c('Icon',{attrs:{"type":"ios-add-circle-outline","title":"新增"},on:{"click":function($event){return _vm.addCondition(item, index)}}}),_vm._v(" "),_c('Icon',{attrs:{"type":"ios-remove-circle-outline","title":"删除"},on:{"click":function($event){return _vm.handleRemove(item, index)}}}),_vm._v(" "),_c('Icon',{attrs:{"type":"ios-more","title":"详情"},on:{"click":function($event){return _vm.handleDetail(item, index)}}})],1):_vm._e()],1)}),1)],1),_vm._v(" "),(!_vm.disabled)?_c('Divider',{staticStyle:{"widht":"300px"}},[_c('div',{staticClass:"divider-btn",on:{"click":function($event){return _vm.addCondition()}}},[_c('Icon',{attrs:{"type":"ios-add-circle-outline"}}),_vm._v("添加条件")],1)]):_vm._e(),_vm._v(" "),_c('Modal',{attrs:{"width":"540px","title":"条件详情"},on:{"on-cancel":function($event){return _vm.detailModalClose()}},model:{value:(_vm.detailModal),callback:function ($$v) {_vm.detailModal=$$v;},expression:"detailModal"}},[_c('Form',{ref:"conditionDetailRef",attrs:{"label-width":130,"model":_vm.currentCondition,"rules":_vm.conditionDetailRules}},[_c('FormItem',{attrs:{"label":"条件标题","prop":"name"}},[_c('Input',{attrs:{"placeholder":"请输入"},model:{value:(_vm.currentCondition.name),callback:function ($$v) {_vm.$set(_vm.currentCondition, "name", $$v);},expression:"currentCondition.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"告警指标","prop":"metricKey","rules":_vm.currentCondition.aggType === 'SCRIPTED' ? '' : _vm.selectCommonRule}},[_c('Select',{attrs:{"disabled":_vm.currentCondition.aggType === 'SCRIPTED'},on:{"on-select":function($event){return _vm.metricKeyChange(_vm.currentCondition, true)}},model:{value:(_vm.currentCondition.metricKey),callback:function ($$v) {_vm.$set(_vm.currentCondition, "metricKey", $$v);},expression:"currentCondition.metricKey"}},_vm._l((_vm.filterMetrics),function(item,index){return _c('Option',{key:index,attrs:{"value":item.code}},[_vm._v(_vm._s(item.title))])}),1)],1),_vm._v(" "),_c('FormItem',{attrs:{"prop":"timeWindowSize"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("时间设置")]),_vm._v(" "),_c('Tooltip',{attrs:{"transfer":"","max-width":"600","content":"建议您设置为最小检查周期+1分钟","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('input-integer',{attrs:{"min":1,"disabled":_vm.disabled},model:{value:(_vm.currentCondition.timeWindowSize),callback:function ($$v) {_vm.$set(_vm.currentCondition, "timeWindowSize", $$v);},expression:"currentCondition.timeWindowSize"}}),_vm._v(" "),_c('FormItem',{staticClass:"display-inline-block",attrs:{"prop":"timeWindowUnit"}},[_c('Select',{staticClass:"ml-sm",staticStyle:{"width":"100px"},attrs:{"placeholder":""},model:{value:(_vm.currentCondition.timeWindowUnit),callback:function ($$v) {_vm.$set(_vm.currentCondition, "timeWindowUnit", $$v);},expression:"currentCondition.timeWindowUnit"}},_vm._l((_vm.meta.timeWindowUnits),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],2),_vm._v(" "),_c('FormItem',{attrs:{"prop":"aggType","label":"聚合方式"}},[_c('Select',{attrs:{"placeholder":"聚合函数"},on:{"on-change":function($event){return _vm.aggTypeOnChange(_vm.currentCondition)}},model:{value:(_vm.currentCondition.aggType),callback:function ($$v) {_vm.$set(_vm.currentCondition, "aggType", $$v);},expression:"currentCondition.aggType"}},_vm._l((_vm.currentCondition.aggregateOperators),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1),_vm._v(" "),_c('FormItem',{attrs:{"prop":"comparer","label":"比较关系"}},[_c('Select',{staticClass:"unset-border-left",attrs:{"label-in-value":"","placeholder":"比较关系"},model:{value:(_vm.currentCondition.comparer),callback:function ($$v) {_vm.$set(_vm.currentCondition, "comparer", $$v);},expression:"currentCondition.comparer"}},_vm._l((_vm.currentCondition.compareOperators),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1),_vm._v(" "),_c('FormItem',{attrs:{"prop":"threshold","label":"阈值"}},[_c('input-integer',{attrs:{"min":0,"disabled":_vm.disabled,"placeholder":"阈值"},model:{value:(_vm.currentCondition.threshold),callback:function ($$v) {_vm.$set(_vm.currentCondition, "threshold", $$v);},expression:"currentCondition.threshold"}})],1),_vm._v(" "),(_vm.type === 'default')?_c('FormItem',{attrs:{"label":"聚合数据过滤条件","prop":"filters"}},[_c('Input',{attrs:{"type":"textarea","autosize":{ minRows: 2, maxRows: 5 },"placeholder":"请输入"},model:{value:(_vm.currentCondition.filters),callback:function ($$v) {_vm.$set(_vm.currentCondition, "filters", $$v);},expression:"currentCondition.filters"}})],1):_vm._e(),_vm._v(" "),(_vm.currentCondition.aggType === 'SCRIPTED')?[_c('FormItem',{attrs:{"label":"初始化","prop":"initScript"}},[_c('Input',{ref:"autoFocusInput",attrs:{"type":"textarea","autosize":{ minRows: 2, maxRows: 5 },"placeholder":"请输入"},model:{value:(_vm.currentCondition.initScript),callback:function ($$v) {_vm.$set(_vm.currentCondition, "initScript", $$v);},expression:"currentCondition.initScript"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"行计算","prop":"mapScript"}},[_c('Input',{ref:"autoFocusInput",attrs:{"type":"textarea","autosize":{ minRows: 2, maxRows: 5 },"placeholder":"请输入"},model:{value:(_vm.currentCondition.mapScript),callback:function ($$v) {_vm.$set(_vm.currentCondition, "mapScript", $$v);},expression:"currentCondition.mapScript"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"分片计算","prop":"combineScript"}},[_c('Input',{ref:"autoFocusInput",attrs:{"type":"textarea","autosize":{ minRows: 2, maxRows: 5 },"placeholder":"请输入"},model:{value:(_vm.currentCondition.combineScript),callback:function ($$v) {_vm.$set(_vm.currentCondition, "combineScript", $$v);},expression:"currentCondition.combineScript"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"结果计算","prop":"reduceScript"}},[_c('Input',{ref:"autoFocusInput",attrs:{"type":"textarea","autosize":{ minRows: 2, maxRows: 5 },"placeholder":"请输入"},model:{value:(_vm.currentCondition.reduceScript),callback:function ($$v) {_vm.$set(_vm.currentCondition, "reduceScript", $$v);},expression:"currentCondition.reduceScript"}})],1)]:_vm._e()],2),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":function($event){return _vm.detailModalClose()}}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.confirmEdit()}}},[_vm._v("确定")])],1)],1)]:_vm._e()],2)};
var __vue_staticRenderFns__$j = [];

  /* style */
  const __vue_inject_styles__$j = function (inject) {
    if (!inject) return
    inject("data-v-8fe1c7e2_0", { source: ".alert-condition[data-v-8fe1c7e2] .ivu-tooltip-rel{display:unset}.alert-condition .condition-item-mouseover .condition-editor-right-toolbar i[data-v-8fe1c7e2]{display:block}.alert-condition .condition-editor-right-toolbar[data-v-8fe1c7e2]{display:flex;align-items:center;width:80px;flex-shrink:0}.alert-condition .condition-editor-right-toolbar i[data-v-8fe1c7e2]{font-size:18px;padding:4px;cursor:pointer;display:none}.alert-condition .condition-list .condition-item[data-v-8fe1c7e2]{margin-bottom:24px}.alert-condition .condition-list .condition-item .ivu-input-number[data-v-8fe1c7e2],.alert-condition .condition-list .condition-item .ivu-select[data-v-8fe1c7e2]{display:block}.alert-condition .condition-list .condition-item .compose-cell[data-v-8fe1c7e2]{margin-left:-2px}.alert-condition .condition-list .condition-item[data-v-8fe1c7e2] .ivu-input-group-append,.alert-condition .condition-list .condition-item[data-v-8fe1c7e2] .ivu-input-group-prepend{border-radius:0}.alert-condition .condition-list .condition-item[data-v-8fe1c7e2] .ivu-select-selection{border-radius:0}.alert-condition .condition-list .condition-item[data-v-8fe1c7e2] .ivu-input{border-radius:0}.alert-condition .condition-list .condition-item[data-v-8fe1c7e2] .ivu-input-number{border-radius:0}.alert-condition .condition-list .condition-item-biref[data-v-8fe1c7e2] .ivu-input-group-append{border-right:none}.alert-condition .hide-border-left[data-v-8fe1c7e2]{border-left:none!important}.alert-condition .hide-border-right[data-v-8fe1c7e2]{border-right:none!important}.alert-condition .fuse-monitor-rule-condition-button[data-v-8fe1c7e2]{display:table-cell;padding:4px 7px;font-size:inherit;font-weight:400;line-height:1.5;color:#515a6e;text-align:center;background-color:#f8f8f9;border:1px solid #dcdee2;white-space:nowrap;vertical-align:middle;border-radius:0;height:32px}.alert-condition .warning-bg[data-v-8fe1c7e2] .ivu-select-selection,.alert-condition .warning-bg[data-v-8fe1c7e2] input{background:#ff0}.alert-condition .section-title[data-v-8fe1c7e2]{color:#515a6e;font-size:14px;font-weight:700}[data-v-8fe1c7e2] .ivu-input-number{width:80px!important}[data-v-8fe1c7e2] .ivu-input-number-focused,[data-v-8fe1c7e2] .ivu-input-number:hover{z-index:100}[data-v-8fe1c7e2] .ivu-select-selection{z-index:99}[data-v-8fe1c7e2] .ivu-select-selection-focused,[data-v-8fe1c7e2] .ivu-select-selection:hover{z-index:100}.ivu-form-item-error .ivu-input-number[data-v-8fe1c7e2],.ivu-form-item-error .ivu-select-selection[data-v-8fe1c7e2]{z-index:100}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$j = "data-v-8fe1c7e2";
  /* module identifier */
  const __vue_module_identifier__$j = undefined;
  /* functional template */
  const __vue_is_functional_template__$j = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$j = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$j, staticRenderFns: __vue_staticRenderFns__$j },
    __vue_inject_styles__$j,
    __vue_script__$j,
    __vue_scope_id__$j,
    __vue_is_functional_template__$j,
    __vue_module_identifier__$j,
    false,
    createInjector,
    undefined,
    undefined
  );

var mixins = {
  data() {
    return {
      columns: [
        {
          type: 'index',
          width: 60,
          align: 'center'
        },
        {
          title: '通知标题',
          key: 'name'
        },
        {
          title: '告警类型',
          key: 'type',
          render: (h, params) => {
            if (params.row.type === 'SENDMAIL') {
              return h('span', {}, '邮件告警');
            } else if (params.row.type === 'WEBHOOK') {
              return h('span', {}, 'WEBHOOK告警');
            }
          }
        },
        {
          title: '操作',
          width: 100,
          render: (h, params) => {
            return h('div', [
              h('Icon', {
                props: {
                  type: 'md-create',
                  size: 'small'
                },
                attrs: {
                  title: '编辑'
                },
                style: {
                  marginRight: '10px',
                  color: '#2d8cf0',
                  fontSize: '16px',
                  cursor: 'pointer'
                },
                on: {
                  click: () => {
                    this.handleEdit(params.row);
                  }
                }
              }),
              h('Icon', {
                props: {
                  type: 'ios-trash',
                  size: 'small'
                },
                attrs: {
                  title: '删除'
                },
                style: {
                  color: '#2d8cf0',
                  fontSize: '16px',
                  cursor: 'pointer'
                },
                on: {
                  click: () => {
                    this.handleDelete(params.row);
                  }
                }
              })
            ]);
          }
        }
      ]
    };
  },
  methods: {
    handleDelete(row) {
      this.$Modal.confirm({
        title: '确认删除？',
        onOk: async () => {
          this.value.alertNotifications.splice(row._index, 1);
        }
      });
    } // 删除
  }
};

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$i = {
  name: 'eamil-alert',
  props: {
    value: {
      type: Object,
      default: function () {
        return {
          name: '',
          sendEmailParams: {
            cc: '',
            recipients: '',
            secured: false
          },
          timeWindowUnit: 'DAYS',
          timeWindowSize: '',
          type: 'SENDMAIL'
        };
      }
    }
  },
  data() {
    return {
      formRules: {
        'sendEmailParams.title': [{ required: true, message: '请输入', trigger: 'change' }],
        name: [{ required: true, message: '请输入', trigger: 'change' }],
        'sendEmailParams.recipients': [{ required: true, message: '请输入', trigger: 'change' }],
        timeWindowSize: [{ required: true, message: '请输入', type: 'number', trigger: 'change' }],
        'sendEmailParams.content': [{ required: true, message: '请输入', trigger: 'change' }],
        'sendEmailParams.smtpHost': [{ required: true, message: '请输入', trigger: 'change' }],
        'sendEmailParams.smtpPort': [{ required: true, type: 'number', message: '请输入', trigger: 'change' }],
        'sendEmailParams.smtpUsername': [{ required: true, message: '请输入', trigger: 'change' }],
        'sendEmailParams.smtpPassword': [{ required: true, message: '请输入', trigger: 'change' }],
        'sendEmailParams.secured': [{ required: true, type: 'boolean', message: '请选择', trigger: 'change' }]
      },
      innerCollapseValue: true
    };
  },
  computed: {
    toggleText() {
      return this.innerCollapseValue ? '展开' : '收起';
    }
  },
  mounted() {
    // if (_.isEmpty(this.value.sendEmailParams.secured)) {
    //   this.value.sendEmailParams.secured = false;
    // }
  },
  methods: {
    validate(callback) {
      this.$refs['formRef'].validate((valid) => {
        callback(valid);
      });
    },
    resetFields() {
      this.$refs['formRef'].resetFields();
    },
    autoFocus() {
      this.$refs.autoFocusInput.$refs.input.focus();
    },
    changeNumber() {
      let str = '' + this.value.sendEmailParams.timeWindowSize;
      if (str.indexOf('.') !== -1) {
        let arr = str.split('.');
        let str2 = arr[0];
        this.value.sendEmailParams.timeWindowSize = str2;
      }
    },
    toggle() {
      this.innerCollapseValue = !this.innerCollapseValue;
    }
  }
};

/* script */
const __vue_script__$i = script$i;

/* template */
var __vue_render__$i = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Form',{ref:"formRef",staticClass:"fuse-email-warning-form",attrs:{"rules":_vm.formRules,"model":_vm.value,"label-width":120}},[_c('FormItem',{attrs:{"label":"通知标题","prop":"name"}},[_c('Input',{ref:"autoFocusInput",attrs:{"placeholder":"请输入通知标题"},model:{value:(_vm.value.name),callback:function ($$v) {_vm.$set(_vm.value, "name", $$v);},expression:"value.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"收件人","prop":"sendEmailParams.recipients"}},[_c('Input',{attrs:{"placeholder":"请输入邮件收件人，用 ; 号分割多个收件人"},model:{value:(_vm.value.sendEmailParams.recipients),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "recipients", $$v);},expression:"value.sendEmailParams.recipients"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"抄送人","prop":"cc"}},[_c('Input',{attrs:{"placeholder":"请输入邮件抄送人，用 ; 号分割多个抄送人"},model:{value:(_vm.value.sendEmailParams.cc),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "cc", $$v);},expression:"value.sendEmailParams.cc"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"主机地址","prop":"sendEmailParams.smtpHost"}},[_c('Input',{attrs:{"placeholder":"请输入主机地址"},model:{value:(_vm.value.sendEmailParams.smtpHost),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "smtpHost", $$v);},expression:"value.sendEmailParams.smtpHost"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"端口号","prop":"sendEmailParams.smtpPort"}},[_c('Input',{attrs:{"type":"number","number":"","placeholder":"请输入端口号"},model:{value:(_vm.value.sendEmailParams.smtpPort),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "smtpPort", $$v);},expression:"value.sendEmailParams.smtpPort"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"认证用户名","prop":"sendEmailParams.smtpUsername"}},[_c('Input',{attrs:{"placeholder":"请输入认证用户名"},model:{value:(_vm.value.sendEmailParams.smtpUsername),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "smtpUsername", $$v);},expression:"value.sendEmailParams.smtpUsername"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"认证密码","prop":"sendEmailParams.smtpPassword"}},[_c('Input',{attrs:{"type":"password","password":"","placeholder":"请输入认证密码"},model:{value:(_vm.value.sendEmailParams.smtpPassword),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "smtpPassword", $$v);},expression:"value.sendEmailParams.smtpPassword"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"是否加密的SMTP协议","prop":"sendEmailParams.secured"}},[_c('Radio',{model:{value:(_vm.value.sendEmailParams.secured),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "secured", $$v);},expression:"value.sendEmailParams.secured"}},[_c('span',[_vm._v("是")])]),_vm._v(" "),_c('Radio',{attrs:{"true-value":false,"false-value":true},model:{value:(_vm.value.sendEmailParams.secured),callback:function ($$v) {_vm.$set(_vm.value.sendEmailParams, "secured", $$v);},expression:"value.sendEmailParams.secured"}},[_c('span',[_vm._v("否")])])],1)],1)};
var __vue_staticRenderFns__$i = [];

  /* style */
  const __vue_inject_styles__$i = function (inject) {
    if (!inject) return
    inject("data-v-62d76ef2_0", { source: ".fuse-email-warning-form .ivu-input-number{width:80px!important}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$i = undefined;
  /* module identifier */
  const __vue_module_identifier__$i = undefined;
  /* functional template */
  const __vue_is_functional_template__$i = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$i = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$i, staticRenderFns: __vue_staticRenderFns__$i },
    __vue_inject_styles__$i,
    __vue_script__$i,
    __vue_scope_id__$i,
    __vue_is_functional_template__$i,
    __vue_module_identifier__$i,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$h = {
  name: 'webhook-alert',
  props: {
    value: {
      type: Object,
      default: function () {
        return {
          type: 'WEBHOOK',
          name: '',
          webhookParams: {
            headers: {},
            headersArr: [{ key: '', value: '' }],
            method: 'POST',
            url: ''
          }
        };
      }
    }
  },
  data() {
    return {
      headerParamsDefault: { key: '', value: '' },
      formRules: {
        name: [{ required: true, message: '请输入', trigger: 'blur' }],
        'webhookParams.level': [{ required: true, message: '请输入', trigger: 'change' }],
        'webhookParams.method': [{ required: true, message: '请输入', trigger: 'change' }],
        timeWindowSize: [{ required: true, message: '请输入', type: 'number', trigger: 'change' }],
        'webhookParams.url': [{ required: true, message: '请输入', trigger: 'blur' }],
        'webhookParams.body': [{ required: true, message: '请输入', trigger: 'blur' }]
      }
    };
  },
  watch: {
    value: {
      handler: function () {
        this.$set(this.value.webhookParams, 'headersArr', [_.cloneDeep(this.headerParamsDefault)]);
        if (this.value && this.value.webhookParams && !_.isEmpty(this.value.webhookParams.headers)) {
          let headersArr = [];
          Object.keys(this.value.webhookParams.headers).forEach((key, index) => {
            headersArr[index] = {};
            headersArr[index].key = key;
            headersArr[index].value = this.value.webhookParams.headers[key];
            // headersArr[index].value = this.value.webhookParams.headers[key]
          });
          this.value.webhookParams.headersArr = headersArr;
        }
      },
      immediate: true
    }
  },

  methods: {
    validate(callback) {
      this.$refs['formRef'].validate((valid) => {
        callback(valid);
      });
    },
    handleAddHeaderParmas(paramsItem, index) {
      if (typeof index === 'number') {
        this.value.webhookParams.headersArr.splice(index + 1, 0, _.cloneDeep(this.headerParamsDefault)); //
      } else {
        this.value.webhookParams.headers.push(_.cloneDeep(this.headerParamsDefault));
      }
    },
    handleRemoveHeaderParmas(item, index) {
      this.value.webhookParams.headersArr.splice(index, 1);
    },

    resetFields() {
      this.value.webhookParams.headersArr = [{ key: '', value: '' }];
      this.$refs['formRef'].resetFields();
    },
    autoFocus() {
      this.$refs.autoFocusInput.$refs.input.focus();
    },
    changeNumber() {
      let str = '' + this.value.webhookParams.timeWindowSize;
      if (str.indexOf('.') !== -1) {
        let arr = str.split('.');
        let str2 = arr[0];
        this.value.webhookParams.timeWindowSize = str2;
      }
    }
  }
};

/* script */
const __vue_script__$h = script$h;

/* template */
var __vue_render__$h = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Form',{ref:"formRef",staticClass:"fuse-webhook-warning-form",attrs:{"rules":_vm.formRules,"model":_vm.value,"label-width":120}},[_c('FormItem',{attrs:{"label":"通知标题","prop":"name"}},[_c('Input',{ref:"autoFocusInput",attrs:{"placeholder":"请输入通知标题"},model:{value:(_vm.value.name),callback:function ($$v) {_vm.$set(_vm.value, "name", $$v);},expression:"value.name"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"请求方式","prop":"webhookParams.method"}},[_c('Select',{attrs:{"filterable":"","placeholder":"请选择请求方式"},model:{value:(_vm.value.webhookParams.method),callback:function ($$v) {_vm.$set(_vm.value.webhookParams, "method", $$v);},expression:"value.webhookParams.method"}},[_c('Option',{attrs:{"label":"POST","value":"POST"}}),_vm._v(" "),_c('Option',{attrs:{"label":"GET","value":"GET"}}),_vm._v(" "),_c('Option',{attrs:{"label":"PUT","value":"PUT"}}),_vm._v(" "),_c('Option',{attrs:{"label":"DELETE","value":"DELETE"}})],1)],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"请求地址","prop":"webhookParams.url"}},[_c('Input',{attrs:{"placeholder":"请输入请求地址"},model:{value:(_vm.value.webhookParams.url),callback:function ($$v) {_vm.$set(_vm.value.webhookParams, "url", $$v);},expression:"value.webhookParams.url"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"附加请求头"}},_vm._l((_vm.value.webhookParams.headersArr),function(params,index){return _c('Row',{key:index,staticClass:"ivu-mb-8",attrs:{"type":"flex"}},[_c('Col',{attrs:{"xl":6,"lg":6,"md":6,"sm":8,"xs":6}},[_c('Input',{attrs:{"placeholder":"请输入参数"},model:{value:(params.key),callback:function ($$v) {_vm.$set(params, "key", $$v);},expression:"params.key"}})],1),_vm._v(" "),_c('Col',{staticClass:"text-center",attrs:{"xl":1,"lg":1,"md":1,"sm":1,"xs":1}},[_vm._v(" = ")]),_vm._v(" "),_c('Col',{attrs:{"xl":12,"lg":12,"md":12,"sm":12,"xs":12}},[_c('Input',{attrs:{"placeholder":"请输入值"},model:{value:(params.value),callback:function ($$v) {_vm.$set(params, "value", $$v);},expression:"params.value"}})],1),_vm._v(" "),_c('Col',[_c('div',{staticClass:"fuse-rule-editor-right-toolbar"},[_c('Icon',{attrs:{"type":"ios-add-circle-outline"},on:{"click":function($event){return _vm.handleAddHeaderParmas(params, index)}}}),_vm._v(" "),(_vm.value.webhookParams.headersArr.length > 1)?_c('Icon',{attrs:{"type":"ios-remove-circle-outline"},on:{"click":function($event){return _vm.handleRemoveHeaderParmas(params, index)}}}):_vm._e()],1)])],1)}),1)],1)};
var __vue_staticRenderFns__$h = [];

  /* style */
  const __vue_inject_styles__$h = function (inject) {
    if (!inject) return
    inject("data-v-9d480ed0_0", { source: ".fuse-webhook-warning-form .ivu-input-number{width:80px!important}.fuse-webhook-warning-form .fuse-rule-editor-right-toolbar{display:flex;align-items:center;height:100%}.fuse-webhook-warning-form .fuse-rule-editor-right-toolbar i{font-size:18px;padding:4px;cursor:pointer}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$h = undefined;
  /* module identifier */
  const __vue_module_identifier__$h = undefined;
  /* functional template */
  const __vue_is_functional_template__$h = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$h = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$h, staticRenderFns: __vue_staticRenderFns__$h },
    __vue_inject_styles__$h,
    __vue_script__$h,
    __vue_scope_id__$h,
    __vue_is_functional_template__$h,
    __vue_module_identifier__$h,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$g = {
  mixins: [mixins],
  props: {
    value: {
      type: Object
    },
    addActionTypes: {
      type: Array,
      default: () => [
        {
          type: 'WEBHOOK',
          label: 'WEBHOOK告警'
        },
        {
          type: 'EMAIL',
          label: '邮件告警'
        }
      ]
    }
  },
  components: { emailActionForm: __vue_component__$i, webhookActionForm: __vue_component__$h },
  data() {
    return {
      addWebhookActionModal: false,
      addEmailActionModal: false,
      currentWebhookActionDeep: {
        type: 'WEBHOOK',
        name: '',
        webhookParams: {
          headers: {},
          headersArr: [{ key: '', value: '' }],
          body: '',
          method: 'POST',
          url: ''
        }
      },
      currentEmailActionDeep: {
        name: '',
        sendEmailParams: {
          cc: '',
          title: '',
          content: '',
          recipients: ''
        },
        type: 'SENDMAIL'
      },
      editWebhookActionModal: false,
      editEmailActionModal: false
    };
  },
  methods: {
    addAction(type) {
      if (type === 'WEBHOOK') {
        this.addWebhookActionModal = true;
      } else if (type === 'EMAIL') {
        this.addEmailActionModal = true;
      }
    },
    saveAddAction(type) {
      if (type === 'webhook') {
        this.$refs.webhookActionFormRef.validate((valid) => {
          if (valid) {
            let headers = {};
            this.$refs.webhookActionFormRef.value.webhookParams.headersArr.forEach((item) => {
              headers[item.key] = item.value;
            });
            this.$refs.webhookActionFormRef.value.webhookParams.headers = headers;
            let data = _.cloneDeep(this.$refs.webhookActionFormRef.value);
            delete data.webhookParams.headersArr;
            if (!this.value.actions) {
              this.$set(this.value, 'actions', []);
            }
            this.value.actions.push(data);
            this.$refs.webhookActionFormRef.resetFields();
            this.addWebhookActionModal = false;
          }
        });
      } else if (type === 'email') {
        this.$refs.emailActionFormRef.validate((valid) => {
          if (valid) {
            let data = _.cloneDeep(this.$refs.emailActionFormRef.value);
            if (!this.value.actions) {
              this.$set(this.value, 'actions', []);
            }
            this.$refs.emailActionFormRef.resetFields();
            this.value.actions.push(data);
            this.addEmailActionModal = false;
          }
        });
      }
    }, // 保存添加的告警信息
    webhookModalVisible(val) {
      setTimeout(() => {
        if (val) {
          this.$refs.webhookActionFormRef.autoFocus();
        }
      }, 200);
    }, //
    emailModalVisible(val) {
      setTimeout(() => {
        if (val) {
          this.$refs.emailActionFormRef.autoFocus();
        }
      }, 200);
    }, //
    addWebhookActionModalClose() {
      this.$refs.webhookActionFormRef.resetFields();
      this.addWebhookActionModal = false;
    }, // 关闭添加告警modal
    addEmailActionModalClose() {
      this.$refs.emailActionFormRef.resetFields();
      this.addEmailActionModal = false;
    }, // 关闭添加告警modal
    editWebhookAlertModalClose() {
      this.$refs.editWebhookActionFormRef.resetFields();
      this.editWebhookActionModal = false;
    }, // 关闭修改wenhook修改的信息
    saveEditWebhookWarn() {
      this.$refs.editWebhookActionFormRef.validate((valid) => {
        if (valid) {
          let headers = {};
          this.currentWebhookActionDeep.webhookParams.headersArr.forEach((item) => {
            headers[item.key] = item.value;
          });
          this.currentWebhookActionDeep.webhookParams.headers = headers;
          delete this.currentWebhookActionDeep.webhookParams.headersArr;
          this.editWebhookActionModal = false;
          this.$set(this.value.actions, this.currentWebhookActionDeep._index, this.currentWebhookActionDeep);
        }
      });
    }, // 保存修改wenhook修改的信息
    editEmailAlertModalClose() {
      this.$refs.editEmailActionFormRef.resetFields();
      this.editEmailActionModal = false;
    }, // 关闭修改email的信息
    saveEditEmailWarn() {
      this.$refs.editEmailActionFormRef.validate((valid) => {
        if (valid) {
          this.$set(this.value.actions, this.currentEmailActionDeep._index, this.currentEmailActionDeep);
          this.editEmailActionModal = false;
        }
      });
    }, // 保存修改email的信息
    handleDelete(row) {
      this.$Modal.confirm({
        title: '确认删除？',
        onOk: async () => {
          this.value.actions.splice(row._index, 1);
        }
      });
    }, // 删除
    handleEdit(row) {
      if (row.type === 'SENDMAIL') {
        this.currentEmailActionDeep = _.cloneDeep(row);
        this.editEmailActionModal = true;
      } else {
        this.currentWebhookActionDeep = _.cloneDeep(row);
        this.editWebhookActionModal = true;
      }
    } // 编辑
  }
};

/* script */
const __vue_script__$g = script$g;

/* template */
var __vue_render__$g = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"alert-actions"},[_c('div',{staticClass:"actions-header"},[_c('span',{staticClass:"section-title"},[_vm._v("告警方式")]),_vm._v(" "),_c('Dropdown',{on:{"on-click":_vm.addAction}},[_c('Button',{attrs:{"type":"primary"}},[_vm._v("\n        添加告警\n        "),_c('Icon',{attrs:{"type":"ios-arrow-down"}})],1),_vm._v(" "),_c('DropdownMenu',{attrs:{"slot":"list"},slot:"list"},_vm._l((_vm.addActionTypes),function(item,index){return _c('DropdownItem',{key:index,attrs:{"name":item.type}},[_vm._v(_vm._s(item.label))])}),1)],1)],1),_vm._v(" "),_c('Divider',{staticStyle:{"margin":"16px 0px"}}),_vm._v(" "),_c('Table',{attrs:{"columns":_vm.columns,"data":_vm.value.actions || []}}),_vm._v(" "),_c('Modal',{attrs:{"width":"760px"},on:{"on-visible-change":_vm.webhookModalVisible,"on-cancel":function($event){return _vm.addWebhookActionModalClose('addWarningForm')}},model:{value:(_vm.addWebhookActionModal),callback:function ($$v) {_vm.addWebhookActionModal=$$v;},expression:"addWebhookActionModal"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("添加告警")]),_vm._v(" "),_c('webhookActionForm',{ref:"webhookActionFormRef"}),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":function($event){return _vm.addWebhookActionModalClose('addWarningForm')}}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.saveAddAction('webhook')}}},[_vm._v("确定")])],1)],1),_vm._v(" "),_c('Modal',{attrs:{"width":"760px"},on:{"on-visible-change":_vm.emailModalVisible,"on-cancel":function($event){return _vm.addEmailActionModalClose('addWarningForm')}},model:{value:(_vm.addEmailActionModal),callback:function ($$v) {_vm.addEmailActionModal=$$v;},expression:"addEmailActionModal"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("添加告警")]),_vm._v(" "),_c('emailActionForm',{ref:"emailActionFormRef"}),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":function($event){return _vm.addEmailActionModalClose('addWarningForm')}}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.saveAddAction('email')}}},[_vm._v("确定")])],1)],1),_vm._v(" "),_c('Modal',{attrs:{"width":"760px"},model:{value:(_vm.editWebhookActionModal),callback:function ($$v) {_vm.editWebhookActionModal=$$v;},expression:"editWebhookActionModal"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("编辑告警")]),_vm._v(" "),_c('webhookActionForm',{ref:"editWebhookActionFormRef",model:{value:(_vm.currentWebhookActionDeep),callback:function ($$v) {_vm.currentWebhookActionDeep=$$v;},expression:"currentWebhookActionDeep"}}),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":function($event){return _vm.editWebhookAlertModalClose()}}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.saveEditWebhookWarn()}}},[_vm._v("确定")])],1)],1),_vm._v(" "),_c('Modal',{attrs:{"width":"760px"},model:{value:(_vm.editEmailActionModal),callback:function ($$v) {_vm.editEmailActionModal=$$v;},expression:"editEmailActionModal"}},[_c('p',{attrs:{"slot":"header"},slot:"header"},[_vm._v("编辑告警")]),_vm._v(" "),_c('emailActionForm',{ref:"editEmailActionFormRef",model:{value:(_vm.currentEmailActionDeep),callback:function ($$v) {_vm.currentEmailActionDeep=$$v;},expression:"currentEmailActionDeep"}}),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{on:{"click":function($event){return _vm.editEmailAlertModalClose()}}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":function($event){return _vm.saveEditEmailWarn()}}},[_vm._v("确定")])],1)],1)],1)};
var __vue_staticRenderFns__$g = [];

  /* style */
  const __vue_inject_styles__$g = function (inject) {
    if (!inject) return
    inject("data-v-9433f2ea_0", { source: ".alert-actions .actions-header[data-v-9433f2ea]{display:flex;justify-content:space-between;align-items:flex-end}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$g = "data-v-9433f2ea";
  /* module identifier */
  const __vue_module_identifier__$g = undefined;
  /* functional template */
  const __vue_is_functional_template__$g = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$g = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$g, staticRenderFns: __vue_staticRenderFns__$g },
    __vue_inject_styles__$g,
    __vue_script__$g,
    __vue_scope_id__$g,
    __vue_is_functional_template__$g,
    __vue_module_identifier__$g,
    false,
    createInjector,
    undefined,
    undefined
  );

//

var script$f = {
  mixins: [mixins$2],
  components: { condition: __vue_component__$j, actions: __vue_component__$g, inputInteger: __vue_component__$k },
  data() {
    return {
      prepare: false,
      time: '',
      timeFlag: '' // 开启时间段的标识 全天or自定义
    };
  },
  provide() {
    return {
      currentMonitoringType: this.currentMonitoringType,
      meta: this.meta,
      monitoringType: this.monitoringType,
      showActions: this.showActions,
      type: this.type,
      metrics: this.metrics,
      metricTableColumns: this.metricTableColumns
    };
  },
  created() {
    this.initNotifyTypes();
  },

  mounted() {
    this.prepare = false;
    this.initTime();
    if (this.value && !this.value.notifyFrequency) {
      this.$set(this.value, 'notifyFrequency', {});
      this.value.notifyFrequency.timeWindowSize = '';
    }
    this.prepare = true;
  },

  methods: {
    validate(callback) {
      this.$refs['formRef'].validate((valid) => {
        callback(valid);
      });
    },
    resetFields() {
      this.$refs['formRef'].resetFields();
    },
    initNotifyTypes() {
      this.$set(this.value, 'notifyTypes', []);
      if (!_.isEmpty(this.value.summary)) {
        this.value.notifyTypes.push('alert');
      }
      if (!_.isEmpty(this.value.restoreSummary)) {
        this.value.notifyTypes.push('restore');
      } else {
        this.value.notifyTypes.push('alert');
      }
    },
    initTime() {
      let time = [];
      time[0] = this.value.timeStart || '';
      time[1] = this.value.timeEnd || '';
      this.time = time;
    },
    handleChangeTime(v) {
      this.value.timeStart = v[0];
      this.value.timeEnd = v[1];
    },
    scheduleIntervalUnitChange(v) {
      if (v === 'SECONDS') {
        this.value.scheduleInterval = 30;
      } else {
        this.value.scheduleInterval = 1;
      }
    },
    getData() {
      return this.value;
    },
    notifyTypesChange(types) {
      if (types.indexOf('restore') === -1) {
        this.value.restoreSummary = '';
        this.value.restoreDescription = '';
      }
    },
    handleSelectGroupBy() {
      this.$refs.conditionRef.initCondition();
    }
  }
};

/* script */
const __vue_script__$f = script$f;

/* template */
var __vue_render__$f = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return (_vm.meta && _vm.monitoringType && _vm.prepare)?_c('div',{staticClass:"fuse-monitoring-rule"},[_c('Form',{ref:"formRef",attrs:{"disabled":_vm.disabled,"rules":_vm.formRules,"model":_vm.value,"label-width":100}},[_c('p',{staticClass:"section-title"},[_vm._v("告警规则")]),_vm._v(" "),_c('Divider',{staticStyle:{"margin":"16px 0px"}}),_vm._v(" "),_c('FormItem',{attrs:{"label":"告警名称","prop":"name"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("告警名称")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"创建的告警规则的名称，用户可自定义名称","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Input',{directives:[{name:"focus",rawName:"v-focus"}],staticStyle:{"max-width":"340px"},attrs:{"placeholder":"创建的告警规则的名称，用户可自定义名称"},model:{value:(_vm.value.name),callback:function ($$v) {_vm.$set(_vm.value, "name", $$v);},expression:"value.name"}})],2),_vm._v(" "),_c('Row',{attrs:{"type":"flex"}},[_c('Col',[_c('FormItem',{attrs:{"prop":"groupBy"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("监控对象")]),_vm._v(" "),_c('Tooltip',{attrs:{"transfer":"","max-width":"600","content":"系统为不同的监控对象提供了不同的监控指标，您可根据监控指标组合出多种监控规则","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Select',{staticStyle:{"width":"120px"},attrs:{"placeholder":"请选择"},on:{"on-change":_vm.handleSelectGroupBy},model:{value:(_vm.value.groupBy),callback:function ($$v) {_vm.$set(_vm.value, "groupBy", $$v);},expression:"value.groupBy"}},_vm._l((_vm.meta.groupByOptions),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],2)],1),_vm._v(" "),_c('Col',[_c('FormItem',{attrs:{"label":"告警级别","prop":"level"}},[_c('Select',{staticStyle:{"width":"120px"},attrs:{"placeholder":"请选择"},model:{value:(_vm.value.level),callback:function ($$v) {_vm.$set(_vm.value, "level", $$v);},expression:"value.level"}},_vm._l((_vm.meta.alertLevels),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],1)],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"检查时段"}},[_c('RadioGroup',{model:{value:(_vm.timeFlag),callback:function ($$v) {_vm.timeFlag=$$v;},expression:"timeFlag"}},[_c('Radio',{attrs:{"label":"all"}},[_vm._v("全天")]),_vm._v(" "),_c('Radio',{attrs:{"label":"diy"}},[_vm._v("自定义")])],1),_vm._v(" "),_c('TimePicker',{staticStyle:{"width":"214px"},attrs:{"disabled":_vm.timeFlag != 'diy',"type":"timerange","confirm":"","format":"HH:mm","placement":"bottom","placeholder":"请选择"},on:{"on-change":_vm.handleChangeTime},model:{value:(_vm.time),callback:function ($$v) {_vm.time=$$v;},expression:"time"}})],1),_vm._v(" "),_c('FormItem',{attrs:{"prop":"scheduleInterval"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("检查周期")]),_vm._v(" "),_c('Tooltip',{attrs:{"transfer":"","max-width":"600","content":"由于网络、机器配置等多种原因，系统建议您每2min检查一次告警规则（最快支持30s）","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('input-integer',{attrs:{"min":_vm.scheduleIntervalMinLimit,"max":_vm.scheduleIntervalMaxLimit,"step":_vm.scheduleIntervalStep,"disabled":_vm.disabled},model:{value:(_vm.value.scheduleInterval),callback:function ($$v) {_vm.$set(_vm.value, "scheduleInterval", $$v);},expression:"value.scheduleInterval"}}),_vm._v(" "),_c('FormItem',{staticClass:"display-inline-block",attrs:{"prop":"scheduleIntervalUnit"}},[_c('Select',{staticClass:"ml-sm",staticStyle:{"width":"100px"},attrs:{"placeholder":""},on:{"on-change":_vm.scheduleIntervalUnitChange},model:{value:(_vm.value.scheduleIntervalUnit),callback:function ($$v) {_vm.$set(_vm.value, "scheduleIntervalUnit", $$v);},expression:"value.scheduleIntervalUnit"}},_vm._l((_vm.meta.checkIntervalUnits),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],2),_vm._v(" "),(_vm.type === 'default')?_c('FormItem',{attrs:{"label":"是否启用","prop":"enabled"}},[_c('Radio',{model:{value:(_vm.value.enabled),callback:function ($$v) {_vm.$set(_vm.value, "enabled", $$v);},expression:"value.enabled"}},[_c('span',[_vm._v("是")])]),_vm._v(" "),_c('Radio',{attrs:{"true-value":false,"false-value":true},model:{value:(_vm.value.enabled),callback:function ($$v) {_vm.$set(_vm.value, "enabled", $$v);},expression:"value.enabled"}},[_c('span',[_vm._v("否")])])],1):_vm._e(),_vm._v(" "),_c('span',{staticClass:"section-title"},[_vm._v("告警通知")]),_vm._v(" "),(_vm.showNotifyDocs)?_c('span',{staticClass:"form-item-tips",staticStyle:{"cursor":"pointer"},on:{"click":function($event){return _vm.$emit('handleClickNotifyDocs')}}},[_c('Icon',{attrs:{"type":"ios-log-out","size":"15"}}),_vm._v(" 查看通知详情自定义配置文档")],1):_vm._e(),_vm._v(" "),_c('Divider',{staticStyle:{"margin":"16px 0px"}}),_vm._v(" "),_c('FormItem',{attrs:{"prop":"notifyFrequency.timeWindowSize"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("重复频率")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"请您决定当同一告警规则多次触发时，接收重复通知的时间间隔","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('input-integer',{attrs:{"min":1,"disabled":_vm.disabled,"placeholder":"时间"},model:{value:(_vm.value.notifyFrequency.timeWindowSize),callback:function ($$v) {_vm.$set(_vm.value.notifyFrequency, "timeWindowSize", $$v);},expression:"value.notifyFrequency.timeWindowSize"}}),_vm._v(" "),_c('FormItem',{staticClass:"display-inline-block",attrs:{"prop":"notifyFrequency.timeWindowUnit"}},[_c('Select',{staticClass:"ml-sm",staticStyle:{"width":"100px"},attrs:{"placeholder":"时间单位"},model:{value:(_vm.value.notifyFrequency.timeWindowUnit),callback:function ($$v) {_vm.$set(_vm.value.notifyFrequency, "timeWindowUnit", $$v);},expression:"value.notifyFrequency.timeWindowUnit"}},_vm._l((_vm.meta.notifyIntervalUnits),function(item,index){return _c('Option',{key:index,attrs:{"value":item.value}},[_vm._v(_vm._s(item.title))])}),1)],1)],2),_vm._v(" "),_c('FormItem',{attrs:{"label":"通知类型","prop":"notifyTypes"}},[_c('CheckboxGroup',{on:{"on-change":_vm.notifyTypesChange},model:{value:(_vm.value.notifyTypes),callback:function ($$v) {_vm.$set(_vm.value, "notifyTypes", $$v);},expression:"value.notifyTypes"}},[_c('Checkbox',{attrs:{"disabled":"","label":"alert"}},[_c('span',[_vm._v("告警通知")])]),_vm._v(" "),_c('Checkbox',{attrs:{"label":"restore"}},[_c('span',[_vm._v("恢复通知")])])],1)],1),_vm._v(" "),(_vm.value && _vm.value.notifyTypes.indexOf('alert') > -1)?[_c('FormItem',{attrs:{"label":"告警概述","prop":"summary"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("告警概述")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"用于推送告警消息时，告警消息的标题显示","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Input',{attrs:{"placeholder":"用于推送告警消息时，告警消息的标题显示"},model:{value:(_vm.value.summary),callback:function ($$v) {_vm.$set(_vm.value, "summary", $$v);},expression:"value.summary"}})],2),_vm._v(" "),_c('FormItem',{attrs:{"label":"告警详情","prop":"description"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("告警详情")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"用于推送告警消息时，告警消息的详情显示","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Input',{attrs:{"wrap":"hard","type":"textarea","autosize":{ minRows: 5, maxRows: 8 },"placeholder":"用于推送告警消息时，告警消息的详情显示"},model:{value:(_vm.value.description),callback:function ($$v) {_vm.$set(_vm.value, "description", $$v);},expression:"value.description"}})],2)]:_vm._e(),_vm._v(" "),(_vm.value && _vm.value.notifyTypes.indexOf('restore') > -1)?[_c('FormItem',{attrs:{"prop":"restoreSummary"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("恢复概述")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"用于推送恢复消息时，恢复消息的标题显示","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Input',{attrs:{"placeholder":"用于推送恢复消息时，恢复消息的标题显示"},model:{value:(_vm.value.restoreSummary),callback:function ($$v) {_vm.$set(_vm.value, "restoreSummary", $$v);},expression:"value.restoreSummary"}})],2),_vm._v(" "),_c('FormItem',{attrs:{"prop":"restoreDescription"}},[_c('template',{slot:"label"},[_c('span',[_vm._v("恢复详情")]),_vm._v(" "),_c('Tooltip',{attrs:{"max-width":"600","content":"用于推送恢复消息时，恢复消息的详情显示","placement":"top-start"}},[_c('Icon',{staticClass:"form-item-tips-icon",attrs:{"type":"ios-information-circle-outline"}})],1)],1),_vm._v(" "),_c('Input',{attrs:{"type":"textarea","autosize":{ minRows: 5, maxRows: 8 },"placeholder":"用于推送恢复消息时，恢复消息的详情显示"},model:{value:(_vm.value.restoreDescription),callback:function ($$v) {_vm.$set(_vm.value, "restoreDescription", $$v);},expression:"value.restoreDescription"}})],2)]:_vm._e(),_vm._v(" "),_c('condition',_vm._b({ref:"conditionRef",attrs:{"disabled":_vm.disabled,"value":_vm.value}},'condition',_vm.$attrs,false)),_vm._v(" "),(_vm.showActions && _vm.type === 'default')?_c('actions',_vm._b({attrs:{"value":_vm.value}},'actions',_vm.$attrs,false)):_vm._e()],2)],1):_vm._e()};
var __vue_staticRenderFns__$f = [];

  /* style */
  const __vue_inject_styles__$f = function (inject) {
    if (!inject) return
    inject("data-v-8b47e438_0", { source: ".fuse-monitoring-rule .form-item-tips{margin-left:4px;color:#2d8cf0}.fuse-monitoring-rule .form-item-tips i{font-size:15px}.fuse-monitoring-rule .form-item-tips-icon{margin-left:4px;color:#2d8cf0;font-size:15px}.fuse-monitoring-rule /deep/ .ivu-tooltip-rel{display:unset}.fuse-monitoring-rule .divider-btn{cursor:pointer}.fuse-monitoring-rule .divider-btn i{padding:4px}.fuse-monitoring-rule .ivu-input-number{width:80px!important}.fuse-monitoring-rule .section-title{color:#515a6e;font-size:14px;font-weight:700}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$f = undefined;
  /* module identifier */
  const __vue_module_identifier__$f = undefined;
  /* functional template */
  const __vue_is_functional_template__$f = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$f = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$f, staticRenderFns: __vue_staticRenderFns__$f },
    __vue_inject_styles__$f,
    __vue_script__$f,
    __vue_scope_id__$f,
    __vue_is_functional_template__$f,
    __vue_module_identifier__$f,
    false,
    createInjector,
    undefined,
    undefined
  );

//
/**
 * iview Button的重写，支持表单model变化后启用，防重复点击
 */
var script$e = {
  props: {
    /**
     * iview Button type
     */
    type: {
      validator(value) {
        return oneOf(value, ['default', 'primary', 'dashed', 'text', 'info', 'success', 'warning', 'error']);
      },
      default: 'default'
    },
    /**
     * iview Button shape
     */
    shape: {
      validator(value) {
        return oneOf(value, ['circle', 'circle-outline']);
      }
    },
    /**
     * iview Button size
     */
    size: {
      validator(value) {
        return oneOf(value, ['small', 'large', 'default']);
      },
      default() {
        return !this.$IVIEW || this.$IVIEW.size === '' ? 'default' : this.$IVIEW.size;
      }
    },
    /**
     * 是否加载中
     */
    loading: Boolean,
    /**
     * 是否禁用按钮，默认禁用
     */
    disabled: {
      type: Boolean,
      default: true
    },
    /**
     * iview Button htmlType
     */
    htmlType: {
      default: 'button',
      validator(value) {
        return oneOf(value, ['button', 'submit', 'reset']);
      }
    },
    /**
     * iview Button icon
     */
    icon: {
      type: String,
      default: ''
    },
    /**
     * iview Button customIcon
     */
    customIcon: {
      type: String,
      default: ''
    },
    /**
     * iview Button long
     */
    long: {
      type: Boolean,
      default: false
    },
    /**
     * iview Button ghost
     */
    ghost: {
      type: Boolean,
      default: false
    },
    /**
     * iview Button to
     */
    to: {
      type: [Object, String]
    },
    /**
     * iview Button replace
     */
    replace: {
      type: Boolean,
      default: false
    },
    /**
     * iview Button target
     */
    target: {
      type: String,
      validator(value) {
        return oneOf(value, ['_blank', '_self', '_parent', '_top']);
      },
      default: '_self'
    },
    /**
     * iview Button append
     */
    append: {
      type: Boolean,
      required: false,
      default: false
    },
    /**
     * 指定被监听的model数据，如果model数据变了按钮才可以点击
     */
    model: {
      type: Object
    }
  },
  data() {
    return {
      innerDisabled: this.disabled
    };
  },
  watch: {
    disabled: function () {
      this.innerDisabled = this.disabled;
    },
    model: {
      handler: function () {
        this.innerDisabled = false;
      },
      deep: true
    }
  },
  methods: {
    handleOnClick(event) {
      if (!this.innerDisabled) {
        //this.innerDisabled = true;
        this.$emit('click', event);
      }
    }
  }
};

/* script */
const __vue_script__$e = script$e;

/* template */
var __vue_render__$e = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Button',{attrs:{"shape":_vm.shape,"size":_vm.size,"loading":_vm.loading,"disabled":_vm.innerDisabled,"html-type":_vm.htmlType,"icon":_vm.icon,"custom-icon":_vm.customIcon,"long":_vm.long,"ghost":_vm.ghost,"type":_vm.type,"to":_vm.to,"replace":_vm.replace,"target":_vm.target,"append":_vm.append},on:{"click":_vm.handleOnClick}},[_vm._t("default")],2)};
var __vue_staticRenderFns__$e = [];

  /* style */
  const __vue_inject_styles__$e = undefined;
  /* scoped */
  const __vue_scope_id__$e = undefined;
  /* module identifier */
  const __vue_module_identifier__$e = undefined;
  /* functional template */
  const __vue_is_functional_template__$e = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$e = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$e, staticRenderFns: __vue_staticRenderFns__$e },
    __vue_inject_styles__$e,
    __vue_script__$e,
    __vue_scope_id__$e,
    __vue_is_functional_template__$e,
    __vue_module_identifier__$e,
    false,
    undefined,
    undefined,
    undefined
  );

//
var script$d = {
  data() {
    return {
      prefixCls: 'back-to-index'
    };
  },
  computed: {
    ...mapState('admin/menu', ['activePath', 'headerName']),
    ...mapState('admin/layout', ['menuCollapse']),
    ...mapGetters$1('fuse/app', {
      app: 'current'
    }),
    ...mapGetters$1('fuse/project', {
      project: 'current',
      projectRouterName: 'returnRouter'
    }),
    isShow() {
      //头部为app展示，为admin不展示
      let headers = ['app', 'project'];
      return headers.includes(this.headerName);
    },
    data() {
      return this.headerName == 'app' ? this.app : this.project;
    }
  },
  methods: {
    ...mapMutations$1('fuse/app', ['setApp']),
    ...mapMutations$1('fuse/project', ['setProject']),
    back() {
      let returnRouter = { path: '/apps/index' };
      returnRouter = Object.assign(returnRouter, { query: { _clearSid: 1, _mid: '_blank' } });
      this.$router.replace(returnRouter);
    }
  }
};

/* script */
const __vue_script__$d = script$d;

/* template */
var __vue_render__$d = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return (_vm.isShow)?_c('div',{staticClass:"back-to-index",class:{ center: _vm.menuCollapse },on:{"click":_vm.back}},[_c('Icon',{directives:[{name:"show",rawName:"v-show",value:(!_vm.menuCollapse),expression:"!menuCollapse"}],class:_vm.prefixCls + '-left',attrs:{"type":_vm.headerName == 'app' ? 'ios-apps' : 'ios-cube',"size":"21"}}),_vm._v(" "),_c('div',{directives:[{name:"show",rawName:"v-show",value:(!_vm.menuCollapse),expression:"!menuCollapse"}],class:_vm.prefixCls + '-center'},[_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"title"},[_vm._v(_vm._s(_vm.data && _vm.data.title))]),_vm._v(" "),_c('div',{staticClass:"tip"},[_vm._v(_vm._s(_vm.headerName == 'app' ? '应用' : '业务系统')+_vm._s(_vm.headerName))])]),_vm._v(" "),_c('Icon',{staticClass:"back-right",attrs:{"type":"ios-arrow-back","size":"23","color":"white"}})],1):_vm._e()};
var __vue_staticRenderFns__$d = [];

  /* style */
  const __vue_inject_styles__$d = undefined;
  /* scoped */
  const __vue_scope_id__$d = undefined;
  /* module identifier */
  const __vue_module_identifier__$d = undefined;
  /* functional template */
  const __vue_is_functional_template__$d = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$d = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$d, staticRenderFns: __vue_staticRenderFns__$d },
    __vue_inject_styles__$d,
    __vue_script__$d,
    __vue_scope_id__$d,
    __vue_is_functional_template__$d,
    __vue_module_identifier__$d,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

/**
 * 扩展iview result组件，type属性支持: success error info（扩展了info），使用方法和iview result一致
 */
var script$c = {
  name: 'aic-result',
  props: {
    /**
     * 支持: success error info
     */
    type: {
      type: String,
      default: 'success'
    }
  },
  data() {
    return {
      slots: Object.keys(this.$slots) || ['title', 'desc', 'extra', 'actions'] //和iview的Result组件保持一致
    };
  }
};

/* script */
const __vue_script__$c = script$c;

/* template */
var __vue_render__$c = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[(_vm.type != 'info')?_c('Result',_vm._b({attrs:{"type":_vm.type}},'Result',_vm.$attrs,false),[_vm._l((_vm.slots),function(item){return _c('template',{slot:item},[_vm._t(item)],2)})],2):_c('Result',_vm._b({staticClass:"result-blank-tips",attrs:{"type":"success"}},'Result',_vm.$attrs,false),[_vm._l((_vm.slots),function(item){return _c('template',{slot:item},[_vm._t(item)],2)})],2)],1)};
var __vue_staticRenderFns__$c = [];

  /* style */
  const __vue_inject_styles__$c = undefined;
  /* scoped */
  const __vue_scope_id__$c = undefined;
  /* module identifier */
  const __vue_module_identifier__$c = undefined;
  /* functional template */
  const __vue_is_functional_template__$c = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$c = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$c, staticRenderFns: __vue_staticRenderFns__$c },
    __vue_inject_styles__$c,
    __vue_script__$c,
    __vue_scope_id__$c,
    __vue_is_functional_template__$c,
    __vue_module_identifier__$c,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//

/**
 * 两列等高布局 一边定宽 另一边自适应
 */
var script$b = {
  props: {
    /**
     * fixedPart 接收left,right
     */
    fixedPart: {
      type: String,
      default: 'left',
      validator: function (value) {
        return ['left', 'right'].some((item) => item == value);
      }
    },
    /**
     * fixedPart宽度
     */
    fixedPartWidth: {
      type: Number,
      default: 200
    },
    /**
     * 内容溢出是否需要滚动条
     */
    showScroll: {
      type: Boolean,
      default: false
    }
  },
  computed: {
    leftStyle() {
      let style = {};
      if (this.fixedPart == 'left') {
        style.width = this.fixedPartWidth + 'px';
        style.minWidth = this.fixedPartWidth + 'px';
      } else {
        style.flex = 1;
        if (this.showScroll) {
          style.overflow = 'auto';
        }
      }
      return style;
    },
    rightStyle() {
      let style = {};
      if (this.fixedPart == 'right') {
        style.width = this.fixedPartWidth + 'px';
        style.minWidth = this.fixedPartWidth + 'px';
      } else {
        style.flex = 1;
        if (this.showScroll) {
          style.overflow = 'auto';
        }
      }
      return style;
    }
  }
};

/* script */
const __vue_script__$b = script$b;

/* template */
var __vue_render__$b = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"double-columns-view"},[_c('div',{staticClass:"double-columns-view-left",style:(_vm.leftStyle)},[_vm._t("left")],2),_vm._v(" "),_c('div',{staticClass:"double-columns-view-right",style:(_vm.rightStyle)},[_vm._t("right")],2)])};
var __vue_staticRenderFns__$b = [];

  /* style */
  const __vue_inject_styles__$b = undefined;
  /* scoped */
  const __vue_scope_id__$b = undefined;
  /* module identifier */
  const __vue_module_identifier__$b = undefined;
  /* functional template */
  const __vue_is_functional_template__$b = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$b = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$b, staticRenderFns: __vue_staticRenderFns__$b },
    __vue_inject_styles__$b,
    __vue_script__$b,
    __vue_scope_id__$b,
    __vue_is_functional_template__$b,
    __vue_module_identifier__$b,
    false,
    undefined,
    undefined,
    undefined
  );

//

var script$a = {
  props: {
    value: {
      type: Object,
      default: () => ({})
    }
  },
  provide() {
    return {
      currentMonitoringType: this.currentMonitoringType,
      meta: this.meta,
      monitoringType: this.monitoringType,
      showActions: this.showActions,
      type: this.type,
      metrics: this.metrics,
      metricTableColumns: this.metricTableColumns
    };
  },
  mixins: [mixins$2],
  components: { condition: __vue_component__$j },
  data() {
    return {};
  },

  computed: {
    groupByDesc() {
      if (this.value.groupBy) {
        const reslut = this.meta.groupByOptions.find((item) => item.value === this.value.groupBy);
        return reslut ? reslut.title : '无';
      }
      return '无';
    },
    alertLevelDesc() {
      if (this.value.level) {
        const reslut = this.meta.alertLevels.find((item) => item.value === this.value.level);
        return reslut ? reslut.title : '无';
      }
      return '无';
    },
    scheduleIntervalUnitDesc() {
      if (this.value.scheduleIntervalUnit) {
        const reslut = this.meta.checkIntervalUnits.find((item) => item.value === this.value.scheduleIntervalUnit);
        return reslut ? reslut.title : '无';
      }
      return '无';
    }
  },
  mounted() {
    this.initNotifyTypes();
  },
  methods: {
    initNotifyTypes() {
      this.$set(this.value, 'notifyTypes', []);
      if (!_.isEmpty(this.value.summary)) {
        this.value.notifyTypes.push('alert');
      }
      if (!_.isEmpty(this.value.restoreSummary)) {
        this.value.notifyTypes.push('restore');
      } else {
        this.value.notifyTypes.push('alert');
      }
    }
  }
};

/* script */
const __vue_script__$a = script$a;

/* template */
var __vue_render__$a = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"f-alert-rule-info"},[(_vm.meta && _vm.monitoringType)?_c('Form',{attrs:{"rules":_vm.formRules,"model":_vm.value,"label-colon":"","label-width":100}},[_c('h4',[_vm._v("告警规则")]),_vm._v(" "),_c('Divider',{staticStyle:{"margin":"16px 0px"}}),_vm._v(" "),_c('FormItem',{attrs:{"label":"告警名称","prop":"name"}},[_c('span',{staticClass:"field-value"},[_vm._v(_vm._s(_vm.value.name))])]),_vm._v(" "),_c('Row',{attrs:{"type":"flex"}},[_c('Col',[_c('FormItem',{attrs:{"prop":"groupBy","label":"监控对象"}},[_c('span',{staticClass:"field-value"},[_vm._v(_vm._s(_vm.groupByDesc))])])],1),_vm._v(" "),_c('Col',{staticClass:"ml-md"},[_c('FormItem',{attrs:{"label":"告警级别","prop":"level"}},[_c('span',{staticClass:"field-value"},[_vm._v(_vm._s(_vm.alertLevelDesc))])])],1)],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"检查时段"}},[_c('span',{staticClass:"field-value"},[_vm._v(" "+_vm._s(_vm.value.timeStart ? _vm.value.timeStart + '-' + _vm.value.timeEnd : '全天'))])]),_vm._v(" "),_c('FormItem',{attrs:{"prop":"scheduleInterval","label":"检查周期"}},[_c('span',{staticClass:"field-value"},[_vm._v(_vm._s(_vm.value.scheduleInterval + _vm.scheduleIntervalUnitDesc))])]),_vm._v(" "),_c('FormItem',{attrs:{"label":"是否启用","prop":"enabled"}},[_c('span',{staticClass:"field-value"},[_vm._v(_vm._s(_vm.value.enabled ? '是' : '否'))])]),_vm._v(" "),(_vm.value && _vm.value.notifyTypes && _vm.value.notifyTypes.indexOf('alert') > -1)?[_c('FormItem',{attrs:{"label":"告警概述","prop":"summary"}},[_c('span',{staticClass:"field-value"},[_vm._v(" "+_vm._s(_vm.value.summary))])]),_vm._v(" "),_c('FormItem',{attrs:{"label":"告警详情","prop":"description"}},[_c('span',{staticClass:"field-value"},[_vm._v(" "+_vm._s(_vm.value.description))])])]:_vm._e(),_vm._v(" "),(_vm.value && _vm.value.notifyTypes && _vm.value.notifyTypes.indexOf('restore') > -1)?[_c('FormItem',{attrs:{"prop":"restoreSummary","label":"恢复概述"}},[_c('span',{staticClass:"field-value"},[_vm._v(" "+_vm._s(_vm.value.restoreSummary))])]),_vm._v(" "),_c('FormItem',{attrs:{"prop":"restoreDescription","label":"恢复详情"}},[_c('span',{staticClass:"field-value"},[_vm._v(" "+_vm._s(_vm.value.restoreDescription))])])]:_vm._e(),_vm._v(" "),_c('condition',_vm._b({attrs:{"disabled":true,"value":_vm.value}},'condition',_vm.$attrs,false))],2):_vm._e()],1)};
var __vue_staticRenderFns__$a = [];

  /* style */
  const __vue_inject_styles__$a = function (inject) {
    if (!inject) return
    inject("data-v-eb96ffd2_0", { source: ".f-alert-rule-info[data-v-eb96ffd2] .ivu-form .ivu-form-item-label{color:#80848f}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$a = "data-v-eb96ffd2";
  /* module identifier */
  const __vue_module_identifier__$a = undefined;
  /* functional template */
  const __vue_is_functional_template__$a = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$a = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$a, staticRenderFns: __vue_staticRenderFns__$a },
    __vue_inject_styles__$a,
    __vue_script__$a,
    __vue_scope_id__$a,
    __vue_is_functional_template__$a,
    __vue_module_identifier__$a,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$9 = {
  props: {
    id: {
      type: String,
      required: true
    },
    userInfo: {
      type: Object,
      default: () => {
        return {};
      }
    },
    showDelete: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      innerUserInfo: null,
      loading: false,
      loadError: false,
      userTypeMap: {
        std: '企业用户',
        virtual: '虚拟账号',
        external: '外部用户'
      },
      notFound: false
    };
  },
  methods: {
    getAccount() {
      return this.innerUserInfo.tenantCode
        ? this.innerUserInfo.username + '@' + this.innerUserInfo.tenantCode
        : this.innerUserInfo.username;
    },
    async onPopperShow() {
      if (!this.id) {
        this.$Message.error('未提供用户ID');
        return;
      }
      //拉取用户信息
      if (this.innerUserInfo) return;
      this.loading = true;
      try {
        const { data } = await iamUserService.get(this.id);
        this.innerUserInfo = data;
        if (!this.innerUserInfo) {
          this.notFound = true;
          return;
        }
        //如果状态不一致 更新状态
        if (this.userInfo) {
          if (
            typeof this.userInfo.isDeleted === 'boolean' &&
            this.userInfo.isDeleted !== this.innerUserInfo.isDeleted
          ) {
            aicService.syncUser(this.innerUserInfo.id);
          }
        }
      } catch (error) {
        this.$Message.error('用户信息获取出错');
        this.loadError = true;
      } finally {
        this.loading = false;
      }
    }
  }
};

/* script */
const __vue_script__$9 = script$9;

/* template */
var __vue_render__$9 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Tooltip',{attrs:{"delay":300,"transfer":"","max-width":"450","theme":"light","placement":"top-start"},on:{"on-popper-show":_vm.onPopperShow}},[_vm._t("default"),_vm._v(" "),_c('div',{attrs:{"slot":"content"},slot:"content"},[(_vm.loadError)?_c('div',{staticClass:"p-md"},[_vm._v("获取用户信息出错")]):_vm._e(),_vm._v(" "),(_vm.notFound)?_c('div',{staticClass:"p-sm"},[_vm._v("用户不存在")]):_vm._e(),_vm._v(" "),(_vm.loading)?_c('Spin',{attrs:{"fix":""}}):_vm._e(),_vm._v(" "),(!_vm.loading && _vm.innerUserInfo)?_c('div',{staticClass:"p-sm userInfo"},[_c('div',[_vm._v("用户名称："+_vm._s(_vm.innerUserInfo.name))]),_vm._v(" "),_c('div',[_vm._v("用户类型："+_vm._s(_vm.userTypeMap[_vm.innerUserInfo.userType] || '其他'))]),_vm._v(" "),(_vm.innerUserInfo.username)?_c('div',[_vm._v("登录账号："+_vm._s(_vm.getAccount()))]):_vm._e(),_vm._v(" "),_c('div',[_vm._v("电话号码："+_vm._s(_vm.innerUserInfo.mobile))]),_vm._v(" "),_c('div',[_vm._v("邮箱："+_vm._s(_vm.innerUserInfo.email))])]):_vm._e()],1),_vm._v(" "),(_vm.showDelete && _vm.innerUserInfo && _vm.innerUserInfo.isDeleted)?_c('Tag',[_vm._v("删")]):_vm._e()],2)};
var __vue_staticRenderFns__$9 = [];

  /* style */
  const __vue_inject_styles__$9 = function (inject) {
    if (!inject) return
    inject("data-v-3fde62aa_0", { source: ".userInfo div[data-v-3fde62aa]{margin-bottom:4px}.userInfo div[data-v-3fde62aa]:last-child{margin-bottom:0}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$9 = "data-v-3fde62aa";
  /* module identifier */
  const __vue_module_identifier__$9 = undefined;
  /* functional template */
  const __vue_is_functional_template__$9 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$9 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$9, staticRenderFns: __vue_staticRenderFns__$9 },
    __vue_inject_styles__$9,
    __vue_script__$9,
    __vue_scope_id__$9,
    __vue_is_functional_template__$9,
    __vue_module_identifier__$9,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//

var script$8 = {
  props: {
    title: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      bgColor: this.createRandomColor()
    };
  },
  methods: {
    createRandomColor() {
      let colorList = ['#f56a00', '#7265e6', '#ffbf00', '#00a2ae'];
      return colorList[Math.floor(Math.random() * colorList.length)];
    }
  }
};

/* script */
const __vue_script__$8 = script$8;

/* template */
var __vue_render__$8 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"icon",style:({ backgroundColor: _vm.bgColor })},[_vm._v("\n  "+_vm._s(_vm.title)+"\n")])};
var __vue_staticRenderFns__$8 = [];

  /* style */
  const __vue_inject_styles__$8 = function (inject) {
    if (!inject) return
    inject("data-v-bf0185f4_0", { source: ".icon[data-v-bf0185f4]{width:100px;height:100px;border-radius:50%;line-height:100px;margin-right:20px;text-align:center;color:#fff;font-size:45px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$8 = "data-v-bf0185f4";
  /* module identifier */
  const __vue_module_identifier__$8 = undefined;
  /* functional template */
  const __vue_is_functional_template__$8 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$8 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$8, staticRenderFns: __vue_staticRenderFns__$8 },
    __vue_inject_styles__$8,
    __vue_script__$8,
    __vue_scope_id__$8,
    __vue_is_functional_template__$8,
    __vue_module_identifier__$8,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$7 = {
  props: {
    app: {
      type: Object,
      default: () => {
        return {};
      }
    }
  },
  data() {
    return {
      avatarList: [],
      showPassword: true
    };
  },
  computed: {
    serviceCount() {
      //审批中状态码为0;已开通状态码为1
      let approve = 0,
        success = 0;
      this.app.agreements.forEach((item) => {
        if (item.status == 0) {
          approve++;
        } else if (item.status == 1) {
          success++;
        }
      });
      return approve + '/' + success;
    }
  },
  methods: {
    createRandomColor() {
      let colorList = ['#f56a00', '#7265e6', '#ffbf00', '#00a2ae'];
      return colorList[Math.floor(Math.random() * colorList.length)];
    },
    togglePassword() {
      this.showPassword = !this.showPassword;
    },
    getCreatedBy(project) {
      if (project && project.__meta__ && project.__meta__.fields && project.__meta__.fields.createdBy) {
        return project.__meta__.fields.createdBy.title + ' ';
      }
      return '无';
    },
    toWebsite() {
      if (this.app.homeUrl) {
        this.$Modal.confirm({
          title: '提示',
          content: `<p>即将访问：<strong style="word-break: break-all">${this.app.homeUrl}</strong>，点击确定按钮即可访问</p>`,
          onOk: () => {
            window.open(this.app.homeUrl);
          }
        });
      } else {
        this.$Message.error('该应用暂未配置访问地址');
      }
    },
    handleCopy(value) {
      this.$Copy({
        text: value
      });
    }
  }
};

/* script */
const __vue_script__$7 = script$7;

/* template */
var __vue_render__$7 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{attrs:{"type":"md-list-box"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("应用基本信息")])],1),_vm._v(" "),_c('Row',{attrs:{"type":"flex","gutter":24}},[_c('Col',{staticClass:"ivu-mb",attrs:{"span":"12","xs":24,"sm":12,"class-name":"base-info-border"}},[_c('div',{staticClass:"base-info"},[_c('div',{staticClass:"base-info-left"},[_c('div',{staticClass:"base-info-left-top"},[(_vm.app.icon)?_c('f-image',{staticClass:"mr-md",attrs:{"width":"100px","height":"100px","item":_vm.app.icon}}):_c('f-default-icon',{attrs:{"title":_vm.app.title.substr(0, 1)}}),_vm._v(" "),_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],staticClass:"base-info-left-top-msg"},[_c('h2',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}]},[_vm._v("\n                "+_vm._s(_vm.app.title)+"\n                "),_c('Icon',{staticClass:"ml-sm",staticStyle:{"cursor":"pointer"},attrs:{"color":"#5cadff","type":"md-home","size":22},on:{"click":_vm.toWebsite}})],1),_vm._v(" "),(_vm.app.creator)?_c('f-user-tool-tip',{attrs:{"id":_vm.app.creator.id,"user-info":_vm.app.creator}},[_vm._v("\n                创建人："+_vm._s(_vm.app.creator.name)+"\n                "),(_vm.app.creator.isDeleted)?_c('Tag',[_vm._v("删")]):_vm._e()],1):_vm._e(),_vm._v(" "),_c('span',[_vm._v("创建于："+_vm._s(_vm.$Date(_vm.app.createdAt).format('YYYY-MM-DD HH:mm:ss')))])],1)],1),_vm._v(" "),_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(3),expression:"3"}],staticClass:"base-info-left-bottom",attrs:{"title":_vm.app.summary || _vm.app.description || '暂无'}},[_vm._v("\n            "+_vm._s(_vm.app.summary || _vm.app.description || '暂无')+"\n          ")])])])]),_vm._v(" "),_c('Col',{staticClass:"ivu-mb",attrs:{"span":"12","xs":24,"sm":12}},[_c('div',{staticClass:"base-info"},[_c('div',{staticClass:"base-info-right"},[_c('div',{staticClass:"base-info-right-static"},[_vm._v("成员")]),_vm._v(" "),(_vm.app._admins.length)?_vm._l((_vm.app._admins),function(item,index){return _c('div',{key:index,staticClass:"base-info-right-member"},[_c('div',{staticClass:"member"},[(item.member)?_c('Avatar',{style:({ background: item.bgColor }),attrs:{"size":"small"}},[_vm._v(_vm._s(item.member.name.substr(item.member.name.length - 1, 1)))]):_vm._e(),_vm._v(" "),(item.member)?_c('span',{staticClass:"member-name"},[_vm._v("\n                  "+_vm._s(item.member.name)+"\n                ")]):_vm._e()],1),_vm._v(" "),(index == _vm.app._admins.length - 1 && _vm.app._developers.length)?_c('div',{staticClass:"member"},[_c('Avatar',{style:({ background: _vm.createRandomColor() }),attrs:{"size":"small"}},[_vm._v(_vm._s(_vm.app._developers.length))]),_vm._v(" "),_c('span',{staticClass:"member-name"},[_vm._v(" 其他成员 ")])],1):_vm._e()])}):[_c('div',{staticClass:"m-sm"},[_vm._v("暂无成员")])],_vm._v(" "),_c('div',{staticClass:"base-info-right-static"},[_vm._v("默认账号")]),_vm._v(" "),(_vm.app.clients.length)?_c('div',{staticClass:"account"},[_c('Form',{attrs:{"label-position":"left","label-width":90}},[_c('FormItem',{attrs:{"label":"应用账号："}},[_vm._v("\n                "+_vm._s(_vm.app.clients[0].id)+"\n                "),_c('Icon',{staticClass:"ml-sm",attrs:{"type":"ios-copy","size":"17","color":"#2d8cf0"},on:{"click":function($event){return _vm.handleCopy(_vm.app.clients[0].id)}}})],1),_vm._v(" "),_c('FormItem',{attrs:{"label":"应用密钥："}},[_vm._v("\n                "+_vm._s(_vm.showPassword ? _vm.app.clients[0].secret : ''.padStart(_vm.app.clients[0].secret.length, '●'))+"\n                "),_c('Icon',{staticClass:"ml-sm",attrs:{"size":"16","type":_vm.showPassword ? 'md-eye' : 'md-eye-off'},on:{"click":_vm.togglePassword}}),_vm._v(" "),_c('Icon',{staticClass:"ml-sm",attrs:{"type":"ios-copy","size":"17","color":"#2d8cf0"},on:{"click":function($event){return _vm.handleCopy(_vm.app.clients[0].secret)}}})],1)],1)],1):_c('div',{staticClass:"m-sm"},[_vm._v("\n            暂无账号信息，点击 "),_c('router-link',{attrs:{"to":{ name: 'appAccountManagement', params: { appId: _vm.app.id }, query: { appId: _vm.app.id, _mid: 1 } }}},[_vm._v("新增")])],1)],2)])])],1)],1)};
var __vue_staticRenderFns__$7 = [];

  /* style */
  const __vue_inject_styles__$7 = function (inject) {
    if (!inject) return
    inject("data-v-dd838a02_0", { source: ".title[data-v-dd838a02]{margin-left:10px}.ivu-avatar-icon[data-v-dd838a02]{line-height:28px!important}.ivu-icon-ios-copy[data-v-dd838a02]{vertical-align:middle;cursor:pointer}.base-info[data-v-dd838a02]{display:flex}.base-info-left[data-v-dd838a02]{display:flex;flex-direction:column;flex:1;padding:10px}.base-info-left-top[data-v-dd838a02]{display:flex;margin-bottom:30px}.base-info-left-top img[data-v-dd838a02]{width:120px;height:120px;border-radius:10px;margin-right:20px}.base-info-left-top .base-info-icon[data-v-dd838a02]{width:100px;height:100px;border-radius:50%;line-height:100px;margin-right:20px;text-align:center;color:#fff;font-size:45px}.base-info-left-top .ivu-icon[data-v-dd838a02]{font-size:100px;margin-right:20px}.base-info-left-top-msg[data-v-dd838a02]{display:flex;flex-direction:column;justify-content:space-between;height:100%;flex:1}.base-info-left-bottom[data-v-dd838a02]{margin-left:5px}.base-info-right[data-v-dd838a02]{flex:1;padding:10px}.base-info-right-static[data-v-dd838a02]{line-height:2;color:#000}.base-info-right-static a[data-v-dd838a02]{color:#000}.base-info-right-static a[data-v-dd838a02]:hover{color:#07a}.base-info-right .member[data-v-dd838a02]{display:flex;align-items:center}.base-info-right-member[data-v-dd838a02]{display:inline-block;margin:8px 8px 0 0}.base-info-right-member .member-name[data-v-dd838a02]{margin:0 7px;font-size:15px}.account[data-v-dd838a02] .ivu-tabs-content{margin-left:10px}.base-info-border[data-v-dd838a02]{border-right:1px solid #dcdee2}.ivu-form-item[data-v-dd838a02]{margin-bottom:0}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$7 = "data-v-dd838a02";
  /* module identifier */
  const __vue_module_identifier__$7 = undefined;
  /* functional template */
  const __vue_is_functional_template__$7 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$7 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$7, staticRenderFns: __vue_staticRenderFns__$7 },
    __vue_inject_styles__$7,
    __vue_script__$7,
    __vue_scope_id__$7,
    __vue_is_functional_template__$7,
    __vue_module_identifier__$7,
    false,
    createInjector,
    undefined,
    undefined
  );

var status = [
  { status: 0, color: 'primary', title: '审批中' },
  { status: 1, color: 'success', title: '已开通' },
  { status: 2, color: 'error', title: '已拒绝' },
  { status: 3, color: 'primary', title: '开通中' },
  { status: 4, color: 'warning', title: '开通失败' }
];

//
var script$6 = {
  props: {
    app: {
      type: Object,
      default: () => {
        return [];
      }
    }
  },
  data() {
    return {
      recommend: [],
      //由web提供 文件放在public/images下
      serviceDefaultIcon: './images/service-default.png',
      area: this.$route.query.area || 'mine' // mine: 应用列表 tenant:租户应用 apply：订阅应用
    };
  },
  async mounted() {
    let { data } = await appService$2.servicePublished({ orderby: 's.rate desc', limit: 5 });
    this.recommend = data;
  },
  methods: {
    del(item) {
      this.$Modal.confirm({
        title: '提示',
        content: '<p>是否删除？</p>',
        onOk: async () => {
          await aicService.abortAuth(item.id);
          this.$Message.success('删除成功');
          this.app.agreements = this.app.agreements.filter((innerItem) => innerItem.id !== item.id);
          this.$forceUpdate();
        }
      });
    },
    apply(item) {
      this.$router.push({ name: `fuseAppProductServiceApplyApp`, params: { serviceId: item.serviceId } });
    },
    getTagMsg(item) {
      for (let i = 0; i < status.length; i++) {
        if (item.authStatus == status[i].status) {
          return status[i];
        }
      }
      return { color: 'default', title: '默认' };
    },
    toDetail(item) {
      if (this.area !== 'mine') return;
      this.$router.push({ name: 'fuseAppProductServiceShow', params: { serviceId: item.serviceId } });
    },
    toService(item) {
      MicroAppHelper.routeToServiceForApp(item.service);
    },
    showMore() {
      this.$router.push({ name: 'fuseAppProductService' });
    }
  }
};

/* script */
const __vue_script__$6 = script$6;

/* template */
var __vue_render__$6 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('f-double-columns-view',{staticClass:"main",attrs:{"fixed-part":"right","fixed-part-width":400}},[_c('template',{slot:"left"},[_c('Card',[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{attrs:{"type":"ios-bookmark"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("已开通服务")])],1),_vm._v(" "),(_vm.area === 'mine')?_c('a',{attrs:{"slot":"extra"},on:{"click":_vm.showMore},slot:"extra"},[_vm._v(" 申请开通 ")]):_vm._e(),_vm._v(" "),_c('div',{staticClass:"body"},[(_vm.app.agreements && _vm.app.agreements.length)?_c('Row',{attrs:{"type":"flex","gutter":20}},_vm._l((_vm.app.agreements),function(agreement,index){return _c('Col',{key:index,attrs:{"xl":6,"lg":6,"md":8,"sm":8,"xs":12}},[_c('Card',{directives:[{name:"height",rawName:"v-height",value:(170),expression:"170"}],staticClass:"list-services-item p-sm",nativeOn:{"click":function($event){return _vm.toDetail(agreement)}}},[_c('Tag',{staticClass:"tag",attrs:{"color":_vm.getTagMsg(agreement).color}},[_vm._v(_vm._s(_vm.getTagMsg(agreement).title))]),_vm._v(" "),(agreement.service.icon)?_c('f-image',{attrs:{"width":"64px","height":"64px","item":agreement.service.icon}}):_c('img',{attrs:{"src":_vm.serviceDefaultIcon,"alt":""}}),_vm._v(" "),_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],attrs:{"title":agreement.service.title}},[_vm._v(_vm._s(agreement.service.title))]),_vm._v(" "),(_vm.area === 'mine')?[(agreement.authStatus === 1 && agreement.service.appInteUrl)?_c('Button',{staticClass:"mt-sm",attrs:{"size":"small"},on:{"click":function($event){$event.stopPropagation();return _vm.toService(agreement)}}},[_vm._v("进入服务")]):_vm._e(),_vm._v(" "),(agreement.authStatus === 4)?_c('div',{staticClass:"mt-sm",staticStyle:{"text-align":"center"}},[_c('Button',{staticClass:"mr-sm",attrs:{"size":"small"},on:{"click":function($event){$event.stopPropagation();return _vm.apply(agreement)}}},[_vm._v("重新开通")]),_vm._v(" "),_c('Button',{attrs:{"size":"small","type":"text"},on:{"click":function($event){$event.stopPropagation();return _vm.del(agreement)}}},[_vm._v("删除")])],1):_vm._e()]:_vm._e()],2)],1)}),1):_c('aic-result',{staticStyle:{"margin-top":"30px"},attrs:{"type":"info","title":"尚未开通任何服务"}},[(_vm.area === 'mine')?_c('Button',{attrs:{"slot":"desc","type":"primary"},on:{"click":_vm.showMore},slot:"desc"},[_vm._v("立即开通")]):_vm._e()],1)],1)])],1),_vm._v(" "),_c('template',{slot:"right"},[_c('Card',{staticClass:"recommend-card"},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{attrs:{"type":"ios-bookmark"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("热门服务推荐")])],1),_vm._v(" "),(_vm.recommend && _vm.recommend.length)?[_c('a',{attrs:{"slot":"extra"},on:{"click":_vm.showMore},slot:"extra"},[_vm._v(" 查看更多>> ")]),_vm._v(" "),_c('div',{staticClass:"body"},[_c('CellGroup',_vm._l((_vm.recommend),function(service,index){return _c('Cell',{key:service.id,attrs:{"to":{ name: 'appProductServiceApplyApp', params: { serviceId: service.id } }}},[_c('Avatar',{directives:[{name:"color",rawName:"v-color",value:(index < 3 ? '#1890ff' : '#8c8c8c'),expression:"index < 3 ? '#1890ff' : '#8c8c8c'"},{name:"bg-color",rawName:"v-bg-color",value:(index < 3 ? '#e6f7ff' : '#f5f5f5'),expression:"index < 3 ? '#e6f7ff' : '#f5f5f5'"}],staticClass:"ivu-mr-8",attrs:{"size":"small"}},[_vm._v(_vm._s(index + 1))]),_vm._v("\n              "+_vm._s(service.title)+"\n              "),_c('template',{slot:"arrow"},[_c('Rate',{attrs:{"disabled":"","value":service.rate}})],1)],2)}),1)],1)]:_vm._e(),_vm._v(" "),(_vm.recommend && _vm.recommend.length == 0)?[_c('span',{staticClass:"body",attrs:{"slot":"extra"},slot:"extra"},[_vm._v(" 暂无数据 ")]),_vm._v(" "),_c('div',{staticClass:"no-recommend"},[_vm._v("暂无推荐")])]:_vm._e()],2)],1)],2)};
var __vue_staticRenderFns__$6 = [];

  /* style */
  const __vue_inject_styles__$6 = function (inject) {
    if (!inject) return
    inject("data-v-fe0f0a56_0", { source: ".main[data-v-fe0f0a56]{margin-top:18px}.title[data-v-fe0f0a56]{margin-left:10px}.list[data-v-fe0f0a56]{display:flex}.list-services[data-v-fe0f0a56]{flex:1}.list-services-item[data-v-fe0f0a56]{cursor:pointer;padding:0;margin-bottom:20px;display:flex;align-items:center;justify-content:center}.list-services-item[data-v-fe0f0a56] .ivu-card-body{display:flex;flex-direction:column;align-items:center}.list-services-item img[data-v-fe0f0a56]{width:64px;height:64px}.list-services-item span[data-v-fe0f0a56]{margin-top:10px}.list-services-item[data-v-fe0f0a56] .tag{position:absolute;top:4px;right:4px}.body[data-v-fe0f0a56] .ivu-cell-title{color:#2d8cf0}.recommend-card[data-v-fe0f0a56]{display:flex;flex-direction:column}.recommend-card[data-v-fe0f0a56] .ivu-card-body{flex:1}.no-recommend[data-v-fe0f0a56]{display:flex;justify-content:center;align-items:center;height:100%}.ivu-rate[data-v-fe0f0a56]{font-size:15px}.ivu-rate[data-v-fe0f0a56] .ivu-rate-star{margin-right:3px}.main[data-v-fe0f0a56] .ivu-cell-title{width:200px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$6 = "data-v-fe0f0a56";
  /* module identifier */
  const __vue_module_identifier__$6 = undefined;
  /* functional template */
  const __vue_is_functional_template__$6 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$6 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$6, staticRenderFns: __vue_staticRenderFns__$6 },
    __vue_inject_styles__$6,
    __vue_script__$6,
    __vue_scope_id__$6,
    __vue_is_functional_template__$6,
    __vue_module_identifier__$6,
    false,
    createInjector,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$5 = {
  props: {
    app: {
      type: Object,
      default: () => {
        return {};
      }
    }
  },
  data() {
    return {
      avatarList: [],
      showPassword: true
    };
  },
  computed: {
    serviceCount() {
      //审批中状态码为0;已开通状态码为1
      let approve = 0,
        success = 0;
      this.app.agreements.forEach((item) => {
        if (item.status == 0) {
          approve++;
        } else if (item.status == 1) {
          success++;
        }
      });
      return approve + '/' + success;
    }
  },
  methods: {
    createRandomColor() {
      let colorList = ['#f56a00', '#7265e6', '#ffbf00', '#00a2ae'];
      return colorList[Math.floor(Math.random() * colorList.length)];
    },
    togglePassword() {
      this.showPassword = !this.showPassword;
    },
    getCreatedBy(project) {
      if (project && project.__meta__ && project.__meta__.fields && project.__meta__.fields.createdBy) {
        return project.__meta__.fields.createdBy.title + ' ';
      }
      return '无';
    },
    toWebsite() {
      if (this.app.homeUrl) {
        this.$Modal.confirm({
          title: '提示',
          content: `<p>即将访问：<strong style="word-break: break-all">${this.app.homeUrl}</strong>，点击确定按钮即可访问</p>`,
          onOk: () => {
            window.open(this.app.homeUrl);
          }
        });
      } else {
        this.$Message.error('该应用暂未配置访问地址');
      }
    },
    handleCopy(value) {
      this.$Copy({
        text: value
      });
    }
  }
};

/* script */
const __vue_script__$5 = script$5;

/* template */
var __vue_render__$5 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{staticClass:"main"},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{attrs:{"type":"md-list-box"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("应用基本信息")])],1),_vm._v(" "),_c('Row',[_c('Col',{attrs:{"flex":"120px"}},[(_vm.app.icon)?_c('f-image',{staticClass:"mr-md",attrs:{"width":"100px","height":"100px","item":_vm.app.icon}}):_c('f-default-icon',{attrs:{"title":_vm.app.title.substr(0, 1)}})],1),_vm._v(" "),_c('Col',{attrs:{"flex":"auto"}},[_c('h2',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}]},[_vm._v("\n        "+_vm._s(_vm.app.title)+"\n        "),_c('Icon',{staticClass:"ml-sm",staticStyle:{"cursor":"pointer"},attrs:{"color":"#5cadff","type":"md-home","size":22},on:{"click":_vm.toWebsite}})],1),_vm._v(" "),_c('DescriptionList',{staticClass:"mt-sm",attrs:{"col":2}},[_c('Description',{attrs:{"term":"创建人："}},[(_vm.app.creator)?_c('f-user-tool-tip',{attrs:{"id":_vm.app.creator.id,"user-info":_vm.app.creator}},[_vm._v("\n            "+_vm._s(_vm.app.creator.name)+"\n            "),(_vm.app.creator.isDeleted)?_c('Tag',[_vm._v("删")]):_vm._e()],1):_vm._e()],1),_vm._v(" "),_c('Description',{attrs:{"term":"应用编码："}},[_vm._v("\n          "+_vm._s(_vm.app.code)+"\n        ")])],1),_vm._v(" "),_c('div',{staticClass:"mt-sm"},[_vm._v("创建于："+_vm._s(_vm.$Date(_vm.app.createdAt).format('YYYY-MM-DD HH:mm:ss')))]),_vm._v(" "),_c('div',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(3),expression:"3"}],staticClass:"mt-sm",attrs:{"title":_vm.app.summary || _vm.app.description || '暂无'}},[_vm._v("\n        "+_vm._s(_vm.app.summary || _vm.app.description || '暂无')+"\n      ")])],1)],1)],1)};
var __vue_staticRenderFns__$5 = [];

  /* style */
  const __vue_inject_styles__$5 = function (inject) {
    if (!inject) return
    inject("data-v-6ac51662_0", { source: ".main[data-v-6ac51662] .ivu-description-detail{color:#515a6e;padding-bottom:0}.main[data-v-6ac51662] .ivu-description-term{padding-bottom:0}.main[data-v-6ac51662] .ivu-row{flex-flow:row nowrap}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$5 = "data-v-6ac51662";
  /* module identifier */
  const __vue_module_identifier__$5 = undefined;
  /* functional template */
  const __vue_is_functional_template__$5 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$5 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$5, staticRenderFns: __vue_staticRenderFns__$5 },
    __vue_inject_styles__$5,
    __vue_script__$5,
    __vue_scope_id__$5,
    __vue_is_functional_template__$5,
    __vue_module_identifier__$5,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$4 = {
  props: {
    app: {
      type: Object,
      default: () => {
        return [];
      }
    }
  },
  data() {
    return {
      recommend: [],
      //由web提供 文件放在public/images下
      serviceDefaultIcon: './images/service-default.png',
      area: this.$route.query.area || 'mine' // mine: 应用列表 tenant:租户应用 apply：订阅应用
    };
  },
  async mounted() {
    let { data } = await appService$2.servicePublished({ orderby: 's.rate desc', limit: 5 });
    this.recommend = data;
  },
  methods: {
    del(item) {
      this.$Modal.confirm({
        title: '提示',
        content: '<p>是否删除？</p>',
        onOk: async () => {
          await aicService.abortAuth(item.id);
          this.$Message.success('删除成功');
          this.app.agreements = this.app.agreements.filter((innerItem) => innerItem.id !== item.id);
          this.$forceUpdate();
        }
      });
    },
    apply(item) {
      //this.$router.push({ path: `app-product-service/${item.id}/apply` });
      this.$router.push({ name: `fuseAppProductServiceApplyApp`, params: { serviceId: item.serviceId } });
    },
    getTagMsg(item) {
      for (let i = 0; i < status.length; i++) {
        if (item.authStatus == status[i].status) {
          return status[i];
        }
      }
      return { color: 'default', title: '默认' };
    },
    toDetail(item) {
      if (this.area !== 'mine') return;
      this.$router.push({ name: 'fuseAppProductServiceShow', params: { serviceId: item.serviceId } });
    },
    toService(item) {
      MicroAppHelper.routeToServiceForApp(item.service);
    },
    showMore() {
      this.$router.push({ name: 'fuseAppProductService' });
    }
  }
};

/* script */
const __vue_script__$4 = script$4;

/* template */
var __vue_render__$4 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Card',{staticClass:"main"},[_c('p',{attrs:{"slot":"title"},slot:"title"},[_c('Icon',{attrs:{"type":"ios-bookmark"}}),_vm._v(" "),_c('span',{staticClass:"title"},[_vm._v("本租户已申请的应用")])],1),_vm._v(" "),(_vm.area === 'mine')?_c('a',{attrs:{"slot":"extra"},on:{"click":_vm.showMore},slot:"extra"},[_vm._v(" 申请开通 ")]):_vm._e(),_vm._v(" "),_c('div',{staticClass:"body"},[(_vm.app.agreements && _vm.app.agreements.length)?_c('Row',{attrs:{"type":"flex","gutter":20}},_vm._l((_vm.app.agreements),function(agreement,index){return _c('Col',{key:index,attrs:{"xl":6,"lg":6,"md":8,"sm":8,"xs":12}},[_c('Card',{directives:[{name:"height",rawName:"v-height",value:(170),expression:"170"}],staticClass:"list-services-item p-sm",nativeOn:{"click":function($event){return _vm.toDetail(agreement)}}},[_c('Tag',{staticClass:"tag",attrs:{"color":_vm.getTagMsg(agreement).color}},[_vm._v(_vm._s(_vm.getTagMsg(agreement).title))]),_vm._v(" "),(agreement.service.icon)?_c('f-image',{attrs:{"width":"64px","height":"64px","item":agreement.service.icon}}):_c('img',{attrs:{"src":_vm.serviceDefaultIcon,"alt":""}}),_vm._v(" "),_c('span',{directives:[{name:"line-clamp",rawName:"v-line-clamp",value:(1),expression:"1"}],attrs:{"title":agreement.service.title}},[_vm._v(_vm._s(agreement.service.title))]),_vm._v(" "),(_vm.area === 'mine')?[(agreement.authStatus === 1 && agreement.service.appInteUrl)?_c('Button',{staticClass:"mt-sm",attrs:{"size":"small"},on:{"click":function($event){$event.stopPropagation();return _vm.toService(agreement)}}},[_vm._v("进入应用")]):_vm._e(),_vm._v(" "),(agreement.authStatus === 4)?_c('div',{staticClass:"mt-sm",staticStyle:{"text-align":"center"}},[_c('Button',{staticClass:"mr-sm",attrs:{"size":"small"},on:{"click":function($event){$event.stopPropagation();return _vm.apply(agreement)}}},[_vm._v("重新开通")]),_vm._v(" "),_c('Button',{attrs:{"size":"small","type":"text"},on:{"click":function($event){$event.stopPropagation();return _vm.del(agreement)}}},[_vm._v("删除")])],1):_vm._e()]:_vm._e()],2)],1)}),1):_c('aic-result',{staticStyle:{"margin-top":"30px"},attrs:{"type":"info","title":"尚未开通任何服务"}},[(_vm.area === 'mine')?_c('Button',{attrs:{"slot":"desc","type":"primary"},on:{"click":_vm.showMore},slot:"desc"},[_vm._v("立即开通")]):_vm._e()],1)],1)])};
var __vue_staticRenderFns__$4 = [];

  /* style */
  const __vue_inject_styles__$4 = function (inject) {
    if (!inject) return
    inject("data-v-2d47c3ba_0", { source: ".main[data-v-2d47c3ba]{margin-top:18px}.title[data-v-2d47c3ba]{margin-left:10px}.list[data-v-2d47c3ba]{display:flex}.list-services[data-v-2d47c3ba]{flex:1}.list-services-item[data-v-2d47c3ba]{cursor:pointer;padding:0;margin-bottom:20px;display:flex;align-items:center;justify-content:center}.list-services-item[data-v-2d47c3ba] .ivu-card-body{display:flex;flex-direction:column;align-items:center}.list-services-item img[data-v-2d47c3ba]{width:64px;height:64px}.list-services-item span[data-v-2d47c3ba]{margin-top:10px}.list-services-item[data-v-2d47c3ba] .tag{position:absolute;top:4px;right:4px}.body[data-v-2d47c3ba] .ivu-cell-title{color:#2d8cf0}.recommend-card[data-v-2d47c3ba]{display:flex;flex-direction:column}.recommend-card[data-v-2d47c3ba] .ivu-card-body{flex:1}.no-recommend[data-v-2d47c3ba]{display:flex;justify-content:center;align-items:center;height:100%}.ivu-rate[data-v-2d47c3ba]{font-size:15px}.ivu-rate[data-v-2d47c3ba] .ivu-rate-star{margin-right:3px}.main[data-v-2d47c3ba] .ivu-cell-title{width:200px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$4 = "data-v-2d47c3ba";
  /* module identifier */
  const __vue_module_identifier__$4 = undefined;
  /* functional template */
  const __vue_is_functional_template__$4 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$4 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$4, staticRenderFns: __vue_staticRenderFns__$4 },
    __vue_inject_styles__$4,
    __vue_script__$4,
    __vue_scope_id__$4,
    __vue_is_functional_template__$4,
    __vue_module_identifier__$4,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script$3 = {
  components: {
    overviewBase: __vue_component__$7,
    productService: __vue_component__$6,
    overviewBaseApply: __vue_component__$5,
    productServiceApply: __vue_component__$4
  },
  data() {
    return {
      app: null,
      showScoped: false,
      area: this.$route.query.area || 'mine' // mine: 应用列表 tenant:租户应用 apply：订阅应用
    };
  },
  props: {
    full: {
      type: Boolean,
      default: true
    }
  },
  async created() {
    this.init();
  },
  methods: {
    ...mapMutations$1('fuse/app', ['setApp']),
    async init() {
      const { appId } = this.$route.params;
      const resp = await appService$2.summary(appId);
      let app = resp.data;
      if (!this.full) {
        this.setApp(app);
      }
      //区分管理员和开发者
      this.initMember(app);
      //默认应用置顶
      this.sortClient(app);
      let { data } = await appService$2.appliedServices(app.id);
      let agreementData = data;
      //过滤不存在service的数据
      this.app = app;
      this.app['agreements'] = agreementData.filter((item) => item.service);
    },
    sortClient(app) {
      for (let i = 0; i < app.clients.length; i++) {
        if (app.clients[i].id === app.clientId) {
          let item = app.clients[i];
          item.name = '默认账号';
          app.clients.splice(i, 1);
          app.clients.unshift(item);
          break;
        }
      }
    },
    initMember(app) {
      app._admins = [];
      app._developers = [];
      app.members.forEach((item) => {
        item.bgColor = this.createRandomColor();
        if (item.role == 'admin') {
          app._admins.push(item);
        } else if (item.role == 'maintainer') {
          app._developers.push(item);
        }
      });
      //最后一项放maintainer的长度(用于界面展示)
      if (app._developers.length) {
        app._admins.push({ name: app._developers.length, title: '其他成员' });
      }
    },
    createRandomColor() {
      let colorList = ['#f56a00', '#7265e6', '#ffbf00', '#00a2ae'];
      return colorList[Math.floor(Math.random() * colorList.length)];
    }
  }
};

/* script */
const __vue_script__$3 = script$3;

/* template */
var __vue_render__$3 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"bvue-page"},[(_vm.app)?_c('Layout',{staticClass:"info-container"},[(_vm.area === 'mine' || _vm.area === 'tenant')?[_c('overview-base',{attrs:{"app":_vm.app}}),_vm._v(" "),(_vm.full)?_c('product-service',{attrs:{"app":_vm.app}}):_vm._e()]:[_c('overviewBaseApply',{attrs:{"app":_vm.app}}),_vm._v(" "),(_vm.full)?_c('product-service-apply',{attrs:{"app":_vm.app}}):_vm._e()],_vm._v(" "),_vm._t("bottom")],2):_vm._e()],1)};
var __vue_staticRenderFns__$3 = [];

  /* style */
  const __vue_inject_styles__$3 = undefined;
  /* scoped */
  const __vue_scope_id__$3 = undefined;
  /* module identifier */
  const __vue_module_identifier__$3 = undefined;
  /* functional template */
  const __vue_is_functional_template__$3 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$3 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$3, staticRenderFns: __vue_staticRenderFns__$3 },
    __vue_inject_styles__$3,
    __vue_script__$3,
    __vue_scope_id__$3,
    __vue_is_functional_template__$3,
    __vue_module_identifier__$3,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$2 = {
  props: {
    data: {
      type: Object,
      default: () => {
        return {};
      }
    },
    node: {
      type: Object,
      default: () => {
        return {};
      }
    },
    isEdit: {
      type: Boolean
    },
    context: {
      type: Object,
      default: () => {
        return {};
      }
    }
  },
  data() {
    return {
      scopeIcon: {
        scope: 'ios-apps',
        resource: 'logo-buffer',
        operation: '',
        kind: 'ios-folder-open'
      }
    };
  },
  computed: {
    showEdit() {
      if (this.isEdit && this.data.checked && this.data.type == 'resource') {
        return true;
      }
      return false;
    },
    currentItems() {
      return this.context.currentRoleScope.filter((item) => item.parentId === this.data.id);
    }
  },
  methods: {
    getFilterEntities(scopeItem) {
      //先获取自己的 没有再获取父的
      let targetScopeItem = this.context.originalScope.find(
        (originalScopeItem) => originalScopeItem.id == scopeItem.id || originalScopeItem.id == scopeItem.originalId
      );
      //如果为全部或者查看 因为是不能编辑他们自己的 所以这里得判断自己的存在不 不然得用父的
      if (targetScopeItem && targetScopeItem.filterEntities) {
        return targetScopeItem.filterEntities;
      }
      return this.data.filterEntities;
    },
    handleEdit() {
      let scope = this.context.currentRoleScope.filter((item) => item.parentId === this.data.id);
      this.context.showGrantModal(this.data, scope);
    },
    calDataRulesTitle(scopeItem) {
      if (scopeItem.dataRules && scopeItem.dataRules.includes('*')) {
        return '全部数据';
      }
      let ret = [];
      //先找自己的 再找父的
      let targetScopeItem = this.context.originalScope.find(
        (originalScopeItem) => originalScopeItem.id == scopeItem.id || originalScopeItem.id == scopeItem.originalId
      );
      let ruleEntities = (targetScopeItem && targetScopeItem.ruleEntities) || this.data.ruleEntities;
      if (!ruleEntities) {
        return '分类不存在';
      }
      ruleEntities.forEach((item) => {
        if (scopeItem.dataRules.includes(item.id)) {
          ret.push(item.title);
        }
      });
      return ret.join(',');
    }
  }
};

/* script */
const __vue_script__$2 = script$2;

/* template */
var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"main"},[_c('Icon',{staticStyle:{"margin-right":"4px"},attrs:{"type":_vm.data.code ? _vm.scopeIcon[_vm.data.type] : _vm.scopeIcon['kind'],"color":_vm.data.code ? '#2d8cf0' : 'goldenrod'}}),_vm._v(" "),_c('span',{style:({ color: _vm.node.node.indeterminate || _vm.data.checked || !_vm.isEdit ? '#515a6e' : '#c5c8ce' })},[_vm._v(_vm._s(_vm.data.title))]),_vm._v(" "),_c('Icon',{directives:[{name:"show",rawName:"v-show",value:(_vm.showEdit),expression:"showEdit"}],staticClass:"edit-icon",staticStyle:{"margin-left":"4px"},attrs:{"type":"md-create","size":"15","color":"#2d8cf0"},on:{"click":_vm.handleEdit}}),_vm._v(" "),(_vm.data.type == 'resource' && _vm.context.currentRoleScope.some(function (item) { return item.parentId === _vm.data.id; }))?_c('div',{staticStyle:{"padding-left":"24px"}},_vm._l((_vm.currentItems),function(scopeItem){return _c('div',{key:scopeItem.id,style:({ color: _vm.node.node.indeterminate || _vm.data.checked || !_vm.isEdit ? '#515a6e' : '#c5c8ce' })},[_vm._v("\n      "+_vm._s(scopeItem.title)+"\n      "),_c('span',{staticClass:"ml-lg"},[_vm._v(_vm._s(_vm.calDataRulesTitle(scopeItem)))]),_vm._v(" "),(scopeItem.dataFilters['*'])?_c('span',{staticClass:"ml-lg"},[_vm._v("全部分类")]):_vm._l((_vm.getFilterEntities(scopeItem)),function(item){return _c('span',{key:item.id,staticClass:"ml-lg"},[(scopeItem.dataFilters[item.id])?[_vm._v("\n            "+_vm._s(item.title)+"(\n            "),_vm._l((item.items),function(dataFiltersInnerItem){return _c('span',{key:dataFiltersInnerItem.code},[(scopeItem.dataFilters[item.id].includes(dataFiltersInnerItem.code))?[_vm._v(_vm._s(dataFiltersInnerItem.title)+"\n              ")]:_vm._e()],2)}),_vm._v(")\n          ")]:_vm._e()],2)})],2)}),0):_vm._e()],1)};
var __vue_staticRenderFns__$2 = [];

  /* style */
  const __vue_inject_styles__$2 = undefined;
  /* scoped */
  const __vue_scope_id__$2 = undefined;
  /* module identifier */
  const __vue_module_identifier__$2 = undefined;
  /* functional template */
  const __vue_is_functional_template__$2 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$2 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
    __vue_inject_styles__$2,
    __vue_script__$2,
    __vue_scope_id__$2,
    __vue_is_functional_template__$2,
    __vue_module_identifier__$2,
    false,
    undefined,
    undefined,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$1 = {
  props: {
    componentId: {
      type: String,
      default: '$app'
    }
  },
  data() {
    return {
      modalShow: false,
      model: {},
      ruleValidate: {},
      selectItem: {},
      currentScope: [],
      tableData: [],
      originalScope: [], //原始全部的权限数据
      all: true, //全部操作
      columns: [
        {
          type: 'selection',
          width: 60,
          align: 'center'
        },
        {
          title: '操作',
          key: 'title'
        },
        {
          title: '数据规则',
          slot: 'dataRule'
        },
        {
          title: '数据分类',
          slot: 'dataCol'
        }
      ],
      scopeMapData: {} //{*:{dataFilters:,dataRules},xxx(operation的id):{}}
    };
  },
  methods: {
    show(selectItem, currentScope, originalScope) {
      this.selectItem = _.cloneDeep(selectItem);
      this.currentScope = _.cloneDeep(currentScope);
      this.tableData = _.cloneDeep(originalScope);
      this.originalScope = _.cloneDeep(originalScope);
      //如果权限为空
      if (this.currentScope.length == 0) {
        this.all = true;
        this.setScopeMapData('*', {
          title: '全部操作',
          dataRules: ['*'],
          dataFilters: ['*']
        });
      } else {
        //有且只有一条并且code为* 选择了全部
        if (this.currentScope.length == 1 && (this.currentScope[0].code || this.currentScope[0].scopeCode) == '*') {
          this.all = true;
          //开启了全部的话只有一条权限 code为*
          this.setScopeMapData('*', {
            title: '全部操作',
            dataRules: this.currentScope[0].dataRules[0],
            dataFilters: this.calDataFilters(this.currentScope[0].dataFilters)
          });
        } else {
          this.all = false;
          this.setScopeMapData('*', {
            title: '全部操作',
            dataRules: '*',
            dataFilters: ['*']
          });
        }
      }

      this.initTableData();
      this.initScopeMapData();
      this.formatFilterEntities(this.selectItem.filterEntities);

      //如果子操作有 父操作没有
      this.tableData.forEach((outItem) => {
        if (outItem.filterEntities && outItem.filterEntities.length) {
          this.formatFilterEntities(outItem.filterEntities);
        }
      });
      this.modalShow = true;
    },
    formatFilterEntities(filterEntities) {
      filterEntities.forEach((item) => {
        item.items = item.items.map((innerItem) => {
          innerItem.code = `${item.id}.${innerItem.code}`;
          return innerItem;
        });
      });
    },
    disabledSelect(scopeMapDataItem) {
      return scopeMapDataItem.dataFilters.includes('*');
    },
    handleSelectChange(val, scopeMapDataItem) {
      //如果选择了全部就去掉其他的 并且禁用
      if (val.includes('*')) {
        scopeMapDataItem.dataFilters = ['*'];
      }
    },
    getCheckboxIndeterminate(item, scopeMapDataItem) {
      let length = scopeMapDataItem.dataFilters.filter((innerItem) => innerItem.includes(item.id)).length;
      if (length > 0 && length < item.items.length) return true;
      return false;
    },
    getCheckboxVal(item, scopeMapDataItem) {
      return (
        scopeMapDataItem.dataFilters.filter((innerItem) => innerItem.includes(item.id)).length === item.items.length
      );
    },
    handleCheckboxChange(val, item, scopeMapDataItem) {
      let indeterminate = this.getCheckboxIndeterminate(item, scopeMapDataItem);
      if (indeterminate) {
        //反选
        this.handleSelectAll(item, scopeMapDataItem);
      } else {
        if (val) {
          //选择全部
          this.handleSelectAll(item, scopeMapDataItem);
        } else {
          //取消全部
          this.handleCancelAll(item, scopeMapDataItem);
        }
      }
    },
    handleSelectAll(item, scopeMapDataItem) {
      let values = item.items.map((innerItem) => innerItem.code);
      scopeMapDataItem.dataFilters = Array.from(new Set(scopeMapDataItem.dataFilters.concat(values)));
    },
    handleCancelAll(item, scopeMapDataItem) {
      scopeMapDataItem.dataFilters = scopeMapDataItem.dataFilters.filter((innerItem) => !innerItem.includes(item.id));
    },
    setScopeMapData(key, value) {
      this.$set(this.scopeMapData, [key], value);
    },
    initTableData() {
      //不显示全部操作那条数据
      if (!this.selectItem.operaEnabled) {
        //   this.tableData = this.originalScope.filter((item) => item.code === '*');
        //   this.tableData[0]._checked = true;
        //   this.tableData[0]._disabled = true;
        this.tableData = [];
      } else {
        this.tableData = this.originalScope.filter((item) => item.code !== '*');
        this.tableData.forEach((item) => {
          if (item.code === 'r') {
            item._checked = true;
            item._disabled = true;
          } else {
            item._disabled = this.all;
          }
        });
      }
    },
    handleSwitchChange() {
      //如果开启了自定义操作
      this.initTableData();
    },
    initScopeMapData() {
      this.tableData.forEach((item) => {
        let targetItem = this.currentScope.filter(
          (itemInner) => itemInner.originalId === item.id || itemInner.scopeId === item.id
        )[0];
        //如果找得到就是授权了的
        if (targetItem) {
          item.dataFilters = this.calDataFilters(targetItem.dataFilters);
          item.dataRules = targetItem.dataRules[0];
          item._checked = true;
          this.setScopeMapData(item.id, _.cloneDeep(item));
        } else {
          //给全部
          item.dataFilters = ['*'];
          item.dataRules = '*';
          this.setScopeMapData(item.id, _.cloneDeep(item));
        }
      });
    },
    ok() {
      //如果开启了全部操作 需要删除自定义操作的数据；
      let formName = this.all ? 'formForAllRef' : 'formForCustomRef';
      this.$refs[formName].validate((valid) => {
        if (valid) {
          let params = this.buildParams();
          this.$emit('on-change', this.selectItem, params);
          this.cancel();
        } else {
          this.$Message.error('请检查所有的必填字段!');
        }
      });
    },
    calDataFilters(dataFilters) {
      //存在星号 代表选择了全部
      if (dataFilters['*']) {
        return ['*'];
      }
      //console.log(dataFilters);
      let ret = [];
      for (let key in dataFilters) {
        ret = ret.concat(
          dataFilters[key].map((item) => {
            return `${key}.${item}`;
          })
        );
      }
      return ret;
    },
    handleBeforeChange() {
      return new Promise((resolve) => {
        //如果权限开启了自定义 这里开关自由
        if (this.selectItem.operaEnabled) {
          resolve();
        } else {
          //如果没有开启自定义操作 这里的全部操作不能关闭
          if (!this.all) {
            resolve();
          }
        }
      });
    },
    buildParams() {
      //根据table选中的数据来计算
      let params = { create: [], delete: [], update: [] };
      let tableSelection = this.$refs.selection.getSelection();
      let currentScopeMap = {};
      this.currentScope.forEach((item) => {
        currentScopeMap[item.originalId] = item;
      });
      //找到全部操作的数据
      let target = this.originalScope.find((item) => item.code === '*');
      if (this.all) {
        //这里判断本来是不是已经是开启了的
        if (
          this.currentScope.length == 1 &&
          (this.currentScope[0].code == '*' || this.currentScope[0].scopeCode == '*') &&
          currentScopeMap['*']
        ) {
          //如果本来就是已经开启了 点击了授权的时候还是开启的 直接更新即可
          //这里得保存这个id
          params.update.push(
            Object.assign(
              {},
              target,
              { dataRules: [this.scopeMapData['*'].dataRules] },
              { dataFilters: this.reDataFilters(this.scopeMapData['*'].dataFilters) },
              { id: currentScopeMap[target.id].authorizedId },
              { originalId: currentScopeMap[target.id].originalId },
              { authorizedId: currentScopeMap[target.id].authorizedId }
            )
          );
        } else {
          //删除其他的授权数据
          this.currentScope.forEach((item) => {
            if (item.authorizedId) {
              params.delete.push(
                Object.assign({}, item, {
                  id: item.authorizedId
                })
              );
            }
          });
          params.create.push(
            Object.assign({}, target, {
              dataRules: [this.scopeMapData['*'].dataRules],
              dataFilters: this.reDataFilters(this.scopeMapData['*'].dataFilters),
              scopeCode: target.code,
              scopeId: target.id,
              code: target.code,
              componentId: this.componentId
            })
          );
        }
      } else {
        for (let item of tableSelection) {
          let { dataRules, dataFilters } = this.scopeMapData[item.id];
          if (!currentScopeMap[item.id]) {
            //新增
            params.create.push(
              Object.assign({}, item, {
                dataRules: [dataRules],
                dataFilters: this.reDataFilters(dataFilters),
                scopeCode: item.code,
                scopeId: item.id,
                code: target.code,
                componentId: this.componentId
              })
            );
          } else {
            if (!item.originalId) {
              //保存 防止后面被重新更新冲掉
              item.originalId = item.id;
            }
            params.update.push(
              Object.assign(
                {},
                item,
                { dataRules: [dataRules] },
                { dataFilters: this.reDataFilters(dataFilters) },
                { id: currentScopeMap[item.id].authorizedId },
                { originalId: item.originalId },
                { authorizedId: currentScopeMap[item.id].authorizedId }
              )
            );
          }
        }
        let tableSelectionMap = {};
        tableSelection.forEach((item) => {
          tableSelectionMap[item.id] = _.cloneDeep(item);
        });
        for (let i = 0; i < this.currentScope.length; i++) {
          if (!tableSelectionMap[this.currentScope[i].originalId] && this.currentScope[i].authorizedId) {
            params.delete.push(
              Object.assign({}, this.currentScope[i], {
                id: this.currentScope[i].authorizedId
              })
            );
          }
        }
      }

      return params;
    },
    reDataFilters(dataFilters) {
      let ret = {};
      //存在星号 代表选择了全部
      if (dataFilters.includes('*')) {
        return { '*': ['*'] };
      }
      for (let item of dataFilters) {
        let scopeId = item.split('.')[0];
        let code = item.split('.')[1];
        if (ret[scopeId]) {
          ret[scopeId].push(code);
        } else {
          ret[scopeId] = [];
          ret[scopeId].push(code);
        }
      }
      return ret;
    },
    cancel() {
      this.modalShow = false;
    }
  }
};

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('Modal',{staticClass:"modal",attrs:{"mask-closable":false,"width":"800","title":"编辑授权"},model:{value:(_vm.modalShow),callback:function ($$v) {_vm.modalShow=$$v;},expression:"modalShow"}},[_c('h4',[_vm._v("权限名称："+_vm._s(_vm.selectItem.title))]),_vm._v(" "),(_vm.modalShow)?_c('Card',{staticClass:"mt-sm mb-sm",staticStyle:{"margin-top":"4px"},attrs:{"dis-hover":"","padding":6}},[_c('div',[_c('span',{staticStyle:{"font-size":"14px","font-weight":"bold"}},[_vm._v("全部操作")]),_vm._v(" "),_c('Switch',{staticClass:"ml-lg",attrs:{"before-change":_vm.handleBeforeChange,"size":"small"},on:{"on-change":_vm.handleSwitchChange},model:{value:(_vm.all),callback:function ($$v) {_vm.all=$$v;},expression:"all"}})]),_vm._v(" "),_c('Form',{ref:"formForAllRef",staticClass:"form",attrs:{"model":_vm.scopeMapData,"label-width":80}},[_c('Row',{staticClass:"mt-md"},[_c('Col',{attrs:{"span":"12"}},[_vm._v("\n          数据规则\n          "),_c('Select',{staticClass:"ml-lg",staticStyle:{"width":"200px"},attrs:{"disabled":!_vm.all,"max-tag-count":2},model:{value:(_vm.scopeMapData['*'].dataRules),callback:function ($$v) {_vm.$set(_vm.scopeMapData['*'], "dataRules", $$v);},expression:"scopeMapData['*'].dataRules"}},[_c('Option',{attrs:{"value":"*"}},[_vm._v("全部数据")]),_vm._v(" "),_vm._l((_vm.selectItem.ruleEntities),function(item){return _c('Option',{key:item.id,attrs:{"value":item.id}},[_vm._v(_vm._s(item.title))])})],2)],1),_vm._v(" "),_c('Col',{attrs:{"span":"12"}},[_c('FormItem',{attrs:{"label":"数据分类"}},[_c('Select',{staticClass:"ml-lg",staticStyle:{"width":"200px"},attrs:{"disabled":!_vm.all,"max-tag-count":2,"multiple":""},on:{"on-change":function (val) { return _vm.handleSelectChange(val, _vm.scopeMapData['*']); }},model:{value:(_vm.scopeMapData['*'].dataFilters),callback:function ($$v) {_vm.$set(_vm.scopeMapData['*'], "dataFilters", $$v);},expression:"scopeMapData['*'].dataFilters"}},[_c('Option',{attrs:{"value":"*"}},[_vm._v("全部分类")]),_vm._v(" "),_vm._l((_vm.selectItem.filterEntities),function(item){return _c('OptionGroup',{key:item.id,attrs:{"label":item.title}},[_c('div',{staticClass:"group-slot"},[_c('Checkbox',{attrs:{"disabled":_vm.disabledSelect(_vm.scopeMapData['*']),"indeterminate":_vm.getCheckboxIndeterminate(item, _vm.scopeMapData['*']),"value":_vm.getCheckboxVal(item, _vm.scopeMapData['*'])},on:{"on-change":function (val) { return _vm.handleCheckboxChange(val, item, _vm.scopeMapData['*']); }}},[_vm._v(_vm._s(item.title))])],1),_vm._v(" "),_vm._l((item.items),function(itemInner){return _c('Option',{key:itemInner.code,attrs:{"disabled":_vm.disabledSelect(_vm.scopeMapData['*']),"value":itemInner.code}},[_vm._v(_vm._s(itemInner.title))])})],2)})],2)],1)],1)],1)],1)],1):_vm._e(),_vm._v(" "),_c('Form',{ref:"formForCustomRef",staticClass:"form",attrs:{"model":_vm.scopeMapData}},[_c('Table',{ref:"selection",attrs:{"border":"","columns":_vm.columns,"data":_vm.tableData},scopedSlots:_vm._u([{key:"dataRule",fn:function(ref){
var row = ref.row;
return [_c('Select',{attrs:{"transfer":"","disabled":_vm.all,"max-tag-count":2},model:{value:(_vm.scopeMapData[row.id].dataRules),callback:function ($$v) {_vm.$set(_vm.scopeMapData[row.id], "dataRules", $$v);},expression:"scopeMapData[row.id].dataRules"}},[_c('Option',{attrs:{"value":"*"}},[_vm._v("全部数据")]),_vm._v(" "),_vm._l((row.ruleEntities || _vm.selectItem.ruleEntities),function(item){return _c('Option',{key:item.id,attrs:{"value":item.id}},[_vm._v(_vm._s(item.title))])})],2)]}},{key:"dataCol",fn:function(ref){
var row = ref.row;
return [_c('FormItem',[_c('Select',{attrs:{"transfer":"","disabled":_vm.all,"max-tag-count":2,"multiple":""},on:{"on-change":function (val) { return _vm.handleSelectChange(val, _vm.scopeMapData[row.id]); }},model:{value:(_vm.scopeMapData[row.id].dataFilters),callback:function ($$v) {_vm.$set(_vm.scopeMapData[row.id], "dataFilters", $$v);},expression:"scopeMapData[row.id].dataFilters"}},[_c('Option',{attrs:{"value":"*"}},[_vm._v("全部分类")]),_vm._v(" "),_vm._l((row.filterEntities || _vm.selectItem.filterEntities),function(item){return _c('OptionGroup',{key:item.id,attrs:{"label":item.title}},[_c('div',{staticClass:"group-slot"},[_c('Checkbox',{attrs:{"disabled":_vm.disabledSelect(_vm.scopeMapData[row.id]),"indeterminate":_vm.getCheckboxIndeterminate(item, _vm.scopeMapData[row.id]),"value":_vm.getCheckboxVal(item, _vm.scopeMapData[row.id])},on:{"on-change":function (val) { return _vm.handleCheckboxChange(val, item, _vm.scopeMapData[row.id]); }}},[_vm._v(_vm._s(item.title))])],1),_vm._v(" "),_vm._l((item.items),function(itemInner){return _c('Option',{key:itemInner.code,attrs:{"disabled":_vm.disabledSelect(_vm.scopeMapData[row.id]),"value":itemInner.code}},[_vm._v(_vm._s(itemInner.title))])})],2)})],2)],1)]}}])})],1),_vm._v(" "),_c('div',{attrs:{"slot":"footer"},slot:"footer"},[_c('Button',{attrs:{"type":"text"},on:{"click":_vm.cancel}},[_vm._v("取消")]),_vm._v(" "),_c('Button',{attrs:{"type":"primary"},on:{"click":_vm.ok}},[_vm._v("确定")])],1)],1)};
var __vue_staticRenderFns__$1 = [];

  /* style */
  const __vue_inject_styles__$1 = function (inject) {
    if (!inject) return
    inject("data-v-4282058d_0", { source: ".modal[data-v-4282058d] .ivu-modal-body{padding:8px 12px}.form[data-v-4282058d] .ivu-form-item{margin-bottom:0}.ivu-select-group-wrap[data-v-4282058d] .ivu-select-group-title:first-child{display:none}.group-slot[data-v-4282058d]{padding-left:8px;font-size:14px;color:#999;height:30px;line-height:30px}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1 = "data-v-4282058d";
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    createInjector,
    undefined,
    undefined
  );

//
var script = {
  components: { GrantModal: __vue_component__$1 },
  model: {
    prop: 'value',
    event: 'change'
  },
  props: {
    value: {
      type: Array,
      default: () => {
        return [];
      }
    },
    componentId: {
      type: String,
      required: true
    },
    appId: {
      type: String,
      required: true
    },
    isEdit: {
      type: Boolean,
      default: true
    },
    clientScopes: {
      type: Array,
      default: () => {
        return [];
      }
    }
  },
  data() {
    return {
      queryOptions: {
        orderby: 'updatedAt desc',
        appId: this.appId,
        componentId: this.componentId,
        limit: 1000
      },
      editTreeData: [],
      readTreeData: [],
      loading: true,
      currentRoleScope: [],
      originalScope: [] //远程拿到的权限数据 未经过任何处理
    };
  },
  mounted() {
    this.init();
  },
  methods: {
    treeRender(h, { node, data }) {
      return h(__vue_component__$2, {
        props: {
          node,
          data,
          isEdit: this.isEdit,
          context: this
        }
      });
    },
    onCheckChange(list, current) {
      //判断选择的是分类还是权限
      if (current.code) {
        //选择了权限
        if (current.type === 'scope') {
          this.grantFuncScope(current);
        } else if (current.type === 'resource') {
          this.grantDataScope(current, true);
        }
      } else {
        //分类 这里需要递归
        current.children &&
          current.children.forEach((item) => {
            this.onCheckChange(list, item);
          });
      }
      this.emitData();
    },
    emitData() {
      let checkNote = this.$refs.tree.getCheckedNodes().filter((i) => i.code || i.scopeCode);
      checkNote.forEach((i) => {
        if (i.type === 'resource') {
          checkNote = checkNote.concat(this.currentRoleScope.filter((item) => item.parentId === i.id));
        }
      });
      checkNote = checkNote.filter((i) => i.type !== 'resource');
      checkNote.forEach((item) => {
        if (!item.id) {
          item.id = item.scopeId;
        }
        if (!item.code) {
          item.code = item.scopeCode;
        }
      });
      this.$emit('change', checkNote);
      this.$emit('on-change', checkNote);
    },
    //isSelf 是否点击元素本身触发的事件（可能是点击了分类触发的）
    grantDataScope(current, isSelf) {
      let targetScope = this.currentRoleScope.filter((item) => item.parentId === current.id)[0];
      let realHasScope = this.originalCurrentRoleScope.some((item) => item.parentId === current.id);
      let checked = current.checked;
      if (targetScope) {
        if (realHasScope) ; else {
          if (!checked && isSelf) {
            this.currentRoleScope = this.currentRoleScope.filter((item) => item.parentId !== current.id);
          }
        }
      } else {
        let target = this.originalScope.filter((item) => {
          return item.code === '*' && item.parentId === current.id;
        })[0];
        if (checked) {
          this.currentRoleScope.push({
            dataRules: ['*'],
            dataFilters: { '*': ['*'] },
            scopeCode: target.code,
            scopeId: target.id,
            parentId: current.id,
            title: '全部操作'
          });
        } else {
          //进行删除操作
          this.currentRoleScope = this.currentRoleScope.filter((item) => item.parentId !== current.id);
        }
      }
    },
    grantFuncScope(current) {
      //判断当前是否有当前的权限
      this.currentRoleScope.push(current);
      // let targetScope = this.originalCurrentRoleScope.filter((item) => item.scopeId === current.id)[0];
      // let checked = current.checked;
      // if (targetScope) {
      //   if (checked) {
      //     //更新
      //   } else {
      //     //删除
      //   }
      // } else {
      //   if (checked) {
      //     //新增
      //   }
      // }
    },
    showGrantModal(selectItem, currentScope) {
      this.$refs.grantModal.show(
        selectItem,
        currentScope,
        this.originalScope.filter((item) => item.type == 'operation' && item.parentId == selectItem.id)
      );
    },
    onGrantChange(selectItem, params) {
      if (params.delete && params.delete.length) {
        let deleteCodes = params.delete.map((item) => item.code);
        this.currentRoleScope = this.currentRoleScope.filter((item) => !deleteCodes.includes(item.code));
      }
      if (params.create && params.create.length) {
        //这里还需要判断界面是否已经存在当前的数据了 如果存在就是更新
        this.currentRoleScope = this.currentRoleScope
          .filter((item) => item.parentId !== selectItem.id)
          .concat(params.create);
      }
      if (params.update && params.update.length) {
        this.currentRoleScope = this.currentRoleScope
          .filter((item) => item.parentId !== selectItem.id)
          .concat(params.update);
      }
      this.emitData();
    },
    findTarget(key, value, findList, resultList) {
      //根据key value来查找对应的元素
      if (!findList) return resultList;
      findList.forEach((item) => {
        if (item[key].search(value) != -1) {
          resultList.push(item);
        } else {
          this.findTarget(key, value, item.children, resultList);
        }
      });
    },
    async getScopeKind() {
      const { data } = await aicService.getScopeKindComponents(this.queryOptions);
      data.forEach((item) => {
        item.label = item.title;
        item.value = item.id;
        item.expand = true;
      });
      return data;
    },
    async getScope() {
      const { data } = await aicService.getScopeComponents(
        Object.assign({}, this.queryOptions, { filters: `applyTo in ('app','all')` })
      );
      return data;
    },
    async init() {
      this.loading = true;
      let scopeds = await this.getScope();
      this.originalScope = _.cloneDeep(scopeds);
      let scopedKinds = await this.getScopeKind();
      this.clientScopes.forEach((i) => {
        i = Object.assign(i, { ...i.scope }, { dataFilters: i.dataFilters, dataRules: i.dataRules });
      });
      this.originalCurrentRoleScope = _.cloneDeep(this.clientScopes);
      this.currentRoleScope = this.clientScopes;
      //获取当前角色对应的权限
      let list = _.cloneDeep(this.currentRoleScope);
      //补齐操作所属的数据权限（获取一个角色所有的权限接口中没有返回这条数据权限的记录）
      for (let item of this.currentRoleScope) {
        if (item.type == 'operation' && !list.some((listItem) => listItem.id == item.parentId)) {
          let target = this.originalScope.find((innerItem) => innerItem.id == item.parentId);
          if (target) {
            list.push(target);
          }
        }
      }
      //过滤掉所有的操作权限
      list = list.filter((item) => item.type !== 'operation');
      let targetScopeKind = [];
      for (let item of list) {
        getParentKind(item.kindId, targetScopeKind);
      }
      function getParentKind(parentId, list) {
        if (!parentId) return;
        for (let item of scopedKinds) {
          if (parentId == item.id && !list.some((innerItem) => innerItem.id === parentId)) {
            list.push(item);
            parentId = item.parentId;
            getParentKind(parentId, list);
          }
        }
      }
      this.readTreeData = this.initTreeData(list, this.getTreeData(targetScopeKind));
      let treeData = scopeds.filter((item) => item.type !== 'operation');
      treeData.forEach((item) => {
        //操作权限判断的是parentId 功能权限判断的是scopeId
        if (
          this.currentRoleScope.some((innerItem) => innerItem.scopeId === item.id || innerItem.parentId === item.id)
        ) {
          item.checked = true;
        } else {
          item.checked = false;
        }
      });
      this.editTreeData = this.initTreeData(treeData, this.getTreeData(_.cloneDeep(scopedKinds)));
      this.loading = false;
    },
    initDataScope(scopeds) {
      //初始化数据操作权限层级
      let operationScope = _.remove(scopeds, function (item) {
        return item.parentId;
      });
      operationScope.forEach((operationScopeItem) => {
        scopeds.forEach((scopeItem) => {
          if (operationScopeItem.parentId == scopeItem.id) {
            operationScopeItem._parentOperaEnabled = scopeItem.operaEnabled; //这里把父节点的operaEnabled属性设置为子节点属性_parentOperaEnabled
            if (scopeItem.operaEnabled) {
              //operaEnabled为true的时候 不展示code eq * 的操作数据
              if (operationScopeItem.code !== '*') {
                if (scopeItem.children) {
                  scopeItem.children.push(operationScopeItem);
                } else {
                  scopeItem.children = [operationScopeItem];
                }
              }
            } else {
              //operaEnabled为false的时候 只展示 code eq * 的操作数据
              if (operationScopeItem.code === '*') {
                if (scopeItem.children) {
                  scopeItem.children.push(operationScopeItem);
                } else {
                  scopeItem.children = [operationScopeItem];
                }
              }
            }
            scopeItem.expand = true;
          }
        });
      });
    },
    initTreeData(scopeds, scopedKinds) {
      let scopedsMap = {};
      scopeds.forEach((item) => {
        if (item.kindId) {
          scopedsMap[item.kindId] = scopedsMap[item.kindId] ? scopedsMap[item.kindId] : [];
          scopedsMap[item.kindId].push(item);
        } else {
          scopedKinds.push(item);
        }
      });

      function findTarget(key, scopes, scopedKinds) {
        for (let i = 0; i < scopedKinds.length; i++) {
          if (scopedKinds[i].id == key) {
            scopedKinds[i].children = scopedKinds[i].children ? scopedKinds[i].children : [];
            scopedKinds[i].children = scopedKinds[i].children.concat(scopes);
            scopedKinds[i]._showChildren = true;
            break;
          }
          if (scopedKinds[i].children) {
            findTarget(key, scopes, scopedKinds[i].children);
          }
        }
      }

      for (let i in scopedsMap) {
        findTarget(i, scopedsMap[i], scopedKinds);
      }

      return scopedKinds;
    },
    getTreeData(data, _primaryKey, _parentKey, _childrenKey, _titleKey) {
      if (!data) {
        //data为空直接返回空数组
        return [];
      }
      let ID_KEY = _primaryKey || 'id';
      let PARENT_KEY = _parentKey || 'parentId';
      let CHILDREN_KEY = _childrenKey || 'children';
      let TITLE_KEY = _titleKey || 'title';
      let tree = [],
        idList = [],
        childrenOf = {};
      let item, id, parentId;
      for (let i = 0, length = data.length; i < length; i++) {
        item = data[i];
        id = item[ID_KEY];
        idList.push(id);
        parentId = item[PARENT_KEY];
        // every item may have children
        childrenOf[id] = childrenOf[id] || [];
        // init its children
        item[CHILDREN_KEY] = childrenOf[id];
        item.title = item[TITLE_KEY];
        if (parentId) {
          // init its parent's children object
          childrenOf[parentId] = childrenOf[parentId] || [];
          // push it into its parent's children object
          childrenOf[parentId].push(item);
        } else {
          tree.push(item);
        }
      }
      // 特殊处理所有条目都有parentId时的情况
      for (let parentId in childrenOf) {
        if (idList.indexOf(parentId) < 0) {
          let d = null;
          for (let item of data) {
            if (item[PARENT_KEY] === parentId) {
              d = item;
              break;
            }
          }
          tree.push(d);
        }
      }
      return tree;
    }
  }
};

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[(_vm.loading)?_c('Spin',{attrs:{"size":"large","fix":""}}):_vm._e(),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(!_vm.isEdit),expression:"!isEdit"}],staticClass:"tree",attrs:{"select-node":false,"render":_vm.treeRender,"data":_vm.readTreeData}}),_vm._v(" "),_c('Tree',{directives:[{name:"show",rawName:"v-show",value:(_vm.isEdit),expression:"isEdit"}],ref:"tree",staticClass:"tree",attrs:{"select-node":false,"check-directly":"","show-checkbox":"","data":_vm.editTreeData,"render":_vm.treeRender},on:{"on-check-change":_vm.onCheckChange}}),_vm._v(" "),_c('GrantModal',{ref:"grantModal",attrs:{"component-id":_vm.componentId},on:{"on-change":_vm.onGrantChange}})],1)};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-286374ce_0", { source: ".tree[data-v-286374ce] .ivu-tree-empty{text-align:center}", map: undefined, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = "data-v-286374ce";
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

var index$1 = {
    /** 表单组件 */
    FPassword: __vue_component__$L,
    FSelect: __vue_component__$G,
    FOption: __vue_component__$I,
    FOptionGroup: __vue_component__$H,
    FRefEntity: __vue_component__$D,
    FSingleImageUpload: __vue_component__$1c,
    FMultiImageUpload: __vue_component__$C,
    FSingleFileUpload: __vue_component__$B,
    FMultiFileUpload: __vue_component__$A,
    FOrgSelect: __vue_component__$z,
    FMemberSelect: __vue_component__$w,
    FMemberOrgSelect: __vue_component__$t,
    FActorSelect: __vue_component__$q,
    FClientSelect: __vue_component__$p,
    /** 普通组件 */
    FTogglePanel: __vue_component__$o,
    FInfoTip: __vue_component__$n,
    FRemote: __vue_component__$1b,
    FAdvancedSettingsPanel: __vue_component__$m,
    FMonitorMetric: __vue_component__$l,
    FAlertRule: __vue_component__$f,
    FAlertRuleInfo: __vue_component__$a,
    FButton: __vue_component__$e,
    FImage: __vue_component__$1k,
    FLoadingTip: __vue_component__$1i,
    FInfiniteScrollList: __vue_component__$1h,
    BackToIndex: __vue_component__$d,
    FResult: __vue_component__$c,
    FDoubleColumnsView: __vue_component__$b,
    FUserToolTip: __vue_component__$9,
    FDefaultIcon: __vue_component__$8,
    FAppOverview: __vue_component__$3,
    FAuthorizeScopeTree: __vue_component__
};

var index = {
    name: process.env.VUE_APP_NAME,
    version: process.env.VUE_APP_VERSION,
    dependencies: ['@fly-vue/core'],
    install: function (webApp, _opts) {
        var _this = this;
        webApp.addRoutes(innerRouter, null);
        webApp.store.registerModule('fuse', stores);
        webApp.registerEvent(WebApplicationEventType.userSignIn, function () {
            return __awaiter(this, void 0, void 0, function () {
                var app, query;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, securityManager.loadPerms()];
                        case 1:
                            _a.sent();
                            if (window.location.href.includes('__to=console')) {
                                webApp.config['settings.app.index'] = '/console';
                            }
                            app = null;
                            query = RouteHelper.resolveQueryString(window.location.href);
                            if (query[MicroAppHelper.KEY_FOR_APP_ID_IN_QUERY]) {
                                app = { id: query[MicroAppHelper.KEY_FOR_APP_ID_IN_QUERY] };
                            }
                            return [4 /*yield*/, webApp.store.dispatch('fuse/app/init', app)];
                        case 2:
                            app = _a.sent();
                            if (app) {
                                MicroAppHelper.rebuildAppMenus(app);
                            }
                            return [2 /*return*/];
                    }
                });
            });
        });
        webApp.registerEvent(WebApplicationEventType.microAppGlobalStateChange, function (event) { return __awaiter(_this, void 0, void 0, function () {
            var state, action, newId;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        state = event.value;
                        action = state.action;
                        newId = state.topEntityId;
                        if (!(includes(action, 'TopEntityIdChanged') && newId)) return [3 /*break*/, 4];
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, webApplication$1.store.dispatch('fuse/app/init', { id: newId })];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        _a.sent();
                        window.location.href = '/403';
                        return [3 /*break*/, 4];
                    case 4:
                        if (includes(action, 'RouterTo') && state.to) {
                            webApplication$1.router.push(state.to);
                        }
                        return [2 /*return*/];
                }
            });
        }); });
        webApplication$1.registerEvent(WebApplicationEventType.routerLoaded, function (event) {
            if (ConfigHelper.getConfigVal('ui.messages.enabled')) {
                event.router.beforeEach(function (to, from, next) { return __awaiter(_this, void 0, void 0, function () {
                    var ex_1;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                _a.trys.push([0, 2, 3, 4]);
                                return [4 /*yield*/, i18nService.ensure(to)];
                            case 1:
                                _a.sent();
                                return [3 /*break*/, 4];
                            case 2:
                                ex_1 = _a.sent();
                                console.error(ex_1);
                                return [3 /*break*/, 4];
                            case 3:
                                next();
                                return [7 /*endfinally*/];
                            case 4: return [2 /*return*/];
                        }
                    });
                }); });
            }
            // 注册扩展的i18n对象$pt
            if (!webApplication$1.Vue.prototype.$pt) {
                webApplication$1.Vue.prototype.$pt = function (key, defautMsgOrValues, values) {
                    var depthInRoute = Utils.calDepthInRoute(this);
                    var matchedRoute = this.$route.matched[depthInRoute];
                    var pathKey = i18nService.buildKey(matchedRoute);
                    if (pathKey) {
                        key = pathKey + "." + key;
                    }
                    if (defautMsgOrValues && !isString(defautMsgOrValues)) {
                        values = defautMsgOrValues;
                        defautMsgOrValues = null;
                    }
                    var result = webApplication$1.i18n.t(key, values);
                    if (result === key && defautMsgOrValues) {
                        return defautMsgOrValues;
                    }
                    return result;
                };
            }
        });
    }
};
var formItemChangedMixin = formItemChanged;
var uploadPolicy = uploadPolicy$1;
var emitterMixin = Emitter;
var modalMixin = ModalMixin;
var routerModules = outerRouter;

export { __vue_component__$d as BackToIndex, __vue_component__$q as FActorSelect, __vue_component__$m as FAdvancedSettingsPanel, __vue_component__$f as FAlertRule, __vue_component__$a as FAlertRuleInfo, __vue_component__$3 as FAppOverview, __vue_component__ as FAuthorizeScopeTree, __vue_component__$e as FButton, __vue_component__$p as FClientSelect, __vue_component__$8 as FDefaultIcon, __vue_component__$b as FDoubleColumnsView, __vue_component__$1k as FImage, __vue_component__$1h as FInfiniteScrollList, __vue_component__$n as FInfoTip, __vue_component__$1i as FLoadingTip, __vue_component__$t as FMemberOrgSelect, __vue_component__$w as FMemberSelect, __vue_component__$l as FMonitorMetric, __vue_component__$A as FMultiFileUpload, __vue_component__$C as FMultiImageUpload, __vue_component__$I as FOption, __vue_component__$H as FOptionGroup, __vue_component__$z as FOrgSelect, __vue_component__$L as FPassword, __vue_component__$D as FRefEntity, __vue_component__$1b as FRemote, __vue_component__$c as FResult, __vue_component__$G as FSelect, __vue_component__$B as FSingleFileUpload, __vue_component__$1c as FSingleImageUpload, __vue_component__$o as FTogglePanel, __vue_component__$9 as FUserToolTip, MicroAppHelper, actionRender, aicClientService, aicService, appService$2 as appService, index$1 as components, dateRender, index as default, emitterMixin, formItemChangedMixin, i18nService, iamUserService, linkRender, memberService, modalHeight, modalMixin, modalWidth, projectService, routerModules, securityManager, singleSelectRadioRender, tagRender, uploadPolicy };
